/*
 *  Copyright 2023 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */


const outgoingReferencesExtractor = Ametys.serviceManager.lookup(org.ametys.cms.content.references.OutgoingReferencesExtractor.ROLE);
const StringUtils = Java.type('org.apache.commons.lang.StringUtils');
  
let handled = 0;
let error = 0;
  
const nodes = Repository.query("//element(local, ametys:reference)", false);
let total = nodes.getSize();
let contentIds = [];

logger.info(`${total} local references will be inspected`);

while (nodes.hasNext())
{
    const node = nodes.next();
    
    try
    {
        const contentNode = node.getParent().getParent().getParent();
        const contentId = StringUtils.substringAfter(contentNode.getPrimaryNodeType().getName(), "ametys:") + "://" + contentNode.getIdentifier();
        if (contentIds.indexOf(contentId) == -1)
        {
            contentIds.push(contentId);
        }
        handled++;
        if (handled % 500 == 0)
        {
            logger.info(`${handled}/${total} local reference nodes inspected`);
        }
    }
    catch(e)
    {
        logger.error(`Failed to get content for local references at path ${node.getPath()}`, e);
    }
}
  
total = contentIds.length;
handled = 0;
logger.info(`Found ${total} contents with local references`);

for (let contentId of contentIds)
{
    try
    {
        let content = Repository.resolver.resolveById(contentId);
        updateOutgoingReferences(content);
        handled++;
        if (handled % 500 == 0)
        {
            logger.info(`${handled}/${total} contents handled.`);
        }
    }
    catch(e)
    {
        error++;
        logger.error(`Failed to update outgoing references for content of id ${contentId}`, e);
    }
}
  
logger.info(`${handled}/${total} content(s) with local references have been updated`);
if (error > 0)
{
    logger.warn(`${error}/${total} content(s) with error`);
}
  
function updateOutgoingReferences(content)
{
    let currentVersionIsLive = Java.from(content.getLabels()).indexOf('Live') >= 0;
    // Outgoing references
    let outgoingReferencesByPath = outgoingReferencesExtractor.getOutgoingReferences(content);
    content.setOutgoingReferences(outgoingReferencesByPath);
    // Save changes
    content.saveChanges();
    // Checkpoint
    content.checkpoint();
    // Move Live if necessary
    if (currentVersionIsLive)
    {
        content.addLabel('Live', true);
    }
}
