<?xml version="1.0" encoding="UTF-8"?>
<!--
   Copyright 2010 Anyware Services

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
   -->
<xsl:stylesheet version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	xmlns:docbook="http://docbook.org/ns/docbook" 
    xmlns:i18n="http://apache.org/cocoon/i18n/2.1"
    xmlns:math="http://exslt.org/math" 
    xmlns:ametys="org.ametys.cms.transformation.xslt.AmetysXSLTHelper"
    xmlns:captcha="org.ametys.core.captcha.CaptchaHelper"
    exclude-result-prefixes="math docbook ametys captcha">

	<xsl:import href="plugin:cms://stylesheets/helper/common.xsl"/>
	    
    <xsl:param name="lang"/>
    <xsl:variable name="captchaType" select="ametys:config('runtime.captcha.type')"/>

	<xsl:template name="comments-head">
	</xsl:template>
	
	<xsl:template name="comments">
        <xsl:param name="contextPath"/>
        <xsl:variable name="commentable" select="@commentable = 'true' and metadata/comment = 'true'"/>
		<xsl:choose>
			<xsl:when test="comments/comment or $commentable">
				<div class="comments-wrapper">
                    <a name="comments"/>
					<xsl:choose>
						<xsl:when test="comments/comment">
							<div class="comments">
								<xsl:for-each select="comments/comment">
									<xsl:sort order="ascending" select="@creation-date"/>
									<xsl:sort order="ascending" select="substring-after(@id, 'comment-')" data-type="number"/>
								
									<xsl:call-template name="comment"/>
								</xsl:for-each>
							</div>
						</xsl:when>
						<xsl:otherwise>
							<xsl:call-template name="nocomment"/>
						</xsl:otherwise>
					</xsl:choose>
                    
					<xsl:if test="$commentable">
						<xsl:call-template name="comment-form">
                            <xsl:with-param name="contextPath"><xsl:value-of select="$contextPath"/></xsl:with-param>
                        </xsl:call-template>
					</xsl:if>
				</div>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="nothingoncomments"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="nocomment"/>
	<xsl:template name="nothingoncomments"/>
	
	<xsl:template name="comment">
		
		<xsl:if test="position() = last()">
			<a name="last-comment"></a>
		</xsl:if>
		<div class="comment">
            <a name="{@id}"/>
			<xsl:if test="position() = last()">
				<xsl:variable name="number" select="substring-after(math:random(), '.')"/>
				<xsl:attribute name="id">M<xsl:value-of select="$number"/></xsl:attribute>
			
				<script type="text/javascript">
					if (/(\?|&amp;)last-comment=highlight(#|&amp;)/.test(window.location.href))
					{
						$j('#M<xsl:value-of select="$number"/>').addClass('last-comment');
					}
				</script>
			</xsl:if>
			
			<div class="comment-header">
				<p>
					
					<span class="comment-author">
						<span class="comment-author-prefix">
							<i18n:text i18n:key="PLUGINS_CMS_CONTENT_COMMENTS_SHOW_AUTHOR" i18n:catalogue="plugin.cms" />
							<xsl:text> </xsl:text>
						</span>
						<span class="comment-author-name">
							<xsl:value-of select="@author-name" />
						</span>
					</span>
					<xsl:text> </xsl:text>
					<span class="comment-creation">
						<i18n:text i18n:key="PLUGINS_CMS_CONTENT_COMMENTS_SHOW_DATE" i18n:catalogue="plugin.cms" />
						<xsl:text> </xsl:text>
						<span class="comment-creation-date">
							<i18n:date src-pattern="yyyy-MM-dd'T'HH:mm:ss.SSSXXX" pattern="long" value="{@creation-date}"/>
						</span>
						<xsl:text> </xsl:text>
						<span class="comment-creation-time">
							<i18n:text i18n:key="PLUGINS_CMS_CONTENT_COMMENTS_SHOW_TIME" i18n:catalogue="plugin.cms"/>
						</span>
						<xsl:text> </xsl:text>
						<i18n:time src-pattern="yyyy-MM-dd'T'HH:mm:ss.SSSXXX" pattern="short" value="{@creation-date}"/>
					</span>
				</p>
			</div>
			<div class="comment-content">
				<xsl:copy-of select="p"/>
			</div>
			<div class="comment-footer">
				<xsl:if test="@author-email">
					<xsl:call-template name="mail-antispam">
						<xsl:with-param name="mail" select="@author-email"/>
						<xsl:with-param name="class" select="'comment-sendmail'"/>
						<xsl:with-param name="text"><i18n:text i18n:key="PLUGINS_CMS_CONTENT_COMMENTS_SHOW_WRITE" i18n:catalogue="plugin.cms"/><xsl:text> </xsl:text><xsl:value-of select="@author-name"/></xsl:with-param>
					</xsl:call-template>
				</xsl:if>
				<xsl:if test="@author-url">
					<p class="comment-url"><a class="comment-url" onclick="window.open(this.href); return false;" href="{@author-url}"><i18n:text i18n:key="PLUGINS_CMS_CONTENT_COMMENTS_SHOW_VISIT" i18n:catalogue="plugin.cms"/><xsl:text> </xsl:text><xsl:value-of select="@author-name"/></a></p>
				</xsl:if>
			</div>
			<div class="comment-bottom"></div>
		</div>	
	</xsl:template>
	
	<xsl:template name="comment-form">
        <xsl:param name="contextPath"/>
		<xsl:variable name="number" select="substring-after(math:random(), '.')"/>
	
		<div class="comments-form">
			<noscript><p><i18n:text i18n:key="PLUGINS_CMS_CONTENT_COMMENTS_POST_DESC" i18n:catalogue="plugin.cms"/></p></noscript>
			<script type="text/javascript">
				document.write("&lt;p&gt;&lt;a href='javascript: comment_form_switch_<xsl:value-of select="$number"/>()'&gt;<i18n:text i18n:key="PLUGINS_CMS_CONTENT_COMMENTS_POST_DESC" i18n:catalogue="plugin.cms"/>&lt;/a&gt;&lt;/p&gt;")
			</script>
			
			<form name="comment" id="comment-{$number}" action="{$prefix}/{$lang}/_plugins/cms/page/comments/add-comment" method="post">
				<input type="hidden" name="content-id" id="comment-{$number}-id" value="{@id}"/>
				<div class="comment-form-name">
					<label for="comment-{$number}-name"><i18n:text i18n:key="PLUGINS_CMS_CONTENT_COMMENTS_POST_AUTHOR_NAME" i18n:catalogue="plugin.cms"/></label> 
					<input type="text" name="name" id="comment-{$number}-name" aria-required="true"/>
					<span class="mandatory">*</span>
				</div>
				<div class="comment-form-email">
					<label for="comment-{$number}-email"><i18n:text i18n:key="PLUGINS_CMS_CONTENT_COMMENTS_POST_AUTHOR_EMAIL" i18n:catalogue="plugin.cms"/></label> 
					<input type="text" name="email" id="comment-{$number}-email"/>
				</div>
				<div class="comment-form-hide-email">
					<label for="comment-{$number}-hide-email"><i18n:text i18n:key="PLUGINS_CMS_CONTENT_COMMENTS_POST_AUTHOR_HIDE_EMAIL" i18n:catalogue="plugin.cms"/></label> 
					<input type="checkbox" name="hide-email" id="comment-{$number}-hide-email"/>
				</div>
				<div class="comment-form-url">
					<label for="comment-{$number}-url"><i18n:text i18n:key="PLUGINS_CMS_CONTENT_COMMENTS_POST_AUTHOR_URL" i18n:catalogue="plugin.cms"/></label> 
					<input type="text" name="url" id="comment-{$number}-url"/>
				</div>
				<div class="comment-form-content">
					<label for="comment-{$number}-text"><i18n:text i18n:key="PLUGINS_CMS_CONTENT_COMMENTS_POST_AUTHOR_CONTENT" i18n:catalogue="plugin.cms"/></label> 
					<textarea name="text" id="comment-{$number}-text" cols="20" rows="3" aria-required="true"></textarea>
					<span class="mandatory">*</span>
				</div>
				<div class="comment-form-captcha">
                    <xsl:if test="captcha:requiresUserInteraction()">
					<label for="comment-{$number}-captcha"><i18n:text i18n:key="PLUGINS_CMS_CONTENT_COMMENTS_POST_AUTHOR_CAPTCHA" i18n:catalogue="plugin.cms"/></label>
					</xsl:if>
					
					<xsl:call-template name="captcha">
						<xsl:with-param name="key-name">captcha-key</xsl:with-param>
						<xsl:with-param name="key-id">comment-<xsl:value-of select="$number"/>-captcha-key</xsl:with-param>

						<xsl:with-param name="value-name">captcha-value</xsl:with-param>
						<xsl:with-param name="value-id">comment-<xsl:value-of select="$number"/>-captcha</xsl:with-param>
						<xsl:with-param name="value-style"></xsl:with-param>
						<xsl:with-param name="value-class"/>

						<xsl:with-param name="image-alt">PLUGINS_CMS_CONTENT_COMMENTS_POST_AUTHOR_CAPTCHA</xsl:with-param>
						<xsl:with-param name="image-alt-i18n" select="true()"/>
						<xsl:with-param name="image-alt-catalogue">plugin.cms</xsl:with-param>
						<xsl:with-param name="image-style"></xsl:with-param>
						<xsl:with-param name="image-class"/>
						
						<xsl:with-param name="js-funcname-torefresh">refresh_comment_<xsl:value-of select="$number"/></xsl:with-param>
                        
                        <xsl:with-param name="contextPath"><xsl:value-of select="$contextPath"/></xsl:with-param>
					</xsl:call-template> 
					
					<span class="mandatory">*</span>
				</div>
				<div class="comment-form-submit">
					<input onclick="return comment_form_submit_{$number}();" type="submit" value="plugin.cms:PLUGINS_CMS_CONTENT_COMMENTS_POST_AUTHOR_SUBMIT" i18n:attr="value"/>
				</div>
				<div class="comment-form-bottom"></div>
			</form>
			<script type="text/javascript">
				function comment_form_switch_<xsl:value-of select="$number"/>()
				{
					var form = document.getElementById('comment-<xsl:value-of select="$number"/>');
					form.style.display = (form.style.display == 'none') ? '' : 'none';
				}
				comment_form_switch_<xsl:value-of select="$number"/>();
				
				function comment_form_submit_<xsl:value-of select="$number"/>()
				{
					var form = document.getElementById('comment-<xsl:value-of select="$number"/>');
					
					var idInput = document.getElementById('comment-<xsl:value-of select="$number"/>-id');
					var nameInput = document.getElementById('comment-<xsl:value-of select="$number"/>-name');
					var emailInput = document.getElementById('comment-<xsl:value-of select="$number"/>-email');
					var emailHideInput = document.getElementById('comment-<xsl:value-of select="$number"/>-hide-email');
					var urlInput = document.getElementById('comment-<xsl:value-of select="$number"/>-url');
					var contentInput = document.getElementById('comment-<xsl:value-of select="$number"/>-text');
					var captchaKey = document.getElementById('comment-<xsl:value-of select="$number"/>-captcha-key');
					var captchaInput = document.getElementById('comment-<xsl:value-of select="$number"/>-captcha');
					
					var errors = false;
					
					if (/^\s*$/.test(nameInput.value))
					{
						errors = true;
						nameInput.parentNode.className = "comment-form-name error";
					}
					else
					{
						nameInput.parentNode.className = "comment-form-name";
					}
					
					if (!/^.*@.*$/.test(emailInput.value))
					{
						errors = true;
						emailInput.parentNode.className = "comment-form-email error";
					}
					else
					{
						emailInput.parentNode.className = "comment-form-email";
					}
					
					if (!/^(https?:\/\/.+)?$/.test(urlInput.value))
					{
						errors = true;
						urlInput.parentNode.className = "comment-form-url error";
					}
					else
					{
						urlInput.parentNode.className = "comment-form-url";
					}

					if (/^\s*$/.test(contentInput.value))
					{
						errors = true;
						contentInput.parentNode.className = "comment-form-content error";
					}
					else
					{
						contentInput.parentNode.className = "comment-form-content";
					}

                    <xsl:if test="$captchaType = 'jcaptcha'">
                        if (!/^[a-z]{6}$/.test(captchaInput.value))
                        {
                            errors = true;
                            captchaInput.parentNode.className = "comment-form-captcha error";
                        }
                        else
                        {
                            captchaInput.parentNode.className = "comment-form-captcha";
                        }
                    </xsl:if>
					
					if (!errors)
					{
						// send it in ajax
						var data = {
							"content-id": idInput.value,
							"name": nameInput.value,
							"email": emailInput.value,
							"url": urlInput.value,
							"text": contentInput.value,
							"captcha-key": captchaKey.value,
							"captcha-value": captchaInput.value,
							"ajax": "true"
						};
						if (emailHideInput.checked)
						{
							data["hide-email"] = "on"; 
						}						
						
						function result(data)
						{
							var s = "";
							$j('errors errors', data).each(function () { s += $j(this).text() + "\n"; });
							
							if (s == "")
							{
								if ($j('published', data).text() == "true")
								{
									/([^?#]*)([\?#].*)*/.test(document.location.href);
									document.location.href = RegExp.$1 + "?last-comment=highlight&amp;foo=" + Math.random() + "#last-comment"; 
								}
								else
								{
									alert("<i18n:text i18n:key="PLUGINS_CMS_CONTENT_COMMENTS_ADD_SENT_TITLE" i18n:catalogue="plugin.cms"/>\n<i18n:text i18n:key="PLUGINS_CMS_CONTENT_COMMENTS_ADD_SENT_DESCRIPTION" i18n:catalogue="plugin.cms"/>\n<i18n:text i18n:key="PLUGINS_CMS_CONTENT_COMMENTS_ADD_SENT_DESCRIPTION2" i18n:catalogue="plugin.cms"/>\n<i18n:text i18n:key="PLUGINS_CMS_CONTENT_COMMENTS_ADD_SENT_DESCRIPTION3" i18n:catalogue="plugin.cms"/>")
									comment_form_switch_<xsl:value-of select="$number"/>();
									
									refresh_comment_<xsl:value-of select="$number"/>();
								}
							}
							else
							{
								alert(s);

								refresh_comment_<xsl:value-of select="$number"/>();
							}
						}
						
						function handleError(jqXHR, textStatus, errorThrown)
                        {
                            alert("<i18n:text i18n:key="PLUGINS_CMS_CONTENT_COMMENTS_ADD_ERROR_SUBMIT" i18n:catalogue="plugin.cms" />");
                        }

                        $j.ajax({
                            url: "<xsl:value-of select="$uri-prefix"/>/plugins/cms/comments/add-comment",
                            data: data,
                            type: 'post',
                            success: result,
                            error: handleError
                        });

					}

					return false;
				}
			</script>
		</div>
	</xsl:template>
	
</xsl:stylesheet>
