<?xml version="1.0" encoding="UTF-8"?>
<!--
   Copyright 2010 Anyware Services

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
   -->
<xsl:stylesheet version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	xmlns:docbook="http://docbook.org/ns/docbook" 
    xmlns:i18n="http://apache.org/cocoon/i18n/2.1"
    xmlns:math="http://exslt.org/math" 
    xmlns:ametys="org.ametys.cms.transformation.xslt.AmetysXSLTHelper"
    xmlns:captcha="org.ametys.core.captcha.CaptchaHelper"
    exclude-result-prefixes="docbook"
    extension-element-prefixes="math ametys captcha">

	<xsl:import href="plugin:cms://stylesheets/helper/common.xsl"/>
	<xsl:import href="like/comments_like.xsl"/>
    <xsl:import href="reporters/comments_reporters.xsl"/>
    <xsl:import href="delete/comments_delete.xsl"/>
        
	<xsl:variable name="commentUniqueId" select="concat('comments_', substring-after(math:random(), '.'))"/>
    <xsl:variable name="captchaType" select="ametys:config('runtime.captcha.type')"/>

    <xsl:template name="get-comment-add-url">
        <xsl:value-of select="ametys:uriPrefix()"/>
        <xsl:text>/plugins/cms/comments/add-comment</xsl:text>
    </xsl:template>
    
    <xsl:template name="get-comment-add-url-ajax">
        <xsl:value-of select="ametys:uriPrefix()"/>
        <xsl:text>/plugins/cms/comments/add-comment</xsl:text>
    </xsl:template>
    
	<!-- +
	     | Entry point to display existing comments and new comments form
	     + -->
	<xsl:template name="comments">
        <xsl:variable name="commentable" select="@commentable = 'true' and metadata/comment = 'true'"/>
        <xsl:variable name="content-id" select="@id" />
        
		<xsl:choose>
			<xsl:when test="comments/comment or $commentable">
				<div class="comments-wrapper" id="{$commentUniqueId}">
					<xsl:call-template name="comments-rss"/>
				
				    <!-- Script for comment -->
					<xsl:call-template name="comment-form-script"/>
                    <!-- Dialog box to confirm the post was sent (with a moderation) -->
                    <xsl:call-template name="comment-post-dialog-box" />
					
					<xsl:choose>
						<xsl:when test="comments/comment">
							<xsl:call-template name="comments-count"/>
		
		
		                    <!-- Dialog boxes to report comment -->
		                    <xsl:call-template name="comment-report-dialog-box" />
		                    <xsl:call-template name="comment-report-confirm-box" />
		    			    <xsl:call-template name="comment-report-form-script" />
		
		                    <!-- Dialog boxes to delete comment -->
		                    <xsl:call-template name="comment-delete-button-right-script">
		                        <xsl:with-param name="content-id" select="$content-id" />
		                        <xsl:with-param name="comment-unique-id" select="$commentUniqueId" />
		                    </xsl:call-template>
		                    <xsl:call-template name="comment-delete-confirm-box" />
		                    <xsl:call-template name="comment-delete-form-script" />
		
		                    <!-- Script for like comment -->
		                    <xsl:call-template name="comment-like-form-script" />

							<ul>
								<xsl:for-each select="comments/comment">
									<xsl:sort order="ascending" select="@creation-date"/>
									<xsl:sort order="ascending" select="substring-after(@id, 'comment-')" data-type="number"/>
								
									<xsl:call-template name="comment">
						              <xsl:with-param name="content-id" select="$content-id" />
									</xsl:call-template>
								</xsl:for-each>
							</ul>

                        </xsl:when>
						<xsl:otherwise>
							<xsl:call-template name="comments-empty"/>
						</xsl:otherwise>
					</xsl:choose>
		
					<xsl:if test="$commentable">
						<xsl:call-template name="comment-add" >
						  <xsl:with-param name="content-id" select="$content-id" />
						</xsl:call-template>
					</xsl:if>
				</div>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="comments-empty-and-inactive"/>
			</xsl:otherwise>
		</xsl:choose>
        
	</xsl:template>

    <xsl:template name="comment-post-dialog-box">
        <div style="display:none" id="dialog-{$commentUniqueId}" title="plugin.cms:PLUGINS_CMS_CONTENT_COMMENTS_ADD_SENT_TITLE" i18n:attr="title">
          <p>
            <i18n:text i18n:key="PLUGINS_CMS_CONTENT_COMMENTS_ADD_SENT_DESCRIPTION" i18n:catalogue="plugin.cms"/>
          </p>
        </div>
    </xsl:template>
    

	<!-- +
	     | Comments header part
	     + -->
	<xsl:template name="comments-count">
		<p class="comments-count">
			<a name="comments"/>
			<xsl:value-of select="count(comments/comment)"/>
			<xsl:text> </xsl:text>
            <xsl:choose>
                <xsl:when test="count(comments/comment) = 1">
                    <i18n:text i18n:key="PLUGINS_CMS_CONTENT_COMMENTS_COUNT_ONE" i18n:catalogue="plugin.cms" />
                </xsl:when>
                <xsl:otherwise>
                    <i18n:text i18n:key="PLUGINS_CMS_CONTENT_COMMENTS_COUNT" i18n:catalogue="plugin.cms" />
                </xsl:otherwise>
            </xsl:choose>
		</p>
	</xsl:template>
	
	<!-- +
	     | When there is no comments (but the comments feature is active)
	     + -->
	<xsl:template name="comments-empty"/>
	
	<!-- +
	     | When there is no comments (but the comments feature is inactive)
	     + -->
	<xsl:template name="comments-empty-and-inactive"/>
	
	<!-- +
	     | Displaying one existing comment
	     + -->
	<xsl:template name="comment">
	    <xsl:param name="content-id" />
        <xsl:param name="level">0</xsl:param>
        
		<li id="{@id}">
			<xsl:attribute name="class"><xsl:call-template name="comment-class"/></xsl:attribute>
			
			<xsl:call-template name="comment-header">
			     <xsl:with-param name="content-id" select="$content-id" />
			</xsl:call-template>

			<xsl:call-template name="comment-content"/>

			<xsl:call-template name="comment-footer">
			     <xsl:with-param name="content-id" select="$content-id" />
                 <xsl:with-param name="level" select="$level" />
            </xsl:call-template>
			
			<xsl:call-template name="comment-sub-comments">
			     <xsl:with-param name="content-id" select="$content-id" />
                 <xsl:with-param name="level" select="$level + 1" />
            </xsl:call-template>
			
			<!-- Add answer button only if it's the parent comment -->
            <xsl:if test="$level = 0">
				<xsl:call-template name="comment-answer-form">
			      <xsl:with-param name="content-id" select="$content-id" />
				</xsl:call-template>
            </xsl:if>
			<div class="comment-bottom"></div>
		</li>	
	</xsl:template>
	
	<!-- +
         | Displaying existing sub-comments
         + -->
    <xsl:template name="comment-sub-comments">
        <xsl:param name="content-id" />
        <xsl:param name="level"/>
        
        <xsl:if test="count(sub-comments/comment) > 0">
	        <ul class="sub-comments">
	            <xsl:for-each select="sub-comments/comment">
	                <xsl:sort order="ascending" select="@creation-date"/>
	                <xsl:sort order="ascending" select="substring-after(@id, 'comment-')" data-type="number"/>
	            
	                <xsl:call-template name="comment">
	                  <xsl:with-param name="content-id" select="$content-id" />
                      <xsl:with-param name="level" select="$level" />
	                </xsl:call-template>
	            </xsl:for-each>
	        </ul>
        </xsl:if>
    </xsl:template>
	
	<!-- +
	     | Returns a class attribute
	     + -->
	<xsl:template name="comment-class">
	</xsl:template>

	<!-- +
	     | The top part of a comment
	     + -->
	<xsl:template name="comment-header">
	    <xsl:param name="content-id" />
        
		<p class="comment-header">
			<a name="{@id}-{$content-id}"/>
				
			<script type="text/javascript">
				if (/(\?|&amp;)last-comment=highlight(#|&amp;)/.test(window.location.href))
				{
				   var commentId = window.location.hash.substr(1);
				   $("[name='" + commentId + "']").parent().parent().addClass('last-comment');
				}
			</script>

			<span class="comment-author">
				<span class="comment-author-prefix">
					<i18n:text i18n:key="PLUGINS_CMS_CONTENT_COMMENTS_SHOW_AUTHOR" i18n:catalogue="plugin.cms" />
					<xsl:text> </xsl:text>
				</span>
				
				<span class="comment-author-name">
					<xsl:value-of select="@author-name" />
				</span>
			</span>
			
			<xsl:text> </xsl:text>
			
			<span class="comment-creation">
				<i18n:text i18n:key="PLUGINS_CMS_CONTENT_COMMENTS_SHOW_DATE" i18n:catalogue="plugin.cms" />
				<xsl:text> </xsl:text>
				<span class="comment-creation-date">
					<i18n:date src-pattern="yyyy-MM-dd'T'HH:mm:ss.SSSXXX" pattern="long" value="{@creation-date}"/>
				</span>
				<xsl:text> </xsl:text>
				<span class="comment-creation-time">
					<i18n:text i18n:key="PLUGINS_CMS_CONTENT_COMMENTS_SHOW_TIME" i18n:catalogue="plugin.cms"/>
				</span>
				<xsl:text> </xsl:text>
				<i18n:time src-pattern="yyyy-MM-dd'T'HH:mm:ss.SSSXXX" pattern="short" value="{@creation-date}"/>
			</span>
		</p>
	</xsl:template>
	
	<!-- +
	     | The main part of a comment
	     + -->
	<xsl:template name="comment-content">
		<div class="comment-content">
			<xsl:copy-of select="p"/>
		</div>
	</xsl:template>
	
	<!-- +
	     | The bottom part of a comment
	     + -->
	<xsl:template name="comment-footer">
	    <xsl:param name="content-id" />
        <xsl:param name="level" />
        
		<div class="comment-footer" >
			<xsl:call-template name="comment-author-info" />
			
            <xsl:call-template name="comment-report">
                <xsl:with-param name="content-id" select="$content-id" />
            </xsl:call-template>
            
            <xsl:call-template name="comment-delete">
                <xsl:with-param name="content-id" select="$content-id" />
            </xsl:call-template>

            <xsl:call-template name="comment-like">
                <xsl:with-param name="content-id" select="$content-id" />
            </xsl:call-template>
            
            <xsl:if test="$level = 0">
                <xsl:call-template name="comment-answer-form-button" />
            </xsl:if>
		</div>
	</xsl:template>
	
	<xsl:template name="comment-author-info">
	   <xsl:if test="@author-email or @author-url">
	       <div class="author-info">
	           <xsl:if test="@author-email">
	               <xsl:call-template name="mail-antispam">
	                   <xsl:with-param name="mail" select="@author-email"/>
	                   <xsl:with-param name="class" select="'comment-sendmail'"/>
	                   <xsl:with-param name="text"><i18n:text i18n:key="PLUGINS_CMS_CONTENT_COMMENTS_SHOW_WRITE" i18n:catalogue="plugin.cms"/><xsl:text> </xsl:text><xsl:value-of select="@author-name"/></xsl:with-param>
	               </xsl:call-template>
	           </xsl:if>
	           
	           <xsl:if test="@author-url">
	               <span class="comment-url">
	                   <a onclick="window.open(this.href); return false;" href="{@author-url}">
	                       <i18n:text i18n:key="PLUGINS_CMS_CONTENT_COMMENTS_SHOW_VISIT" i18n:catalogue="plugin.cms"/>
	                       <xsl:text> </xsl:text>
	                       <xsl:value-of select="@author-name"/>
	                   </a>
	               </span>
	           </xsl:if>
           </div>
       </xsl:if>
	</xsl:template>
	
	<!-- +
	     | The form to add a new comment 
	     + -->
	<xsl:template name="comment-add">
        <xsl:param name="content-id" />
	
        <div class="comment-form">
			<xsl:call-template name="comment-add-form" >
			  <xsl:with-param name="content-id" select="$content-id" />
            </xsl:call-template>
		</div>
	</xsl:template>
    
    <xsl:template name="comment-add-form">
        <xsl:param name="content-id" />
    
        <xsl:call-template name="comment-add-form-button" />
    
        <xsl:call-template name="comment-form" >
          <xsl:with-param name="accessibility-title">plugin.cms:PLUGINS_CMS_CONTENT_COMMENTS_POST_DESC</xsl:with-param>
          <xsl:with-param name="comment-id">comment</xsl:with-param>
          <xsl:with-param name="content-id" select="$content-id" />
        </xsl:call-template>
    </xsl:template>
    
    <xsl:template name="comment-add-form-button">
        <script type="text/javascript">
            document.write("&lt;p&gt;&lt;a href='javascript: comment_form_switch_<xsl:value-of select="$commentUniqueId"/>(\"comment\")'&gt;<i18n:text i18n:key="PLUGINS_CMS_CONTENT_COMMENTS_POST_DESC" i18n:catalogue="plugin.cms"/>&lt;/a&gt;&lt;/p&gt;")
        </script>
    </xsl:template>
    
    <xsl:template name="comment-answer-form">
        <xsl:param name="content-id" />
    
        <xsl:call-template name="comment-form" >
          <xsl:with-param name="accessibility-title">plugin.cms:PLUGINS_CMS_CONTENT_COMMENTS_ANSWER_TITLE</xsl:with-param>
          <xsl:with-param name="comment-id" select="@id"/>
          <xsl:with-param name="content-id" select="$content-id" />
        </xsl:call-template>
    </xsl:template>
    
    <xsl:template name="comment-answer-form-button">
        <!-- Add answer button only if it's the parent comment -->
        <xsl:if test="not(@level) or @level = 0">
	        <p class="answer-comment">
	          <span>
	             <script type="text/javascript">
	                 document.write("&lt;a href='javascript: comment_form_switch_<xsl:value-of select="$commentUniqueId"/>(\"<xsl:value-of select="@id" />\")'&gt;<i18n:text i18n:key="PLUGINS_CMS_CONTENT_COMMENTS_ANSWER_TITLE" i18n:catalogue="plugin.cms"/>&lt;/a&gt;")
	             </script>
	          </span>
	        </p>
        </xsl:if>
    </xsl:template>
    
    <xsl:template name="comment-form">
        <xsl:param name="accessibility-title" />
        <xsl:param name="comment-id" />
        <xsl:param name="content-id" />
    
        <xsl:variable name="comment-add-url">
            <xsl:call-template name="get-comment-add-url"/>
        </xsl:variable>
        
        <xsl:if test="not(@level) or @level = 0">
            <xsl:call-template name="form-accessibility-title">
                <xsl:with-param name="accessibility-title" select="$accessibility-title"/>
            </xsl:call-template>
        </xsl:if>
        
        <form id="{$comment-id}-{$commentUniqueId}" action="{$comment-add-url}" method="post">
            <div>
                <input type="hidden" name="content-id" id="{$comment-id}-{$commentUniqueId}-id" value="{$content-id}"/>
                <xsl:if test="$comment-id != 'comment'">
                    <input type="hidden" name="comment-id" id="{$comment-id}-{$commentUniqueId}-comment-id" value="{$comment-id}"/>
                </xsl:if>
                
                <xsl:call-template name="comment-form-showhint" />               
                <xsl:call-template name="comment-form-field-name">
                    <xsl:with-param name="comment-id" select="$comment-id" />
                </xsl:call-template>
                <xsl:call-template name="comment-form-field-mail">
                    <xsl:with-param name="comment-id" select="$comment-id" />
                </xsl:call-template>
                <xsl:call-template name="comment-form-field-hidemail">
                    <xsl:with-param name="comment-id" select="$comment-id" />
                </xsl:call-template>
                <xsl:call-template name="comment-form-field-url">
                    <xsl:with-param name="comment-id" select="$comment-id" />
                </xsl:call-template>
                <xsl:call-template name="comment-form-field-content">
                    <xsl:with-param name="comment-id" select="$comment-id" />
                </xsl:call-template>
                <xsl:call-template name="comment-form-field-captcha">
                    <xsl:with-param name="comment-id" select="$comment-id" />
                </xsl:call-template>
                <xsl:call-template name="comment-form-field-additional">
                    <xsl:with-param name="comment-id" select="$comment-id" />
                </xsl:call-template>
                <xsl:call-template name="comment-form-field-submit">
                    <xsl:with-param name="comment-id" select="$comment-id" />
                </xsl:call-template>
                     
                <div class="comment-form-bottom"></div>
            </div>
        </form>
        
        <script type="text/javascript">
            comment_form_switch_<xsl:value-of select="$commentUniqueId"/>('<xsl:value-of select="$comment-id" />');
        </script>
    </xsl:template>
    
    <xsl:template name="comment-form-field-additional">
        <xsl:param name="comment-id" />
    </xsl:template>
    
    <xsl:template name="comment-captcha-required">true</xsl:template>
	
	<xsl:template name="comment-form-script">
			<script type="text/javascript">
	            function comment_form_switch_<xsl:value-of select="$commentUniqueId"/>(commentId)
	            {
	                <xsl:call-template name="comment-form-switch-form-javascript" />
	            }
			
				function comment_form_submit_<xsl:value-of select="$commentUniqueId"/>(id)
				{
					var form = document.getElementById(id + '-<xsl:value-of select="$commentUniqueId"/>');
					
					var idInput =  $j('#' + id + '-<xsl:value-of select="$commentUniqueId"/>-id');
					var idComment = $j('#' + id + '-<xsl:value-of select="$commentUniqueId"/>-comment-id');
					var nameInput = $j('#' + id + '-<xsl:value-of select="$commentUniqueId"/>-name');
					var emailInput = $j('#' + id + '-<xsl:value-of select="$commentUniqueId"/>-email');
					var emailHideInput = $j('#' + id + '-<xsl:value-of select="$commentUniqueId"/>-hide-email');
					var urlInput = $j('#' + id + '-<xsl:value-of select="$commentUniqueId"/>-url');
					var contentInput = $j('#' + id + '-<xsl:value-of select="$commentUniqueId"/>-text');
					
					var errors = false;
					if (/^\s*$/.test(nameInput.val()))
					{
						errors = true;
						nameInput.parentsUntil('.field').parent().addClass('error');
                        nameInput.attr("aria-invalid", true);
					}
					else
					{
						nameInput.parentsUntil('.field').parent().removeClass('error');
                        nameInput.removeAttr("aria-invalid");
					}
					
					if (!/^.+@.+$/.test(emailInput.val()))
					{
						errors = true;
						emailInput.parentsUntil('.field').parent().addClass('error');
                        emailInput.attr("aria-invalid", true);
					}
					else
					{
						emailInput.parentsUntil('.field').parent().removeClass('error');
                        emailInput.removeAttr("aria-invalid");
					}
					
					if (!/^(https?:\/\/.+)?$/.test(urlInput.val()))
					{
						errors = true;
						urlInput.parentsUntil('.field').parent().addClass('error');
                        urlInput.attr("aria-invalid", true);
					}
					else
					{
						urlInput.parentsUntil('.field').parent().removeClass('error');
                        urlInput.removeAttr("aria-invalid");
					}

					if (/^\s*$/.test(contentInput.val()))
					{
						errors = true;
						contentInput.parentsUntil('.field').parent().addClass('error');
                        contentInput.attr("aria-invalid", true);
					}
					else
					{
						contentInput.parentsUntil('.field').parent().removeClass('error');
                        contentInput.removeAttr("aria-invalid");
					}
                    
                    <xsl:if test="$captchaType = 'jcaptcha'">
                        var captchaRequired = "<xsl:call-template name="comment-captcha-required"/>" == "true";
                        if (captchaRequired)
                        {
                            var captchaKey = $j('#' + id + '-<xsl:value-of select="$commentUniqueId"/>-captcha-key');
                            var captchaInput = $j('#' + id + '-<xsl:value-of select="$commentUniqueId"/>-captcha');
                            
                            if (captchaRequired &amp;&amp; !/^[a-z]{6}$/.test(captchaInput.val()))
                            {
                                errors = true;
                                captchaInput.parentsUntil('.field').parent().addClass('error');
                                captchaInput.attr("aria-invalid", true);
                            }
                            else
                            {
                                captchaInput.parentsUntil('.field').parent().removeClass('error');
                                captchaInput.removeAttr("aria-invalid");
                            }
                        }
                    </xsl:if>

					if (!errors)
					{
						// send it in ajax
						var data = {
							"content-id": idInput.val(),
							"comment-id": idComment.val(),
							"name": nameInput.val(),
							"email": emailInput.val(),
							"url": urlInput.val(),
							"text": contentInput.val(),
							"ajax": "true"
						};
						if ((emailHideInput[0].type == 'checkbox' &amp;&amp; emailHideInput[0].checked) || (emailHideInput[0].type != 'checkbox' &amp;&amp; emailHideInput.val() == 'true'))
						{
							data["hide-email"] = "on"; 
						}						
						
                        if (captchaRequired)
                        {
                            var captchaKey = $j('#' + id + '-<xsl:value-of select="$commentUniqueId"/>-captcha-key');
                            var captchaInput = $j('#' + id + '-<xsl:value-of select="$commentUniqueId"/>-captcha');
                            data['captcha-key'] = captchaKey.val();
                            data['captcha-value'] = captchaInput.val();
                        }
                        
                        <xsl:call-template name="comment-form-script-additional-data"/>
                        
						function result(data)
						{
							var s = "";
							$j('errors errors error', data).each(function () { s += $j(this).text() + "\n"; });
							
							if (s == "")
							{
								if ($j('published', data).text() == "true")
								{
								    var commentId = $j('commentId', data).text();
									var contentId = $j('contentId', data).text();
                                    /([^?#]*)([\?#].*)*/.test(document.location.href);
									document.location.href = RegExp.$1 + "?last-comment=highlight&amp;foo=" + Math.random() + "#" + commentId + "-" + contentId; 
								}
								else
								{
									comment_form_switch_<xsl:value-of select="$commentUniqueId"/>(id);
								    $j("#dialog-<xsl:value-of select="$commentUniqueId" />").dialog({
	                                      modal: true,
	                                      buttons: {
	                                          "<i18n:text i18n:key="PLUGINS_CMS_CONTENT_COMMENTS_POST_OK" i18n:catalogue="plugin.cms"/>": function() {
	                                               $j( this ).dialog( "close" );
	                                          }
	                                      }
	                                });
									
									if (captchaRequired)
								    {
    									eval("refresh_" + id.replace("-", "_") + "_<xsl:value-of select="$commentUniqueId"/>")();
	                                }							    
								}
							}
							else
							{
								 alert(s);
							     if (captchaRequired)
                                 {
                                    eval("refresh_" + id.replace("-", "_") + "_<xsl:value-of select="$commentUniqueId"/>")();
                                 }
                            }
						}
                        
                        function handleError(jqXHR, textStatus, errorThrown)
                        {
                    	   alert("<i18n:text i18n:key="PLUGINS_CMS_CONTENT_COMMENTS_FORM_ERROR_AJAX" i18n:catalogue="plugin.cms"/>");
                        }
                        
                        $j.ajax({
                            url: "<xsl:call-template name="get-comment-add-url-ajax" />",
                            data: data,
                            type: 'post',
                            success: result,
                            error: handleError
                        });
					}

					return false;
				}
			</script>
	</xsl:template>	
    
    <xsl:template name="comment-form-script-additional-data">
        function addAdditionalData (data)
        {
            // Nothing
        }
    </xsl:template>

    <xsl:template name="comment-form-switch-form-javascript">
        var form = document.getElementById(commentId + '-<xsl:value-of select="$commentUniqueId"/>');
        if (form.style.display == 'none')
        {
            form.style.display = '';
            $("#" + form.id + " textarea[name=text]").focus();
        }
        else
        {
            form.style.display = 'none';
        }
    </xsl:template>

	<xsl:template name="comment-form-showhint">
	</xsl:template>	

	<xsl:template name="comment-form-manadtorymarker">
		<span>*</span>
	</xsl:template>	
	
	<xsl:template name="comment-form-field-name">
		<xsl:param name="comment-id" />
        
        <div class="field">
			<div class="label">
				<label for="{$comment-id}-{$commentUniqueId}-name">
					<i18n:text i18n:key="PLUGINS_CMS_CONTENT_COMMENTS_POST_AUTHOR_NAME" i18n:catalogue="plugin.cms"/>
					<xsl:call-template name="comment-form-manadtorymarker"/>
				</label>
			</div>
			<div class="input">
				<input type="text" name="name" id="{$comment-id}-{$commentUniqueId}-name" aria-required="true"/>
			</div>
			<div class="field-end"></div>
		</div>
	</xsl:template>

	<xsl:template name="comment-form-field-mail">
		<xsl:param name="comment-id" />
        
        <div class="field">
			<div class="label">
				<label for="{$comment-id}-{$commentUniqueId}-email">
                    <i18n:text i18n:key="PLUGINS_CMS_CONTENT_COMMENTS_POST_AUTHOR_EMAIL" i18n:catalogue="plugin.cms"/>
                    <xsl:call-template name="comment-form-manadtorymarker"/>
                </label>
			</div>
			<div class="input">
				<input type="text" name="email" id="{$comment-id}-{$commentUniqueId}-email" aria-required="true"/>
			</div>
			<div class="field-end"></div>
		</div>
	</xsl:template>
	
	<xsl:template name="comment-form-field-hidemail">
		<xsl:param name="comment-id" />
        
        <div class="field checkbox">
			<div class="label">
				<label for="{$comment-id}-{$commentUniqueId}-hide-email"><i18n:text i18n:key="PLUGINS_CMS_CONTENT_COMMENTS_POST_AUTHOR_HIDE_EMAIL" i18n:catalogue="plugin.cms"/></label> 
			</div>
			<div class="input">
				<input type="checkbox" name="hide-email" id="{$comment-id}-{$commentUniqueId}-hide-email"/>
			</div>
			<div class="field-end"></div>
		</div>
	</xsl:template>	

	<xsl:template name="comment-form-field-url">
		<xsl:param name="comment-id" />
        
        <div class="field">
			<div class="label">
				<label for="{$comment-id}-{$commentUniqueId}-url"><i18n:text i18n:key="PLUGINS_CMS_CONTENT_COMMENTS_POST_AUTHOR_URL" i18n:catalogue="plugin.cms"/></label> 
			</div>
			<div class="input">
				<input type="text" name="url" id="{$comment-id}-{$commentUniqueId}-url"/>
			</div>
			<div class="field-end"></div>
		</div>
	</xsl:template>	

	<xsl:template name="comment-form-field-content">
		<xsl:param name="comment-id" />
        
        <div class="field">
			<div class="label">
				<label for="{$comment-id}-{$commentUniqueId}-text">
					<i18n:text i18n:key="PLUGINS_CMS_CONTENT_COMMENTS_POST_AUTHOR_CONTENT" i18n:catalogue="plugin.cms"/>
					<xsl:call-template name="comment-form-manadtorymarker"/>
				</label> 
			</div>
			<div class="input">
				<textarea name="text" id="{$comment-id}-{$commentUniqueId}-text" cols="20" rows="3" aria-required="true"></textarea>
			</div>
			<div class="field-end"></div>
		</div>
	</xsl:template>
	
	<xsl:template name="comment-form-field-captcha">
        <xsl:param name="comment-id" />
         
        <xsl:variable name="captcha-required"><xsl:call-template name="comment-captcha-required"/></xsl:variable>
        <xsl:if test="$captcha-required = 'true'">
    		<div class="field">
                <xsl:if test="captcha:requiresUserInteraction()">
        			<div class="label">
        				<label for="{$comment-id}-{$commentUniqueId}-captcha">
        					<i18n:text i18n:key="PLUGINS_CMS_CONTENT_COMMENTS_POST_AUTHOR_CAPTCHA" i18n:catalogue="plugin.cms"/>
        					<xsl:call-template name="comment-form-manadtorymarker"/>
        				</label>
        			</div>
                </xsl:if>
    			<div class="input">
    				<xsl:call-template name="captcha">
    					<xsl:with-param name="key-name">captcha-key</xsl:with-param>
    					<xsl:with-param name="key-id"><xsl:value-of select="$comment-id"/>-<xsl:value-of select="$commentUniqueId"/>-captcha-key</xsl:with-param>
    
    					<xsl:with-param name="value-name">captcha-value</xsl:with-param>
    					<xsl:with-param name="value-id"><xsl:value-of select="$comment-id"/>-<xsl:value-of select="$commentUniqueId"/>-captcha</xsl:with-param>
    					<xsl:with-param name="value-style"></xsl:with-param>
    					<xsl:with-param name="value-class"/>
    
    					<xsl:with-param name="image-alt">PLUGINS_CMS_CONTENT_COMMENTS_POST_AUTHOR_CAPTCHA</xsl:with-param>
    					<xsl:with-param name="image-alt-i18n" select="true()"/>
    					<xsl:with-param name="image-alt-catalogue">plugin.cms</xsl:with-param>
    					<xsl:with-param name="image-style"></xsl:with-param>
    					<xsl:with-param name="image-class"/>
    					
    					<xsl:with-param name="js-funcname-torefresh">refresh_<xsl:value-of select="translate($comment-id, '-', '_')"/>_<xsl:value-of select="$commentUniqueId"/></xsl:with-param>
    				</xsl:call-template> 
    			</div>
    			<div class="field-end"></div>
    		</div>
        </xsl:if>
	</xsl:template>	

	<xsl:template name="comment-form-field-submit">
	     <xsl:param name="comment-id" />
         <!-- Template for submit button -->
         <xsl:call-template name="common-utils-input-submit">
             <xsl:with-param name="i18nkey" select="'plugin.cms:PLUGINS_CMS_CONTENT_COMMENTS_POST_AUTHOR_SUBMIT'" />                
             <xsl:with-param name="onclick">return comment_form_submit_<xsl:value-of select="$commentUniqueId"/>("<xsl:value-of select="$comment-id" />");</xsl:with-param>                
         </xsl:call-template>
	</xsl:template>
	
	<xsl:template name="comments-rss"/>
	
	   <xsl:template name="i18n-convert">
        <xsl:param name="i18nkey"/>

        <xsl:choose>
            <xsl:when test="contains($i18nkey,':')">
                <i18n:text i18n:catalogue="{substring-before($i18nkey,':')}" i18n:key="{substring-after($i18nkey,':')}"/>
            </xsl:when>
            <xsl:otherwise>
                <i18n:text i18n:key="{$i18nkey}"/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    
    <xsl:template name="form-accessibility-title">
        <xsl:param name="accessibility-title" />
        <xsl:param name="accessibility-titleI18n" select="true()" />
        
        <noscript>
           <p>
            <xsl:choose>
                <xsl:when test="$accessibility-titleI18n">
                    <xsl:call-template name="i18n-convert" >
                        <xsl:with-param name="i18nkey" select="$accessibility-title"></xsl:with-param>
                    </xsl:call-template>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="$accessibility-titleI18n" />
                </xsl:otherwise>
            </xsl:choose>
           </p>
        </noscript>
    </xsl:template>
</xsl:stylesheet>
