<?xml version="1.0" encoding="UTF-8"?>
<!--
   Copyright 2010 Anyware Services

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
   -->
<xsl:stylesheet version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	xmlns:docbook="http://docbook.org/ns/docbook" 
    xmlns:i18n="http://apache.org/cocoon/i18n/2.1"
    xmlns:math="http://exslt.org/math" 
    xmlns:ametys="org.ametys.cms.transformation.xslt.AmetysXSLTHelper"
    xmlns:captcha="org.ametys.core.captcha.CaptchaHelper"
    exclude-result-prefixes="docbook"
    extension-element-prefixes="math ametys captcha">

	<xsl:import href="plugin:cms://stylesheets/helper/common.xsl"/>
   
   
    <!-- Set to 'false' to sort comments in descending order -->
    <xsl:variable name="sortCommentsAsc">true</xsl:variable>
    <!-- Set to 'true' to sort comments in descending order -->
    <xsl:variable name="sortSubCommentsAsc">true</xsl:variable>
    
    <!-- Function to call after loading comments -->
    <xsl:variable name="loadCommentsCallback">function(){}</xsl:variable>
    
    <xsl:template name="comments-uri-prefix"><xsl:value-of select="$uri-prefix"/></xsl:template>
    
	<xsl:template name="comments">
        <xsl:variable name="commentable" select="@commentable = 'true' and metadata/comment = 'true'"/>
        
        <xsl:if test="$commentable">
            <xsl:call-template name="comments-inner"/>
            
            <xsl:call-template name="content-comments-js"/>
            <xsl:call-template name="comments-additional-js"/>
        </xsl:if>
    </xsl:template>
    
    <xsl:template name="comments-inner">
        <div class="comments-wrapper" data-ametys-comments-wrapper="{@id}">
            
            <xsl:call-template name="comments-loader"/>
            
            <xsl:call-template name="comments-rss"/>
            
            <xsl:call-template name="comments-title"/>
            
            <xsl:call-template name="comments-list"/>
            
            <xsl:call-template name="comment-form"/>
        
            <xsl:call-template name="content-comment-template-script"/>
        </div>
    </xsl:template>
    
    <xsl:template name="comments-list">
        <ul id="content-comments-{$uniqueId}" class="ametys-comments" data-ametys-comments="{@id}">
            <!-- Comments will be inserted here -->
        </ul>
    </xsl:template>
    
    <xsl:template name="comment-subcomments">
        <ul class="sub-comments" data-ametys-comment-subcomments="true" style="display: none">
            <!-- Subcomments will be inserted here -->
        </ul>
    </xsl:template>
    
    <!-- Template to a loader animation -->
    <xsl:template name="comments-loader"/>
    
    <!-- Template to add a RSS link of comments -->
    <xsl:template name="comments-rss"/>
    
    <!-- Template for comments title -->
    <xsl:template name="comments-title">
    </xsl:template>
    
    <xsl:template name="comments-additional-js">
        <!-- Template to insert additionnal JS for comments -->
    </xsl:template>
    
    <xsl:template name="content-comments-js">
        <script type="text/javascript" src="{concat(ametys:uriPrefix(), '/plugins/cms/resources/js/AmetysFront/Comments.', ametys:lang(), '.js')}"/>
        <script type="text/javascript">
            $j(document).ready(function(){
                AmetysFront.Comments.loadComments('<xsl:value-of select="$uniqueId"/>', '<xsl:value-of select="@id"/>', <xsl:value-of select="$sortCommentsAsc"/>, <xsl:value-of select="$sortSubCommentsAsc"/>, <xsl:value-of select="$loadCommentsCallback"/>);
            })
         </script>
    </xsl:template>
    
    <xsl:template name="content-comment-template-script">
        <template id="content-comment-template-{$uniqueId}">
            <xsl:call-template name="content-comment-template"/>
        </template>
        
        <template id="content-subcomment-template-{$uniqueId}">
            <xsl:call-template name="content-subcomment-template"/>
        </template>
    </xsl:template>
    
    <xsl:template name="content-comment-template">
        <li class="ametys-comment" data-comment-id="true">
            <!-- Here insert the HTML template for a comment using %%date-name%% -->
        </li>
    </xsl:template>
    
    <!-- Sample template for a sub-comment -->
    <xsl:template name="content-subcomment-template">
        <li class="ametys-subcomment" data-comment-id="true">
            <!-- Here insert the HTML template for a subcomment using %%date-name%% -->
        </li>
    </xsl:template>
    
    <xsl:template name="comment-form">
        <form method="post" style="display: none" data-ametys-comments-form="{@id}" id="form-comment-{$uniqueId}" onsubmit="return false;" >
            <xsl:call-template name="comment-form-inner"/>
        </form>
    </xsl:template>
    
    <xsl:template name="comment-answer-form">
        <form method="post" style="display: none" id="form-%%id%%-{$uniqueId}" onsubmit="return false;" >
            <xsl:call-template name="comment-form-inner">
                <xsl:with-param name="level">1</xsl:with-param>
                <xsl:with-param name="comment-id">%%id%%</xsl:with-param>
                <xsl:with-param name="commentUniqueId">%%uniqueId%%</xsl:with-param>
            </xsl:call-template>
        </form>
    </xsl:template>
    
    <xsl:template name="comment-form-inner">
        <xsl:param name="level">0</xsl:param>
        <xsl:param name="content-id" select="@id"/>
        <xsl:param name="comment-id">comment</xsl:param>
        <xsl:param name="commentUniqueId" select="concat('comment_', $uniqueId)"/>
        
        
        <div>
            <input value="{$content-id}" name="content-id" type="hidden"/>
            
            <xsl:if test="$level != 0">
                <input value="%%id%%" name="comment-id" type="hidden"/>
            </xsl:if>
            
            <xsl:call-template name="comment-form-field-name">
                <xsl:with-param name="level" select="$level"/>
                <xsl:with-param name="comment-id" select="$comment-id"/>
                <xsl:with-param name="commentUniqueId" select="$commentUniqueId"/>
            </xsl:call-template>
            <xsl:call-template name="comment-form-field-mail">
                <xsl:with-param name="level" select="$level"/>
                <xsl:with-param name="comment-id" select="$comment-id"/>
                <xsl:with-param name="commentUniqueId" select="$commentUniqueId"/>
            </xsl:call-template>
            <xsl:call-template name="comment-form-field-hidemail">
                <xsl:with-param name="level" select="$level"/>
                <xsl:with-param name="comment-id" select="$comment-id"/>
                <xsl:with-param name="commentUniqueId" select="$commentUniqueId"/>
            </xsl:call-template>
            <xsl:call-template name="comment-form-field-url">
                <xsl:with-param name="level" select="$level"/>
                <xsl:with-param name="comment-id" select="$comment-id"/>
                <xsl:with-param name="commentUniqueId" select="$commentUniqueId"/>
            </xsl:call-template>
            <xsl:call-template name="comment-form-field-content">
                <xsl:with-param name="level" select="$level"/>
                <xsl:with-param name="comment-id" select="$comment-id"/>
                <xsl:with-param name="commentUniqueId" select="$commentUniqueId"/>
            </xsl:call-template>
            <xsl:call-template name="comment-form-field-additional">
                <xsl:with-param name="level" select="$level"/>
                <xsl:with-param name="comment-id" select="$comment-id"/>
                <xsl:with-param name="commentUniqueId" select="$commentUniqueId"/>
            </xsl:call-template>
            <xsl:call-template name="comment-form-field-captcha">
                <xsl:with-param name="level" select="$level"/>
                <xsl:with-param name="comment-id" select="'%%safe-id%%'"/>
                <xsl:with-param name="commentUniqueId" select="$commentUniqueId"/>
            </xsl:call-template>
                
            <xsl:call-template name="comment-form-field-submit">
                <xsl:with-param name="level" select="$level"></xsl:with-param>
                <xsl:with-param name="comment-id" select="$comment-id"/>
                <xsl:with-param name="commentUniqueId" select="$commentUniqueId"/>
            </xsl:call-template>
        </div>
    </xsl:template>
    
    <xsl:template name="comment-form-field-name">
        <xsl:param name="level" />
        <xsl:param name="comment-id" />
        <xsl:param name="commentUniqueId" />
        
        <div class="field">
            <div class="label">
                <label for="{$commentUniqueId}-name">
                    <i18n:text i18n:key="PLUGINS_CMS_CONTENT_COMMENTS_POST_AUTHOR_NAME" i18n:catalogue="plugin.cms"/>
                    <xsl:call-template name="comment-form-mandatorymarker"/>
                </label>
            </div>
            <div class="input">
                <input type="text" name="name" id="{$commentUniqueId}-name" aria-required="true"/>
            </div>
            <div class="field-end"></div>
        </div>
    </xsl:template>
    
    <xsl:template name="comment-form-field-mail">
        <xsl:param name="level" />
        <xsl:param name="comment-id" />
        <xsl:param name="commentUniqueId" />
        
        <div class="field">
			<div class="label">
				<label for="{$commentUniqueId}-mail">
                    <i18n:text i18n:key="PLUGINS_CMS_CONTENT_COMMENTS_POST_AUTHOR_EMAIL" i18n:catalogue="plugin.cms"/>
                    <xsl:call-template name="comment-form-mandatorymarker"/>
                </label>
			</div>
			<div class="input">
				<input type="text" name="email" id="{$commentUniqueId}-mail" aria-required="true"/>
			</div>
			<div class="field-end"></div>
		</div>
	</xsl:template>
	
	<xsl:template name="comment-form-field-hidemail">
		<xsl:param name="level" />
        <xsl:param name="comment-id" />
        <xsl:param name="commentUniqueId" />
        
        <div class="field checkbox">
			<div class="label">
				<label for="{$commentUniqueId}-hidemail"><i18n:text i18n:key="PLUGINS_CMS_CONTENT_COMMENTS_POST_AUTHOR_HIDE_EMAIL" i18n:catalogue="plugin.cms"/></label> 
			</div>
			<div class="input">
				<input type="checkbox" name="hide-email" id="{$commentUniqueId}-hidemail"/>
			</div>
			<div class="field-end"></div>
		</div>
	</xsl:template>	

	<xsl:template name="comment-form-field-url">
		<xsl:param name="level" />
        <xsl:param name="comment-id" />
        <xsl:param name="commentUniqueId" />
        
        <div class="field">
			<div class="label">
				<label for="{$commentUniqueId}-url"><i18n:text i18n:key="PLUGINS_CMS_CONTENT_COMMENTS_POST_AUTHOR_URL" i18n:catalogue="plugin.cms"/></label> 
			</div>
			<div class="input">
				<input type="text" name="url" id="{$commentUniqueId}-url"/>
			</div>
			<div class="field-end"></div>
		</div>
	</xsl:template>	

	<xsl:template name="comment-form-field-content">
		<xsl:param name="level" />
        <xsl:param name="comment-id" />
        <xsl:param name="commentUniqueId" />
        
        <div class="field">
			<div class="label">
				<label for="{$commentUniqueId}-text">
					<i18n:text i18n:key="PLUGINS_CMS_CONTENT_COMMENTS_POST_AUTHOR_CONTENT" i18n:catalogue="plugin.cms"/>
					<xsl:call-template name="comment-form-mandatorymarker"/>
				</label> 
			</div>
			<div class="input">
				<textarea name="text" id="{$commentUniqueId}-text" cols="20" rows="3" aria-required="true"></textarea>
			</div>
			<div class="field-end"></div>
		</div>
	</xsl:template>
	
	<xsl:template name="comment-form-field-captcha">
        <xsl:param name="level" />
        <xsl:param name="comment-id" />
        <xsl:param name="commentUniqueId" />
         
        <xsl:variable name="captcha-required"><xsl:call-template name="comment-captcha-required"/></xsl:variable>
        <xsl:if test="$captcha-required = 'true'">
    		<div class="field">
                <xsl:if test="captcha:requiresUserInteraction()">
        			<div class="label">
        				<label for="{$commentUniqueId}-captcha">
        					<i18n:text i18n:key="PLUGINS_CMS_CONTENT_COMMENTS_POST_AUTHOR_CAPTCHA" i18n:catalogue="plugin.cms"/>
        					<xsl:call-template name="comment-form-mandatorymarker"/>
        				</label>
        			</div>
                </xsl:if>
    			<div class="input">
    				<xsl:call-template name="captcha">
    					<xsl:with-param name="key-name">captcha-key</xsl:with-param>
                        <xsl:with-param name="key-id"><xsl:value-of select="$commentUniqueId"/>-captcha-key</xsl:with-param>
    
    					<xsl:with-param name="value-name">captcha-value</xsl:with-param>
                        <xsl:with-param name="value-id"><xsl:value-of select="$commentUniqueId"/>-captcha</xsl:with-param>
    					<xsl:with-param name="value-style"></xsl:with-param>
    					<xsl:with-param name="value-class"/>
                        
    					<xsl:with-param name="image-alt">PLUGINS_CMS_CONTENT_COMMENTS_POST_AUTHOR_CAPTCHA</xsl:with-param>
    					<xsl:with-param name="image-alt-i18n" select="true()"/>
    					<xsl:with-param name="image-alt-catalogue">plugin.cms</xsl:with-param>
    					<xsl:with-param name="image-style"></xsl:with-param>
    					<xsl:with-param name="image-class"/>
                        <xsl:with-param name="image-id"><xsl:value-of select="$commentUniqueId"/>-img</xsl:with-param>
                        
                        <xsl:with-param name="js-funcname-torefresh">refresh_<xsl:value-of select="$commentUniqueId"/></xsl:with-param>
    				</xsl:call-template> 
    			</div>
    			<div class="field-end"></div>
    		</div>
        </xsl:if>
	</xsl:template>	

	<xsl:template name="comment-form-field-submit">
	     <xsl:param name="level" />
         
         <xsl:variable name="onclick">
            <xsl:choose>
                <xsl:when test="$level = 0">AmetysFront.Comments.addComment('<xsl:value-of select="$uniqueId"/>', '<xsl:value-of select="@id"/>', <xsl:value-of select="$sortCommentsAsc"/>)</xsl:when>
                <xsl:otherwise>AmetysFront.Comments.addSubComment(this, '<xsl:value-of select="$uniqueId"/>', '<xsl:value-of select="@id"/>', <xsl:value-of select="$sortSubCommentsAsc"/>)</xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
                
         <!-- Template for submit button -->
         <xsl:call-template name="common-utils-input-submit">
             <xsl:with-param name="i18nkey" select="'plugin.cms:PLUGINS_CMS_CONTENT_COMMENTS_POST_AUTHOR_SUBMIT'" />                
             <xsl:with-param name="onclick" select="$onclick"/>    
         </xsl:call-template>
	</xsl:template>
    
    <xsl:template name="comment-form-mandatorymarker">
        <span>*</span>
    </xsl:template> 
    
    <xsl:template name="comment-captcha-required">true</xsl:template>
    
    <xsl:template name="comment-report">
        <xsl:call-template name="comment-report-btn"/>
    </xsl:template>
    
    <xsl:template name="comment-report-btn">
        <button class="ametys-comment-report-btn" 
              data-ametys-comment-report="true"
              data-ametys-comment-id="%%id%%" 
              title="plugin.cms:PLUGINS_CMS_CONTENT_COMMENTS_REPORT_BUTTON_TOOLTIP"
              i18n:attr="title"
              onclick="AmetysFront.Comments.reportComment(this,'{@id}', $j(this).attr('data-ametys-comment-id'))">
            <span><i18n:text i18n:key="PLUGINS_CMS_CONTENT_COMMENTS_REPORT_BUTTON_TITLE" i18n:catalogue="plugin.cms"/></span>
        </button>
    </xsl:template>
    
    <xsl:template name="comment-delete">
        <xsl:call-template name="comment-delete-btn"/>
    </xsl:template>
    
    <!-- Sample template for delete button on a comment -->
    <xsl:template name="comment-delete-btn">
        <button class="ametys-comment-delete-btn" 
              data-ametys-comment-delete="true"
              data-ametys-comment-id="%%id%%" 
              title="plugin.cms:PLUGINS_CMS_CONTENT_COMMENTS_DELETE_BUTTON_TOOLTIP"
              i18n:attr="title"
              onclick="AmetysFront.Comments.deleteComment(this, '{@id}', $j(this).attr('data-ametys-comment-id'))">
            <span><i18n:text i18n:key="PLUGINS_CMS_CONTENT_COMMENTS_DELETE_BUTTON_TITLE" i18n:catalogue="plugin.cms"/></span>
        </button>
    </xsl:template>
    
    <xsl:template name="comment-like">
        <xsl:call-template name="comment-like-btn"/>
        <xsl:call-template name="comment-like-counters"/>
    </xsl:template>
    
    <xsl:template name="comment-like-counters">
        <div class="ametys-likes-counter" data-ametys-comment-like="true"><span class="ametys-like-count" data-ametys-comment-nb-likes="true">%%nb-likes%%</span></div>
    </xsl:template>
    
    <!-- Sample template for like button on a comment -->
    <xsl:template name="comment-like-btn">
        <button class="ametys-comment-like-btn" 
              data-ametys-comment-like="true"
              data-ametys-own-liker="%%own-liker%%" 
              data-ametys-comment-id="%%id%%" 
              data-ametys-comment-likers="%%likers%%"
              title="plugin.cms:PLUGINS_CMS_CONTENT_COMMENTS_LIKE_BUTTON_TOOLTIP"
              i18n:attr="title"
              onclick="AmetysFront.Comments.likeOrUnlikeComment(this, '{@id}', $j(this).attr('data-ametys-comment-id'), $j(this).attr('data-ametys-own-liker') == 'true')">
              <span><i18n:text i18n:key="PLUGINS_CMS_CONTENT_COMMENTS_LIKE_BUTTON_TITLE" i18n:catalogue="plugin.cms"/></span>
        </button>
    </xsl:template>
    
</xsl:stylesheet>
