<?xml version="1.0" encoding="UTF-8"?>
<!--
   Copyright 2018 Anyware Services

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
   -->
<xsl:stylesheet version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	xmlns:docbook="http://docbook.org/ns/docbook" 
    xmlns:i18n="http://apache.org/cocoon/i18n/2.1"
    xmlns:math="http://exslt.org/math" 
    xmlns:ametys="org.ametys.cms.transformation.xslt.AmetysXSLTHelper"
    exclude-result-prefixes="docbook"
    extension-element-prefixes="math ametys">

    <xsl:import href="plugin:cms://stylesheets/helper/common.xsl"/>
    
    <xsl:variable name="deleteUniqueId" select="concat('delete_comments_', substring-after(math:random(), '.'))"/>
    
    <xsl:template name="get-comment-delete-url-ajax">
        <xsl:value-of select="ametys:uriPrefix()"/>
        <xsl:text>/plugins/cms/comments/delete-comment</xsl:text>
    </xsl:template>
    
    <xsl:template name="comment-delete">
        <xsl:param name="content-id" />
      
        <xsl:call-template name="comment-delete-form" >
            <xsl:with-param name="title" >plugin.cms:PLUGINS_CMS_CONTENT_COMMENTS_DELETE_BUTTON_TITLE</xsl:with-param>
               <xsl:with-param name="button-tooltip" >plugin.cms:PLUGINS_CMS_CONTENT_COMMENTS_DELETE_BUTTON_TOOLTIP</xsl:with-param>
               <xsl:with-param name="class" >ametys-delete</xsl:with-param>
            <xsl:with-param name="content-id" select="$content-id" />
        </xsl:call-template>
    </xsl:template>
    
    <xsl:template name="comment-delete-confirm-box">
        <div style="display:none" id="dialog-confirm-{$deleteUniqueId}" title="plugin.cms:PLUGINS_CMS_CONTENT_COMMENTS_DELETE_TITLE" i18n:attr="title">
          <p><i18n:text i18n:key="PLUGINS_CMS_CONTENT_COMMENTS_DELETE_MSG" i18n:catalogue="plugin.cms"/></p>
        </div>
    </xsl:template>
    
    <xsl:template name="comment-delete-form">
        <xsl:param name="title" />
        <xsl:param name="button-tooltip" />
        <xsl:param name="class" />
        <xsl:param name="content-id" />
    
        <!-- Warning : we put the email in data-mail-user despite of the authorization because the page is in limited access -->
        <form style="display:none" data-mail-user="{@author-email}" id="delete-{@id}-{$deleteUniqueId}" method="post" class="{$class}-form">
            <div class="{$class}-form-div"> 
                <input type="hidden" name="content-id" id="delete-{@id}-{$deleteUniqueId}-id" value="{$content-id}"/>
                <input type="hidden" name="comment-id" id="delete-{@id}-{$deleteUniqueId}-comment-id" value="{@id}"/>
                
                <xsl:call-template name="comment-delete-form-field-submit">
                    <xsl:with-param name="title" select="$title" />
                    <xsl:with-param name="tooltip" select="$button-tooltip" />
                    <xsl:with-param name="class" select="$class" />
                </xsl:call-template>
                     
                <div class="comment-form-bottom"></div>
            </div>
        </form>
        
        <script type="text/javascript">
            var form = $j("#delete-<xsl:value-of select="@id" />-<xsl:value-of select="$deleteUniqueId" />");
            if (form.attr("data-mail-user") == ametysUser.email)
            {
                form.show();
            }
        </script>
    </xsl:template>
	
	<xsl:template name="comment-delete-button-right-script">
	   <xsl:param name="content-id" />
	   <xsl:param name="comment-unique-id" />
    
	   <script type="text/javascript">
            $j(document).ready(function() 
            {
	            // send it in ajax
	            var data = {
	               "content-id": '<xsl:value-of select="$content-id" />'
	            };
	           
	            $j.ajax({
	                  url: "<xsl:value-of select="$uri-prefix"/>/plugins/cms/comments/get-right-delete-comment",
	                  data: data,
	                  type: 'post',
	                  success: result,
	                  error: handleError
	            });
	            
	            function handleError(jqXHR, textStatus, errorThrown)
	            {
	               alert("<i18n:text i18n:key="PLUGINS_CMS_CONTENT_COMMENTS_FORM_ERROR_AJAX" i18n:catalogue="plugin.cms"/>");
	            }
	            
	            function result(data)
	            {
	                 if ($j('hasRight', data).text() == "true")
	                 {
	                      $j("#<xsl:value-of select="$comment-unique-id"/>").find(".ametys-delete-form").show();
	                 }
	            }
            });
	   </script>
	</xsl:template>
	
	<xsl:template name="comment-delete-form-script">
		<script type="text/javascript">
		    function delete_comment_form_submit_<xsl:value-of select="$deleteUniqueId"/>(id)
            {
                $j("#dialog-confirm-<xsl:value-of select="$deleteUniqueId" />").dialog({
                      modal: true,
                      buttons: {
                        "<i18n:text i18n:key="PLUGINS_CMS_CONTENT_COMMENTS_DELETE_OK" i18n:catalogue="plugin.cms"/>": function() {
                          $j( this ).dialog( "close" );
                          delete_comment_<xsl:value-of select="$deleteUniqueId"/>(id);
                        },
                        "<i18n:text i18n:key="PLUGINS_CMS_CONTENT_COMMENTS_DELETE_CANCEL" i18n:catalogue="plugin.cms"/>": function() {
                          $j( this ).dialog( "close" );
                        }
                      }
                });
                 
                return false;
            }
		
			function delete_comment_<xsl:value-of select="$deleteUniqueId"/>(id)
			{
				// send it in ajax
				var data = {
					"content-id": $j('#delete-' + id + '-<xsl:value-of select="$deleteUniqueId"/>-id').val(),
					"comment-id": $j('#delete-' + id + '-<xsl:value-of select="$deleteUniqueId"/>-comment-id').val()
				};
                      
				function result(data)
				{
					var s = "";
					$j('errors errors', data).each(function () { s += $j(this).text() + "\n"; });
					
					if (s == "")
					{
						if ($j('deleted', data).text() == "true")
						{
							/([^?#]*)([\?#].*)*/.test(document.location.href);
							document.location.href = RegExp.$1; 
						}
						else
						{
							alert("<i18n:text i18n:key="PLUGINS_CMS_CONTENT_COMMENTS_DELETE_ERROR_MSG" i18n:catalogue="plugin.cms"/>")
						}
					}
					else
					{
						alert(s);
					}
				}
                      
                function handleError(jqXHR, textStatus, errorThrown)
                {
            	    alert("<i18n:text i18n:key="PLUGINS_CMS_CONTENT_COMMENTS_FORM_ERROR_AJAX" i18n:catalogue="plugin.cms"/>");
                }
                
                $j.ajax({
                    url: "<xsl:call-template name="get-comment-delete-url-ajax" />",
                    data: data,
                    type: 'post',
                    success: result,
                    error: handleError
                });
                
                return false;
			}
		</script>
	</xsl:template>	
    
	<xsl:template name="comment-delete-form-field-submit">
	     <xsl:param name="title" />
	     <xsl:param name="tooltip" />
         <xsl:param name="class" />
         
         <!-- Template for submit button -->
         <xsl:call-template name="common-utils-input-submit">
             <xsl:with-param name="i18nkey" select="$title" />
             <xsl:with-param name="i18ntitle" select="$tooltip" />
             <xsl:with-param name="class-name" select="concat($class, '-button')" />
             <xsl:with-param name="onclick">return delete_comment_form_submit_<xsl:value-of select="$deleteUniqueId"/>("<xsl:value-of select="@id" />");</xsl:with-param>                
         </xsl:call-template>
	</xsl:template>
</xsl:stylesheet>
