<?xml version="1.0" encoding="UTF-8"?>
<!--
   Copyright 2018 Anyware Services

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
   -->
<xsl:stylesheet version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	xmlns:docbook="http://docbook.org/ns/docbook" 
    xmlns:i18n="http://apache.org/cocoon/i18n/2.1"
    xmlns:math="http://exslt.org/math" 
    xmlns:ametys="org.ametys.cms.transformation.xslt.AmetysXSLTHelper"
    exclude-result-prefixes="docbook"
    extension-element-prefixes="math ametys">

    <xsl:import href="plugin:cms://stylesheets/helper/common.xsl"/>
    
    <xsl:variable name="likeUniqueId" select="concat('like_comments_', substring-after(math:random(), '.'))"/>
    
    <xsl:template name="get-comment-like-url-ajax">
        <xsl:value-of select="ametys:uriPrefix()"/>
        <xsl:text>/plugins/cms/comments/like-comment</xsl:text>
    </xsl:template>
    
    <xsl:template name="comment-like">
        <xsl:param name="content-id" />
    
        <xsl:call-template name="comment-like-form" >
            <xsl:with-param name="like-title">plugin.cms:PLUGINS_CMS_CONTENT_COMMENTS_LIKE_BUTTON_TITLE</xsl:with-param>
            <xsl:with-param name="like-button-tooltip">plugin.cms:PLUGINS_CMS_CONTENT_COMMENTS_LIKE_BUTTON_TOOLTIP</xsl:with-param>
            <xsl:with-param name="unlike-title">plugin.cms:PLUGINS_CMS_CONTENT_COMMENTS_UNLIKE_BUTTON_TITLE</xsl:with-param>
            <xsl:with-param name="unlike-button-tooltip">plugin.cms:PLUGINS_CMS_CONTENT_COMMENTS_UNLIKE_BUTTON_TOOLTIP</xsl:with-param>
            <xsl:with-param name="content-id" select="$content-id" />
        </xsl:call-template>
    </xsl:template>

    <xsl:template name="comment-like-form">
        <xsl:param name="like-title" />
        <xsl:param name="unlike-title" />
        <xsl:param name="like-button-tooltip" />
        <xsl:param name="unlike-button-tooltip" />
        <xsl:param name="content-id" />
        
        <form id="like-{@id}-{$likeUniqueId}" method="post" class="ametys-like-form">
            <div class="ametys-like-form-div" data-nblike="{@nb-like}"> 
                <input type="hidden" name="content-id" id="like-{@id}-{$likeUniqueId}-id" value="{$content-id}"/>
                <input type="hidden" name="comment-id" id="like-{@id}-{$likeUniqueId}-comment-id" value="{@id}"/>
                
                <xsl:call-template name="comment-like-form-field-submit">
                    <xsl:with-param name="title" select="$like-title" />
                    <xsl:with-param name="tooltip" select="$like-button-tooltip" />
                </xsl:call-template>
                
                <div class="ametys-likes-counter">
	                <xsl:call-template name="comment-like-tooltip-likers">
	                    <xsl:with-param name="nb-liker-max">5</xsl:with-param>
	                </xsl:call-template>
	
		            <i18n:translate>
		                <i18n:text i18n:key="PLUGINS_CMS_CONTENT_COMMENTS_LIKE_COUNT_MSG" i18n:catalogue="plugin.cms"/>
		                <i18n:param><xsl:value-of select="count(reactions/reaction[@type='LIKE']/actor)"/></i18n:param>
		            </i18n:translate>
                </div>

                <div class="comment-form-bottom"></div>
            </div>
        </form>
        
        <script type="text/javascript">
            var commentId = '<xsl:value-of select="@id" />';
            var uniqueId = '<xsl:value-of select="$likeUniqueId" />';
            likers[commentId] = [
                <xsl:for-each select="reactions/reaction[@type='LIKE']/actor">
                    '<xsl:value-of select="@login" />#<xsl:value-of select="@population" />'<xsl:if test="position() != last()">,</xsl:if>
                </xsl:for-each>
            ];
            
            if (likers[commentId].indexOf(ametysUser.login + "#" + ametysUser.populationId) != -1)
            {
                var form = $j("#like-" + commentId + "-" + uniqueId);
                form.removeClass("ametys-like-form");
                form.addClass("ametys-unlike-form");
                
                var divform = $j("#like-" + commentId + "-" + uniqueId + " .ametys-like-form-div");
                divform.removeClass("ametys-like-form-div");
                divform.addClass("ametys-unlike-form-div");
                
                var buttonform = $j("#like-" + commentId + "-" + uniqueId + " .ametys-like-button");
                buttonform.removeClass("ametys-like-button");
                buttonform.addClass("ametys-unlike-button");
                
                <xsl:variable name="value">
                    <xsl:call-template name="i18n-convert" >
	                  <xsl:with-param name="i18nkey" select="$unlike-title"></xsl:with-param>
	                </xsl:call-template>
                </xsl:variable>
                <xsl:variable name="title">
	                <xsl:call-template name="i18n-convert" >
	                  <xsl:with-param name="i18nkey" select="$unlike-button-tooltip"></xsl:with-param>
	                </xsl:call-template>
                </xsl:variable>
                buttonform.val("<xsl:copy-of select="$value" />");
                buttonform.attr("title", "<xsl:copy-of select="$title" />");
            }
            
        </script>
    </xsl:template>
    
    <xsl:template name="comment-like-tooltip-likers">
        <xsl:param name="nb-liker-max" />
    
        <xsl:variable name="nbLikes" select="count(reactions/reaction[@type='LIKE'])"/>
        <xsl:if test="$nbLikes > 0">  
            <div class="ametys-likers">
                <ul>
                    <xsl:for-each select="reactions/reaction[@type='LIKE'][position() &lt; ($nb-liker-max + 1)]">
                        <li><span><xsl:value-of select="actor/fullname" /></span></li>
                    </xsl:for-each>
                </ul>
                <xsl:variable name="other-count" select="$nbLikes - $nb-liker-max" />
                <xsl:if test="$other-count > 0">
                    <p class="ametys-other-like">
                        <xsl:choose>
                            <xsl:when test="$other-count = 1">
                                 <i18n:text i18n:key="PLUGINS_CMS_CONTENT_COMMENTS_LIKE_OTHER_TOOLTIP" i18n:catalogue="plugin.cms"/>
                            </xsl:when>
                            <xsl:otherwise>
                                 <i18n:translate>
                                    <i18n:text i18n:key="PLUGINS_CMS_CONTENT_COMMENTS_LIKE_OTHERS_TOOLTIP" i18n:catalogue="plugin.cms"/>
                                    <i18n:param><xsl:value-of select="$other-count"/></i18n:param>
                                 </i18n:translate>
                            </xsl:otherwise>
                        </xsl:choose>
                    </p>
                </xsl:if>
            </div>
        </xsl:if>
    </xsl:template>
    
	<xsl:template name="comment-like-form-script">
			<script type="text/javascript">
			    likers = [];
			    
				function like_comment_form_submit_<xsl:value-of select="$likeUniqueId"/>(id)
				{
					// send it in ajax
					var data = {
						"content-id": $j('#like-' + id + '-<xsl:value-of select="$likeUniqueId"/>-id').val(),
						"comment-id": $j('#like-' + id + '-<xsl:value-of select="$likeUniqueId"/>-comment-id').val()
					};
                       
					function result(data)
					{
						var s = "";
						$j('errors errors', data).each(function () { s += $j(this).text() + "\n"; });
						
						if (s == "")
						{
							if ($j('liked', data).text())
							{
							    var commentId = $j('commentId', data).text();
								var contentId = $j('contentId', data).text();
                                /([^?#]*)([\?#].*)*/.test(document.location.href);
								document.location.href = RegExp.$1 + "?foo=" + Math.random() + "#" + commentId + "-" + contentId; 
							}
						}
						else
						{
							alert(s);
						}
					}
                       
                    function handleError(jqXHR, textStatus, errorThrown)
                    {
                	   alert("<i18n:text i18n:key="PLUGINS_CMS_CONTENT_COMMENTS_FORM_ERROR_AJAX" i18n:catalogue="plugin.cms"/>");
                    }
                    
                    $j.ajax({
                        url: "<xsl:call-template name="get-comment-like-url-ajax" />",
                        data: data,
                        type: 'post',
                        success: result,
                        error: handleError
                    });
                    
                    return false;
				}
			</script>
	</xsl:template>	
    
	<xsl:template name="comment-like-form-field-submit">
	     <xsl:param name="title" />
	     <xsl:param name="tooltip" />
         
         <!-- Template for submit button -->
         <xsl:call-template name="common-utils-input-submit">
             <xsl:with-param name="i18nkey" select="$title" />
             <xsl:with-param name="i18ntitle" select="$tooltip" />
             <xsl:with-param name="class-name" >ametys-like-button</xsl:with-param>
             <xsl:with-param name="onclick">return like_comment_form_submit_<xsl:value-of select="$likeUniqueId"/>("<xsl:value-of select="@id" />");</xsl:with-param>                
         </xsl:call-template>
	</xsl:template>
</xsl:stylesheet>
