<?xml version="1.0" encoding="UTF-8"?>
<!--
   Copyright 2018 Anyware Services

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
   -->
<xsl:stylesheet version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	xmlns:docbook="http://docbook.org/ns/docbook" 
    xmlns:i18n="http://apache.org/cocoon/i18n/2.1"
    xmlns:math="http://exslt.org/math" 
    xmlns:ametys="org.ametys.cms.transformation.xslt.AmetysXSLTHelper"
    exclude-result-prefixes="docbook"
    extension-element-prefixes="math ametys">

    <xsl:import href="plugin:cms://stylesheets/helper/common.xsl"/>
    
    <xsl:variable name="reportUniqueId" select="concat('report_comments_', substring-after(math:random(), '.'))"/>
    
    <xsl:template name="get-comment-report-url-ajax">
        <xsl:value-of select="ametys:uriPrefix()"/>
        <xsl:text>/plugins/cms/comments/report-comment</xsl:text>
    </xsl:template>
    
    <xsl:template name="comment-report-dialog-box">
        <div style="display:none" id="dialog-{$reportUniqueId}" title="plugin.cms:PLUGINS_CMS_CONTENT_COMMENTS_REPORTED_TITLE" i18n:attr="title">
          <p><i18n:text i18n:key="PLUGINS_CMS_CONTENT_COMMENTS_REPORTED_MSG" i18n:catalogue="plugin.cms"/></p>
        </div>
    </xsl:template>

    <xsl:template name="comment-report-confirm-box">
        <div style="display:none" id="dialog-confirm-{$reportUniqueId}" title="plugin.cms:PLUGINS_CMS_CONTENT_COMMENTS_REPORTED_CONFIRM_TITLE" i18n:attr="title">
          <p><i18n:text i18n:key="PLUGINS_CMS_CONTENT_COMMENTS_REPORTED_CONFIRM_MSG" i18n:catalogue="plugin.cms"/></p>
        </div>
    </xsl:template>

    <xsl:template name="comment-report">
        <xsl:param name="content-id" />
        
        <xsl:call-template name="comment-report-form" >
            <xsl:with-param name="title" >plugin.cms:PLUGINS_CMS_CONTENT_COMMENTS_REPORT_BUTTON_TITLE</xsl:with-param>
	        <xsl:with-param name="button-tooltip" >plugin.cms:PLUGINS_CMS_CONTENT_COMMENTS_REPORT_BUTTON_TOOLTIP</xsl:with-param>
               <xsl:with-param name="class" >ametys-report</xsl:with-param>
            <xsl:with-param name="content-id" select="$content-id" />
        </xsl:call-template>
    </xsl:template>

    <xsl:template name="comment-report-form">
        <xsl:param name="title" />
        <xsl:param name="button-tooltip" />
        <xsl:param name="class" />
        <xsl:param name="content-id" />
    
        <form id="report-{@id}-{$reportUniqueId}" method="post" class="{$class}-form">
            <div class="{$class}-form-div" >
                <input type="hidden" name="content-id" id="report-{@id}-{$reportUniqueId}-id" value="{$content-id}"/>
                <input type="hidden" name="comment-id" id="report-{@id}-{$reportUniqueId}-comment-id" value="{@id}"/>
                
                <xsl:call-template name="comment-report-form-field-submit">
                    <xsl:with-param name="title" select="$title" />
                    <xsl:with-param name="tooltip" select="$button-tooltip" />
                    <xsl:with-param name="class" select="$class" />
                </xsl:call-template>
                     
                <div class="comment-form-bottom"></div>
            </div>
        </form>
    </xsl:template>
    
	<xsl:template name="comment-report-form-script">
			<script type="text/javascript">
			    function report_comment_form_submit_<xsl:value-of select="$reportUniqueId"/>(id)
                {
                    $j("#dialog-confirm-<xsl:value-of select="$reportUniqueId" />").dialog({
                          modal: true,
                          width: '60%',
                          minWidth: 300,
                          buttons: {
					        "<i18n:text i18n:key="PLUGINS_CMS_CONTENT_COMMENTS_REPORT_OK" i18n:catalogue="plugin.cms"/>": function() {
					          $j( this ).dialog( "close" );
					          report_comment_report_<xsl:value-of select="$reportUniqueId"/>(id);
					        },
					        "<i18n:text i18n:key="PLUGINS_CMS_CONTENT_COMMENTS_REPORT_CANCEL" i18n:catalogue="plugin.cms"/>": function() {
					          $j( this ).dialog( "close" );
					        }
					      }
                     });
                     
                     return false;
                }
			
				function report_comment_report_<xsl:value-of select="$reportUniqueId"/>(id)
				{
					// send it in ajax
					var data = {
						"content-id": $j('#report-' + id + '-<xsl:value-of select="$reportUniqueId"/>-id').val(),
						"comment-id": $j('#report-' + id + '-<xsl:value-of select="$reportUniqueId"/>-comment-id').val()
					};
                       
					function result(data)
					{
						var s = "";
						$j('errors errors', data).each(function () { s += $j(this).text() + "\n"; });
						
						if (s == "")
						{
							if ($j('reported', data).text() == "true")
							{
							     $j("#dialog-<xsl:value-of select="$reportUniqueId" />").dialog({
								      modal: true,
								      buttons: {
									      "<i18n:text i18n:key="PLUGINS_CMS_CONTENT_COMMENTS_REPORTED_OK" i18n:catalogue="plugin.cms"/>": function() {
									        $j( this ).dialog( "close" );
									      }
								      }
							     });
							}
						}
						else
						{
							alert(s);
						}
					}
                       
                    function handleError(jqXHR, textStatus, errorThrown)
                    {
                	   alert("<i18n:text i18n:key="PLUGINS_CMS_CONTENT_COMMENTS_FORM_ERROR_AJAX" i18n:catalogue="plugin.cms"/>");
                    }
                    
                    $j.ajax({
                        url: "<xsl:call-template name="get-comment-report-url-ajax" />",
                        data: data,
                        type: 'post',
                        success: result,
                        error: handleError
                    });
                    
                    return false;
				}
			</script>
	</xsl:template>	
    
	<xsl:template name="comment-report-form-field-submit">
	     <xsl:param name="title" />
	     <xsl:param name="tooltip" />
         <xsl:param name="class" />
         
         <!-- Template for submit button -->
         <xsl:call-template name="common-utils-input-submit">
             <xsl:with-param name="i18nkey" select="$title"/>
             <xsl:with-param name="i18ntitle" select="$tooltip" />
             <xsl:with-param name="class-name" select="concat($class, '-button')"/>
             <xsl:with-param name="onclick">return report_comment_form_submit_<xsl:value-of select="$reportUniqueId"/>("<xsl:value-of select="@id" />");</xsl:with-param>                
         </xsl:call-template>
	</xsl:template>
</xsl:stylesheet>
