<?xml version="1.0" encoding="UTF-8"?>
<!--
   Copyright 2010 Anyware Services

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
   -->
<xsl:stylesheet version="1.0" 
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
    xmlns:xalan="http://xml.apache.org/xalan"
    xmlns:resolver="org.ametys.cms.transformation.xslt.ResolveURIComponent"
    xmlns:ametys="org.ametys.cms.transformation.xslt.AmetysXSLTHelper"
    xmlns:cms="http://ametys.org/cms/3.0"
    xmlns:func="http://exslt.org/functions"
    xmlns:i18n="http://apache.org/cocoon/i18n/2.1"
    xmlns:dyn="http://exslt.org/dynamic"
    exclude-result-prefixes="i18n xalan resolver cms func dyn">
    
    <xsl:param name="contextPath"/>
    
    <!-- +
         | This function tests if a fieldset is not empty, 
         | ie. it is composed at least of a valued metadata or a non-empty fieldset.
         | Be careful, metadata of type 'boolean' are excluded for the test.
         | So if the fieldset has only boolean metadata that are valued, it will be considered as empty.
         | Parameters are:
         | - fieldset: the fieldset node
         | - [prefix]: the xpath of the node holding the values. By default /view/content/metadata/
         + -->
    <func:function name="cms:isNotFieldsetEmpty">
        <xsl:param name="fieldset"/>
        <xsl:param name="prefix">/view/content/metadata/</xsl:param>
        
        <xsl:variable name="xpath">
            <xsl:call-template name="compute-xpath">
                <xsl:with-param name="fieldset" select="$fieldset"/>
                <xsl:with-param name="prefix" select="$prefix"/>
            </xsl:call-template>
        </xsl:variable>
        
        <func:result select="dyn:evaluate($xpath)"/>
    </func:function>
    
    <!-- +
         | This template compute the xpath to be evaluated to test if the fieldset is empty
         | Parameters are:
         | - fieldset: the fieldset node
         | - [prefix]: the xpath of the node holding the values. By default /view/content/metadata/
         + -->
    <xsl:template name="compute-xpath">
        <xsl:param name="fieldset"/>
        <xsl:param name="prefix">/view/content/metadata/</xsl:param>
        
        <xsl:for-each select="$fieldset/fieldset|$fieldset/metadata[@type != 'boolean']">
            <xsl:if test="position() != 1"> or </xsl:if>
            <xsl:choose>
                <xsl:when test="@type = 'repeater'"><xsl:value-of select="concat($prefix, @name)"/>[not(@entryCount) or @entryCount != '0']</xsl:when>
                <xsl:when test="@type = 'composite'">
                    <xsl:call-template name="compute-xpath">
                        <xsl:with-param name="fieldset" select="."/>
                        <xsl:with-param name="prefix" select="concat($prefix, @name)"/>
                    </xsl:call-template>
                </xsl:when>
                <xsl:when test="local-name() = 'fieldset'">
                    <xsl:call-template name="compute-xpath">
                        <xsl:with-param name="fieldset" select="."/>
                        <xsl:with-param name="prefix" select="$prefix"/>
                    </xsl:call-template>
                </xsl:when>
                <xsl:otherwise><xsl:value-of select="concat($prefix, @name)"/></xsl:otherwise>
            </xsl:choose>
        </xsl:for-each>
    </xsl:template>
    
    <xsl:template match="/view">
        <xml>
            <xsl:call-template name="card"/>
            
            <xsl:call-template name="content-metadata"/>
            <xsl:call-template name="content-tags"/>
            <xsl:call-template name="referencing-contents"/>
        </xml>
    </xsl:template>
    
    <xsl:template name="content-metadata">
        <xsl:apply-templates select="contentType/fieldset|contentType/metadata" mode="display"/>
    </xsl:template>
    
    <xsl:template name="referencing-contents">
        <div class="bloc referencing-contents">
            <h1><i18n:text i18n:catalogue="plugin.cms" i18n:key='UITOOL_DETAILS_REFERENCING_CONTENTS'/></h1>
            <xsl:choose>
                <xsl:when test="content/referencing-contents/@count = 0">
                    <i18n:text i18n:catalogue="plugin.cms" i18n:key="UITOOL_DETAILS_REFERENCING_CONTENTS_NO_CONTENTS"/>
                </xsl:when>
                <xsl:otherwise>
                    <i18n:translate>
                        <i18n:text i18n:catalogue="plugin.cms" i18n:key="UITOOL_DETAILS_REFERENCING_CONTENTS_NB_CONTENTS"/>
                        <i18n:param><xsl:value-of select="content/referencing-contents/@count"/></i18n:param>
                    </i18n:translate>
                    <xsl:if test="content/workflow-step/@workflowName != 'reference-table'">
                        <ul>
                            <xsl:for-each select="content/referencing-contents/referencing-content">
                                <xsl:sort select="@title"/>
                                <li><a href="{resolver:resolve('content', @id)}"><xsl:value-of select="@title"/></a></li>
                            </xsl:for-each>
                        </ul>
                        <xsl:if test="content/referencing-contents/@hasOther = 'true'">
                            <em><i18n:text i18n:catalogue="plugin.cms" i18n:key="UITOOL_DETAILS_REFERENCING_CONTENTS_MORE"/></em>
                        </xsl:if>
                    </xsl:if>
                </xsl:otherwise>
            </xsl:choose>
        </div>
    </xsl:template>
    
    <xsl:template name="content-tags">
        <xsl:if test="content/tags/tag">
            <div class="bloc content-tags">
                <h1><i18n:text i18n:catalogue="plugin.cms" i18n:key='UITOOL_DETAILS_CONTENT_TAGS'/></h1>
                
                <ul>
                    <xsl:for-each select="content/tags/tag">
                        <li>
                            <xsl:value-of select="."/>
                        </li>
                    </xsl:for-each>
                </ul>
            </div>
        </xsl:if>
    </xsl:template>
    
    <xsl:template name="card">
        <div class="details-view-card">
            <p>
                <span class="title"><i18n:text i18n:catalogue="plugin.cms" i18n:key="UITOOL_DETAILS_CONTENT_NAME"/><xsl:text>&#160;</xsl:text></span>
                <span><xsl:value-of select="content/@name"/></span>
            </p>    
            <p>
                <span>
                    <span class="title"><i18n:text i18n:catalogue="plugin.cms" i18n:key="UITOOL_DETAILS_CONTENT_ID"/><xsl:text>&#160;</xsl:text></span>
                    <button class="copy-button" title="plugin.cms:UITOOL_DETAILS_CONTENT_COPY_ID_HINT" i18n:attr="title" type="button" onclick="javascript:Ametys.plugins.cms.content.tool.PropertiesTool.copyToClipboard(this, '{content/@id}')">
                       <span class="ametysicon-document28" ></span>
                    </button>    
                    <xsl:choose>
                        <xsl:when test="content/@path and content/repository/rights/access='true'">
                           <a href="javascript:void(0)" onclick="Ametys.openWorkspaceTool('repository', 'uitool-repository-ametysobject-metadata', {{id: '{content/@id}'}})">
                               <span><xsl:value-of select="content/@id"/></span>
                           </a>
                       </xsl:when>
                        <xsl:otherwise><span><xsl:value-of select="content/@id"/></span></xsl:otherwise>
                    </xsl:choose>
                </span>
            </p>    
            <xsl:if test="content/@uuid">
                <p>
                    <span>
                        <span class="title"><i18n:text i18n:catalogue="plugin.cms" i18n:key="UITOOL_DETAILS_CONTENT_UUID"/><xsl:text>&#160;&#160;</xsl:text></span>
                        <button class="copy-button" title="plugin.cms:UITOOL_DETAILS_CONTENT_COPY_UUID_HINT" i18n:attr="title" type="button" onclick="javascript:Ametys.plugins.cms.content.tool.PropertiesTool.copyToClipboard(this, '{content/@uuid}')">
                           <span class="ametysicon-document28" ></span>
                        </button>
                        <xsl:choose>
                            <xsl:when test="content/@path and content/repository/rights/access='true'">
                              <a href="javascript:void(0)" onclick="Ametys.openWorkspaceTool('repository', 'uitool-repository-nodeproperties', {{id : '{content/@uuid}', workspaceName: 'default', path: '{content/@path}'}})">
                                  <span><xsl:value-of select="content/@uuid"/></span>
                              </a>
                          </xsl:when>
                            <xsl:otherwise><span><xsl:value-of select="content/@uuid"/></span></xsl:otherwise>
                        </xsl:choose>
                    </span>
                </p>
            </xsl:if>
            
            <p>
                <span class="title"><i18n:text i18n:catalogue="plugin.cms" i18n:key="UITOOL_DETAILS_CONTENT_LANGUAGE"/><xsl:text>&#160;&#160;</xsl:text></span>
                <span style="background: url('{$contextPath}{content/content-language/@icon-small}') 0 0 no-repeat; padding-left: 20px">
                    <xsl:choose>
                        <xsl:when test="content/content-language != ''"><xsl:value-of select="content/content-language"/></xsl:when>
                        <xsl:otherwise><xsl:value-of select="content/content-language/@code"/></xsl:otherwise>
                    </xsl:choose>
                </span>
            </p>
            
            <p>
                <span class="title"><i18n:text i18n:catalogue="plugin.cms" i18n:key="UITOOL_DETAILS_CONTENT_WORKFLOW_STEP"/><xsl:text>&#160;&#160;</xsl:text></span>
                <span style="background: url('{$contextPath}{content/workflow-step/@icon-small}') left center no-repeat; padding-left: 20px; line-height: 16px; display: inline-block;"><xsl:value-of select="content/workflow-step"/></span>
            </p>
            
            <p>
                <span class="title"><i18n:text i18n:catalogue="plugin.cms" i18n:key="UITOOL_DETAILS_CONTENT_HAS_LIVE"/><xsl:text>&#160;&#160;</xsl:text></span>
                <span i18n:attr="title">
                    <xsl:choose>
                        <xsl:when test="content/@has-live = 'true'">
                            <xsl:attribute name="class">ametysicon-sign-raw-check</xsl:attribute>
                            <xsl:attribute name="title">plugin.cms:UITOOL_SEARCH_BOOLEAN_YES</xsl:attribute>
                        </xsl:when>
                        <xsl:otherwise>
                            <xsl:attribute name="class">ametysicon-sign-raw-cross</xsl:attribute>
                            <xsl:attribute name="title">plugin.cms:UITOOL_SEARCH_BOOLEAN_NO</xsl:attribute>
                        </xsl:otherwise>
                    </xsl:choose>
                </span>
            </p>
            
            <xsl:call-template name="content-types"/>
            <xsl:call-template name="mixins"/>
            <xsl:call-template name="input-text-clipboard"/>
        </div>
    </xsl:template>
    
    <xsl:template name="input-text-clipboard">
       <input type="text" id="input-text-clipboard" value="" style="opacity: 0; position: absolute; top: -1000px;" />
    </xsl:template>
    
    <!-- Content Types -->
    <xsl:template name="content-types">
        <p>
            <span class="title">
                <xsl:choose>
                    <xsl:when test="count(content/content-types/content-type) = 1"><i18n:text i18n:catalogue="plugin.cms" i18n:key="UITOOL_DETAILS_CONTENT_CONTENT_TYPE"/></xsl:when>
                    <xsl:otherwise><i18n:text i18n:catalogue="plugin.cms" i18n:key="UITOOL_DETAILS_CONTENT_CONTENT_TYPES"/></xsl:otherwise>
                </xsl:choose>
            </span>
            
            <xsl:if test="content/content-types/content-type/content-type">
                <xsl:text> </xsl:text><a class="showhide" href="javascript:Ametys.plugins.cms.content.tool.PropertiesTool.showHideSubTypes()">(...)</a>
            </xsl:if>
        </p>
        
        <ul class="content-types">
            <xsl:for-each select="content/content-types/content-type">
                <li>
                    <xsl:choose>
                        <xsl:when test="@icon-glyph"><span class="icon {@icon-glyph} {@icon-decorator}"><xsl:comment></xsl:comment></span></xsl:when>
                        <xsl:otherwise><img src="{$contextPath}{@icon}" alt="" title="{label}"/></xsl:otherwise>
                    </xsl:choose>
                    <xsl:value-of select="label"/>
                    <xsl:if test="content-type">
                        <ul class="subtypes hidden">
                            <xsl:apply-templates select="content-type"/>
                        </ul>
                    </xsl:if>
                </li>
            </xsl:for-each>
        </ul>
    </xsl:template>
    
    <!-- Mixins -->
    <xsl:template name="mixins">
        <xsl:if test="content/mixins/mixin">
            <p>
                <span class="title">
                    <xsl:choose>
                        <xsl:when test="count(content/mixins/mixin) = 1"><i18n:text i18n:catalogue="plugin.cms" i18n:key="UITOOL_DETAILS_CONTENT_MIXIN"/></xsl:when>
                        <xsl:otherwise><i18n:text i18n:catalogue="plugin.cms" i18n:key="UITOOL_DETAILS_CONTENT_MIXINS"/></xsl:otherwise>
                    </xsl:choose>
                </span>
                
                <xsl:if test="content/mixins/mixin/mixin">
                    <xsl:text> </xsl:text><a class="showhide" href="javascript:Ametys.plugins.cms.content.tool.PropertiesTool.showHideMixins()">(...)</a>
                </xsl:if>
            </p>
            <ul>
                <xsl:for-each select="content/mixins/mixin">
                    <li>
                        <img src="{$contextPath}{@icon}" alt="" title="{label}"/><xsl:value-of select="label"/>
                        <xsl:if test="mixin">
                            <ul class="mixins hidden">
                                <xsl:apply-templates select="mixin"/>
                            </ul>
                        </xsl:if>
                    </li>
                </xsl:for-each>
            </ul>
        </xsl:if>
    </xsl:template>
    
    <xsl:template match="content-type|mixin">
        <li>
            <xsl:attribute name="class">content-type<xsl:if test="position() = last()"> last</xsl:if></xsl:attribute>
            
            <xsl:choose>
                <xsl:when test="@icon-glyph"><span class="icon {@icon-glyph} {@icon-decorator}"><xsl:comment></xsl:comment></span></xsl:when>
                <xsl:otherwise><img src="{$contextPath}{@icon}" alt="" title="{label}"/></xsl:otherwise>
            </xsl:choose>
                    
            <xsl:value-of select="label"/>
            
            <xsl:if test="content-type|mixin">
                <ul>
                    <xsl:apply-templates select="content-type|mixin"/>
                </ul>
            </xsl:if>
        </li>
    </xsl:template>
    
    <xsl:template match="fieldset" mode="display">
        
        <xsl:variable name="self" select="."/>
        <xsl:if test="cms:isNotFieldsetEmpty($self)">
            <p><strong><xsl:value-of select="label"/></strong></p>
            
            <div class="sub">
                <xsl:apply-templates select="fieldset|metadata" mode="display"/>
            </div>
        </xsl:if>
    </xsl:template>
    
    <xsl:template match="medatata[@type='composite']" mode="display">
        <xsl:param name="name" select="@name"/>
        <xsl:param name="value" select="/view/content/metadata/*[local-name() = $name]"/>
         
        <xsl:if test="$value/*">
            <p><strong><xsl:value-of select="label"/></strong></p>
            <div class="sub">
                <xsl:apply-templates select="medatata" mode="display"/>
            </div>
        </xsl:if>
    </xsl:template>
    
    <xsl:template match="metadata[@type='repeater']" mode="display">
        <xsl:param name="name" select="@name"/>
        <xsl:param name="value" select="/view/content/metadata/*[local-name() = $name]"/>
        
        <xsl:if test="$value/@entryCount != '0'">
            <p><strong><xsl:value-of select="label"/></strong></p>
                        
            <xsl:variable name="repeaterDef" select="."/>
                
            <xsl:for-each select="$value/entry">
                <div class="sub">
                    <p class="entry"><i18n:text i18n:catalogue="plugin.cms" i18n:key='UITOOL_DETAILS_REPEATER_ENTRY'/><xsl:text> </xsl:text><xsl:value-of select="@name"/></p>
                    <div class="subsub">
                        <xsl:for-each select="node()">
                            <xsl:variable name="subname" select="local-name()"/>
                            <xsl:apply-templates select="$repeaterDef/metadata[@name = $subname]" mode="display">
                                <xsl:with-param name="value" select="."/>
                            </xsl:apply-templates>
                        </xsl:for-each>
                    </div>
                </div>
            </xsl:for-each>
        </xsl:if>
    </xsl:template>
    
    <xsl:template match="metadata" mode="display">
        <xsl:param name="name" select="@name"/>
        <xsl:param name="value" select="/view/content/metadata/*[local-name() = $name]"/>
        
        <xsl:if test="$value">
            <p>
                <strong><xsl:value-of select="label"/></strong><br/>
                
                <xsl:variable name="self" select="."/>
                
                <xsl:for-each select="$value">
                    <xsl:variable name="name" select="local-name()"/>
                    <xsl:apply-templates select="$self" mode="value">
                        <xsl:with-param name="value" select="."/>
                    </xsl:apply-templates>
                    <xsl:if test="position() != last()"><xsl:text>, </xsl:text></xsl:if>
                </xsl:for-each>
            </p>
        </xsl:if>
    </xsl:template>
    
    <xsl:template match="metadata[@type='content']" mode="value">
        <xsl:param name="value"/>
        
        <xsl:variable name="contentId" select="$value/@id" />
        <xsl:if test="$contentId != ''">
            <xsl:choose>
                <xsl:when test="ametys:isReferenceTableContent($contentId)">
                    <xsl:value-of select="$value/@title"/>
                </xsl:when>
                <xsl:otherwise>
                    <a href="{resolver:resolve('content', $contentId)}">
                        <xsl:value-of select="$value/@title"/>
                    </a>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:if>
    </xsl:template>
    
    <xsl:template match="metadata[@type='date']" mode="value">
        <xsl:param name="value"/>
        
        <i18n:date src-pattern="yyyy-MM-dd'T'HH:mm:ss.SSSXXX" pattern="long">
            <xsl:value-of select="$value"/>
        </i18n:date>
    </xsl:template>
    
    <xsl:template match="metadata[@type='datetime']" mode="value">
        <xsl:param name="value"/>
        
        <i18n:date-time src-pattern="yyyy-MM-dd'T'HH:mm:ss.SSSXXX" pattern="long">
            <xsl:value-of select="$value"/>
        </i18n:date-time>
    </xsl:template>
    
    <xsl:template match="metadata[@type='reference']" mode="value">
        <xsl:param name="value"/>
        
        <a>
            <xsl:attribute name="href"><xsl:value-of select="$value"/></xsl:attribute>
            <xsl:value-of select="$value"/>
        </a>
    </xsl:template>
        
    <xsl:template match="metadata[@type='file']" mode="value">
        <xsl:param name="value"/>
        
        <a href="{resolver:resolve($value/@type, $value/@path, 'true')}" title="{$value/@filename} ({$value/@size})">
            <xsl:value-of select="$value/@filename"/>
        </a>
    </xsl:template>
    
    <xsl:template match="metadata[@type='geocode']" mode="value">
        <xsl:param name="value"/>
        
        <xsl:value-of select="concat(substring-before($value/@latitude, '.'), '.', substring(substring-after($value/@latitude, '.'), 1, 4))"/><xsl:text>°N , </xsl:text><xsl:value-of select="concat(substring-before($value/@longitude, '.'), '.', substring(substring-after($value/@longitude, '.'), 1, 4))"/><xsl:text>°E</xsl:text>
    </xsl:template>
    
    <xsl:template match="metadata[@type='boolean']" mode="value">
        <xsl:param name="value"/>
        
        <xsl:choose>
            <xsl:when test="$value = 'true'"><i18n:text i18n:catalogue="plugin.cms" i18n:key="UITOOL_DETAILS_BOOLEAN_TRUE"/></xsl:when>
            <xsl:otherwise><i18n:text i18n:catalogue="plugin.cms" i18n:key="UITOOL_DETAILS_BOOLEAN_FALSE"/></xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    
    <xsl:template match="metadata" mode="value">
        <xsl:param name="value"/>
        
        <xsl:value-of select="$value"/>
    </xsl:template>
    
    <xsl:template match="*" mode="value">
        <not>
            <xsl:copy-of select="."></xsl:copy-of>
        </not>
    </xsl:template>
    
</xsl:stylesheet>