<?xml version="1.0" encoding="UTF-8"?>
<!--
   Copyright 2013 Anyware Services

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
   -->
<xsl:stylesheet version="1.0"
    			xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    			xmlns:i18n="http://apache.org/cocoon/i18n/2.1"
    			xmlns:su="org.apache.commons.lang3.StringUtils"
                xmlns:resolver="org.ametys.cms.transformation.xslt.ResolveURIComponent"
    			xmlns:exslt="http://exslt.org/common"
    			extension-element-prefixes="su"> 
                              
    <xsl:variable name="separator"><xsl:text>;</xsl:text></xsl:variable>
    <xsl:variable name="multi-value-separator"><xsl:text>
</xsl:text></xsl:variable>
	<xsl:variable name="double-quotes"><xsl:text>"</xsl:text></xsl:variable>
	<xsl:variable name="two-double-quotes"><xsl:text>""</xsl:text></xsl:variable>

	<xsl:template match="/export">
		<xsl:call-template name="headers"/>
		
		<xsl:for-each select="contents/content">
			<xsl:call-template name="content-line">
         		<xsl:with-param name="contentId" select="@id"/>
         		<xsl:with-param name="metadatas" select="."/>
			</xsl:call-template>     
        </xsl:for-each>
	</xsl:template>
	
	<xsl:template name="headers">
		<xsl:for-each select="columns/column">
       		<xsl:value-of select="."/><xsl:value-of select="$separator"/>
       	</xsl:for-each><xsl:text>
</xsl:text>
	</xsl:template>
	
	<xsl:template name="content-line">
    	<xsl:param name="contentId"/>
    	<xsl:param name="metadatas"/>
    	
		<xsl:for-each select="/export/columns/column">
        	<xsl:variable name="id" select="@id"/>
        	<xsl:variable name="type" select="@type"/>
            
            <xsl:text>"</xsl:text>
           	<xsl:variable name="values">
           		<xsl:apply-templates select="$metadatas" mode="get-values">
					<xsl:with-param name="search-tag" select="@id"/>
           		</xsl:apply-templates>
           	</xsl:variable>
			<xsl:for-each select="exslt:node-set($values)/*">
           		<xsl:call-template name="content-value">
           			<xsl:with-param name="type" select="$type"/>
           			<xsl:with-param name="value" select="."/>
           		</xsl:call-template>
                <xsl:if test="position() != last()"><xsl:value-of select="$multi-value-separator"/></xsl:if>
           	</xsl:for-each>
           	<xsl:text>"</xsl:text>
           	<xsl:value-of select="$separator"/>
		</xsl:for-each><xsl:text>
</xsl:text>
    </xsl:template>
	
    <xsl:template name="content-value">
        <xsl:param name="type"/>
        <xsl:param name="value"/>
		<xsl:choose>
			<xsl:when test="$type = 'DATETIME' and $value != ''">
                <i18n:date-time src-pattern="yyyy-MM-dd'T'HH:mm:ss.SSSXXX" pattern="short" value="{$value}"/>
			</xsl:when>
			<xsl:when test="$type = 'DATE' and $value != ''">
                <i18n:date src-pattern="yyyy-MM-dd'T'HH:mm:ss.SSSXXX" pattern="short" value="{$value}"/>
			</xsl:when>
			<xsl:when test="$type = 'GEOCODE' and @latitude != '' and @longitude != ''">
				<xsl:value-of select="@latitude" />
				<xsl:text>, </xsl:text>
				<xsl:value-of select="@longitude" />
			</xsl:when>
			<xsl:when test="$type = 'BOOLEAN' and $value = 'true'">
				<i18n:text i18n:key="PLUGINS_CMS_SEARCH_EXPORT_BOOLEAN_TRUE" i18n:catalogue="plugin.cms"/>
			</xsl:when>
			<xsl:when test="$type = 'BOOLEAN' and $value = 'false'">
				<i18n:text i18n:key="PLUGINS_CMS_SEARCH_EXPORT_BOOLEAN_FALSE" i18n:catalogue="plugin.cms"/>
			</xsl:when>
			<xsl:when test="$type = 'CONTENT'">
				<xsl:value-of select="su:replace($value/@title, $double-quotes, $two-double-quotes)" />
			</xsl:when>
            <xsl:when test="$type = 'FILE'">
                <xsl:value-of select="$value/@filename"/>
            </xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="su:replace($value, $double-quotes, $two-double-quotes)" />
			</xsl:otherwise>
		</xsl:choose>
    </xsl:template>
    
    <xsl:template match="*" mode="get-values">
    	<xsl:param name="search-tag"/>
    	
    	<xsl:choose>
			<xsl:when test=".//*[@fullModelPath=$search-tag]">
			    <xsl:copy-of select=".//*[@fullModelPath=$search-tag]"/>
			</xsl:when>
    		<xsl:when test="contains($search-tag, '/')">
    			<xsl:variable name="subtag-name" select="substring-before($search-tag, '/')"/>
    			<xsl:apply-templates select="*[local-name() = $subtag-name]" mode="get-values">
    				<xsl:with-param name="search-tag" select="substring-after($search-tag, '/')"/>
    			</xsl:apply-templates>
    		</xsl:when>
    		<xsl:otherwise><xsl:copy-of select="*[local-name() = $search-tag]"/></xsl:otherwise>
    	</xsl:choose>
    </xsl:template>
</xsl:stylesheet>
