/*
 *  Copyright 2021 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

/**
 * This class provides a widget to edit a rich-text.<br>
 * 
 * This widget overrides the runtime {@link Ametys.form.field.RichText} to handle specific editor styles in content edition mode
 * 
 */
Ext.define('Ametys.cms.form.field.RichText', {
    override : 'Ametys.form.field.RichText',
    
    getTinyMCEToolbar: function(config)
    {
        if (!config.toolbar)
        {
            config.toolbar = Ametys.form.field.RichText.DEFAULT_TOOLBAR_BUTTONS
                .replace("alignleft", "ametysalignleft")
                .replace("aligncenter", "ametysaligncenter")
                .replace("alignright", "ametysalignright")
                .replace("alignjustify", "ametysalignjustify");
                
            if (config.contentId || config.contentInfo && config.contentInfo.contentId)
	        {
	            config.toolbar += ' | insertlinkmenu insertimage ametystablebutton';
	        }
	        else
	        {
	            config.toolbar += ' | insertlinkmenu ametystablebutton';
	        }
        }
        return this.callParent(arguments);
    },
    
    getTinyMCEPlugins: function(config)
    {
        if (!config.tinyMCEPlugins)
        {
            if (config.contentId || config.contentInfo && config.contentInfo.contentId)
            {
                config.tinyMCEPlugins = Ametys.form.field.RichText.DEFAULT_TINYMCE_PLUGINS + ',ametysbasicstyles,ametyslists,ametysstyles,ametyslinks,ametysimages,ametystables';
            }
            else
            {
                config.toolbar = Ametys.form.field.RichText.DEFAULT_TINYMCE_PLUGINS + ',ametysbasicstyles,ametyslists,ametysstyles,ametyslinks,ametystables';
            }
        }
        
        return this.callParent(arguments);
    }
});
    