/*
 *  Copyright 2017 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

/**
 * This class provides a widget to edit a string in multiple locales.<br>
 * 
 * This widget overrides the runtime {@link Ametys.form.widget.MultilingualString} to get languages for language manager.
 * 
 */
Ext.define('Ametys.cms.form.widget.MultilingualString', {
    override : 'Ametys.form.widget.MultilingualString',
    
    /**
     * @private
     * @property {Object[]} A array of available languages
     */
    _languages: null,
    
    loadAvailableLanguages: function(callback, scope)
    {
        if (!this._languages)
        {
            Ametys.data.ServerComm.callMethod({
	            role: "org.ametys.cms.languages.LanguagesManager",
	            methodName: "getAvailableLanguagesAsJsonObject",
	            parameters: [],
	            callback: {
	                handler: function(languages) {
                        this._languages = languages;
                        callback.call(scope || this, this._languages);  
                    },
	                scope: this
	            },
	            errorMessage: true
	        });
        }
        else
        {
            callback.call(scope || this, this._languages);  
        }
    },
    
    afterRender: function()
    {
        this.callParent(arguments);
        
        // Try to get current language current content target
        var contentTarget = Ametys.message.MessageBus.getCurrentSelectionMessage().getTarget(Ametys.message.MessageTarget.CONTENT);
        if (contentTarget && contentTarget.getParameters().lang)
        {
            this.defaultLanguage = contentTarget.getParameters().lang;
        }
        else
        {
            this.defaultLanguage = Ametys.cms.language.LanguageDAO.getCurrentLanguage() || Ametys.LANGUAGE_CODE;
        }
    }
});
    