/*
 *  Copyright 2014 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

/**
 * Interface allowing navigation on elements of a tool (previous, next, first, last).<br/>
 * You have to implement {@link #previousElement}, {@link #nextElement}, {@link #firstElement}, {@link #lastElement}, {@link #hasPrevious} and {@link #hasNext}
 */
Ext.define('Ametys.cms.navigation.NavigationElementTool', {
	
	/** 
	 * Navigate to the previous element.
	 * @param {String} elementId The id of the current element 
	 */
	previousElement: function (elementId) 
	{ 
		throw 'Unimplemented method #previousElement'; 
	},
	
	/** 
	 * Navigate to the next element.
	 * @param {String} elementId The id of the current element 
	 */
	nextElement: function(elementId)
	{ 
		throw 'Unimplemented method #nextElement'; 
	},
	
	/** 
	 * Determine if there is a previous element 
	 * @param {String} elementId The id of the current element 
	 * @returns true if this element is not the first of its tool, false otherwise
	 */
	hasPrevious: function(elementId)
	{ 
		throw 'Unimplemented method #hasPrevious'; 
	},
	
	/** 
	 * Determine if there is a previous element  
	 * @param {String} elementId The id of the current element 
	 * @returns true if this element is not the last of its tool, false otherwise
	 */
	hasNext: function(elementId)
	{ 
		throw 'Unimplemented method #hasNext'; 
	},
	
	/** 
	 * Determine if a element exists
 	 * @param {String} elementId The id of the current element 
 	 * @returns true if this element exists in the store of its tool, false otherwise
	 */
	hasElement: function(elementId) 
	{ 
		throw 'Unimplemented method #hasElement'; 
	},
	
	/** 
	 * Navigate to the first element. 
	 * @param {String} elementId The id of the current element
	 */
	firstElement: function(elementId)
	{ 
		throw 'Unimplemented method #firstElement'; 
	},
	
	/** 
	 * Navigate to the last element. 
	 * @param {String} elementId The id of the current element 
	*/
	lastElement: function(elementId)
	{ 
		throw 'Unimplemented method #lastElement'; 
	}
});
