/*
 *  Copyright 2013 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

/**
 * This factory creates Ametys.message.MessageTarget for an archived content. See #createTargets.
 * @private
 */
Ext.define('Ametys.plugins.cms.content.ArchivedContentMessageTargetFactory', {
    extend: 'Ametys.message.factory.DefaultMessageTargetFactory',
    
    /**
     * Create the targets for a message
     * @param {Object} parameters The parameters needed by the factory to create the message. Can not be null.
     * @param {String[]} parameters.ids The content's identifiers. Must be present if contents is empty
     * @param {Ametys.cms.content.Content[]} parameters.contents The contents themselves. Must be present if ids is empty
     * @param {Function} callback The callback function called when the targets are created. Parameters are
     * @param {Ametys.message.MessageTarget[]} callback.targets The targets created. Cannot be null.
     */
    createTargets: function(parameters, callback)
    {
        var targets = [];
        
        if (parameters.ids)
        {
            for (var i=0; i < parameters.ids.length; i++)
            {
                targets.push(Ext.create('Ametys.message.MessageTarget', {
                    id: this.getId(),
                    parameters: {id: parameters.ids[i]}
                }));    
            }
        }
        
        callback(targets);
    }
    
});
