/*
 *  Copyright 2013 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

/**
 * Singleton class to switch between tab policy in the form edition panel.
 * @private
 */
Ext.define('Ametys.plugins.cms.content.actions.EditionTabPolicyActions', {
	singleton: true,
	
	/**
	 * Action that change the current edition tab policy.
	 * Function to be called by the controller.
	 * @param {Ametys.ribbon.element.ui.ButtonController} controller The controller calling this function
	 */
	switchPolicy: function (controller)
	{
		var tabPolicy = controller.getInitialConfig('tab-policy');
		Ametys.userprefs.UserPrefsDAO.saveValues({'edition-tab-policy': tabPolicy}, Ext.bind(this._switchPolicyCb, this, [tabPolicy], 3));
	},
	
	/**
	 * @private
	 * Callback after the new policy has been saved server side (as an user pref)
	 * @param {Boolean} success True is save worked fine.
	 * @param {Object} errors Association (preference name, error message)
	 * @param {String} tabPolicy The name of the new display tab policy.
	 */
	_switchPolicyCb: function(success, errors, tabPolicy)
	{
		// Handling errors.
		if (!success && errors)
		{
			var details = '';
			for (var error in errors)
			{
				details += error + ": " + errors[error] + "\n";
			}

			Ametys.log.ErrorDialog.display({
				title: "{{i18n PLUGINS_CMS_BO_USER_PREFERENCES_TAB_POLICY_FAILURE_TITLE}}",
				text: "{{i18n PLUGINS_CMS_BO_USER_PREFERENCES_TAB_POLICY_FAILURE_DESC}}",
				details: details,
				category: this.self.getName() 
			});
		}
		else
		{
			Ext.create('Ametys.message.Message', {
                type: Ametys.message.Message.MODIFIED,
                
                targets: {
                    id: Ametys.message.MessageTarget.USER_PREFS,
                    parameters: { 
                        context: Ametys.userprefs.UserPrefsDAO.getDefaultPrefContext()
                    }
                }
            });
		}
	}
});
