/*
 *  Copyright 2014 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

/**
 * Singleton class dispatching the navigation request to the appropriate tools.
 * @private
 */
Ext.define('Ametys.plugins.cms.content.actions.NavigateAction', {
	singleton: true,
	
	/**
	 * Calls the dispatcher, setting its navigationRequest to 'first' 
	 * @param {Ametys.ribbon.element.ui.ButtonController} controller the controller calling this function
	 */
	navigateFirst: function(controller)
	{
		this._navigate(controller,'first');
	},
	
	/**
	 * Calls the dispatcher, setting its navigationRequest to 'previous' 
	 * @param {Ametys.ribbon.element.ui.ButtonController} controller the controller calling this function
	 */
	navigatePrevious: function(controller)
	{
		this._navigate(controller, 'previous');
	},
	
	/**
	 * Calls the dispatcher, setting its navigationRequest to 'next' 
	 * @param {Ametys.ribbon.element.ui.ButtonController} controller the controller calling this function
	 */
	navigateNext: function(controller)
	{
		this._navigate(controller, 'next');
	},
	
	/**
	 * Calls the dispatcher, setting its navigationRequest to 'last' 
	 * @param {Ametys.ribbon.element.ui.ButtonController} controller the controller calling this function
	 */
	navigateLast: function(controller)
	{
		this._navigate(controller, 'last');
	},
	
	/**
	 * @private
	 * This function calls the right navigation method in the opened tool.
	 * @param {Ametys.ribbon.element.ui.ButtonController} controller The controller calling this function
	 * @param {String} navigationRequest 'first' || 'previous' || 'next' || 'last'
	 */
	_navigate: function(controller, navigationRequest)
	{
		var target = controller.getMatchingTargets()[0];
		if (target != null)
		{
			var contentId = target.getParameters().id,
				contentTool = Ametys.tool.ToolsManager.getTool('uitool-content$' + contentId);
			
			if (contentTool != null)
			{
				var referrerTool = Ametys.tool.ToolsManager.getTool(contentTool.getToolReferrerId());
				if (referrerTool != null)
				{
					switch (navigationRequest)
					{
						case 'first':
							referrerTool.firstElement(contentId);
							break;
							
						case 'previous':
							referrerTool.previousElement(contentId);
							break;
							
						case 'next':
							referrerTool.nextElement(contentId);
							break;
							
						case 'last':
							referrerTool.lastElement(contentId);
							break;
							
						default:
							throw 'Unknown navigation request ' + navigationRequest;
					}
				}
			}
		}
	}
});