/*
 *  Copyright 2013 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

/**
 * This class controls a ribbon button handling an edition form tab policy.
 * This controller handle (un)toggling itself.
 * @private
 */
Ext.define('Ametys.plugins.cms.content.controller.EditionTabPolicyButtonController', {
	extend: 'Ametys.ribbon.element.ui.ButtonController',
	
	/**
	 * @cfg {String} tab-policy (required) The edition form tab policy name.
	 */
	/**
	 * @cfg {String} tab-policy-selected-description Additional description for the button controller
	 * displayed when the policy of this controller is selected.
	 */
	
	constructor: function(config)
	{
		// Do not allow 'toggle-enabled' and 'toggle-state' parameters.
		config['toggle-enabled'] = 'false';
		config['toggle-state'] = 'false';
		
		this.callParent(arguments);
		
		this._currentPolicy = Ametys.userprefs.UserPrefsDAO.getValue('edition-tab-policy') || 'default';
		this.refresh(); // initialization.
		
		// Message bus listeners.
		Ametys.message.MessageBus.on(Ametys.message.Message.MODIFIED, this._onUserPrefsChanged, this);
	},
	
	/**
	 * Listener when the edition tab policy has changed.
	 * Will update the state of the button effectively.
	 * @param {Ametys.message.Message} message The edition tab policy changed message.
	 * @private
	 */
	_onUserPrefsChanged: function(message)
	{
		var target = message.getTarget(Ametys.message.MessageTarget.USER_PREFS);
		if (target && this._currentPolicy != Ametys.userprefs.UserPrefsDAO.getValue('edition-tab-policy'))
		{
			this._currentPolicy = Ametys.userprefs.UserPrefsDAO.getValue('edition-tab-policy');
			this.refresh();
		}
	},
	
	updateState: function()
	{
		// Button is disabled and toggled when the policy match.
		var policyMatch = this.getInitialConfig("tab-policy") === this._currentPolicy;
		
		this.setDisabled(policyMatch);
		this.toggle(policyMatch);
		
		this.setAdditionalDescription(policyMatch ? this.getInitialConfig("tab-policy-selected-description") : '');
	}
});
