/*
 *  Copyright 2013 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

/**
 * This class controls a ribbon button handling an edition form tab policy.
 * This controller handle (un)toggling itself.
 * @private
 */
Ext.define('Ametys.plugins.cms.content.controller.EditionTabPolicyGalleryController', {
	extend: 'Ametys.ribbon.element.ui.ButtonController',
	
	/**
	 * @cfg {String} no-tab-in-metadataset-description Additional description when no tabs are found
	 * in the metadataset of the edited content.
	 */
	
	additionalErrorDescriptionOnSelectionChanged: function(targets)
	{
		if (targets[0].getSubtargets("form"))
		{
			return null;
		}
		else
		{
			return "";
		}
	},
	
	updateState: function()
	{
		this._hasTab(this.getMatchingTargets()[0]);
	},
	
	/**
	 * Call the server to determines if the current content has at least one tab in its metadataset.
	 * @param {Ametys.message.MessageTarget} target The target to test against.
	 * @private
	 */
	_hasTab: function(target)
	{
		this.disable();

		var contentId = target.getParameters().id;
		var contentTool = Ametys.tool.ToolsManager.getTool('uitool-content$' + contentId);
		if (contentTool != null)
		{
			var viewName = contentTool.getViewName();
            var fallbackViewName = contentTool.getFallbackViewName();
			
			this.serverCall ('getStatus', [contentId, viewName, fallbackViewName], this._hasTabCb, { refreshing: true });
		}
	},
	
	/**
	 * @private
	 * Callback function called when receiving the response to the 'get status' server call.
	 * @param params The JSON result 
	 */
	_hasTabCb: function(params)
	{
		if (params['has-tab'] === true)
		{
			this.enable();
			this.setAdditionalDescription('');
		}
		else
		{
			this.disable();
			this.setAdditionalDescription(this.getInitialConfig("no-tab-in-metadataset-description"));
		}
	}
});
