/*
 *  Copyright 2014 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

/**
 * @private
 * This is a controller to manage the state of the navigation buttons.
 */
Ext.define('Ametys.plugins.cms.content.controller.NavigationController', {
	extend: 'Ametys.ribbon.element.ui.ButtonController',

	/**
	 * @property {String} _selectionNavigationToolReferrrer the previously selected navigation tool referrer, equals null if there is none
	 * @private
	 */
	
	updateState: function()
	{
		// A content is selected
		var target = this.getMatchingTargets()[0],
			contentId = target.getParameters().id,
			contentTool = Ametys.tool.ToolsManager.getTool('uitool-content$' + contentId);

		if (contentTool != null)
		{
			var buttonId = this.getId();

			// The content has a tool referrer
			var	toolReferrerId = contentTool.getToolReferrerId();
			if (toolReferrerId == null)
			{
				this.disable();
				return;
			}
			
			// And the content tool has the focus
			if (!contentTool.hasFocus())
			{
				this.disable();
				return;
			}
			
			// The tool referrer is opened
			var referrerTool = Ametys.tool.ToolsManager.getTool(toolReferrerId);
			if (referrerTool == null)
			{
				this.disable();
				return;
			}
			
			// And has the NavigationElementTool mixin
			var mixins = referrerTool.mixins || {};
			if (mixins["Ametys.cms.navigation.NavigationElementTool"] == null)
			{
				this.disable();
				return;
			}
			
			// The content exists in the referrer tool's store
			if(!referrerTool.hasElement(contentId))
			{
				this.disable();
				return;
			}
		
			var functionName = this.getInitialConfig("enable-on-available-function");
			if (!eval('referrerTool.' + functionName + '(contentId)'))
			{
				this.disable();
				return;
			}
		}
		else
		{
			this.disable();
		}
	},
	
	areSameTargets: function(target1, target2)
	{
		var sameTargets = this.callParent(arguments);
		return sameTargets && Ametys.message.MessageBus.getCurrentSelectionMessage().getParameters()['navigation-tool-referrer'] == this._selectionNavigationToolReferrer;
	},
	
	_updateMatchingSelectionTargets: function(targets)
	{
		this.callParent(arguments);
		
		this._selectionNavigationToolReferrer = this._selectionMatchingTargets == targets ? Ametys.message.MessageBus.getCurrentSelectionMessage().getParameters()['navigation-tool-referrer'] : null;
	}
});

