/*
 *  Copyright 2022 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

/**
 * This is a controller for a button that is active when the selected content data is currently not opened.
 * Useful for a "Open content data" button.
 * @private
 */
Ext.define('Ametys.plugins.cms.content.controller.NotOpenedContentDataController', {
	extend: 'Ametys.plugins.cms.content.controller.SmartContentController',
	
	updateState : function()
	{
		// A content is selected: enable the button if its tool is closed.
		var target = this.getMatchingTargets()[0];
        
        var toolId = target.getParameters().id;
        if (target.getParameters().version)
        {
            toolId += "$" + target.getParameters().version;
        }
		var toolOpened = Ametys.tool.ToolsManager.getTool('uitool-content-data$' + toolId) != null;
		if (toolOpened)
		{
			this.disable();
            this.setAdditionalDescription('');
		}
		else
		{
			this.callParent(arguments);
		}
	},
    
    areSameTargets: function (target1, target2)
    {
        // Standard SmartContentController checks.
        var same = this.callParent(arguments);
        
        if (same)
        {
            // Check that the content versions are the same as well.
            return target1.getParameters().version == target2.getParameters().version;
        }
        
        return false;
    }
});

