/*
 *  Copyright 2017 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

/**
 * Convertor for SemanticAnnotation
 * @private
 */
Ext.define('Ametys.plugins.cms.editor.semanticannotation.SemanticAnnotationConvertor', {
    /**
     * @property {RegExp} _regexpSetContent The RegExp to use in setcontent method
     * @private
     */
    _regexpSetContent: /(<span[^>]+class=["']semantic["'][^>]*)>/g, 
    
    /**
     * Registered to intercept setContent on richtext
     * @param {Ametys.form.field.RichText} field The richtext to convert
     * @param {tinymce.Editor} editor The current richtext editor
     * @param {Object} object The object of value to be modified
     */
    onSetContent: function(field, editor, object)
    {
        var me = this;
        
        if (object.content)
        {
            object.content = object.content.replace(
                me._regexpSetContent, 
                function(s, m1) {
                    var annotationValue = /annotation=['"]([^'"]+)['"]/.test(s) ? RegExp.$1 : null;
                    
                    if (annotationValue && field.hasSemanticAnnotations())
                    {
                        var annotation = field.getSemanticAnnotation(annotationValue);
                        if (annotation != null)
                        {
                            return m1  + ' title="' + annotation.label + '">';  
                        }
                    }
                    else
                    {
                        return s;
                    }
                }
            );
        }
    }
});
