/*
 *  Copyright 2015 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
/**
 * Grammar for advanced search.
 * The goal is to build the syntax tree from the criteria list.
 * 
 * Tests:
 * (A && B)
 * (A || B)
 * (A && B && C && D)
 * (A || B || C || D)
 * (A && B && C) && (D)
 * (A || B || C) || (D)
 * (TEST1 || A && B || C) && (D || E && F && test2 || test3) || (G) || (H) && (I)
 */

start
  = orExpression

orExpression
  = left:andExpression "||" right:orExpression { return {type: 'or', expressions: [left, right]}; }
  / andExpression

andExpression
  = left:expression "&&" right:andExpression { return {type: 'and', expressions: [left, right]}; }
  / expression

expression
  = str
  / ws "(" ws exp:orExpression ws ")" ws {return exp;}

str
  = ws chars:[a-zA-Z0-9_\-\.]+ ws {return {type: 'criterion', id: chars.join('')};}

ws "whitespace" = [ \t\n\r]*
