/*
 *  Copyright 2014 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

/**
 * This class is the model for nodes of a tags tree.
 * @private
 */
Ext.define('Ametys.plugins.cms.tag.TagsTreePanel.TagNode', {
    extend : 'Ext.data.Model',

    fields : [ 'id',
               'name',
               'visibility',
               'color',
               'class',
               'isColorable',
               'title',
               'description', 
               'target',
               'target-info',
               {
                   name : 'text',
                   depends: ['title'],
                   calculate: function (data)
            	   {
                	   return data.title;
            	   }
               },
               
               {
            	   name: 'iconCls',
            	   depends: ['visibility', 'authorized', 'color'],
            	   calculate: function (data)
            	   {
                       var classText = "";
            		   if (data.root)
            	       {
            			   return 'a-tree-glyph ametysicon-tag25';
            	       }
            		   else if (data.type != 'provider' && data.visibility.toLowerCase() == 'private' && !data.authorized)
            		   {
            			   classText += 'a-tree-glyph tag-icon-unauthorized ametysicon-object-lock-closed';
            		   }
            		   else if (data.type != 'provider' && data.visibility.toLowerCase() == 'private')
            		   {
            			   classText += 'a-tree-glyph tag-icon-private ametysicon-object-lock-closed';
            		   }
            		   else
            		   {
            			   classText += 'a-tree-glyph tag-icon ametysicon-label49';
            		   }
            		   
            		   if (data.type != 'provider' && data.isColorable)
            		   {
                		   if (data.color)
                		   {
                               classText += ' ' + data.class + "-" + data.color;
                           }
                           else
                           {
                               classText += ' ' + data.class + '-default';
                           }
                       }
                       
                       return classText;
            	   }
               },
               {
            	   name: 'tooltipIconCls',
            	   depends: ['visibility', 'authorized'],
            	   calculate: function (data)
            	   {
            		   if (data.root)
            	       {
            			   return 'ametysicon-tag25';
            	       }
            		   else if (data.type != 'provider' && data.visibility.toLowerCase() == 'private' && !data.authorized)
            		   {
            			   return 'tag-icon-unauthorized ametysicon-label49 decorator-ametysicon-lock81';
            		   }
            		   else if (data.type != 'provider' && data.visibility.toLowerCase() == 'private')
            		   {
            			   return 'tag-icon-private ametysicon-label49 decorator-ametysicon-lock81';
            		   }
            		   else
            		   {
            			   return 'tag-icon ametysicon-label49';
            		   }
            	   }
               },
               { name: 'disabled', type: 'boolean', defaultValue: false },
               { name: 'authorized', type: 'boolean', defaultValue: true },
               {
                   name: 'cls',
                   depends: ['authorized'],
                   calculate: function (data)
                   {
                       return data.authorized === false ? 'disabled' : '';
                   }
               },
               { 
                   name : 'creationAllowed',
                   type: 'boolean',
                   defaultValue: null
               },
               { name: 'type', defaultValue: 'tag'}
             ]
});