/*
 *  Copyright 2016 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
(function(mod) {
    if (typeof exports == "object" && typeof module == "object") // CommonJS
        mod(require("../../lib/codemirror"));
    else if (typeof define == "function" && define.amd) // AMD
        define(["../../lib/codemirror"], mod);
    else // Plain browser env
        mod(CodeMirror);
})(function(CodeMirror) {
    var Pos = CodeMirror.Pos;
    
    function scriptHint(editor, keywords, getToken, options) {
        // Find the token at the cursor
        var cur = editor.getCursor(), token = getToken(editor, cur), tprop = token;
        var hintOpt = editor.options.hintOptions || {};
        token.state = CodeMirror.innerMode(editor.getMode(), token.state).state;
        
        if (SolrHint.getLogger().isDebugEnabled())
        {
            SolrHint.getLogger().debug('Token string=[' + token.string + '], type=[' + token.type + '], state=' + JSON.stringify(token.state));
        }
        
        if (token.string.trim() == '')
        {
            token = tprop = {start: cur.ch, end: cur.ch, string: '', state: token.state, type: token.type};
        }
        if (token.type == null)
        {
            token = {start: cur.ch, end: cur.ch, string: '', state: token.state, type: token.type};
        }
        
        // If it is a property, find out what it is a property of.
        var context = null;
        
        if (tprop.state.solrInSubquery)
        {
            if (tprop.string == '=')
            {
                tprop = getToken(editor, Pos(cur.line, tprop.start));
                if (tprop.type == 'sqparam')
                {
                    if (context == null) context = [];
                    context.push(tprop);
                }
            }
            else if (tprop.type == 'string' || tprop.type == 'content' || tprop.state.solrInNestedQuery)
            {
                if (tprop.string != '[')
                {
                    tprop = getToken(editor, Pos(cur.line, tprop.start));
                }
                if (tprop.string == '=')
                {
                    tprop = getToken(editor, Pos(cur.line, tprop.start));
                    
                    if (tprop.type == 'sqparam')
                    {
                        if (context == null) context = [];
                        context.push(tprop);
                    }
                    
                    if (tprop.string == 'q' && tprop.state.sqJoin && tprop.state.sqJoin.length)
                    {
                        if (token.string.charAt(0) == '"')
                        {
                            token.string = token.string.substr(1);
                            token.start++;
                        }
                        if (token.string.charAt(token.string.length - 1) == '"')
                        {
                            token.string = token.string.substr(0, token.string.length - 1);
                            token.end--;
                        }
                    }
                }
            }
            while (tprop.state.solrInNestedQuery || tprop.type == 'string' && tprop.string != '' || tprop.type == null && (tprop.string == '/' || tprop.string == '->'))
            {
                tprop = getToken(editor, Pos(cur.line, tprop.start));
                if (tprop.type == 'composite' || tprop.type == 'content')
                {
                    if (context == null) context = [];
                    context.push(tprop);
                    tprop = getToken(editor, Pos(cur.line, tprop.start));
                }
            }
        }
        else
        {
            while (tprop.type == 'string' && tprop.string != '' || tprop.type == null && tprop.string == '/')
            {
                tprop = getToken(editor, Pos(cur.line, tprop.start));
                if (tprop.type == 'composite')
                {
                    if (context == null) context = [];
                    context.push(tprop);
                    tprop = getToken(editor, Pos(cur.line, tprop.start));
                }
            }
        }
        
        if (SolrHint.getLogger().isDebugEnabled())
        {
            var c = '';
            if (context)
            {
                for (var i = 0; i < context.length; i++)
                {
                    if (i > 0) c += ', ';
                    c += '[' + context[i].string + ':' + context[i].type + ']';
                }
            }
            SolrHint.getLogger().debug('Contexts= ' + c);
        }
        
        var data = {
            list: getCompletions(token, context, keywords, options, hintOpt, cur),
            from: Pos(cur.line, token.start),
            to: Pos(cur.line, token.end)
        };
        CodeMirror.on(data, "pick", function(completion)
        {
            if (completion.cursorPos != null)
            {
                editor.setCursor(completion.cursorPos);
            }
        });
        return data;
    }

    function solrHint(editor, options) {
        return scriptHint(editor, solrKeywords,
                          function (e, cur) {return e.getTokenAt(cur)},
                          options);
    };
    CodeMirror.registerHelper('hint', 'solr-ametys', solrHint);

    var solrKeywords = ['AND', 'OR', 'NOT', 'TO'];
    var solrSQKeywords = {
        'join': {
            description: "{{i18n PLUGINS_CMS_UITOOL_SOLR_HINT_SQ_KEYWORD_JOIN}}",
            replacement: 'join='
        },
        'q': {
            description: "{{i18n PLUGINS_CMS_UITOOL_SOLR_HINT_SQ_KEYWORD_Q}}",
            replacement: 'q=""'
        }
    };
    var solrMacros = {
        'join': {
            description: "{{i18n PLUGINS_CMS_UITOOL_SOLR_HINT_MACRO_JOIN}}",
            replacement: '{!ametys join= q=""}',
            cursorPos: '{!ametys join='.length
        }
    };
    
    function getCompletions(token, context, keywords, options, hintOpt, cur) {
        var found = [],
            completions = [],
            start = token.string,
            global = options && options.globalScope || window,
            cTypes = hintOpt.ctypes,
            commonFields = SolrHint.getCommonFields();
        function maybeAdd(str) {
            if (SolrHint.startsWithIgnoreCase(str, start) && !Ext.Array.contains(found, str))
            {
                found.push(str);
                completions.push(str);
            }
        }
        function maybeAddMacro(str, macro) {
            if (SolrHint.startsWithIgnoreCase(str, start) && !Ext.Array.contains(found, str))
            {
                found.push(str);
                completions.push({
                    text: macro.replacement,
                    displayText: str,
                    className: 'macro',
                    details: macro.description,
                    cursorPos: {line: cur.line, ch: token.start + macro.cursorPos},
                    render: SolrHint.renderSolr
                });
            }
        }
        function maybeAddField(name, field) {
            // "fl" in case of a real field, "name" in case of a composite/repeater.
            var str = field.fl || name;
            if (SolrHint.startsWithIgnoreCase(str, start) && !Ext.Array.contains(found, str))
            {
                var text = str + ':',
                    from = undefined,
                    cursorPos = undefined;
                var details = field.type;
                if (field.type == 'composite')
                {
                    text = str + '/';
                }
                else if (field.type == 'repeater')
                {
                    var join = field.joinFl,
                        currentPath = "";
                    for (var i = 0; i < (context || []).length; i++)
                    {
                        if (!context || context[i].type != 'composite')
                        {
                            break;
                        }
                        currentPath = context[i].string + '/' + currentPath;
                    }
                    if (currentPath)
                    {
                        from = Pos(cur.line, token.start - currentPath.length);
                        join = currentPath + join;
                    }
                    var text1 = '{!ametys join=' + join + ' q="',
                        text2 = '"}',
                    text = text1 + text2;
                    details = "{{i18n PLUGINS_CMS_UITOOL_SOLR_HINT_JOIN_REPEATER}}";
                    cursorPos = {line: cur.line, ch: token.start - (currentPath ? currentPath.length : 0) + text1.length};
                }
                else if (field.type == 'string' || field.type == 'reference')
                {
                    if (field.ftFl)
                    {
                        completions.push({
                            text: field.ftFl + ':',
                            displayText: field.ftFl,
                            className: 'field',
                            details: "{{i18n PLUGINS_CMS_UITOOL_SOLR_HINT_SEARCH_FULLTEXT}}",
                            render: SolrHint.renderSolr
                        });
                    }
                    
                    if (field.wcFl)
                    {
                        completions.push({
                            text: field.wcFl + ':',
                            displayText: field.wcFl,
                            className: 'field',
                            details: "{{i18n PLUGINS_CMS_UITOOL_SOLR_HINT_SEARCH_WILDCARD}}",
                            render: SolrHint.renderSolr
                        });
                    }
                    
                    details = "{{i18n PLUGINS_CMS_UITOOL_SOLR_HINT_SEARCH_EQUAL}}";
                }
                else if (field.type == 'rich_text')
                {
                    if (field.ftFl)
                    {
                        completions.push({
                            text: field.ftFl + ':',
                            displayText: field.ftFl,
                            className: 'field',
                            details: "{{i18n PLUGINS_CMS_UITOOL_SOLR_HINT_SEARCH_FULLTEXT}}",
                            render: SolrHint.renderSolr
                        });
                    }
                }
                
                found.push(str);
                
                completions.push({
                    text: text,
                    displayText: str,
                    className: 'field',
                    details: details,
                    from: from,
                    cursorPos: cursorPos,
                    render: SolrHint.renderSolr
                });
            }
        }
        function maybeAddSQField(name, field) {
            var str = field.joinFl || field.fl;
            if (str.lastIndexOf(start, 0) == 0 && !Ext.Array.contains(found, str))
            {
                var text = field.type == 'composite' ? str + '/' : str;
                
                found.push(str);
                completions.push({
                    text: text,
                    displayText: str,
                    className: 'field',
                    details: field.type,
                    render: SolrHint.renderSolr
                });
            }
        }
        function gatherCTypeMetas(cType) {
            var cType = SolrHint.getCTypeMetadatas(cType);
            if (cType == null)
            {
                return;
            }
            
            gatherMetas(cType.fields);
            
            if (cType.superTypes)
            {
                for (var i = 0; i < cType.superTypes.length; i++)
                {
                    gatherCTypeMetas(cType.superTypes[i]);
                }
            }
        }
        function gatherCTypeMetasSubquery(cType) {
            var cType = SolrHint.getCTypeMetadatas(cType);
            if (cType == null)
            {
                return;
            }
            
            gatherMetasSubquery(cType.fields);
            
            if (cType.superTypes)
            {
                for (var i = 0; i < cType.superTypes.length; i++)
                {
                    gatherCTypeMetasSubquery(cType.superTypes[i]);
                }
            }
        }
        function gatherMetas(metas) {
            for (var name in metas)
            {
                maybeAddField(name, metas[name]);
            }
        }
        function gatherMetasSubquery(metas) {
            for (var name in metas)
            {
                var type = metas[name].type;
                if (type == 'content' || type == 'repeater' || type == 'composite')
                {
                    maybeAddSQField(name, metas[name]);
                }
            }
        }
        function getHolder(cTypes, context)
        {
            var element = SolrHint.getPathElement(cTypes, context[0]);
            for (var i = 1; i < context.length && element != null; i++)
            {
                if (element.type == 'composite' || element.type == 'repeater')
                {
                    element = SolrHint.getPathElementInHolder(element, context[i]);
                }
                else if (element.type == 'content')
                {
                    element = SolrHint.getPathElement([element.cType], context[i]);
                }
            }
            
            return element;
        }
        function getJoinContext(join)
        {
            var context = [];
            for (var i = 0; i < join.length; i++)
            {
                context[i] = {
                    type: join[i].type,
                    string: join[i].field
                };
            }
            return context;
        }
        
        if (token.state.solrInSubquery)
        {
            if (context && context.length && context.length > 0)
            {
                if (context[0].type == 'sqparam' && context[0].string == 'join')
                {
                    for (var i = 0; i < cTypes.length; i++)
                    {
                        gatherCTypeMetasSubquery(cTypes[i]);
                    }
                }
                else if (context[0].type == 'sqparam' && context[0].string == 'q' || token.state.solrInNestedQuery)
                {
                    if (token.state.sqJoin)
                    {
                        var joinContext = getJoinContext(token.state.sqJoin);
                        var holder = getHolder(cTypes, joinContext);
                        if (holder != null && holder.type == 'content')
                        {
                            for (var name in commonFields)
                            {
                                maybeAddField(name, commonFields[name]);
                            }
                            
                            gatherCTypeMetas(holder.cType);
                        }
                        else if (holder != null && holder.type == 'repeater')
                        {
                            gatherMetas(holder.fields);
                        }
                    }
                }
                else
                {
                    // The context array is provided backwards, we have to reverse it.
                    context.reverse();
                    var holder = getHolder(cTypes, context);
                    if (holder != null && (holder.type == 'composite' || holder.type == 'repeater'))
                    {
                        // Composite: gather sub-metadatas.
                        gatherMetasSubquery(holder.fields);
                    }
                    else if (holder != null && holder.type == 'content')
                    {
                        // Content type: gather content type metadatas.
                        gatherCTypeMetasSubquery(holder.cType);
                    }
                }
            }
            else
            {
                for (var kw in solrSQKeywords)
                {
                    maybeAddMacro(kw, solrSQKeywords[kw]);
                }
            }
        }
        else if (context && context.length && context.length > 0)
        {
            var composite = SolrHint.getComposite(cTypes, context[context.length - 1].string);
            for (var i = context.length - 2; i >= 0 && composite != null; i--)
            {
                var meta = composite.fields[context[i].string];
                composite = meta && meta.type == 'composite' ? meta : null;
            }
            
            if (composite != null)
            {
                gatherMetas(composite.fields);
            }
        }
        else
        {
            for (var name in commonFields)
            {
                maybeAddField(name, commonFields[name]);
            }
            
            for (var i = 0; i < cTypes.length; i++)
            {
                gatherCTypeMetas(cTypes[i]);
            }
            
            for (var macro in solrMacros)
            {
                maybeAddMacro(macro, solrMacros[macro]);
            }
        }
        
        return completions.sort(SolrHint.sortCompletions);
    }
    
});
