/*
 *  Copyright 2016 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
CodeMirror.defineMode('solr-ametys-columns', function() {
  "use strict";

  var isStringChar = /[^\s\|\!\+\*\?\~\^\&\:\.\,\(\)\[\]\{\}\^\"\\]/;
  var isKeywordString = /^(AS)$/i;

  function tokenWord(ch) {
    return function(stream, state) {
      var word = ch;
      while ((ch = stream.peek()) && ch.match(isStringChar) != null) {
        word += stream.next();
      }

      state.tokenize = tokenBase;
      if (isKeywordString.test(word))
        return "keyword";
      else
        return 'string';
    };
  }

  function tokenBase(stream, state) {
    var ch = stream.next();
    if (ch == ',')
      return 'comma';
    else if (ch == '.')
      return 'dot';
    else
      state.tokenize = tokenWord(ch);
    
    return (state.tokenize != tokenBase) ? state.tokenize(stream, state) : null;
  }

  return {
    startState: function() {
      return {
        tokenize: tokenBase
      };
    },

    token: function(stream, state) {
      if (stream.eatSpace()) return null;
      return state.tokenize(stream, state);
    }
  };
});
