/*
 *  Copyright 2023 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */


tinymce.PluginManager.add('ametysbasicstyles', function(editor) {
    
    function changeSelectionToAlignableElement()
    {
        var sel = editor.selection;
        var n = sel.getNode();
        if (/^img$/i.test(n.tagName))
        {
            sel.collapse();
        }
    }
    
    function isManuallyAlignableElement()
    {
        return /^caption$/i.test(editor.selection.getNode().tagName);
    }
    
    function getManuallyAlignement()
    {
        return editor.selection.getNode().style.textAlign;
    }
    
    function applyAlignment(align, alignCmd)
    {
        var dom = editor.dom;
        var sel = editor.selection;
            
        var carretLocation = editor.selection.getBookmark();
            changeSelectionToAlignableElement(sel);
            editor.execCommand(alignCmd);
            editor.selection.moveToBookmark(carretLocation);

        editor.focus();
        
    }
    
    function alignmentSelectionListener(e, component, cmd)
    {
        var off = editor.selection.getNode() == null;
        var state = !off && (
                isManuallyAlignableElement() ? 
                    /^center$/.test(getManuallyAlignement()) 
                    : editor.queryCommandState(cmd)
        );
        
        component.setEnabled(!off);
        component.setActive(state);
    }
    
    editor.ui.registry.addToggleButton('ametysalignleft', {
        tooltip: 'Align Left',
        icon: 'align-left',
        onSetup: function(component) {
            editor.on('NodeChange', function (e) {
                alignmentSelectionListener(e, component, "JustifyLeft")              
            })
        },
        onAction: function() { applyAlignment("left", "JustifyLeft") }
    });
    
    editor.ui.registry.addToggleButton('ametysaligncenter', {
        tooltip: 'Align Center',
        icon: 'align-center',
        onSetup: function(component) {
            editor.on('NodeChange', function (e) {
                alignmentSelectionListener(e, component, "JustifyCenter")	           
	        })
        },
        onAction: function() { applyAlignment("center", "JustifyCenter") }
    });
    
    editor.ui.registry.addToggleButton('ametysalignright', {
        tooltip: 'Align Right',
        icon: 'align-right',
        onSetup: function(component) {
            editor.on('NodeChange', function (e) {
                alignmentSelectionListener(e, component, "JustifyRight")              
            })
        },
        onAction: function() { applyAlignment("right", "JustifyRight") }
    });
    
    editor.ui.registry.addToggleButton('ametysalignjustify', {
        tooltip: 'Align Justify',
        icon: 'align-justify',
        onSetup: function(component) {
            editor.on('NodeChange', function (e) {
                alignmentSelectionListener(e, component, "JustifyFull")              
            })
        },
        onAction: function() { applyAlignment("justify", "JustifyFull") }
    });
    
    
    
    
    
});
