/*
 *  Copyright 2017 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

AmetysImagesPlugin = {
    
    /**
     * @private
     * @property {Object} The current image
     */
    _currentImage: null,
    
    /**
     * @private
     * @property {String} The context path
     */
    CONTEXT_PATH: Ametys.CONTEXT_PATH,
    
    /**
     * @readOnly
     * @property {String} UPLOAD_URL The URL for upload
     */
    UPLOAD_URL: null,
    
    /**
     * @readOnly
     * @property The URL object (containing plugin & url) to use for cropping.
     */
    CROP_URL: null,
    
    menuItems: {
        '': [],
        'content': [
                // Local image
                {
                    icon: 'image',
                    type: 'menuitem',
                    text: "{{i18n plugin.cms:CONTENT_EDITION_IMAGE_INSERTLOCAL_LABEL}}",
                    tooltip: "{{i18n plugin.cms:CONTENT_EDITION_IMAGE_INSERTLOCAL_DESCRIPTION}}",
                    action: function(editor) {
                        Ametys.plugins.cms.editor.Images._insertLocalImage(
                            editor,
                            "ametysicon-image2",
                            AmetysImagesPlugin.UPLOAD_URL,
                            AmetysImagesPlugin.CROP_URL
                        );
                    },
                    onSetup: function(component, editor) {
                        AmetysImagesPlugin.createHideMenuOnNodeChangeListener(component, false, editor)
                    }
                },
                // Shared image
                {
                    icon: 'image',
                    type: 'menuitem',
                    text: "{{i18n plugin.cms:CONTENT_EDITION_IMAGE_INSERTRESOURCE_LABEL}}",
                    tooltip: "{{i18n plugin.cms:CONTENT_EDITION_IMAGE_INSERTRESOURCE_DESCRIPTION}}",
                    action: function(editor) {
                        Ametys.plugins.cms.editor.Images._insertResourceImage(
                            "ametysicon-image2 decorator-ametysicon-world91",
                            false
                        );
                    },
                    onSetup: function(component, editor) {
                        AmetysImagesPlugin.createHideMenuOnNodeChangeListener(component, false, editor)
                    }
                }
        ]
    },
    
    registerMenuItem: function (item, category, position)
    {
        if (position)
            AmetysImagesPlugin.menuItems[category].splice(position, 0, item );
        else
            AmetysImagesPlugin.menuItems[category].push(item);
    },
    
    createHideMenuOnNodeChangeListener: function(component, showInImage)
    {
        var display = AmetysImagesPlugin._currentImage != null;
        if (!showInImage)
        {
            display = !display;
        }
        
        component.setEnabled(display);
    }
}

tinymce.PluginManager.add('ametysimages', function(editor) {
    function getEventImage(event)
    {
        var element = null;
        var tagName = event.element.tagName.toUpperCase();
        if (tagName == 'IMG')
        {
            element = event.element;
        }

        AmetysImagesPlugin._currentImage = element;
        return element;
    };
    
    function createFloatListener(component, cssClass)
    {
        if (AmetysImagesPlugin._currentImage)
        {
            var node = AmetysImagesPlugin._currentImage;
            var toggleFunction = Ext.bind(component.setActive, component);
            var enableFunction = function(toggle) {component.setEnabled(toggle)};
            Ametys.plugins.cms.editor.Images.floatListener(node, editor, toggleFunction, enableFunction, cssClass);
        }
    };
    function createNoFloatListener(component, cssClass)
    {
        if (AmetysImagesPlugin._currentImage)
        {
            var node = AmetysImagesPlugin._currentImage;
            var toggleFunction = Ext.bind(component.setActive, component);
            var enableFunction = function(toggle) {component.setEnabled(toggle)};
            Ametys.plugins.cms.editor.Images.noFloatListener(node, editor, toggleFunction, enableFunction, cssClass);
        }
    };

    function createStyleOnclickFunction(cssClass)
    {
        return function(event)
        {
            if (AmetysImagesPlugin._currentImage)
            {
                Ametys.plugins.cms.editor.basicactions.ApplyStyle.applyStyle(AmetysImagesPlugin._currentImage, editor, cssClass);
            }
        };
    };
    function createStyleListener(component, cssClass)
    {
        if (AmetysImagesPlugin._currentImage)
        {
            var toggleFunction = Ext.bind(component.setActive, component);
            var enableFunction = function(toggle) {component.setEnabled(toggle)};
            Ametys.plugins.cms.editor.basicactions.ApplyStyle.styleListener(AmetysImagesPlugin._currentImage, editor, toggleFunction, enableFunction, cssClass);
        }
    };
    function getStyleMenuFromConf()
    {
        var stylemenu = [];
        var stylesFromConf = Ametys.form.widget.RichText.RichTextConfiguration.getStyledElements("image", editor.getParam('category'));
        for (var i = 0; i < stylesFromConf.length; i++) 
        {
            let buttonMenu = [];
            for (var j = 0; j < stylesFromConf[i].values.length; j++) 
            {
                var current = stylesFromConf[i].values[j];
                let cssClass = current.cssClass;
                var imagePath = current.buttonMediumIcon || current.buttonSmallIcon;
                        
                var iconId = 'icon-' + Math.random();
                editor.ui.registry.addIcon(iconId, '<svg version="1.1" style="width: 16px" class="' + current.buttonCSSClass + '" viewBox="0 0 32 32" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"><image xlink:href="' + AmetysImagesPlugin.CONTEXT_PATH + imagePath + '" x="0" y="0" height="100" width="100" /></svg>');
                        
                var buttonMenuItem = {
                    text: current.label,
                    type: 'togglemenuitem',
                    icon: iconId,
                    tooltip: Ext.util.Format.stripTags(current.description),
                    onSetup: function(component) { AmetysImagesPlugin.createHideMenuOnNodeChangeListener(component, true); createStyleListener(component, cssClass); },
                    onAction: createStyleOnclickFunction(cssClass)
                };
                buttonMenu.push(buttonMenuItem);
            }
            if (buttonMenu.length > 0)
            {
                var button = {
                    text : stylesFromConf[i].label,
                    type : 'nestedmenuitem',
                    getSubmenuItems: function() { return buttonMenu; }
                };
                stylemenu.push(button);
            }
        }
        return stylemenu;
    };
    
    var menuItems = AmetysImagesPlugin.menuItems[editor.getParam('contentInfo') ? 'content' : ''];
    if (menuItems.length > 0)
    {
	    editor.ui.registry.addMenuButton('insertimage', {
	        icon: 'image',
	        fetch: function(callback) {
	            var items = [];
                for(var i=0; i < menuItems.length; i++)
                {
                    let item = menuItems[i]; 
                    
                    if (item.submenuitems)
                    {
                        items.push({
                            icon: item.icon,
                            text: item.text,
                            type: item.type,
                            tooltip: item.tooltip,
                            onSetup: function(component) { item.onSetup(component, editor); },
                            getSubmenuItems: function() { 
                                var subitems = [];
                                for (var j=0; j < item.submenuitems.length; j++)
                                {
                                    let subitem = item.submenuitems[j];
                                    subitems.push({
			                            icon: subitem.icon,
			                            text: subitem.text,
			                            type: subitem.type,
			                            tooltip: subitem.tooltip,
			                            onSetup: function(component) { item.onSetup(component, editor); },
			                            onAction: function() {
			                                subitem.action(editor);
			                            }
			                        });
                                }
                                return subitems;
                            }
                        });
                    }
                    else
                    {
                        items.push({
	                        icon: item.icon,
	                        text: item.text,
	                        type: item.type,
	                        tooltip: item.tooltip,
	                        onSetup: function(component) { item.onSetup(component, editor); },
	                        onAction: function() {
	                            item.action(editor);
	                        }
	                    });
                    }
                    
                }
                
	            items.push(
	                // Float
	                {
	                    icon: 'image',
	                    text: "{{i18n plugin.cms:RIBBON_TABS_TAB_IMAGE_GROUPS_GROUP_POSITION_LABEL}}",
	                    type: 'nestedmenuitem',
	                    onSetup: function(component) { AmetysImagesPlugin.createHideMenuOnNodeChangeListener(component, true); },
	                    getSubmenuItems: function() { 
	                        return [
	                            {
	                                text: "{{i18n plugin.cms:CONTENT_EDITION_IMAGE_FLOAT_LEFT_LABEL}}",
	                                type: 'togglemenuitem',
	                                tooltip: Ext.util.Format.stripTags("{{i18n plugin.cms:CONTENT_EDITION_IMAGE_FLOAT_LEFT_DESCRIPTION}}"),
	                                image: Ametys.getPluginResourcesPrefix('cms') + "/img/content/edition/image/Image_Float_Left_32.png",
	                                onSetup: function(component) { AmetysImagesPlugin.createHideMenuOnNodeChangeListener(component, true); createFloatListener(component, "floatleft"); },
	                                onAction: function() {
	                                    Ametys.plugins.cms.editor.Images.applyFloatLeft(null);
	                                }
	                            },{
	                                text: "{{i18n plugin.cms:CONTENT_EDITION_IMAGE_NO_FLOAT_LABEL}}",
	                                type: 'togglemenuitem',
	                                tooltip: Ext.util.Format.stripTags("{{i18n plugin.cms:CONTENT_EDITION_IMAGE_NO_FLOAT_DESCRIPTION}}"),
	                                image: Ametys.getPluginResourcesPrefix('cms') +  "/img/content/edition/image/Image_No_Float_32.png",
	                                onSetup: function(component) { AmetysImagesPlugin.createHideMenuOnNodeChangeListener(component, true); createNoFloatListener(component, ['floatleft', 'floatright']); },
	                                onAction: function() {
	                                    Ametys.plugins.cms.editor.Images.applyNoFloat(null);
	                                }
	                            },{
	                                text: "{{i18n plugin.cms:CONTENT_EDITION_IMAGE_FLOAT_RIGHT_LABEL}}",
	                                type: 'togglemenuitem',
	                                tooltip: Ext.util.Format.stripTags("{{i18n plugin.cms:CONTENT_EDITION_IMAGE_FLOAT_RIGHT_DESCRIPTION}}"),
	                                image: Ametys.getPluginResourcesPrefix('cms') + "/img/content/edition/image/Image_Float_Right_32.png",
	                                onSetup: function(component) { AmetysImagesPlugin.createHideMenuOnNodeChangeListener(component, true); createFloatListener(component, "floatright"); },
	                                onAction: function() {
	                                    Ametys.plugins.cms.editor.Images.applyFloatRight(null);
	                                }
	                            }
	                        ];
	                    }
	                });
	                
	           items.push(
	                // Image styles
	                {
	                    icon: 'image',
	                    text: "{{i18n plugin.cms:RIBBON_TABS_TAB_IMAGE_GROUPS_GROUP_STYLE_LABEL}}",
	                    type: 'nestedmenuitem',
	                    onSetup: function(component) { AmetysImagesPlugin.createHideMenuOnNodeChangeListener(component, true); },
	                    getSubmenuItems: getStyleMenuFromConf
	                }
	            );    
	            callback(items);
	        }
	    });
        
    }

    
    editor.on('NodeChange', function (e) {
        var element = getEventImage(e);

        if (element != null)
        {
            Ametys.plugins.cms.editor.Images.imageSelectionListener(null, null, element);
        }
    });
});
