/*
 *  Copyright 2017 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
 
AmetysLinksPlugin = {
    
    /**
     * @private
     * @property {Object} The current llink
     */
    _currentLink: null,
    
    /**
     * @private
     * @property {String} The context path
     */
    CONTEXT_PATH: Ametys.CONTEXT_PATH,
    
    /**
     * @private
     * @property {Number} The workflow action id for attachment insertion
     */
    insertAttachmentActionId: null,
    
    menuItems: { 
            '': [
                    // External
                    {
                        icon: 'link',
                        text: "{{i18n plugin.cms:CONTENT_EDITION_LINK_INSERT_WEB_LABEL}}",
                        type: 'menuitem',
                        action: Ext.bind(Ametys.plugins.cms.editor.Links.insertWebLink, Ametys.plugins.cms.editor.Links),
                        onSetup: function(component, editor) {
                            AmetysLinksPlugin.createHideMenuOnNodeChangeListener(component, false, editor)
                        }
                        
                    },
                    // Mailto
                    {
                        icon: 'link',
                        text: "{{i18n plugin.cms:CONTENT_EDITION_LINK_INSERT_MAILTO_LABEL}}",
                        type: 'menuitem',
                        action: Ext.bind(Ametys.plugins.cms.editor.Links._insertMailtoLink, Ametys.plugins.cms.editor.Links),
                        onSetup: function(component, editor) {
                            AmetysLinksPlugin.createHideMenuOnNodeChangeListener(component, false, editor)
                        }
                    },
                    // Phone
                    {
                        icon: 'link',
                        text: "{{i18n plugin.cms:CONTENT_EDITION_LINK_INSERT_PHONE_LABEL}}",
                        type: 'menuitem',
                        action: Ext.bind(Ametys.plugins.cms.editor.Links._insertPhoneLink, Ametys.plugins.cms.editor.Links),
                        onSetup: function(component, editor) {
                            AmetysLinksPlugin.createHideMenuOnNodeChangeListener(component, false, editor)
                        }
                    }
             ],
            'content': [
                    // External
	                {
	                    icon: 'link',
	                    text: "{{i18n plugin.cms:CONTENT_EDITION_LINK_INSERT_WEB_LABEL}}",
	                    type: 'menuitem',
	                    action: Ext.bind(Ametys.plugins.cms.editor.Links.insertWebLink, Ametys.plugins.cms.editor.Links),
                        onSetup: function(component, editor) {
                            AmetysLinksPlugin.createHideMenuOnNodeChangeListener(component, false, editor)
                        }
	                },
	                // Mailto
	                {
	                    icon: 'link',
	                    text: "{{i18n plugin.cms:CONTENT_EDITION_LINK_INSERT_MAILTO_LABEL}}",
	                    type: 'menuitem',
	                    action: Ext.bind(Ametys.plugins.cms.editor.Links._insertMailtoLink, Ametys.plugins.cms.editor.Links),
                        onSetup: function(component, editor) {
                            AmetysLinksPlugin.createHideMenuOnNodeChangeListener(component, false, editor)
                        }
                    },
                    // Phone
                    {
                        icon: 'link',
                        text: "{{i18n plugin.cms:CONTENT_EDITION_LINK_INSERT_PHONE_LABEL}}",
                        type: 'menuitem',
                        action: Ext.bind(Ametys.plugins.cms.editor.Links._insertPhoneLink, Ametys.plugins.cms.editor.Links),
                        onSetup: function(component, editor) {
                            AmetysLinksPlugin.createHideMenuOnNodeChangeListener(component, false, editor)
                        }
                    },
	                // Attachment
	                {
	                    icon: 'link',
	                    text: "{{i18n plugin.cms:CONTENT_EDITION_LINK_INSERT_ATTACHMENT_LABEL}}",
	                    type: 'menuitem',
	                    action: function(editor)
	                    {
	                        var contentId = editor.getParam('contentInfo').contentId;
	                        Ametys.plugins.cms.editor.Links._doInsertAttachmentLink(contentId, null, AmetysLinksPlugin.insertAttachmentActionId);
	                    },
                        onSetup: function(component, editor) {
                            AmetysLinksPlugin.createHideMenuOnNodeChangeListener(component, false, editor)
                        }
	                },
	                // Resource
	                {
	                    icon: 'link',
	                    text: "{{i18n plugin.cms:CONTENT_EDITION_LINK_INSERT_RESOURCE_LABEL}}",
	                    type: 'menuitem',
	                    action: function(editor) {
                            Ametys.plugins.cms.editor.Links._doInsertResourcesLink();
                        },
                        onSetup: function(component, editor) {
                            AmetysLinksPlugin.createHideMenuOnNodeChangeListener(component, false, editor)
                        }
	                }
             ]
    },
    
    registerMenuItem: function (item, category, position)
    {
        if (position)
            AmetysLinksPlugin.menuItems[category].splice(position, 0, item );
        else
            AmetysLinksPlugin.menuItems[category].push(item);
    },
    
    linkHandlers: [
        Ext.bind(Ametys.plugins.cms.editor.Links.initialize, Ametys.plugins.cms.editor.Links),
        Ext.bind(Ametys.plugins.cms.editor.Links.initializeMailLink, Ametys.plugins.cms.editor.Links),
        Ext.bind(Ametys.plugins.cms.editor.Links.initializeAttachmentLink, Ametys.plugins.cms.editor.Links),
        Ext.bind(Ametys.plugins.cms.editor.Links.initializeResourcesLink, Ametys.plugins.cms.editor.Links),
        Ext.bind(Ametys.plugins.cms.editor.Links.initializePhoneLink, Ametys.plugins.cms.editor.Links)
    ],
    
    registerLinkHandler: function (handler)
    {
        AmetysLinksPlugin.linkHandlers.push(handler);
    },
    
    createHideMenuOnNodeChangeListener: function(button, showInLink, editor)
    {
        var display = AmetysLinksPlugin._currentLink != null;
        if (!showInLink)
        {
            display = !display;
        }
        
        button.setEnabled(display);
        
        editor.on('NodeChange', function (e)
        {
            var display = AmetysLinksPlugin._currentLink != null;
            if (!showInLink)
            {
                display = !display;
            }
            button.setEnabled(display);
        });
    }
}

tinymce.PluginManager.add('ametyslinks', function(editor) {
    
    function getEventLink(event)
    {
        var element = null;
        var tagName = tinymce.activeEditor.selection.getNode().tagName.toUpperCase();
        if (tagName == 'A')
        {
            element = tinymce.activeEditor.selection.getNode();
        }

        AmetysLinksPlugin._currentLink = element;
        return element;
    };
    
    function initializeLinkHandlers()
    {
        for (var i=0; i < AmetysLinksPlugin.linkHandlers.length; i++)
        {
            if (typeof AmetysLinksPlugin.linkHandlers[i] == 'function')
            {
                AmetysLinksPlugin.linkHandlers[i]();
            }
        }
    }
    
    initializeLinkHandlers();
    
    function getStyleMenuFromConf()
    {
        var stylemenu = [];
        var stylesFromConf = Ametys.form.widget.RichText.RichTextConfiguration.getStyledElements("link", editor.getParam('category'));
        for (var i = 0; i < stylesFromConf.length; i++) 
        {
            let buttonMenu = [];
            for (var j = 0; j < stylesFromConf[i].values.length; j++) 
                {
                var current = stylesFromConf[i].values[j];
                let cssClass = current.cssClass;
                var imagePath = current.buttonMediumIcon || current.buttonSmallIcon;
                        
                var iconId = 'icon-' + Math.random();
                editor.ui.registry.addIcon(iconId, '<svg version="1.1" style="width: 16px" class="' + current.buttonCSSClass + '" viewBox="0 0 32 32" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"><image xlink:href="' + AmetysLinksPlugin.CONTEXT_PATH + imagePath + '" x="0" y="0" height="100" width="100" /></svg>');

                var buttonMenuItem = {
                    text: current.label,
                    type: 'togglemenuitem',
                    icon: iconId,
                    tooltip: Ext.util.Format.stripTags(current.description),
                    onSetup : function(component) { AmetysLinksPlugin.createHideMenuOnNodeChangeListener(component, true, editor); createStyleListener(component, cssClass); },
                    onAction: createStyleOnclickFunction(cssClass)
                };
                buttonMenu.push(buttonMenuItem);
            }
            if (buttonMenu.length > 0)
            {
                var button = {
                    text : stylesFromConf[i].label,
                    type : 'nestedmenuitem',
                    getSubmenuItems: function() { return buttonMenu; }
                };
                stylemenu.push(button);
            }
        }
        return stylemenu;
    };
    
    function createStyleOnclickFunction(cssClass)
    {
        return function(event)
        {
            if (AmetysLinksPlugin._currentLink)
            {
                Ametys.plugins.cms.editor.basicactions.ApplyStyle.applyStyle(AmetysLinksPlugin._currentLink, editor, cssClass);
            }
        };
    };
    function createStyleListener(component, cssClass)
    {
        if (AmetysLinksPlugin._currentLink)
        {
            var toggleFunction = Ext.bind(component.setActive, component);
            var enableFunction = function(toggle) {component.setEnabled(toggle)};
            Ametys.plugins.cms.editor.basicactions.ApplyStyle.styleListener(AmetysLinksPlugin._currentLink, editor, toggleFunction, enableFunction, cssClass);
        }
    };
    
    // Disabled drag and drop in attachment and explorer tree
    Ametys.plugins.cms.editor.Links._allowDragAndDrop = false;
    
    var menuItems = AmetysLinksPlugin.menuItems[editor.getParam('contentInfo') ? 'content' : ''];
    if (menuItems.length > 0)
    {
	    editor.ui.registry.addMenuButton('insertlinkmenu', {
	        icon: 'link',
	        fetch: function(callback) {
	            var items = [];
	            for(var i=0; i < menuItems.length; i++)
	            {
                    let item = menuItems[i]; 
	                items.push({
                        icon: item.icon,
                        text: item.text,
                        type: item.type,
                        tooltip: item.tooltip,
                        onSetup: function(component) { item.onSetup(component, editor); },
                        onAction: function() {
                            item.action(editor);
                        }
                    });
	            }
	            // Edit
	            items.push({
	                    icon: 'link',
	                    text: "{{i18n plugin.cms:CONTENT_EDITION_LINK_EDIT_LABEL}}",
	                    type: 'menuitem',
	                    tooltip: "{{i18n plugin.cms:CONTENT_EDITION_LINK_EDIT_DESCRIPTION}}",
	                    onSetup: function(component) { AmetysLinksPlugin.createHideMenuOnNodeChangeListener(component, true, editor); },
	                    onAction: function() {
	                        Ametys.plugins.cms.editor.Links.editLink();
	                    }
	            });
	            // Remove    
	            items.push({
	                    icon: 'remove',
	    	            text: "{{i18n plugin.cms:CONTENT_EDITION_LINK_REMOVE_LABEL}}",
	                    type: 'menuitem',
	    	            tooltip: "{{i18n plugin.cms:CONTENT_EDITION_LINK_REMOVE_DESCRIPTION}}",
	                    onSetup: function(component) { AmetysLinksPlugin.createHideMenuOnNodeChangeListener(component, true, editor); },
	    	            onAction: function() {Ametys.plugins.cms.editor.Links.removeLink();}
	    	    });
	            // Styles
	            items.push({
	                    icon: 'link',
	    	            text: "{{i18n plugin.cms:CONTENT_EDITION_LINK_STYLE_LABEL}} ", /* space after needed, to avoid that tinymce try to translate this value */
	                    type: 'nestedmenuitem',
	    	            onSetup: function(component) { AmetysLinksPlugin.createHideMenuOnNodeChangeListener(component, true, editor); },
	    	            getSubmenuItems: getStyleMenuFromConf
	    	    });
	            callback(items);
	        }
	    });
    }
    
    editor.on('NodeChange', function(e){window.setTimeout(function (e) {
        var element = getEventLink(e);

        if (element != null)
        {
            Ametys.plugins.cms.editor.Links.linkSelectionListener(null, null, element);
        }
    },1)});
});

//Ext.define('Ametys.plugins.frontedition.editor.Links', {
//    override: 'Ametys.plugins.cms.editor.Links',
//    
//    _getCurrentLanguage: function()
//    {
//        return Ametys.LANGUAGE_CODE;
//    }
//});
