/*
 *  Copyright 2017 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */


tinymce.PluginManager.add('ametyslists', function(editor) {
    var lastStyles = {};

    function buildMenuItems(listName, styleValues) {
        var items = [];

        items.push({
            text: "{{i18n plugin.cms:CONTENT_EDITION_CHARACTER_UNORDEREDLIST_STYLE_NO}}",
            remove: true
        });

        for (var i=0; i < styleValues.length; i++)
        {
            for (var j=0; j < styleValues[i].values.length; j++)
            {
                items.push({
                    type: 'choiceitem',
                    text: styleValues[i].values[j].label,
                    value: styleValues[i].values[j].cssClass
                });
            }
        }
        
        return items;
    }

    function applyListFormat(listName, item) {
        editor.undoManager.transact(function() {
            var dom = editor.dom;
            var sel = editor.selection;
            var styleValue = item.value ? item.value : false;
            var removeBullet = item.remove ? item.remove : false;
            
            // Check for existing list element
            var list = dom.getParent(sel.getNode(), 'ol,ul');
            // Switch/add list type if needed
            if (!list || list.nodeName != listName || styleValue === false) {
                if (!removeBullet || list != null)
            	{
            		// If we remove the bullet, the list is not null and we remove the current tag list and not the selected list name
            		var tagName = removeBullet ? list.tagName : listName;
        			editor.execCommand(tagName == 'UL' ? 'InsertUnorderedList' : 'InsertOrderedList');
                    list = editor.dom.getParent(sel.getNode(), tagName);
            	}
            	
                if (list == null)
                {
                    // may happen when the selection is around the text
                    // CMS-2483 Problem when creating square list on pasted text
                    sel.collapse();
                    var isThatNode = sel.getNode().previousSibling;
                    list = isThatNode && /^ul|ol$/i.test(isThatNode.tagName) ? isThatNode : null;
                }            
            }
            else if (removeBullet && list != null)
            {
                editor.execCommand(list.tagName == 'UL' ? 'InsertUnorderedList' : 'InsertOrderedList');
            }

            // Set style
            if (!removeBullet && list != null)
            {
                var cls = styleValue || Ametys.form.widget.RichText.RichTextConfiguration.getTag(list.tagName.toLowerCase(), editor.getParam('category')).attributes['class'].defaultValue;
                if (cls)
                {
                    list.setAttribute("class", cls);
                }
            }
            
            editor.focus();
        });
    }

    editor.ui.registry.addSplitButton('numlist', {
        tooltip: 'Numbered list',
        icon: 'ordered-list',
        fetch: function(callback) {
            var olMenuItems = buildMenuItems('OL', Ametys.form.widget.RichText.RichTextConfiguration.getStyledElements("ol", editor.getParam('category')));
            callback(olMenuItems);
        },
        select: function(value) {
            var list = editor.dom.getParent(editor.selection.getNode(), "ol,ul");
            return list ? list.classList.contains(value) : false;
        },
        onItemAction: function(e, value) {
            var list = editor.dom.getParent(editor.selection.getNode(), "ol,ul");
            var remove = list ? list.classList.contains(value) : false;

            applyListFormat('OL', {value: value, remove: remove});
        },
        onAction: function() {
            applyListFormat('OL', false);
        }
    });

    editor.ui.registry.addSplitButton('bullist', {
        tooltip: 'Bullet list',
        icon: 'unordered-list',
        fetch: function(callback) {
            var ulMenuItems = buildMenuItems('UL', Ametys.form.widget.RichText.RichTextConfiguration.getStyledElements("ul", editor.getParam('category')));
            callback(ulMenuItems);
        },
        select: function(value) {
            var list = editor.dom.getParent(editor.selection.getNode(), "ol,ul");
            return list ? list.classList.contains(value) : false;
        },
        onItemAction: function(e, value) {
            var list = editor.dom.getParent(editor.selection.getNode(), "ol,ul");
            var remove = list ? list.classList.contains(value) : false;

            applyListFormat('UL', {value: value, remove: remove});
        },
        onAction: function() {
            applyListFormat('UL', false);
        }
    });
});
