/*
 *  Copyright 2017 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */


tinymce.PluginManager.add('ametysstyles', function(editor) {
    var blocks = [];
    var stylesCategories = Ametys.form.widget.RichText.RichTextConfiguration.getStyledElements("paragraph", editor.getParam('category'));
    
    if (stylesCategories)
    {
	    for (var i=0; i < stylesCategories.length; i++)
	    {
	        var styleCategory = stylesCategories[i];
	        var styles = styleCategory.values;
	        for (var j=0; j < styles.length; j++)
	        {
	            let id = ('formatstyle-menu-' + Math.random()).replace(/\./g, '');
	            editor.ui.registry.addIcon(id, '<span id="' + id + '" style="">' + styles[j].label + '</span>'); 
	
	            var style = styles[j];
	            let block = {
	                icon: id,
	                text: ' ', // unbreakable spaces
	                type: 'togglemenuitem',
	                value: styles[j],
	                onSetup: function(component) { 
	                    // Called each time the menu is recreated, to activate the right item
	                    var found = null;
	                    
	                    if (!block.menuStyles)
	                    {
	                        block.menuStyles = "display: block; width: 150px; position: absolute; left: 8px; overflow: hidden; white-space: nowrap;" + editor.formatter.getCssText({block: (block.value.tagName || 'p'), selector: (block.value.tagName || 'p') + (block.value.cssClass ? '.' + block.value.cssClass : '')});
	                    }
	                    
	                    var elt = document.getElementById(id);
	                    elt.style = block.menuStyles;
	                    elt.className = block.value.buttonCSSClass;
	    
	                    for (var k=0; k < blocks.length; k++)
	                    {
	                        var b = blocks[k];
	                        var blockSelector = (b.value.tagName || 'p') + (b.value.cssClass ? '.' + b.value.cssClass : '');
	                        var parent = editor.dom.getParent(editor.selection.getNode(), blockSelector);
	                        if (parent)
	                        {
	                            found = b;
	                            if (b.value.cssClass)
	                            {
	                                break;
	                            }
	                        }
	                    }
	                    
	                    component.setActive(found == block);
	                },
	                onAction: function() { toggleFormat(block); }
	            };
	            blocks.push(block);
	        }
	    }
        
	    let id = ('formatstyle-' + Math.random()).replace(/\./g, '');
	    editor.ui.registry.addIcon(id, '<span id="' + id + '" style="display: inline-block;width: 100px;overflow: hidden;"></span>'); 
	    editor.ui.registry.addMenuButton('formatstyle', {
	        icon: id,
	        fetch: function(callback) {
	            callback(blocks);
	        },
	        onSetup: function(component)
	        {
	            editor.on('nodeChange', function(e) {
	                var found = null;
	
	                for (var k=0; k < blocks.length; k++)
	                {
	                    var b = blocks[k];
	                    var blockSelector = (b.value.tagName || 'p') + (b.value.cssClass ? '.' + b.value.cssClass : '');
	                    var parent = editor.dom.getParent(editor.selection.getNode(), blockSelector);
	                    if (parent)
	                    {
	                        found = b;
	                        if (b.value.cssClass)
	                        {
	                            break;
	                        }
	                    }
	                }
	                
	                if (found)
	                {
	                    document.getElementById(id).innerHTML = found.value.label;
	                }
	            });
	        }
	    });
    }
    
    
    function toggleFormat(block)
    {
        var style = block.value;
        var tagName = style.tagName || 'p';
        editor.focus();
        editor.execCommand('mceBeginUndoLevel');
        
        var carretLocation = editor.selection.getBookmark(); // CMS-3513

        var selectedBlocks = editor.selection.getSelectedBlocks();
        for (var i = 0; i < selectedBlocks.length; i++)
        {
            var block = selectedBlocks[i];
            var selectionParentNode = editor.dom.getParent(block, tagName);

            if (selectionParentNode == null)
            {
                editor.selection.select(block);
                editor.execCommand('FormatBlock', false, tagName);
                block = editor.selection.getSelectedBlocks()[0];
                selectionParentNode = editor.dom.getParent(block, tagName);
            }

            if (selectionParentNode != null)
            {
                if (style.cssClass && style.cssClass != '')
                {
                    // remove existing classes
                    for (var k = 0; k < blocks.length; k++)
                    {
                        var r = blocks[k]; 
                        if ((r.tagName || 'p') == tagName && r.value.cssClass && editor.dom.hasClass(selectionParentNode, r.value.cssClass))
                        {
                            editor.dom.removeClass(selectionParentNode, r.value.cssClass);
                        }
                    }
                    editor.dom.addClass(selectionParentNode, style.cssClass);
                }
                else
                {
                    selectionParentNode.className = "";
                }
            }
        }

        editor.selection.moveToBookmark(carretLocation); // CMS-3513
        editor.execCommand('mceEndUndoLevel');
    }
});
