/*
 *  Copyright 2017 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

AmetysTablesPlugin = {
    
    /**
     * @private
     * @property {String} The context path
     */
    CONTEXT_PATH: Ametys.CONTEXT_PATH
}

tinymce.PluginManager.add('ametystables', function(editor) {
    var _currentCell;
    function generateTableGrid()
    {
        var html = '<div class="insert-table-title" role="presentation">{{i18n plugin.cms:CONTENT_EDITION_TABLE_INSERT_TABLE_TITLE}}</div>';
        html +=  Ametys.plugins.cms.editor.Tables.createTabCreator();
        return html;
    };
    function getEventCell(event)
    {
        var element = null;
        var tagName = event.element.tagName.toUpperCase();
        if (tagName == 'TD' || tagName == 'TR' || tagName == 'TH' || tagName == 'TABLE')
        {
            element = event.element;
        }

        //We can be inside anything in a cell (ul/li for example), we need to look up
        if (element == null)
        {
            for (var i = 0; i < event.parents.length; i++) {
                tagName = event.parents[i].tagName.toUpperCase();
                if (tagName == 'TD' || tagName == 'TR' || tagName == 'TH' || tagName == 'TABLE')
                {
                    element = event.parents[i];
                    break;
                }
            }
        }
        _currentCell = element;
        return element;
    };
    function createHideMenuOnNodeChangeListener(component, showInTable)
    {
        var display = _currentCell != null;
        if (!showInTable)
        {
            display = !display;
        }
        
        component.setEnabled(display);
    };
    
    var menuItems = [
        {
            icon: 'table',
            text: '{{i18n plugin.cms:CONTENT_EDITION_TABLE_INSERT_TABLE_TITLE}}',
            type: 'nestedmenuitem',
            onSetup: function(component) { createHideMenuOnNodeChangeListener(component, false); },
            getSubmenuItems: function() { return [{
                        type : 'fancymenuitem',
                        fancytype: 'inserttable',
                        onAction: function(_a) {
                            if (!_currentCell) // This menu cannot be disabled... at leat clicking will do nothing
                            {
                                editor.focus();
                                var numRows = _a.numRows, numColumns = _a.numColumns;
                                Ametys.plugins.cms.editor.Tables.createTable(numColumns, numRows);
                                editor.focus();
                            }
                        }
                    }]
            }
        },
        
        {
            icon: 'table-delete-table',
            text: '{{i18n plugin.cms:CONTENT_EDITION_TABLE_DELETE_MENU_LABEL}}',
            type: 'nestedmenuitem',
            onSetup: function(component) { createHideMenuOnNodeChangeListener(component, true); },
            getSubmenuItems: function() { 
                return [
                    {
                        icon: 'table-delete-column',
                        text: "{{i18n plugin.cms:CONTENT_EDITION_TABLE_DELETE_COL_LABEL}}",
                        type: 'menuitem',
                        onSetup: function(component) { createHideMenuOnNodeChangeListener(component, true); },
                        onAction: function() { Ametys.plugins.cms.editor.Tables.deleteCol(); }
                    },
                    {
                        icon: 'table-delete-row',
                        text: "{{i18n plugin.cms:CONTENT_EDITION_TABLE_DELETE_ROW_LABEL}}",
                        type: 'menuitem',
                        onSetup: function(component) { createHideMenuOnNodeChangeListener(component, true); },
                        onAction: function() { Ametys.plugins.cms.editor.Tables.deleteRow(); }
                    },
                    {
                        icon: 'table-delete-table',
                        text: "{{i18n plugin.cms:CONTENT_EDITION_TABLE_DELETE_TABLE_LABEL}}",
                        type: 'menuitem',
                        onSetup: function(component) { createHideMenuOnNodeChangeListener(component, true); },
                        onAction: function() { Ametys.plugins.cms.editor.Tables.deleteTable(); }
                    }
                ];
            }
        },
        
        {
            icon: 'table-insert-row-above',
            text: '{{i18n plugin.cms:CONTENT_EDITION_TABLE_INSERT_ROW_COLUMN_LABEL}}',
            type: 'nestedmenuitem',
            onSetup: function(component) { createHideMenuOnNodeChangeListener(component, true); },
            getSubmenuItems: function() { 
                return [
                    {
                        icon: 'table-insert-row-above',
                        text: "{{i18n plugin.cms:CONTENT_EDITION_TABLE_INSERT_ROW_UP_LABEL}}",
                        type: 'menuitem',
                        onSetup: function(component) { createHideMenuOnNodeChangeListener(component, true); },
                        onAction: function() { Ametys.plugins.cms.editor.Tables.insertRowUp(); }
                    },
                    {
                        icon: 'table-insert-row-after',
                        text: "{{i18n plugin.cms:CONTENT_EDITION_TABLE_INSERT_ROW_DOWN_LABEL}}",
                        type: 'menuitem',
                        onSetup: function(component) { createHideMenuOnNodeChangeListener(component, true); },
                        onAction: function() { Ametys.plugins.cms.editor.Tables.insertRowDown(); }
                    },
                    {
                        icon: 'table-insert-column-before',
                        text: "{{i18n plugin.cms:CONTENT_EDITION_TABLE_INSERT_COLUMN_RIGHT_LABEL}}",
                        type: 'menuitem',
                        onSetup: function(component) { createHideMenuOnNodeChangeListener(component, true); },
                        onAction: function() { Ametys.plugins.cms.editor.Tables.insertColumnRight(); }
                    },
                    {
                        icon: 'table-insert-column-after',
                        text: "{{i18n plugin.cms:CONTENT_EDITION_TABLE_INSERT_COLUMN_LEFT_LABEL}}",
                        type: 'menuitem',
                        onSetup: function(component) { createHideMenuOnNodeChangeListener(component, true); },
                        onAction: function() { Ametys.plugins.cms.editor.Tables.insertColumnLeft(); }
                    }
                ];
            }
        },
        
        {
            icon: 'align-none',
            text: "{{i18n plugin.cms:RIBBON_TABS_TAB_TABLE_GROUPS_GROUP_ALIGN_LABEL}}",
            type: 'nestedmenuitem',
            onSetup: function(component) { createHideMenuOnNodeChangeListener(component, true); },
            getSubmenuItems: function() { 
                return [
                    {
                        text: "{{i18n plugin.cms:CONTENT_EDITION_TABLE_ALIGN_LEFT_VALIGN_TOP_LABEL}}",
                        type: 'togglemenuitem',
                        onSetup: function(component) { createHideMenuOnNodeChangeListener(component, true); createAlignListener(component, 'left', 'top'); },
                        onAction: function() { Ametys.plugins.cms.editor.Tables.alignTable('left', 'top'); }
                    },
                    {
                        text: "{{i18n plugin.cms:CONTENT_EDITION_TABLE_ALIGN_CENTER_VALIGN_TOP_LABEL}}",
                        type: 'togglemenuitem',
                        onSetup: function(component) { createHideMenuOnNodeChangeListener(component, true); createAlignListener(component, 'center', 'top'); },
                        onAction: function() { Ametys.plugins.cms.editor.Tables.alignTable('center', 'top'); }
                    },
                    {
                        text: "{{i18n plugin.cms:CONTENT_EDITION_TABLE_ALIGN_RIGHT_VALIGN_TOP_LABEL}}",
                        type: 'togglemenuitem',
                        onSetup: function(component) { createHideMenuOnNodeChangeListener(component, true); createAlignListener(component, 'right', 'top'); },
                        onAction: function() { Ametys.plugins.cms.editor.Tables.alignTable('right', 'top'); }
                    },
        
                    {
                        text: "{{i18n plugin.cms:CONTENT_EDITION_TABLE_ALIGN_LEFT_VALIGN_MIDDLE_LABEL}}",
                        type: 'togglemenuitem',
                        onSetup: function(component) { createHideMenuOnNodeChangeListener(component, true); createAlignListener(component, 'left', 'middle'); },
                        onAction: function() { Ametys.plugins.cms.editor.Tables.alignTable('left', 'middle'); }
                    },
                    {
                        text: "{{i18n plugin.cms:CONTENT_EDITION_TABLE_ALIGN_CENTER_VALIGN_MIDDLE_LABEL}}",
                        type: 'togglemenuitem',
                        onSetup: function(component) { createHideMenuOnNodeChangeListener(component, true); createAlignListener(component, 'center', 'middle'); },
                        onAction: function() { Ametys.plugins.cms.editor.Tables.alignTable('center', 'middle'); }
                    },
                    {
                        text: "{{i18n plugin.cms:CONTENT_EDITION_TABLE_ALIGN_RIGHT_VALIGN_MIDDLE_LABEL}}",
                        type: 'togglemenuitem',
                        onSetup: function(component) { createHideMenuOnNodeChangeListener(component, true); createAlignListener(component, 'right', 'middle'); },
                        onAction: function() { Ametys.plugins.cms.editor.Tables.alignTable('right', 'middle'); }
                    },
        
                    {
                        text: "{{i18n plugin.cms:CONTENT_EDITION_TABLE_ALIGN_LEFT_VALIGN_BOTTOM_LABEL}}",
                        type: 'togglemenuitem',
                        onSetup: function(component) { createHideMenuOnNodeChangeListener(component, true); createAlignListener(component, 'left', 'bottom'); },
                        onAction: function() { Ametys.plugins.cms.editor.Tables.alignTable('left', 'bottom'); }
                    },
                    {
                        text: "{{i18n plugin.cms:CONTENT_EDITION_TABLE_ALIGN_CENTER_VALIGN_BOTTOM_LABEL}}",
                        type: 'togglemenuitem',
                        onSetup: function(component) { createHideMenuOnNodeChangeListener(component, true); createAlignListener(component, 'center', 'bottom'); },
                        onAction: function() { Ametys.plugins.cms.editor.Tables.alignTable('center', 'bottom'); }
                    },
                    {
                        text: "{{i18n plugin.cms:CONTENT_EDITION_TABLE_ALIGN_CENTER_VALIGN_BOTTOM_LABEL}}",
                        type: 'togglemenuitem',
                        onSetup: function(component) { createHideMenuOnNodeChangeListener(component, true); createAlignListener(component, 'right', 'bottom'); },
                        onAction: function() { Ametys.plugins.cms.editor.Tables.alignTable('right', 'bottom'); }
                    }
                ];
            }
        },
        
        {
            icon: 'color-picker',
            text: "{{i18n plugin.cms:CONTENT_EDITION_TABLE_STYLES_LABEL}} ", /* space after needed, to avoid that tinymce try to translate this value */
            type: 'nestedmenuitem',
            onSetup: function(component) { createHideMenuOnNodeChangeListener(component, true); },
            getSubmenuItems: function()
            {
                var stylemenu = [];
                var stylesFromConf = Ametys.form.widget.RichText.RichTextConfiguration.getStyledElements("table", editor.getParam('category'));
                for (var i = 0; i < stylesFromConf.length; i++) 
                {
                    let buttonMenu = [];
                    for (var j = 0; j < stylesFromConf[i].values.length; j++) 
                    {
                        var current = stylesFromConf[i].values[j];
                        let cssClass = current.cssClass;
                        var imagePath = current.buttonMediumIcon || current.buttonSmallIcon;
                        
                        var iconId = 'icon-' + Math.random();
                        editor.ui.registry.addIcon(iconId, '<svg version="1.1" style="width: 16px" class="' + current.buttonCSSClass + '" viewBox="0 0 32 32" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"><image xlink:href="' + AmetysTablesPlugin.CONTEXT_PATH + imagePath + '" x="0" y="0" height="100" width="100" /></svg>');
                        
                        var buttonMenuItem = {
                            text: current.label,
                            type: 'togglemenuitem',
                            icon: iconId,
                            tooltip: Ext.util.Format.stripTags(current.description),
                            onSetup: function(component) { createHideMenuOnNodeChangeListener(component, true); createStyleListener(component, cssClass); },
                            onAction: createStyleOnclickFunction(cssClass)
                        };
                        buttonMenu.push(buttonMenuItem);
                    }
                    if (buttonMenu.length > 0)
                    {
                        var button = {
                            text : stylesFromConf[i].label,
                            type: 'nestedmenuitem',
                            getSubmenuItems: function() { return buttonMenu; }
                        };
                        stylemenu.push(button);
                    }
                }
                return stylemenu;
            }
        },
        
        {
            icon: 'table-top-header',
            text: '{{i18n plugin.cms:CONTENT_EDITION_TABLE_HEADER_LABEL}}',
            type: 'nestedmenuitem',
            onSetup: function(component) { createHideMenuOnNodeChangeListener(component, true); },
            getSubmenuItems: function()
            {
                return [
                    {
                        icon: 'table-top-header',
                        type: 'menuitem',
                        text: "{{i18n plugin.cms:CONTENT_EDITION_TABLE_ROW_HEADER_LABEL}}",
                        onSetup: function(component) { createHideMenuOnNodeChangeListener(component, true); },
                        onAction: function() { Ametys.plugins.cms.editor.Tables.toggleRowHeader(); }
                    },
                    {
                        icon: 'table-left-header',
                        type: 'menuitem',
                        text: "{{i18n plugin.cms:CONTENT_EDITION_TABLE_COLUMN_HEADER_LABEL}}",
                        onSetup: function(component) { createHideMenuOnNodeChangeListener(component, true); },
                        onAction: function() { Ametys.plugins.cms.editor.Tables.toggleColHeader(); }
                    }
                ];
            }
        }        
    ];

    function alignListener(button, align, valign)
    {
        if (_currentCell != null)
        {
            var tagName = _currentCell.tagName.toUpperCase();
            if (tagName == 'TD' || tagName == 'TH')
            {
                var toggleFunction = Ext.bind(button.setActive, button);
                Ametys.plugins.cms.editor.Tables.alignListener(_currentCell, editor, toggleFunction, align, valign);
            }
        }
    };
    function createAlignListener(button, align, valign)
    {
        alignListener(button, align, valign);
    };
    function createStyleOnclickFunction(cssClass)
    {
        return function(event)
        {
            if (_currentCell)
            {
                var table = Ametys.plugins.cms.editor.Tables.getTable(_currentCell, false, editor);
                Ametys.plugins.cms.editor.basicactions.ApplyStyle.applyStyle(table, editor, cssClass);
            }
        };
    };
    
    function styleListener(component, cssClass)
    {
        var table = Ametys.plugins.cms.editor.Tables.getTable(_currentCell, false, editor);
        var toggleFunction = Ext.bind(component.setActive, component);
        var enableFunction = function(toggle) {component.setEnabled(toggle)};
        Ametys.plugins.cms.editor.basicactions.ApplyStyle.styleListener(table, editor, toggleFunction, enableFunction, cssClass);
    }
    function createStyleListener(component, cssClass)
    {
        styleListener(component, cssClass);
    };

    editor.ui.registry.addMenuButton('ametystablebutton', {
                icon : 'table',
                fetch: function(callback) {
                    callback(menuItems);
                }
            });
    editor.on('NodeChange', function (e) {
        var element = getEventCell(e);

        if (element != null)
        {
            Ametys.plugins.cms.editor.Tables.currentCellListener(null, null, element);
        }
    });
});
