/*
 *  Copyright 2019 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
Ametys.namespace('Content', (function() {
        function create(config) {
			const workflowName = config.workflowName || "content";
			const initialActionId = config.initialActionId || 1;
			
			if (config.contentTitle == undefined)
			{
				throw new Error("The configuration 'contentTitle' is missing")
			}
			var multilingual;
			if(typeof config.contentTitle == "string")
			{
				multilingual = false
			}
			else if (typeof config.contentTitle == "object")
			{
				multilingual = true
			}
			else
			{
				throw new Error("The configuration 'contentTitle' must be a String or an Object. Type " + typeof config.contentTitle + " is not supported")
			}
			const contentTitle = config.contentTitle;
			
			if (config.contentName == undefined && multilingual)
			{
				throw new Error("The configuration 'contentName' is mandatory if the content is multilingual")
			}
			const contentName = config.contentName || contentTitle;
			
			if (config.contentTypes == undefined)
			{
				throw new Error("The configuration 'contentTypes' is missing")
			}
			var contentTypes;
			if (typeof config.contentTypes == "string")
			{
				contentTypes = [config.contentTypes];
			}
			else if (typeof config.contentTypes == "object" && Array.isArray(config.contentTypes))
			{
				contentTypes = config.contentTypes;
			}
			else
			{
				throw new Error("The configuration 'contentTypes' must be a String or a String[]. Type " + typeof config.contentTypes + " is not supported")
			}
			
			var mixins;
			if(typeof config.mixins == "string")
			{
				mixins = [config.mixins];
			}
			else if(typeof config.mixins == "object" && Array.isArray(config.mixins))
			{
				mixins = config.mixins;
			}
			else if (config.mixins != undefined)
			{
                throw new Error("The configuration 'mixins' must be a String or a String[]. Type " + typeof config.contentTypes + " is not supported")
			}
			
			if (multilingual && config.languageCode != undefined)
			{
				print("The configuration 'languageCode' will be ignored as the content is multilingual")
			}
			else if (!multilingual && config.languageCode == undefined)
			{
				throw new Error("The configuration 'languageCode' is missing. It is mandatory when the content is not multilingual")
			}
			const languageCode = config.languageCode;
			
            const Map = Java.type('java.util.Map');
            const HashMap = Java.type('java.util.HashMap');
            var hashMap = new HashMap();
            for (var propertyName in (config.inputs || {})) 
            {
                hashMap.put(propertyName, config.inputs[propertyName])
            }
            const inputs = hashMap;
            
            const contentWorkflowHelper = Ametys.serviceManager.lookup("org.ametys.cms.workflow.ContentWorkflowHelper");
            
            var result;
			if(multilingual)
			{
				result = contentWorkflowHelper.createContent(workflowName, 
					initialActionId, 
					contentName, 
					contentTitle, 
					contentTypes, 
					mixins, 
					inputs)
			}
			else
			{
				result = contentWorkflowHelper.createContent(workflowName, 
					initialActionId, 
					contentName, 
					contentTitle, 
					contentTypes, 
					mixins, 
					languageCode, 
					inputs)
			}
            
            if (result == null)
            {
                throw new Error("An error occured while creating the content");
            }
            var content = result.get("org.ametys.cms.repository.Content");
            if (content == null)
            {
                throw new Error("The content was not created");
            }
            
            return content;
        }

        return {
            create
        }
    })()
);