/*
 *  Copyright 2019 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
Ametys.namespace('Content', (function() {
    function deleteContent(contents, options)
    {
        function toArray(arg)
        {
            if (typeof arg == "object" && Array.isArray(arg))
            {
                return arg;
            }
            else
            {
                return [arg];
            }
        }

        contents = toArray(contents);
        
        var contentList = new java.util.ArrayList();
        for (var f in contents)
        {
            var content = contents[f];
            if (typeof content == 'string')
            {
                contentList.add(content);
            }
            else
            {
                contentList.add(content.getId());
            }
        }
        
        var contentDAO = Ametys.serviceManager.lookup(org.ametys.cms.repository.ContentDAO.ROLE);
        var result = options && options.force
            ? contentDAO.forceDeleteContents(contentList)
            : contentDAO.deleteContents(contentList);
        
        if (options && options.verbose)
        {
            _listToConsole(result.get('deleted-contents'), " content(s) correctly removed", 'info');
            _listToConsole(result.get('undeleted-contents'), " content(s) not removed due to an unexpected error (see logs for details)", 'error');
            _listToConsole(result.get('referenced-contents'), " content(s) not removed because still referenced by other contents", 'error');
            _listToConsole(result.get('unauthorized-contents'), " content(s) not removed because your rights are insufficient", 'error');
            _listToConsole(result.get('locked-contents'), " content(s) not removed because they are locked", 'error');
        }
        
        return result;
    }
    
    function _listToConsole(list, message, level)
    {
        if (list.size() > 0)
        {
            Ametys.console[level](list.size() + message, list.stream().map(o => "\"" + o.get('title') + "\" (" + o.get('name') + " - " + o.get('id') + ")").collect(java.util.stream.Collectors.toList()));
        }
    }
    
    return {
        'delete': deleteContent
    }
})());