/*
 *  Copyright 2019 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
Ametys.namespace('Solr', (function() {
	
        function _changeWorkspace(request, workspaceName) {
	 		
			const WorkspaceSelector = Java.type('org.ametys.plugins.repository.provider.RequestAttributeWorkspaceSelector');
        	const Arrays = Java.type('java.util.Arrays');
	        
			if (workspaceName != null) 
			{
                const workspaces = Repository.session.getWorkspace().getAccessibleWorkspaceNames();
                const workspaceList = Arrays.asList(workspaces);
                if (!workspaceList.contains(workspaceName)) 
				{
                    throw new Error("Incorrect workspace name: workspace should be part of " + workspaceList);
                }
                WorkspaceSelector.setForcedWorkspace(request, workspaceName);
            }
		}
		
        function _solrSearch(query, workspaceName, filterQueries) {
		
			const WorkspaceSelector = Java.type('org.ametys.plugins.repository.provider.RequestAttributeWorkspaceSelector');
        	const ContextHelper = Java.type('org.apache.cocoon.components.ContextHelper');
			
			const workspaceSelector = Ametys.serviceManager.lookup("org.ametys.plugins.repository.provider.WorkspaceSelector");
			const searcherFactory = Ametys.serviceManager.lookup("org.ametys.cms.search.solr.SearcherFactory");
        
            const request = ContextHelper.getRequest(avalonContext);
            const currentWorkspace = workspaceSelector.getWorkspace();
            try 
			{
                _changeWorkspace(request, workspaceName)
				if(filterQueries != undefined)
				{
					return searcherFactory.create()
                                   	.withFilterQueries(filterQueries)
									.withQueryString(query)
									.search();
				}
				else
				{
					return searcherFactory.create()
									.withQueryString(query)
									.search();
				}
            } 
			finally 
			{
                WorkspaceSelector.setForcedWorkspace(request, currentWorkspace)
            }
		}

        function query(query, workspaceName) {

            return _solrSearch(query, workspaceName)
        }

        function contentQuery(query, contentTypes, facets, workspaceName) {

			const ArrayList = Java.type('java.util.ArrayList');
	        const HashSet = Java.type('java.util.HashSet');
	        const DocumentTypeQuery = Java.type('org.ametys.cms.search.query.DocumentTypeQuery');
			
			const queryBuilder = Ametys.serviceManager.lookup("org.ametys.cms.search.QueryBuilder");
		
			filterQueries = new ArrayList();
            filterQueries.add(new DocumentTypeQuery("content"));
            
			contentTypesSet = new HashSet();
			
			if(typeof contentTypes == "string")
			{
				contentTypesSet.add(contentTypes)
			}
			else if(typeof contentTypes == "object" && Array.isArray(contentTypes))
			{
				contentTypes.forEach(contentType => contentTypesSet.add(contentType));
			}
			else if (contentTypes != undefined)
			{
				throw new Error("contentTypes should not be " + typeof contentTypes)
			}
			
			filterQueries.add(queryBuilder.createContentTypeOrMixinQuery(contentTypesSet, null, true));
            
            return _solrSearch(query, workspaceName, filterQueries)
        }

        return {
            query,
            contentQuery
        }
    })()
);