/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms;

/**
 * Constants for observers.
 */
public interface ObservationConstants
{
    /** Event id when a content is added. */
    public static final String EVENT_CONTENT_ADDED = "content.added";
    /** Event id when a content is being modified. */
    public static final String EVENT_CONTENT_MODIFYING = "content.modifying";
    /** Event id when a content is modified. */
    public static final String EVENT_CONTENT_MODIFIED = "content.modified";
    /** Event id when a content is validated. */
    public static final String EVENT_CONTENT_VALIDATED = "content.validated";
    /** Event id when a content is unpublished. */
    public static final String EVENT_CONTENT_UNTAG_LIVE = "content.untag.live";
    /** Event id when a content is being delete. */
    public static final String EVENT_CONTENT_DELETING = "content.deleting";
    /** Event id when a content is deleled. */
    public static final String EVENT_CONTENT_DELETED = "content.deleted";
    /** Event id when a content is tagged. */
    public static final String EVENT_CONTENT_TAGGED = "content.tagged";
    /** Event id when the workflow a content is modified. */
    public static final String EVENT_CONTENT_WORKFLOW_CHANGED = "content.workflow.changed";
    /** Event id when the reaction change on a content. */
    public static final String EVENT_CONTENT_REACTION_CHANGED = "content.reaction.changed";
    
    /** Event id when a content is archived */
    public static final String EVENT_CONTENT_ARCHIVED = "event.content.archived";
    /** Event id when a content is unarchived */
    public static final String EVENT_CONTENT_UNARCHIVED = "event.content.unarchived";
    
    /** Event id when a comment is added with auto-validation. */
    public static final String EVENT_CONTENT_COMMENT_ADDED = "content.comment.added";
    /** Event id when a comment is modified. */
    public static final String EVENT_CONTENT_COMMENT_MODIFYING = "content.comment.modified";
    /** Event id when a comment is being deleted. */
    public static final String EVENT_CONTENT_COMMENT_DELETING = "content.comment.deleting";
    /** Event id when a comment is deleted. */
    public static final String EVENT_CONTENT_COMMENT_DELETED = "content.comment.deleted";
    /** Event id when a comment is validated. */
    public static final String EVENT_CONTENT_COMMENT_VALIDATED = "content.comment.validated";
    /** Event id when a comment is removed from validation. */
    public static final String EVENT_CONTENT_COMMENT_UNVALIDATED = "content.comment.unvalidated";
    /** Event id when a reaction changed on a comment. */
    public static final String EVENT_CONTENT_COMMENT_REACTION_CHANGED = "content.comment.reaction.changed";
    /** Event id when a comment is reported. */
    public static final String EVENT_CONTENT_COMMENT_REPORTED = "content.comment.reported";
    /** Event id when reports are ignored on comment. */
    public static final String EVENT_CONTENT_COMMENT_IGNORE_REPORTS = "content.comment.ignore.reports";
    /** Event id when reports are ignored on content. */
    public static final String EVENT_CONTENT_IGNORE_REPORTS = "content.ignore.reports";
    
    /** Event id when a contributor comment is added */
    public static final String EVENT_CONTENT_CONTRIBUTOR_COMMENT_ADDED = "content.contributor.comment.added";
    
    /** Argument name for processed ametys object's id */
    public static final String ARGS_AMETYS_OBJECT_ID = "ametys-object.id";
    /** Argument name for processed content */
    public static final String ARGS_CONTENT = "content";
    /** Argument name for processed content's name */
    public static final String ARGS_CONTENT_NAME = "content.name";
    /** Argument name for processed content's new values */
    public static final String ARGS_CONTENT_VALUES = "content.values";
    /** Argument name for processed content's id */
    public static final String ARGS_CONTENT_ID = "content.id";
    /** Argument name for indicating if content modifications have to be commited into Solr */
    public static final String ARGS_CONTENT_COMMIT = "content.commit";
    /** Argument name for processed comment */
    public static final String ARGS_COMMENT = "comment";
    /** Argument name for processed comment's id */
    public static final String ARGS_COMMENT_ID = "comment.id";
    /** Argument name for processed comment's author */
    public static final String ARGS_COMMENT_AUTHOR = "comment.author";
    /** Argument name for processed comment's author email */
    public static final String ARGS_COMMENT_AUTHOR_EMAIL = "comment.author.email";
    /** Argument name for processed comment's validation state */
    public static final String ARGS_COMMENT_VALIDATED = "comment.validated";
    /** Argument name for processed comment's creation date */
    public static final String ARGS_COMMENT_CREATION_DATE = "comment.creation.date";
    /** Argument name for processed jcr tag */
    public static final String ARGS_TAG = "tag";
    /** Argument name for processed tag's id */
    public static final String ARGS_TAG_ID = "tag.id";
    /** Argument name for processed tag's name */
    public static final String ARGS_TAG_NAME = "tag.name";
    /** Argument name for reaction type */
    public static final String ARGS_REACTION_TYPE = "reaction.type";
    /** Argument name for reaction issuer */
    public static final String ARGS_REACTION_ISSUER = "reaction.issuer";
    /** Argument name (optional, default=false) for the acl.update event for indicating if this update has no influence on Solr ACL cache */
    public static final String ARGS_ACL_SOLR_CACHE_UNINFLUENTIAL = "acl-solr-cache-uninfluential";
    
    /** Event id when a tag is created. */
    public static final String EVENT_TAG_ADDED = "tag.added";
    /** Event id when a tag is modified. */
    public static final String EVENT_TAG_UPDATED = "tag.updated";
    /** Event id when a tag is removed. */
    public static final String EVENT_TAG_DELETED = "tag.deleted";
    /** Event id when a tag is moved. */
    public static final String EVENT_TAG_MOVED = "tag.moved";
}
