/*
 *  Copyright 2014 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.clientsideelement;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.commons.lang3.StringUtils;

import org.ametys.cms.repository.Content;
import org.ametys.core.ui.Callable;
import org.ametys.plugins.repository.AmetysRepositoryException;

/**
 * This element creates a ribbon button to archive a content.
 */
public class ArchiveContentClientSideElement extends SmartContentClientSideElement
{
    /**
     * Test if contents can be archived.
     * @param contentIds The ids of contents to test.
     * @return the deleted and undeleted contents.
     */
    @SuppressWarnings("unchecked")
    @Callable
    public Map<String, Object> canArchive(List<String> contentIds)
    {
        Map<String, Object> results = new HashMap<>();
        
        results.put("referenced-contents", new ArrayList<>());
        
        for (String contentId : contentIds)
        {
            Content content = _resolver.resolveById(contentId);
            String contentName = content.getName();
            String contentTitle = StringUtils.defaultString(_contentHelper.getTitle(content), contentName);
            
            Map<String, Object> contentParams = new HashMap<>();
            contentParams.put("id", content.getId());
            contentParams.put("title", contentTitle);
            contentParams.put("name", contentName);
            
            try
            {
                // Test if the content is referenced.
                if (content.hasReferencingContents())
                {
                    // Indicate that the content is referenced.
                    List<Map<String, Object>> referencedContents = (List<Map<String, Object>>) results.get("referenced-contents");
                    referencedContents.add(contentParams);
                }
            }
            catch (AmetysRepositoryException e)
            {
                getLogger().error("Unable to test if a content can be archived: '" + contentId + "'", e);
            }
        }
        
        return results;
    }
    
}
