/*
 *  Copyright 2013 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.clientsideelement;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;

import org.ametys.cms.repository.Content;
import org.ametys.core.observation.ObservationManager;
import org.ametys.core.ui.Callable;
import org.ametys.runtime.i18n.I18nizableText;

/**
 * This element creates a ribbon button to delete a content
 */
public class DeleteContentClientSideElement extends SmartContentClientSideElement
{
    /** Observer manager. */
    protected ObservationManager _observationManager;
    
    @Override
    public void service(ServiceManager smanager) throws ServiceException
    {
        super.service(smanager);
        _observationManager = (ObservationManager) smanager.lookup(ObservationManager.ROLE);
    }
    
    @Override
    @Callable
    public Map<String, Object> getStatus(List<String> contentsId)
    {
        Map<String, Object> results = super.getStatus(contentsId);
        
        results.put("referenced-contents", new ArrayList<>());
        
        List<Map<String, Object>> orphanContents = new ArrayList<>();
        
        @SuppressWarnings("unchecked")
        List<Map<String, Object>> allrightContents = (List<Map<String, Object>>) results.get("allright-contents");
        for (Map<String, Object> allRightContent : allrightContents)
        {
            String contentId = (String) allRightContent.get("id");
            Content content = _resolver.resolveById(contentId);
            
            // Is orphan content ?
            if (!_isContentReferenced(content))
            {
                // Yes, this is a 'all-right' content
                orphanContents.add(allRightContent);
            }
            else
            {
                // No, content is still referenced
                Map<String, Object> contentParams = getContentDefaultParameters (content);
                contentParams.put("description", _getReferencedDescription(content));

                @SuppressWarnings("unchecked")
                List<Map<String, Object>> referencedContents = (List<Map<String, Object>>) results.get("referenced-contents");
                referencedContents.add(contentParams);
            }
        }
        
        // All right contents are only orphan contents
        results.put("allright-contents", orphanContents);
        
        return results;
    }
    
    /**
     * Test if content is still referenced before removing it
     * @param content The content to remove
     * @return true if content is still referenced
     */
    protected boolean _isContentReferenced (Content content)
    {
        return content.hasReferencingContents();
    }
    
    /**
     * Get i18n description when the content is orphan
     * @param content The content
     * @return The {@link I18nizableText} description
     */
    protected I18nizableText _getReferencedDescription (Content content)
    {
        List<String> workflowI18nParameters = new ArrayList<>();
        workflowI18nParameters.add(_contentHelper.getTitle(content));
        
        I18nizableText ed = (I18nizableText) this._script.getParameters().get("referenced-content-description");
        return new I18nizableText(ed.getCatalogue(), ed.getKey(), workflowI18nParameters);
    }
}
