/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.clientsideelement;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;

import org.ametys.cms.repository.Content;
import org.ametys.core.right.RightManager.RightResult;
import org.ametys.core.ui.ClientSideElementHelper;
import org.ametys.plugins.repository.AmetysObjectResolver;

/**
 * This element creates a toggle button representing the lock state.
 */
public class LockedContentClientSideElement extends AbstractContentClientSideElement
{
    /** Repository content */
    protected AmetysObjectResolver _resolver;
    
    @Override
    public void service(ServiceManager smanager) throws ServiceException
    {
        super.service(smanager);
        _resolver = (AmetysObjectResolver) smanager.lookup(AmetysObjectResolver.ROLE);
    }
    
    /**
     * Get the context to check rights
     * @param content The content 
     * @return the right context
     */
    protected String getRightContext (Content content)
    {
        return "/cms";
    }
    
    @Override
    public List<Script> getScripts(boolean ignoreRights, Map<String, Object> contextParameters)
    {
        List<Script> scripts = super.getScripts(ignoreRights, contextParameters);
        List<Script> clonedScripts = new ArrayList<>();
        boolean canUnlockAll = _rightManager.hasRight(_currentUserProvider.getUser(), "CMS_Rights_UnlockAll", "/cms") == RightResult.RIGHT_ALLOW;
        for (Script script : scripts)
        {
            Script scriptClone = ClientSideElementHelper.cloneScript(script);

            scriptClone.getParameters().put("canUnlockAll", canUnlockAll);
            clonedScripts.add(scriptClone);
        }
        return clonedScripts;
    }
}
