/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.clientsideelement;

import org.apache.avalon.framework.configuration.Configuration;
import org.apache.avalon.framework.configuration.ConfigurationException;

import org.ametys.core.ui.StaticClientSideElement;
import org.ametys.runtime.i18n.I18nizableText;

/**
 * This element creates a control button with a menu
 */
public class StaticMenu extends StaticClientSideElement
{
    private int _galleryIndex;
    private int _menuIndex;
    
    @Override
    public void configure(Configuration configuration) throws ConfigurationException
    {
        super.configure(configuration);
        
        _configureGalleries (configuration);
        _configureItemsMenu(configuration);
    }
    
    /**
     * Configure the galleries
     * @param configuration the configuration
     * @throws ConfigurationException If the configuration has an issue
     */
    protected void _configureGalleries(Configuration configuration) throws ConfigurationException
    {
        for (Configuration galleryConfiguration : configuration.getChildren("gallery-item"))
        {
            _configureGroupsGallery (galleryConfiguration);
        }
    }
    
    /**
     * Configure the groups gallery
     * @param configuration the configuration
     * @throws ConfigurationException If the configuration has an issue
     */
    protected void _configureGroupsGallery(Configuration configuration) throws ConfigurationException
    {
        for (Configuration gpConfiguration : configuration.getChildren("gallery-group"))
        {
            _configureItemsGallery(gpConfiguration, gpConfiguration.getAttribute("label"));
        }
    }
    
    /**
     * Configure the gallery items
     * @param configuration the configuration
     * @param group the group gallery
     * @throws ConfigurationException If the configuration has an issue
     */
    protected void _configureItemsGallery(Configuration configuration, String group) throws ConfigurationException
    {
        for (Configuration itemConfiguration : configuration.getChildren("button"))
        {
            this._script.getParameters().put("gallery-" + _galleryIndex, itemConfiguration.getAttribute("id"));
            this._script.getParameters().put("gallery-" + _galleryIndex + "-group",  new I18nizableText("plugin." + _pluginName, group));
            _configureItem(itemConfiguration, "gallery-" + _galleryIndex);
            _galleryIndex++;
        }
        this._script.getParameters().put("gallery-size", _galleryIndex);
    }
    
    /**
     * Configure the items menu
     * @param configuration the configuration
     * @throws ConfigurationException If the configuration has an issue
     */
    protected void _configureItemsMenu(Configuration configuration) throws ConfigurationException
    {
        for (Configuration itemConfiguration : configuration.getChildren("menu-item"))
        {
            this._script.getParameters().put("menu-" + _menuIndex,  itemConfiguration.getAttribute("id"));
            _configureItem(itemConfiguration, "menu-" + _menuIndex);
            _menuIndex++;
        }
        this._script.getParameters().put("menu-size", _menuIndex);
    }
    
    /**
     * Configure the item parameters
     * @param configuration the item configuration
     * @param prefix the item prefix
     * @throws ConfigurationException If the configuration has an issue
     */
    protected void _configureItem (Configuration configuration, String prefix) throws ConfigurationException
    {
        for (Configuration paramConfiguration : configuration.getChildren("param"))
        {
            String name = paramConfiguration.getAttribute("name");
            String value = paramConfiguration.getValue("");
            
            if (paramConfiguration.getAttributeAsBoolean("i18n", false))
            {
                this._script.getParameters().put(prefix + "-" + name, new I18nizableText("plugin." + _pluginName, value));
            }
            else if (paramConfiguration.getAttributeAsBoolean("file", false))
            {
                String pluginName = paramConfiguration.getAttribute("plugin", getPluginName());
                this._script.getParameters().put(prefix + "-" + name, "/plugins/" + pluginName + "/resources/" + value);
            }
            else
            {
                this._script.getParameters().put(prefix + "-" + name, value);
            }
        }
    }
}
