/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.clientsideelement.styles;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;

import org.ametys.core.ui.StaticClientSideElement;
import org.ametys.plugins.core.ui.util.ConfigurationHelper;

/**
 * This static client side element also add parameters taken from the HTMLEditorStyle
 */
public class ParaStyleClientSideElement extends StaticClientSideElement
{
    /** The HTMLEditorStyle instance */
    protected HTMLEditorStyle _htmlEditorStyle;
    
    @Override
    public void service(ServiceManager smanager) throws ServiceException
    {
        super.service(smanager);
        _htmlEditorStyle = (HTMLEditorStyle) smanager.lookup(HTMLEditorStyle.ROLE);
    }

    @Override
    public List<Script> getScripts(boolean ignoreRights, Map<String, Object> contextParameters)
    {
        List<Script> scripts = super.getScripts(ignoreRights, contextParameters);
        
        if (scripts.size() == 0)
        {
            return scripts;
        }
        
        List<ScriptFile> cssFiles = new ArrayList<>();
        List<ScriptFile> scriptFiles = new ArrayList<>();
        Map<String, Object> parameters = new HashMap<>();
        for (Script script : scripts)
        {
            cssFiles.addAll(script.getCSSFiles());
            scriptFiles.addAll(script.getScriptFiles());
            parameters.putAll(ConfigurationHelper.clonePluginParameters(script.getParameters()));
        }
        
        parameters.put("data", new ArrayList<>());
        
        @SuppressWarnings("unchecked")
        List<Map<String, Object>> styles = (List<Map<String, Object>>) parameters.get("data");
        
        for (String category : _htmlEditorStyle.getCategories())
        {
            StyleCategory paraStyleCategory = _htmlEditorStyle.getPara(category, contextParameters);
            if (paraStyleCategory != null)
            {
                for (String cssFile : paraStyleCategory.getBackOfficeCSSFiles())
                {
                    if (cssFile != null)
                    {
                        cssFiles.add(new ScriptFile(cssFile));
                    }
                }
                
                for (Style para : paraStyleCategory.getStyles())
                {
                    styles.add(para.getAsParameters());
                }
                
            }
            
            cssFiles.addAll(_htmlEditorStyle.getBackOfficeCSSFiles(category, contextParameters));
        }
        
        List<Script> scriptList = new ArrayList<>();
        scriptList.add(new Script(this.getId(), _script.getScriptClassname(), scriptFiles, cssFiles, parameters));
        return scriptList;
    }
}
