/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.clientsideelement.styles;

import java.util.List;
import java.util.Set;

/**
 * A category of style. A style and files to import
 */
public class StyleCategory
{
    /** The name of the css file. See getBackOfficeCSSFile */
    protected Set<String> _boCSSFiles;
    /** The name of the css file. See getInlineEditorCSSFile */
    protected Set<String> _inlineEditorCSSFiles;
    /** The list of styles configured. See getStyles */
    protected List<Style> _styleList;
    
    /**
     * Build a style
     * @param boCSSFiles cannot be null.
     * @param inlineEditorCSSFiles cannot be null.
     * @param styleList cannot be null.
     */
    public StyleCategory(Set<String> boCSSFiles, Set<String> inlineEditorCSSFiles, List<Style> styleList)
    {
        _boCSSFiles = boCSSFiles;
        _inlineEditorCSSFiles = inlineEditorCSSFiles;
        _styleList = styleList;
    }
    
    /**
     * Get the url of CSS files to import in the BO HMI to give to the style buttons the right appearance
     * @return Contains absolute urls to CSS files
     */
    public Set<String> getBackOfficeCSSFiles()
    {
        return _boCSSFiles;
    }
    
    /**
     * Get the url of CSS files to import in the inline html editor to give the styles the right appearance
     * @return Contains absolute urls to CSS files
     */
    public Set<String> getInlineEditorCSSFiles()
    {
        return _inlineEditorCSSFiles;
    }
    
    /**
     * Get the list of styles
     * @return A non-null list of para
     */
    public List<Style> getStyles()
    {
        return _styleList;
    }
}
