/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.content;

import java.util.HashMap;
import java.util.Map;

import org.apache.avalon.framework.parameters.Parameters;
import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.cocoon.acting.ServiceableAction;
import org.apache.cocoon.environment.ObjectModelHelper;
import org.apache.cocoon.environment.Redirector;
import org.apache.cocoon.environment.Request;
import org.apache.cocoon.environment.SourceResolver;
import org.apache.commons.lang.StringUtils;
import org.apache.commons.lang3.ArrayUtils;

import org.ametys.cms.contenttype.ContentTypeExtensionPoint;
import org.ametys.cms.contenttype.ContentTypesHelper;
import org.ametys.cms.repository.Content;
import org.ametys.plugins.repository.AmetysObject;
import org.ametys.plugins.repository.AmetysObjectResolver;
import org.ametys.plugins.repository.version.VersionAwareAmetysObject;

/**
 * This action export the plugin name and content type for the current content.
 */
public class GetContentAction extends ServiceableAction
{
    /** The key for plugin's name */
    public static final String RESULT_PLUGINNAME = "plugin";
    /** The key for content type */
    public static final String RESULT_CONTENTTYPE = "contentType";
    /** The key for content version */
    public static final String RESULT_CONTENTVERSION = "contentVersion";
    /** The key for rendering  language */
    public static final String RESULT_RENDERINGLANGUAGE = "renderingLanguage";
    
    /** The content type extension point */
    protected ContentTypeExtensionPoint _contentTypeExtensionPoint;
    /** The ametys object resolver */
    protected AmetysObjectResolver _resolver;
    /** Helper for content types */
    protected ContentTypesHelper _contentTypeshelper;
    
    @Override
    public void service(ServiceManager serviceManager) throws ServiceException
    {
        super.service(serviceManager);
        _contentTypeExtensionPoint = (ContentTypeExtensionPoint) serviceManager.lookup(ContentTypeExtensionPoint.ROLE);
        _resolver = (AmetysObjectResolver) manager.lookup(AmetysObjectResolver.ROLE);
        _contentTypeshelper = (ContentTypesHelper) manager.lookup(ContentTypesHelper.ROLE);
    }

    public Map<String, String> act(Redirector redirector, SourceResolver resolver, Map objectModel, String source, Parameters parameters) throws Exception
    {
        Map<String, String> result = new HashMap<>();
        Request request = ObjectModelHelper.getRequest(objectModel);
        
        AmetysObject ametysObject;
        String id = parameters.getParameter("id", null);
        String path = parameters.getParameter("path", null);
        
        if (id != null)
        {
            ametysObject = _resolver.resolveById(id);
        }
        else if (path != null)
        {
            path = path.replaceAll("%3A", ":");
            ametysObject = _resolver.resolveByPath(path);
        }
        else
        {
            Content content = (Content) request.getAttribute(Content.class.getName());
            ametysObject = content != null ? content : (AmetysObject) request.getAttribute(AmetysObject.class.getName());
        }
        
        if (ametysObject instanceof Content)
        {
            String versionLabel = parameters.getParameter("versionLabel", null);
            String revision = parameters.getParameter("contentVersion", null);
            
            if (StringUtils.isNotEmpty(versionLabel) && ametysObject instanceof VersionAwareAmetysObject versionAO)
            {
                String[] allLabels = versionAO.getAllLabels();
                if (ArrayUtils.contains(allLabels, versionLabel))
                {
                    versionAO.switchToLabel(versionLabel);
                }
            }
            else if (StringUtils.isNotEmpty(revision) && ametysObject instanceof VersionAwareAmetysObject versionAO)
            {
                versionAO.switchToRevision(revision);
            }

            Content content = (Content) ametysObject;
            request.setAttribute(Content.class.getName(), content);
            if (request.getAttribute(RESULT_RENDERINGLANGUAGE) == null)
            {
                request.setAttribute(RESULT_RENDERINGLANGUAGE, content.getLanguage());
                result.put(RESULT_RENDERINGLANGUAGE, content.getLanguage());
            }
            else
            {
                result.put(RESULT_RENDERINGLANGUAGE, (String) request.getAttribute(RESULT_RENDERINGLANGUAGE));
            }
            
            String contentTypeId = _contentTypeshelper.getContentTypeIdForRendering(content);
            
            request.setAttribute(RESULT_CONTENTTYPE, contentTypeId);
            
            result.put(RESULT_CONTENTTYPE, contentTypeId);
            result.put(RESULT_PLUGINNAME, _contentTypeshelper.getContentTypePluginForRendering(content));
            result.put(RESULT_CONTENTVERSION, revision);
        }
        else
        {
            request.setAttribute(AmetysObject.class.getName(), ametysObject);
        }
        
        return result;
    }
}

