/*
 *  Copyright 2013 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.content;

import java.util.ArrayList;
import java.util.Collections;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.avalon.framework.parameters.Parameters;
import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.cocoon.acting.ServiceableAction;
import org.apache.cocoon.environment.ObjectModelHelper;
import org.apache.cocoon.environment.Redirector;
import org.apache.cocoon.environment.Request;
import org.apache.cocoon.environment.SourceResolver;

import org.ametys.cms.contenttype.ContentTypeExtensionPoint;
import org.ametys.cms.lock.LockContentManager;
import org.ametys.cms.repository.Content;
import org.ametys.cms.repository.ContentDAO;
import org.ametys.cms.workflow.ContentWorkflowHelper;
import org.ametys.core.cocoon.JSonReader;
import org.ametys.core.right.RightManager;
import org.ametys.core.user.CurrentUserProvider;
import org.ametys.plugins.repository.AmetysObjectResolver;
import org.ametys.plugins.repository.UnknownAmetysObjectException;

/**
 * Get the content information
 *
 */
public class GetContentInformationAction extends ServiceableAction
{
    /** The Ametys object resolver */
    protected AmetysObjectResolver _resolver;
    /** The current user provider */
    protected CurrentUserProvider _userProvider;
    /** The rights manager */
    protected RightManager _rightManager;
    /** The content type extension point */
    protected ContentTypeExtensionPoint _contentTypeEP;
    /** The lock manager. */
    protected LockContentManager _lockManager;
    /** The content workflow helper */
    protected ContentWorkflowHelper _contentWorkflowHelper;
    /** DAO for contents */
    protected ContentDAO _contentDAO;
    
    @Override
    public void service(ServiceManager smanager) throws ServiceException
    {
        super.service(smanager);
        _resolver = (AmetysObjectResolver) smanager.lookup(AmetysObjectResolver.ROLE);
        _userProvider = (CurrentUserProvider) smanager.lookup(CurrentUserProvider.ROLE);
        _rightManager = (RightManager) smanager.lookup(RightManager.ROLE);
        _contentTypeEP = (ContentTypeExtensionPoint) smanager.lookup(ContentTypeExtensionPoint.ROLE);
        _lockManager = (LockContentManager) smanager.lookup(LockContentManager.ROLE);
        _contentWorkflowHelper = (ContentWorkflowHelper) smanager.lookup(ContentWorkflowHelper.ROLE);
        _contentDAO = (ContentDAO) smanager.lookup(ContentDAO.ROLE);
    }
    
    @Override
    public Map act(Redirector redirector, SourceResolver resolver, Map objectModel, String source, Parameters parameters) throws Exception
    {
        @SuppressWarnings("unchecked")
        Map<String, Object> jsParameters = (Map<String, Object>) objectModel.get(ObjectModelHelper.PARENT_CONTEXT);
        
        @SuppressWarnings("unchecked")
        List<String> contentIds = (List<String>) jsParameters.get("ids");
        
        Map<String, Object> result = new HashMap<>();
        
        List<Map<String, Object>> contents = new ArrayList<>();
        List<String> contentsNotFound = new ArrayList<>();
        
        for (String contentId : contentIds)
        {
            try
            {
                Content content = _resolver.resolveById(contentId);
                contents.add(_contentDAO.getContentProperties(content));
            }
            catch (UnknownAmetysObjectException e)
            {
                contentsNotFound.add(contentId);
            }
        }
        
        result.put("contents", contents);
        result.put("contentsNotFound", contentsNotFound);
        
        Request request = ObjectModelHelper.getRequest(objectModel);
        request.setAttribute(JSonReader.OBJECT_TO_READ, result);
        
        return EMPTY_MAP;
    }
    
    /**
     * Get content additional properties
     * @param content The content
     * @return The additionnal properties
     */
    protected Map<String, Object> getAdditionalProperties (Content content)
    {
        return Collections.EMPTY_MAP;
    }
}
