/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

package org.ametys.cms.content;

import java.util.HashMap;
import java.util.Map;

import org.apache.avalon.framework.parameters.Parameters;
import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.cocoon.acting.ServiceableAction;
import org.apache.cocoon.environment.ObjectModelHelper;
import org.apache.cocoon.environment.Redirector;
import org.apache.cocoon.environment.Request;
import org.apache.cocoon.environment.SourceResolver;
import org.apache.commons.lang3.StringUtils;

import org.ametys.cms.contenttype.ContentTypesHelper;
import org.ametys.cms.repository.Content;
import org.ametys.runtime.model.View;

/**
 * Helper action for getting plugin names for content-types pipelines.
 * The name is get either in request parameter or in request attribute.
 */
public class GetContentTypeInformationAction extends ServiceableAction
{
    private ContentTypesHelper _cTypesHelper;

    @Override
    public void service(ServiceManager smanager) throws ServiceException
    {
        _cTypesHelper = (ContentTypesHelper) smanager.lookup(ContentTypesHelper.ROLE);
    }
    
    @Override
    public Map act(Redirector redirector, SourceResolver resolver, Map objectModel, String source, Parameters parameters) throws Exception
    {
        Map<String, String> result = new HashMap<>();
        
        Request request = ObjectModelHelper.getRequest(objectModel);
        
        String pluginName = request.getParameter("pluginName");
        
        if (pluginName == null)
        {
            pluginName = (String) request.getAttribute("pluginName");
        }
        
        result.put("pluginName", pluginName);
        
        Content content = (Content) request.getAttribute(Content.class.getName());
        if (content != null && content.getLanguage() != null)
        {
            result.put("contentLanguage", content.getLanguage());
        }
        
        if (content != null)
        {
            View view = _getView(content, parameters);
            if (view != null)
            {
                result.put("viewName", view.getName());
            }
        }
        
        return result;
    }
    
    private View _getView(Content content, Parameters parameters)
    {
        String fallbackViewName = parameters.getParameter("fallbackViewName", StringUtils.EMPTY);
        String viewName = parameters.getParameter("viewName", StringUtils.EMPTY);
        
        return _cTypesHelper.getViewWithFallback(viewName, fallbackViewName, content);
    }
}
