/*
 *  Copyright 2016 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.content;

import org.apache.avalon.framework.component.Component;
import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.avalon.framework.service.Serviceable;

import org.ametys.cms.repository.Content;
import org.ametys.plugins.repository.AmetysObjectResolver;
import org.ametys.plugins.repository.RepositoryConstants;
import org.ametys.plugins.repository.collection.AmetysObjectCollection;

/**
 * Helper for retrieving root of contents
 */
public class RootContentHelper implements Component, Serviceable
{
    /** The component role. */
    public static final String ROLE = RootContentHelper.class.getName();
    
    /** Ametys object resolver */
    protected AmetysObjectResolver _resolver;
    
    @Override
    public void service(ServiceManager manager) throws ServiceException
    {
        _resolver = (AmetysObjectResolver) manager.lookup(AmetysObjectResolver.ROLE);
    }
    
    /**
     * Gets the root of contents
     * @return the root of contents
     */
    public AmetysObjectCollection getRootContent()
    {
        return _resolver.resolveByPath("/" + RepositoryConstants.NAMESPACE_PREFIX + ":contents");
    }
    
    /**
     * Tests if the given content is child of the root of contents, i.e. the given content is managed by the CMS workspace
     * @param content The content to test
     * @return true if the given content is child of the root of contents
     */
    public boolean isChildOfRootContent(Content content)
    {
        return getRootContent().equals(content.getParent());
    }
}
