/*
 *  Copyright 2015 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.content.archive;

import java.util.Map;

import org.apache.avalon.framework.context.Context;
import org.apache.avalon.framework.context.ContextException;
import org.apache.avalon.framework.context.Contextualizable;
import org.apache.avalon.framework.logger.AbstractLogEnabled;
import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.avalon.framework.service.Serviceable;

import org.ametys.cms.ObservationConstants;
import org.ametys.cms.content.indexing.solr.SolrIndexer;
import org.ametys.cms.content.indexing.solr.SolrWorkflowIndexer;
import org.ametys.cms.content.indexing.solr.observation.ObserverHelper;
import org.ametys.core.observation.AsyncObserver;
import org.ametys.core.observation.Event;

/**
 * Observer in charge for indexing contents when archived to the archived workspace.
 */
public class IndexArchivedContentObserver extends AbstractLogEnabled implements AsyncObserver, Contextualizable, Serviceable
{
    /** The Solr indexer. */
    protected SolrIndexer _solrIndexer;
    
    /** The solr workflow indexer. */
    protected SolrWorkflowIndexer _solrWfIndexer;
    
    /** The component context. */
    protected Context _context;

    @Override
    public void contextualize(Context context) throws ContextException
    {
        _context = context;
    }
    
    @Override
    public void service(ServiceManager serviceManager) throws ServiceException
    {
        _solrIndexer = (SolrIndexer) serviceManager.lookup(SolrIndexer.ROLE);
        _solrWfIndexer = (SolrWorkflowIndexer) serviceManager.lookup(SolrWorkflowIndexer.ROLE);
    }
    
    @Override
    public boolean supports(Event event)
    {
        return event.getId().equals(ObservationConstants.EVENT_CONTENT_ARCHIVED);
    }
    
    @Override
    public int getPriority(Event event)
    {
        return MAX_PRIORITY + 3000;
    }
    
    @Override
    public void observe(Event event, Map<String, Object> transientVars) throws Exception
    {
        if (ObserverHelper.isNotSuspendedObservationForIndexation())
        {
            String contentId = (String) event.getArguments().get(ObservationConstants.ARGS_CONTENT_ID);
            if (contentId != null)
            {
                _solrIndexer.indexContent(contentId, ArchiveConstants.ARCHIVE_WORKSPACE, true);
            }
        }
    }
    
}
