/*
 *  Copyright 2015 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.content.archive;

import java.util.Map;

import org.apache.avalon.framework.logger.AbstractLogEnabled;
import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.avalon.framework.service.Serviceable;

import org.ametys.cms.ObservationConstants;
import org.ametys.cms.content.indexing.solr.SolrIndexer;
import org.ametys.core.observation.Event;
import org.ametys.core.observation.Observer;

/**
 * Observer in charge for removing unarchived contents from the Solr server.
 */
public class UnindexUnarchivedContentObserver extends AbstractLogEnabled implements Observer, Serviceable
{
    
    /** The Solr indexer. */
    protected SolrIndexer _solrIndexer;
    
    @Override
    public void service(ServiceManager serviceManager) throws ServiceException
    {
        _solrIndexer = (SolrIndexer) serviceManager.lookup(SolrIndexer.ROLE);
    }
    
    @Override
    public boolean supports(Event event)
    {
        return event.getId().equals(ObservationConstants.EVENT_CONTENT_UNARCHIVED);
    }
    
    @Override
    public int getPriority(Event event)
    {
        return 0;
    }
    
    @Override
    public void observe(Event event, Map<String, Object> transientVars) throws Exception
    {
        String contentId = (String) event.getArguments().get(ObservationConstants.ARGS_CONTENT_ID);
        
        if (contentId != null)
        {
            _solrIndexer.unindexContent(contentId, ArchiveConstants.ARCHIVE_WORKSPACE, true);
        }
    }
    
}
