/*
 *  Copyright 2017 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.content.attachments;

import org.ametys.cms.indexing.explorer.AbstractSolrIndexResourceObserver;
import org.ametys.cms.repository.Content;
import org.ametys.plugins.explorer.resources.Resource;
import org.ametys.plugins.explorer.resources.ResourceCollection;
import org.ametys.plugins.repository.AmetysObject;
import org.ametys.plugins.repository.RepositoryConstants;

/**
 * Listener on content attachments events
 */
public class ContentAttachmentsSolrObserver extends AbstractSolrIndexResourceObserver
{
    private Content _content;

    @Override
    protected String[] getWorkspacesToIndex()
    {
        return new String[] {RepositoryConstants.DEFAULT_WORKSPACE};
    }
    
    @Override
    protected boolean isHandledResource(AmetysObject object)
    {
        AmetysObject parent = object.getParent();
        while (parent != null)
        {
            if (parent instanceof Content)
            {
                _content = (Content) parent;
                return true;
            }
            parent = parent.getParent();
        }
        
        return false;
    }
    
    @Override
    protected void onResourceCreated(Resource resource, String workspaceName) throws Exception
    {
        if (_content != null)
        {
            // _content must be != null because #isHandledResource is called just before
            _solrIndexer.indexContentAttachment(resource, _content);
            _content = null;
        }
    }
    
    @Override
    protected void onResourceUpdated(Resource resource, String workspaceName) throws Exception
    {
        if (_content != null)
        {
            // _content must be != null because #isHandledResource is called just before
            _solrIndexer.indexContentAttachment(resource, _content);
            _content = null;
        }
    }
    
    @Override
    protected void onCollectionRenamedOrMoved(ResourceCollection resourceCollection, String workspaceName) throws Exception
    {
        if (_content != null)
        {
            // _content must be != null because #isHandledResource is called just before
            _solrIndexer.indexContentAttachments(resourceCollection, _content);
            _content = null;
        }
    }
}
