/*
 *  Copyright 2023 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.content.consistency;

import java.util.Map;

import org.apache.avalon.framework.parameters.Parameters;
import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.avalon.framework.service.Serviceable;
import org.apache.cocoon.acting.AbstractAction;
import org.apache.cocoon.environment.ObjectModelHelper;
import org.apache.cocoon.environment.Redirector;
import org.apache.cocoon.environment.Request;
import org.apache.cocoon.environment.SourceResolver;

import org.ametys.core.util.ServerCommHelper;

/**
 * Perform a search of content consistency result based on JS parameters.
 * The search result will be stored in request attribute
 */
public class ContentConsistencySearchAction extends AbstractAction implements Serviceable
{
    /** The content consistency searcher */
    protected ContentConsistencySearcher _consitencySearcher;
    /** The server Comm helper */
    protected ServerCommHelper _serverCommHelper;

    public void service(ServiceManager manager) throws ServiceException
    {
        _consitencySearcher = (ContentConsistencySearcher) manager.lookup(ContentConsistencySearcher.ROLE);
        _serverCommHelper = (ServerCommHelper) manager.lookup(ServerCommHelper.ROLE);
    }
    
    public Map act(Redirector redirector, SourceResolver resolver, Map objectModel, String source, Parameters parameters) throws Exception
    {
        Request request = ObjectModelHelper.getRequest(objectModel);
        
        Map<String, Object> searchResults = _consitencySearcher.searchResults(_serverCommHelper.getJsParameters());
        
        request.setAttribute(ContentConsistencyResultGenerator.RESULTS_REQUEST_ATTRIBUTE_NAME, searchResults.get("consistencyResults"));
        return EMPTY_MAP;
    }
}
