/*
 *  Copyright 2016 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.content.external;

import java.util.HashSet;
import java.util.Set;

import org.ametys.cms.repository.Content;
import org.ametys.plugins.repository.data.external.ExternalizableDataProviderExtensionPoint;
import org.ametys.runtime.plugin.component.AbstractThreadSafeComponentExtensionPoint;

/**
 * Extension point for {@link ExternalizableMetadataProvider}s.
 * @deprecated Use {@link ExternalizableDataProviderExtensionPoint} instead
 */
@Deprecated
public class ExternalizableMetadataProviderExtensionPoint extends AbstractThreadSafeComponentExtensionPoint<ExternalizableMetadataProvider>
{
    /** Avalon Role */
    public static final String ROLE = ExternalizableMetadataProviderExtensionPoint.class.getName();
    
    /**
     * Get the path of metadata that can be valued externally or locally by a {@link ExternalizableMetadataProvider}
     * @param content The content
     * @return The path of external or local metadata
     */
    public Set<String> getExternalAndLocalMetadata (Content content)
    {
        Set<String> metadataPaths = new HashSet<>();
        
        for (String id : getExtensionsIds())
        {
            ExternalizableMetadataProvider provider = getExtension(id);
            
            for (String metadataPath : provider.getExternalAndLocalMetadata(content))
            {
                if (metadataPaths.contains(metadataPath))
                {
                    throw new UnsupportedOperationException("The metadata of path " + metadataPath + " is already handled by a externalisable metadata provider");
                }
                metadataPaths.add(metadataPath);
            }
        }
        return metadataPaths;
    }
    
}
