/*
 *  Copyright 2015 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.content.indexing.solr;

import org.ametys.cms.contenttype.ContentType;
import org.ametys.plugins.repository.AmetysObject;

/**
 * Constants for Solr field names related to indexation.
 */
public interface SolrFieldNames
{
    //// CMS
    
    /** Separator before language suffix */
    public static final String LANGUAGE_SEPARATOR = "_";
    /** Stemmed operator */
    public static final String STEMMED_OPERATOR = "_stemmed";
    /** Exact word search operator */
    public static final String EXACT_WS_OPERATOR = "_s_ws";
    
    
    /** Document type. */
    public static final String DOCUMENT_TYPE = "_documentType";
    
    /** Repeater entry position. */
    public static final String REPEATER_ENTRY_POSITION = "_position";
    
    /** Document type for a content */
    public static final String TYPE_CONTENT = "content";
    /** Document type for a content repeater */
    public static final String TYPE_REPEATER = "repeater";
    /** Document type for a resource */
    public static final String TYPE_RESOURCE = "resource";
    /** Document type for a resource of a content (as a content attachment) */
    public static final String TYPE_CONTENT_ATTACHMENT_RESOURCE = "contentAttachmentResource";
    /** Document type for a resource of a content (as an attribute of content) */
    public static final String TYPE_CONTENT_ATTRIBUTE_RESOURCE = "contentAttributeResource";
    /** The id of the content for an attachment */
    public static final String ATTACHMENT_CONTENT_ID = "attachedContentId";
    /** Document type for a workflow entry. */
    public static final String TYPE_WF_ENTRY = "workflowEntry";
    /** Document type for a workflow step. */
    public static final String TYPE_WF_STEP = "workflowStep";
    
    /** Id field name. */
    public static final String ID = "id";
    /** Title field name. */
    public static final String TITLE = "title";
    /** Page title for sorting field name. */
    public static final String TITLE_SORT = "title_sort";
    
    /** Full-text field name with general text indexation. */
    public static final String SYSTEM_FULL = "systemFull";
    /** Full-text field name with general text indexation. */
    public static final String FULL = "full";
    /** Last modified date field name. */
    public static final String LAST_MODIFIED = "lastModified";
    /** Creation date field name. */
    public static final String CREATION_DATE = "creationDate";
    
    /** Validated comments of a content. */
    public static final String CONTENT_COMMENTS_VALIDATED = "commentsValidated";
    /** Non-validated comments of a content. */
    public static final String CONTENT_COMMENTS_NONVALIDATED = "commentsNonValidated";
    
    /** Content name field name. */
    public static final String CONTENT_NAME = "contentName";
    /** Content types field name. */
    public static final String CONTENT_TYPES = "contentTypes";
    /** All content types field name. */
    public static final String ALL_CONTENT_TYPES = "allContentTypes";
    /** Mixin types field name. */
    public static final String MIXIN_TYPES = "mixinTypes";
    /** All mixin types field name. */
    public static final String ALL_MIXIN_TYPES = "allMixinTypes";
//    /** The content types and mixins of a content. */
//    public static final String CONTENT_TYPE_OR_MIXIN = "contentTypeOrMixin";
    /** Pseudo content types field name. */
    public static final String PSEUDO_CONTENT_TYPES = "pseudoContentTypes";
    /** Pseudo content type value for a resource */
    public static final String PSEUDO_CONTENT_TYPE_VALUE_RESOURCE = "resource";
    /** Content language field name. */
    public static final String CONTENT_LANGUAGE = "contentLanguage";
    /** Content creator field name. */
    public static final String CONTENT_CREATOR = "creator";
    /** Content last contributor field name. */
    public static final String CONTENT_LAST_CONTRIBUTOR = "contributor";
    /** Content first validator field name */
    public static final String CONTENT_FIRST_VALIDATOR = "firstValidator";
    /** Content last validator field name. */
    public static final String CONTENT_LAST_VALIDATOR = "lastValidator";
    /** Content last major validator field name */
    public static final String CONTENT_LAST_MAJOR_VALIDATOR = "lastMajorValidator";
    /** Tags field name. */
    public static final String TAGS = "tags";
    /** All tags (including parent ones). */
    public static final String ALL_TAGS = "allTags";
    /** The ids of the outgoing references to resources or folders of resources (as metadata, in docbooks, attachments of this content...) */
    public static final String CONTENT_OUTGOING_REFEERENCES_RESOURCE_IDS = "content-outgoingResourceRefIds";
    /** The ids of visible content attachments */
    public static final String CONTENT_VISIBLE_ATTACHMENT_RESOURCE_IDS = "content-visibleAttachmentIds";
    
    /** Content: embedded mode. */
    /** Content titles field name. */
    public static final String CONTENT_TITLES = "content-titles";
    /** Content languages field. */
    public static final String CONTENT_LANGUAGES = "content-languages";
    /** Sub-content field name. */
    public static final String SUB_CONTENT = "subContent";
    
    /** Resource excerpt field name. */
    public static final String EXCERPT = "excerpt";
    /** The file name for resources. */
    public static final String FILENAME = "filename";
    /** The resource path */
    public static final String PATH = "path";
    /** The mime type for resources. */
    public static final String MIME_TYPES = "mimeTypes";
    /** The length of a resource. */
    public static final String LENGTH = "length";
    /** The dummy "content type" of a resource. */
    public static final String CONTENT_TYPE_RESOURCE = "resource";
    /** The resource root ID */
    public static final String RESOURCE_ROOT_ID = "resourceRootId";
    /** The ids of the ancestors of the resource (i.e. ids of the parent resource collections) */
    public static final String RESOURCE_ANCESTOR_IDS = "resource-ancestorIds";
    /** The ids of the ancestors of the resource and the resource itself */
    public static final String RESOURCE_ANCESTOR_AND_SELF_IDS = "resource-ancestorAndSelfIds";
    /** The resource author */
    public static final String RESOURCE_CREATOR = "resourceCreator";
    /** The resource date */
    public static final String RESOURCE_DATE = "resourceDate";
    /** Last modified date field name. */
    public static final String RESOURCE_LAST_MODIFIED = "last-modified";
    
    //// Date facet
    // TODO Use docValues ?
    /** Date facet field. */
    public static final String DATES_FACET = "dates-facet";
    /** Date sorting */
    public static final String DATE_FOR_SORTING = "date-for-sorting";
    
    //// Dublin Core metadatas
    /** Dublin Core title. */
    public static final String DC_TITLE = "DCTitle";
    /** Dublin Core creator. */
    public static final String DC_CREATOR = "DCCreator";
    /** Dublin Core subject. */
    public static final String DC_SUBJECT = "DCSubject";
    /** Dublin Core description. */
    public static final String DC_DESCRIPTION = "DCDescription";
    /** Dublin Core publisher. */
    public static final String DC_PUBLISHER = "DCPublisher";
    /** Dublin Core contributor. */
    public static final String DC_CONTRIBUTOR = "DCContributor";
    /** Dublin Core date. */
    public static final String DC_DATE = "DCDate";
    /** Dublin Core type. */
    public static final String DC_TYPE = "DCType";
    /** Dublin Core format. */
    public static final String DC_FORMAT = "DCFormat";
    /** Dublin Core identifier. */
    public static final String DC_IDENTIFIER = "DCIdentifier";
    /** Dublin Core source. */
    public static final String DC_SOURCE = "DCSource";
    /** Dublin Core language. */
    public static final String DC_LANGUAGE = "DCLanguage";
    /** Dublin Core relation. */
    public static final String DC_RELATION = "DCRelation";
    /** Dublin Core coverage. */
    public static final String DC_COVERAGE = "DCCoverage";
    /** Dublin Core rights. */
    public static final String DC_RIGHTS = "DCRights";
    
    /** Group of MIME-Type of the resource */
    public static final String RESOURCE_MIME_TYPE_GROUP = "resource-mimeTypeGroup";
    
    //// Workflow fields.
    /** Constant for workflow reference field (on the AmetysObject itself). */
    public static final String WORKFLOW_REF = "workflowRef";
    /** Constant for workflow reference field with suffix (on the AmetysObject itself). */
    public static final String WORKFLOW_REF_DV = "workflowRef_s_dv";
    /** Constant for workflow name field. */
    public static final String WORKFLOW_NAME = "wfName";
    /** Constant for workflow entry state field. */
    public static final String WORKFLOW_ENTRY_STATE = "wfEntryState";
    /** Constant for workflow history steps field. */
    public static final String WORKFLOW_HISTORY_STEPS = "wfHistorySteps";
    /** Constant for workflow history steps field (with suffix). */
    public static final String WORKFLOW_HISTORY_STEPS_DV = WORKFLOW_HISTORY_STEPS + "_s_dv";
    /** Constant for workflow current steps field. */
    public static final String WORKFLOW_CURRENT_STEPS = "wfCurrentSteps";
    /** Constant for workflow current steps field (with suffix). */
    public static final String WORKFLOW_CURRENT_STEPS_DV = WORKFLOW_CURRENT_STEPS + "_s_dv";
    /** Constant for workflow step ID field. */
    public static final String WORKFLOW_STEP_ID = "wfStepId";
    /** Constant for workflow step action ID field. */
    public static final String WORKFLOW_STEP_ACTIONID = "wfStepActionId";
    /** Constant for workflow step owner field. */
    public static final String WORKFLOW_STEP_OWNER = "wfStepOwner";
    /** Constant for workflow step caller field. */
    public static final String WORKFLOW_STEP_CALLER = "wfStepCaller";
    /** Constant for workflow step start date field. */
    public static final String WORKFLOW_STEP_STARTDATE = "wfStepStartDate";
    /** Constant for workflow step due date field. */
    public static final String WORKFLOW_STEP_DUEDATE = "wfStepDueDate";
    /** Constant for workflow step finish date field. */
    public static final String WORKFLOW_STEP_FINISHDATE = "wfStepFinishDate";
    /** Constant for workflow step status field. */
    public static final String WORKFLOW_STEP_STATUS = "wfStepStatus";
    
    //// ACL fields.
    /** Constant for indicating if it is an {@link AmetysObject}. */
    public static final String IS_AMETYS_OBJECT = "ametysObject";
    /** Constant for initial value of read-access for anonymous user */
    public static final String ACL_INIT_VALUE_ANONYMOUS = "__initValueAclAnonymous";
    /** Constant for initial value of read-access for any connected user */
    public static final String ACL_INIT_VALUE_ANYCONNECTED = "__initValueAclAnyConnectedUser";
    /** Constant for initial value of read-access for allowed users */
    public static final String ACL_INIT_VALUE_ALLOWED_USERS = "__initValueAclAllowedUsers";
    /** Constant for initial value of read-access for denied users */
    public static final String ACL_INIT_VALUE_DENIED_USERS = "__initValueAclDeniedUsers";
    /** Constant for initial value of read-access for allowed groups */
    public static final String ACL_INIT_VALUE_ALLOWED_GROUPS = "__initValueAclAllowedGroups";
    /** Constant for initial value of read-access for denied groups */
    public static final String ACL_INIT_VALUE_DENIED_GROUPS = "__initValueAclDeniedGroups";
    
    /** Constant for parents of the content, i.e. all the ascending hierarchy (parent, grandparent, etc.). See {@link ContentType#getParentAttributeDefinition()}  */
    public static final String SIMPLE_CONTENT_PARENTS = "parents";

}
