/*
 *  Copyright 2019 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.content.indexing.solr.content.attachment.impl;

import java.util.Collection;
import java.util.List;
import java.util.Map.Entry;
import java.util.Set;
import java.util.stream.Collectors;

import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.avalon.framework.service.Serviceable;

import org.ametys.cms.content.indexing.solr.content.attachment.ContentVisibleAttachmentIndexer;
import org.ametys.cms.content.references.OutgoingReferences;
import org.ametys.cms.content.references.OutgoingReferencesExtractor;
import org.ametys.cms.repository.Content;

/**
 * A {@link ContentVisibleAttachmentIndexer} for attachments extracted from the {@link OutgoingReferencesExtractor} component.
 */
public class OutgoingRefsContentAttachmentIndexer implements ContentVisibleAttachmentIndexer, Serviceable
{
    /** The outgoing references extractor */
    protected OutgoingReferencesExtractor _outgoingReferencesExtractor;
    
    @Override
    public void service(ServiceManager manager) throws ServiceException
    {
        _outgoingReferencesExtractor = (OutgoingReferencesExtractor) manager.lookup(OutgoingReferencesExtractor.ROLE);
    }
    
    @Override
    public Collection<String> getVisibleAttachmentIds(Content content)
    {
        return _outgoingReferencesExtractor.getOutgoingReferences(content)
                // key of #getOutgoingReferences() is the data path, we do not care what data it comes from
                .values()
                .parallelStream()
                .map(OutgoingReferences::entrySet)
                .flatMap(Set::parallelStream)
                .filter(this::_filterReferences)
                .map(Entry::getValue)
                // flat resource ids
                .flatMap(List::parallelStream)
                .collect(Collectors.toList());
    }
    
    private boolean _filterReferences(Entry<String, List<String>> outgoingRefsEntry)
    {
        // only references of 'explorer' type or 'attachment-content' type
        String outgoingRefsType = outgoingRefsEntry.getKey();
        return "explorer".equals(outgoingRefsType) || "attachment-content".equals(outgoingRefsType);
    }
}

