/*
 *  Copyright 2015 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.content.indexing.solr.observation;

import java.util.Map;

import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.avalon.framework.service.Serviceable;

import org.ametys.cms.ObservationConstants;
import org.ametys.cms.content.indexing.solr.SolrIndexer;
import org.ametys.cms.repository.Content;
import org.ametys.cms.search.solr.field.CommentsSearchField;
import org.ametys.core.observation.Event;
import org.ametys.core.observation.Observer;
import org.ametys.runtime.plugin.component.AbstractLogEnabled;

/**
 * Observes when comments change on a content, to index the comments status.
 */
public class ContentCommentsObserver extends AbstractLogEnabled implements Observer, Serviceable
{
    
    /** The Solr indexer. */
    protected SolrIndexer _solrIndexer;
    
    public void service(ServiceManager manager) throws ServiceException
    {
        _solrIndexer = (SolrIndexer) manager.lookup(SolrIndexer.ROLE);
    }
    
    public boolean supports(Event event)
    {
        return event.getId().equals(ObservationConstants.EVENT_CONTENT_COMMENT_ADDED)
             || event.getId().equals(ObservationConstants.EVENT_CONTENT_COMMENT_DELETED)
             || event.getId().equals(ObservationConstants.EVENT_CONTENT_COMMENT_VALIDATED)
             || event.getId().equals(ObservationConstants.EVENT_CONTENT_COMMENT_UNVALIDATED);
    }
    
    public int getPriority(Event event)
    {
        return Observer.MAX_PRIORITY + 1000;
    }
    
    public void observe(Event event, Map<String, Object> transientVars) throws Exception
    {
        Content content = (Content) event.getArguments().get(ObservationConstants.ARGS_CONTENT);
        
        if (content != null)
        {
            _solrIndexer.updateSystemProperty(content, CommentsSearchField.NAME, null);
        }
    }

}
