/*
 *  Copyright 2016 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.content.indexing.solr.observation;

/**
 * This helper centralize a few common helper methods
 */
public final class ObserverHelper
{
    private static int _suspended;
    
    private ObserverHelper()
    {
        // Nothing
    }
    
    /**
     * <b>Expert method</b>
     * <br><b>This should only be used when there is only one thread working at that time (i.e. during the initialization of the application) 
     * and that you manually do the global indexing after your long process.</b>
     * <br>All threads will not index anymore after observed events
     * <br>Call {@link #restartObservationForIndexation()} to listen to events again.
     * <br>You have to call {@link #restartObservationForIndexation()} the same number of times you called before {@link #suspendObservationForIndexation()}
     */
    public static synchronized void suspendObservationForIndexation()
    {
        _suspended++;
    }
    
    /**
     * Is events observation suspended for indexation?
     * @return true if events are not suspended, false otherwise.
     */
    public static synchronized boolean isNotSuspendedObservationForIndexation()
    {
        return _suspended == 0;
    }

    /**
     * <b>Expert method</b>
     * <br>Listen to events again after a call to {@link #suspendObservationForIndexation()}
     * <br>You have to call {@link #restartObservationForIndexation()} the same number of times you called before {@link #suspendObservationForIndexation()}
     */
    public static synchronized void restartObservationForIndexation()
    {
        _suspended--;
    }
}
