/*
 *  Copyright 2015 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.content.indexing.solr.observation;

import java.util.Map;

import org.apache.avalon.framework.logger.AbstractLogEnabled;
import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.avalon.framework.service.Serviceable;
import org.apache.solr.client.solrj.SolrClient;

import org.ametys.cms.ObservationConstants;
import org.ametys.cms.content.indexing.solr.SolrIndexer;
import org.ametys.cms.search.solr.SolrClientProvider;
import org.ametys.core.observation.Event;
import org.ametys.core.observation.Observer;
import org.ametys.plugins.repository.provider.AbstractRepository;
import org.ametys.plugins.repository.provider.JackrabbitRepository;

/**
 * Observer in charge for removing deleted contents from the Solr server.
 */
public class UnindexContentObserver extends AbstractLogEnabled implements Observer, Serviceable
{
    /** The provider of solr clients */
    protected SolrClientProvider _solrClientProvider;
    /** The Solr indexer. */
    protected SolrIndexer _solrIndexer;
    
    /** The JCR repository */
    protected JackrabbitRepository _repository;
    
    @Override
    public void service(ServiceManager serviceManager) throws ServiceException
    {
        _solrClientProvider = (SolrClientProvider) serviceManager.lookup(SolrClientProvider.ROLE);
        _solrIndexer = (SolrIndexer) serviceManager.lookup(SolrIndexer.ROLE);
        _repository = (JackrabbitRepository) serviceManager.lookup(AbstractRepository.ROLE);
    }
    
    @Override
    public boolean supports(Event event)
    {
        return event.getId().equals(ObservationConstants.EVENT_CONTENT_DELETED);
    }
    
    @Override
    public int getPriority(Event event)
    {
        return 0;
    }
    
    @Override
    public void observe(Event event, Map<String, Object> transientVars) throws Exception
    {
        if (ObserverHelper.isNotSuspendedObservationForIndexation())
        {
            Map<String, Object> args = event.getArguments();
            Boolean commit = (Boolean) args.get(ObservationConstants.ARGS_CONTENT_COMMIT);
            if (commit == null)
            {
                // If not specified, let commit argument be 'true' by default, in order to be sure to commit changes.
                commit = true;
            }
            
            String contentId = (String) event.getArguments().get(ObservationConstants.ARGS_CONTENT_ID);
            if (contentId != null)
            {
                String[] workspaceNames = _repository.getWorkspaces();
                for (String workspaceName : workspaceNames)
                {
                    SolrClient solrClient = _solrClientProvider.getUpdateClient(workspaceName, commit);
                    _solrIndexer.unindexContent(contentId, workspaceName, true, solrClient);
                }
            }
        }
    }
    
}
