/*
 *  Copyright 2022 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.content.properties;

import java.lang.reflect.Array;
import java.util.Arrays;
import java.util.HashSet;
import java.util.List;
import java.util.Optional;
import java.util.Set;

import org.ametys.cms.model.properties.Property;
import org.ametys.cms.repository.Content;
import org.ametys.runtime.model.Model;
import org.ametys.runtime.model.ModelItem;
import org.ametys.runtime.model.type.ModelItemType;

/**
 * {@link Property} referencing multiple typed values in one property.
 * @param <T> Type of the element value
 */
public abstract class AbstractMultiTypedValuesProperty<T> extends AbstractMultiValuesProperty<T>
{
    @Override
    public void setModel(Model model)
    {
        for (String attributePath : _attributePaths)
        {
            Optional.of(attributePath)
                .map(model::getModelItem)
                .map(ModelItem::getType)
                .map(ModelItemType::getId)
                .filter(_getTypeId()::equals)
                .orElseThrow(() -> new RuntimeException("'" + attributePath + "' is invalid for property '" + getName() + "', it should only reference " + _getTypeId() + " model items."));
        }
        
        super.setModel(model);
    }
    
    @Override
    @SuppressWarnings("unchecked")
    public Object getValue(Content content)
    {
        Set<T> allValues = new HashSet<>();
        for (String attributePath : _attributePaths)
        {
            Object value = content.getValue(attributePath, true);
            if (value != null)
            {
                if (getType().getManagedClassArray().isInstance(value))
                {
                    allValues.addAll(Arrays.asList((T[]) value));
                }
                else if (value instanceof List)
                {
                    allValues.addAll((List<T>) value);
                }
                else if (getType().getManagedClass().isInstance(value))
                {
                    allValues.add((T) value);
                }
            }
        }

        T[] array = (T[]) Array.newInstance(getType().getManagedClass(), allValues.size());
        return allValues.toArray(array);
    }
}
