/*
 *  Copyright 2022 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.content.properties;

import java.util.ArrayList;
import java.util.List;

import org.apache.avalon.framework.configuration.Configuration;
import org.apache.avalon.framework.configuration.ConfigurationException;

import org.ametys.cms.model.properties.ElementRefProperty;
import org.ametys.cms.model.properties.Property;
import org.ametys.cms.repository.Content;
import org.ametys.runtime.model.Enumerator;

/**
 * {@link Property} referencing multiple values in one property.
 * @param <T> Type of the element value
 */
public abstract class AbstractMultiValuesProperty<T> extends ElementRefProperty<T, Content>
{
    /** The attribute paths. */
    protected List<String> _attributePaths;
    
    @Override
    protected void configureReferencedElementPath(Configuration configuration) throws ConfigurationException
    {
        _attributePaths = new ArrayList<>();
        for (Configuration attributeConf : configuration.getChildren("attribute"))
        {
            _attributePaths.add(attributeConf.getAttribute("path"));
        }
        
        if (!_attributePaths.isEmpty())
        {
            setElementPath(_attributePaths.get(0));
        }
        else
        {
            throw new ConfigurationException("The property '" + getName() + "' has to reference at least one attribute", configuration);
            
        }
    }
    
    @Override
    public boolean isMultiple()
    {
        return true;
    }
    
    @Override
    public Enumerator<T> getEnumerator()
    {
        // There is no sense to retrieve the enumerator of the first referenced attribute -> it could lead to errors
        return null;
    }
}
