/*
 *  Copyright 2015 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.content.properties;

import java.util.Arrays;
import java.util.HashSet;
import java.util.Set;

import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.avalon.framework.service.Serviceable;

import org.ametys.cms.model.properties.Property;
import org.ametys.cms.repository.Content;
import org.ametys.cms.search.content.ContentSearchHelper;
import org.ametys.runtime.model.type.ElementType;
import org.ametys.runtime.model.type.ModelItemTypeConstants;

/**
 * {@link Property} referencing multiple string values in one property.
 * String values can come from attributes of different types like string, content, double, ...
 * Each value is converted as string.
 */
public class MultiStringValuesProperty extends AbstractMultiValuesProperty<String> implements Serviceable
{
    /** The content search helper. */
    protected ContentSearchHelper _contentSearchHelper;
    
    public void service(ServiceManager manager) throws ServiceException
    {
        _contentSearchHelper = (ContentSearchHelper) manager.lookup(ContentSearchHelper.ROLE);
    }
    
    @Override
    @SuppressWarnings("unchecked")
    public Object getValue(Content content)
    {
        Set<String> valuesAsString = new HashSet<>();
        for (String attributePath : _attributePaths)
        {
            Object value = content.getValue(attributePath, true);
            if (value != null)
            {
                ElementType type = content.getType(attributePath);
                
                if (type.getManagedClassArray().isInstance(value))
                {
                    Arrays.stream((Object[]) value)
                          .map(type::toString)
                          .forEach(valueAsString -> valuesAsString.add(valueAsString));
                }
                else
                {
                    String valueAsString = type.toString(value);
                    valuesAsString.add(valueAsString);
                }
            }
        }
        
        return valuesAsString.toArray(new String[valuesAsString.size()]);
    }
    
    @Override
    protected String _getTypeId()
    {
        return ModelItemTypeConstants.STRING_TYPE_ID;
    }
}
