/*
 *  Copyright 2014 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

package org.ametys.cms.content.references;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * Outgoing references.
 * <p>
 * They are simply a {@link Map} where keys are the reference types (String) and
 * values are the reference values (List) with some convenient methods.
 * </p>
 */
public class OutgoingReferences extends HashMap<String, List<String>>
{
    /** An unmodifiable empty map of outgoing references */
    public static final OutgoingReferences EMPTY = new OutgoingReferences(); 
    
    /**
     * Merge outgoing references with the current ones
     * @param others The new references
     */
    public void merge(OutgoingReferences others)
    {
        if (others != null)
        {
            for (String type : others.keySet())
            {
                if (this.containsKey(type))
                {
                    this.get(type).addAll(others.get(type));
                }
                else
                {
                    this.put(type, others.get(type));
                }
            }
        }
    }
}
