/*
 *  Copyright 2019 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

package org.ametys.cms.content.references;

import javax.jcr.NodeIterator;
import javax.jcr.RepositoryException;
import javax.jcr.query.InvalidQueryException;
import javax.jcr.query.Query;

import org.ametys.cms.content.type.ContentContentElementType;
import org.ametys.cms.repository.DefaultContent;
import org.ametys.plugins.repository.RepositoryConstants;
import org.ametys.plugins.repository.jcr.JCRAmetysObject;

/**
 * Helper for outgoing references
 */
public final class OutgoingReferencesHelper
{
    private OutgoingReferencesHelper()
    {
        // Helper class, never to be instantiated.
    }
    
    /**
     * Get content outgoing references from the content
     * @param content the content
     * @return the node iterator of outgoing references
     * @throws InvalidQueryException if a query error occurred
     * @throws RepositoryException if a repository error occurred
     */
    public static NodeIterator getContentOutgoingReferences(JCRAmetysObject content) throws InvalidQueryException, RepositoryException
    {
        StringBuilder queryStr = new StringBuilder("//element(")
                .append(ContentContentElementType.OUTGOING_REFERENCE_TYPE).append(", ")
                .append(RepositoryConstants.NAMESPACE_PREFIX).append(':').append(DefaultContent.METADATA_OUTGOING_REFERENCE_NODETYPE)
                .append(')');

        queryStr.append('[').append(RepositoryConstants.NAMESPACE_PREFIX).append(':').append(DefaultContent.METADATA_OUTGOING_REFERENCE_PROPERTY).append("='").append(content.getId()).append("']");
        @SuppressWarnings("deprecation")
        Query query = content.getNode().getSession().getWorkspace().getQueryManager().createQuery(queryStr.toString(), Query.XPATH);
        return query.execute().getNodes();
    }
}
