/*
 *  Copyright 2017 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.content.referencetable;

import java.util.HashMap;
import java.util.List;

import org.apache.avalon.framework.configuration.Configuration;
import org.apache.avalon.framework.configuration.ConfigurationException;
import org.apache.avalon.framework.configuration.DefaultConfiguration;
import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;

import org.ametys.core.ui.StaticFileImportsClientSideElement;

/**
 * This implementation imports the file only if it is needed, i.e. if there is at least one hierarchy of simple content
 */
public class ChooseHierarchicalContentFileImportsClientSideElement extends StaticFileImportsClientSideElement
{
    /** The helper component for hierarchical simple contents */
    protected HierarchicalReferenceTablesHelper _hierarchicalSimpleContentsHelper;
    
    @Override
    public void service(ServiceManager smanager) throws ServiceException
    {
        super.service(smanager);
        _hierarchicalSimpleContentsHelper = (HierarchicalReferenceTablesHelper) smanager.lookup(HierarchicalReferenceTablesHelper.ROLE);
    }
    
    @Override
    protected Script _configureScript(Configuration configuration) throws ConfigurationException
    {
        DefaultConfiguration dynamicScriptConfig = new DefaultConfiguration("scripts");
        
        // Only import ChooseHierarchicalContent.js if needed
        if (_hierarchicalSimpleContentsHelper.hasAtLeastOneHierarchy())
        {
            DefaultConfiguration fileConfig = new DefaultConfiguration("file");
            fileConfig.setValue("js/Ametys/plugins/cms/content/tree/HierarchicalReferenceTablesTree.js");
            dynamicScriptConfig.addChild(fileConfig);
            
            fileConfig = new DefaultConfiguration("file");
            fileConfig.setValue("js/Ametys/plugins/cms/content/tree/HierarchicalReferenceTablesTree/HierarchicalReferenceTablesTreeEntry.js");
            dynamicScriptConfig.addChild(fileConfig);
            
            fileConfig = new DefaultConfiguration("file");
            fileConfig.setValue("js/Ametys/cms/uihelper/ChooseHierarchicalContent.js");
            dynamicScriptConfig.addChild(fileConfig);
        }
        
        List<ScriptFile> scriptsImports = _configureImports(dynamicScriptConfig);
        List<ScriptFile> cssImports = _configureImports(configuration.getChild("css"));
        
        return new Script(this.getId(), "", scriptsImports, cssImports, new HashMap<>());
    }
}
