/*  Copyright 2018 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.content.referencetable;


import java.util.ArrayList;
import java.util.List;
import java.util.Map;

import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.cocoon.components.ContextHelper;
import org.apache.cocoon.environment.Request;

import org.ametys.cms.repository.Content;
import org.ametys.cms.repository.ContentDAO;
import org.ametys.core.ui.Callable;

/**
 * DAO deleting a content from a hierarchical reference table reference table
 *
 */
public class HierarchicalReferenceTablesDeleteContentDAO extends ContentDAO
{
    /** The request attribute name to list all children contents to delete */
    protected static final String _REQUEST_ATTRIBUTE_CONTENT_IDS = "ContentIdsToDelete";
    
    /** The helper component for hierarchical reference tables */
    protected HierarchicalReferenceTablesHelper _hierarchicalReferenceTablesHelper;
    
    @Override
    public void service(ServiceManager manager) throws ServiceException
    {
        super.service(manager);
        _hierarchicalReferenceTablesHelper = (HierarchicalReferenceTablesHelper) manager.lookup(HierarchicalReferenceTablesHelper.ROLE);
    }
    
    @Override
    protected String getRightToDelete()
    {
        return "CMS_Rights_ReferenceTables_Delete";
    }

    @Override
    @Callable
    public Map<String, Object> forceDeleteContents(List<String> contentsId)
    {
        Request request = ContextHelper.getRequest(_context);
        
        List<String> contentsIdToDelete = new ArrayList<>(contentsId);
        for (String contentId : contentsId)
        {
            Content content = _resolver.resolveById(contentId);
            contentsIdToDelete.addAll(_hierarchicalReferenceTablesHelper.getAllChildren(content));
        }
        
        request.setAttribute(_REQUEST_ATTRIBUTE_CONTENT_IDS, contentsIdToDelete);
        Map<String, Object> returnMap = super.forceDeleteContents(contentsIdToDelete);
        request.removeAttribute(_REQUEST_ATTRIBUTE_CONTENT_IDS);
        
        return returnMap;
    }
    
    @Override
    @Callable
    public Map<String, Object> deleteContents(List<String> contentsId)
    {
        Request request = ContextHelper.getRequest(_context);
        
        List<String> contentsIdToDelete = new ArrayList<>(contentsId);
        for (String contentId : contentsId)
        {
            Content content = _resolver.resolveById(contentId);
            contentsIdToDelete.addAll(_hierarchicalReferenceTablesHelper.getAllChildren(content));
        }
        
        request.setAttribute(_REQUEST_ATTRIBUTE_CONTENT_IDS, contentsIdToDelete);
        Map<String, Object> returnMap = super.deleteContents(contentsIdToDelete);
        request.removeAttribute(_REQUEST_ATTRIBUTE_CONTENT_IDS);
        
        return returnMap;
    }
    
    /**
     * Test if content is still referenced by a content other than a child or its parent before removing it
     * @param content The content to remove
     * @return true if content is still referenced
     */
    @SuppressWarnings("unchecked")
    @Override
    protected boolean _isContentReferenced(Content content)
    {
        Request request = ContextHelper.getRequest(_context);
        return _hierarchicalReferenceTablesHelper._isContentReferenced(content, (List<String>) request.getAttribute(_REQUEST_ATTRIBUTE_CONTENT_IDS));
    }
}
