/*
 *  Copyright 2017 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.content.referencetable;

import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;
import java.util.regex.Pattern;

import org.apache.avalon.framework.configuration.Configuration;
import org.apache.avalon.framework.configuration.ConfigurationException;
import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.avalon.framework.service.Serviceable;

import org.ametys.core.ui.StaticRibbonImportManager;

/**
 * Ribbon import manager, which import ribbon files only if there is at least one hierarchical reference tables in the application 
 */
public class HierarchicalReferenceTablesRibbonImportManager extends StaticRibbonImportManager implements Serviceable
{
    /** The helper component for hierarchical simple contents */
    protected HierarchicalReferenceTablesHelper _hierarchicalSimpleContentsHelper;
    
    private boolean _atLeastOneHierarchy;
    
    @Override
    public void service(ServiceManager smanager) throws ServiceException
    {
        _hierarchicalSimpleContentsHelper = (HierarchicalReferenceTablesHelper) smanager.lookup(HierarchicalReferenceTablesHelper.ROLE);
    }
    
    @Override
    public void configure(Configuration configuration) throws ConfigurationException
    {
        _atLeastOneHierarchy = _hierarchicalSimpleContentsHelper.hasAtLeastOneHierarchy();
        if (_atLeastOneHierarchy)
        {
            super.configure(configuration);
        }
    }
    
    @Override
    public Map<List<String>, Pattern> getImports()
    {
        return _atLeastOneHierarchy ? super.getImports() : new LinkedHashMap<>();
    }
}
