/*
 *  Copyright 2019 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.content.type;

import java.util.Arrays;
import java.util.Collections;
import java.util.List;
import java.util.stream.Collectors;

import org.ametys.cms.content.references.OutgoingReferences;
import org.ametys.cms.content.references.Referencer;
import org.ametys.cms.data.ContentValue;
import org.ametys.cms.data.type.impl.ContentRepositoryElementType;
import org.ametys.cms.repository.Content;

/**
 * Class for content type of elements used by contents
 */
public class ContentContentElementType extends ContentRepositoryElementType implements Referencer
{
    /** Constant for the content type for outgoing references */
    public static final String OUTGOING_REFERENCE_TYPE = "content";
    
    public OutgoingReferences getOutgoingReferences(Object value)
    {
        if (value != null)
        {
            if (value instanceof String)
            {
                OutgoingReferences references = new OutgoingReferences();
                List<String> contentIds = Collections.singletonList((String) value);
                references.put(OUTGOING_REFERENCE_TYPE, contentIds);
                return references;
            }
            else if (value instanceof String[])
            {
                OutgoingReferences references = new OutgoingReferences();
                List<String> contentIds = Arrays.asList((String[]) value);
                references.put(OUTGOING_REFERENCE_TYPE, contentIds);
                return references;
            }
            else if (value instanceof Content)
            {
                OutgoingReferences references = new OutgoingReferences();
                List<String> contentIds = Collections.singletonList(((Content) value).getId());
                references.put(OUTGOING_REFERENCE_TYPE, contentIds);
                return references;
            }
            else if (value instanceof Content[])
            {
                OutgoingReferences references = new OutgoingReferences();
                List<String> contentIds = Arrays.stream((Content[]) value)
                        .map(Content::getId)
                        .collect(Collectors.toList());
                references.put(OUTGOING_REFERENCE_TYPE, contentIds);
                return references;
            }
            else if (value instanceof ContentValue)
            {
                OutgoingReferences references = new OutgoingReferences();
                List<String> contentIds = Collections.singletonList(((ContentValue) value).getContentId());
                references.put(OUTGOING_REFERENCE_TYPE, contentIds);
                return references;
            }
            else if (value instanceof ContentValue[])
            {
                OutgoingReferences references = new OutgoingReferences();
                List<String> contentIds = Arrays.stream((ContentValue[]) value)
                        .map(ContentValue::getContentId)
                        .collect(Collectors.toList());
                references.put(OUTGOING_REFERENCE_TYPE, contentIds);
                return references;
            }
            else
            {
                throw new IllegalArgumentException("Try to get outgoing references of the non content value '" + value + "'");
            }
        }
        else
        {
            return OutgoingReferences.EMPTY;
        }
    }
}
