/*
 *  Copyright 2019 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.content.type;

import java.util.Arrays;
import java.util.Collections;
import java.util.List;
import java.util.stream.Collectors;

import org.ametys.cms.content.references.OutgoingReferences;
import org.ametys.cms.content.references.Referencer;
import org.ametys.cms.data.Binary;
import org.ametys.cms.data.ExplorerFile;
import org.ametys.cms.data.type.impl.FileRepositoryElementType;

/**
 * Class for file type of elements used by contents
 */
public class FileContentElementType extends FileRepositoryElementType implements Referencer
{
    /** Constants for the explorer type for outgoing references */
    private static final String __OUTGOING_REFERENCE_TYPE = "explorer";
    
    public OutgoingReferences getOutgoingReferences(Object value)
    {
        if (value != null)
        {
            if (value instanceof String)
            {
                OutgoingReferences references = new OutgoingReferences();
                List<String> fileIds = Collections.singletonList((String) value);
                references.put(__OUTGOING_REFERENCE_TYPE, fileIds);
                return references;
            }
            else if (value instanceof String[])
            {
                OutgoingReferences references = new OutgoingReferences();
                List<String> fileIds = Arrays.asList((String[]) value);
                references.put(__OUTGOING_REFERENCE_TYPE, fileIds);
                return references;
            }
            else if (value instanceof ExplorerFile)
            {
                OutgoingReferences references = new OutgoingReferences();
                List<String> fileIds = Collections.singletonList(((ExplorerFile) value).getResourceId());
                references.put(__OUTGOING_REFERENCE_TYPE, fileIds);
                return references;
            }
            else if (value instanceof ExplorerFile[])
            {
                OutgoingReferences references = new OutgoingReferences();
                List<String> fileIds = Arrays.stream((ExplorerFile[]) value)
                        .map(ExplorerFile::getResourceId)
                        .collect(Collectors.toList());
                references.put(__OUTGOING_REFERENCE_TYPE, fileIds);
                return references;
            }
            else if (value instanceof Binary || value instanceof Binary[])
            {
                return OutgoingReferences.EMPTY;
            }
            else
            {
                throw new IllegalArgumentException("Try to get outgoing references of the non file value '" + value + "'");
            }
        }
        else
        {
            return OutgoingReferences.EMPTY;
        }
    }
}
