/*
 *  Copyright 2019 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.content.type;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

import org.ametys.cms.content.references.OutgoingReferences;
import org.ametys.cms.content.references.Referencer;
import org.ametys.cms.data.Reference;
import org.ametys.cms.data.type.impl.ReferenceRepositoryElementType;

/**
 * Class for reference type of elements used by contents
 */
public class ReferenceContentElementType extends ReferenceRepositoryElementType implements Referencer
{
    public OutgoingReferences getOutgoingReferences(Object value)
    {
        if (value != null)
        {
            if (value instanceof Reference)
            {
                OutgoingReferences references = new OutgoingReferences();
                List<String> refValues = Collections.singletonList(((Reference) value).getValue());
                references.put(((Reference) value).getType(), refValues);
                return references;
            }
            else if (value instanceof Reference[])
            {
                OutgoingReferences references = new OutgoingReferences();
                for (Reference singleValue : (Reference[]) value)
                {
                    List<String> values;
                    if (references.containsKey(singleValue.getType()))
                    {
                        values = references.get(singleValue.getType());
                    }
                    else
                    {
                        values = new ArrayList<>();
                    }
                    values.add(singleValue.getValue());
                    
                    references.put(singleValue.getType(), values);
                }
                return references;
            }
            else
            {
                throw new IllegalArgumentException("Try to get outgoing references of the non reference value '" + value + "'");
            }
        }
        else
        {
            return OutgoingReferences.EMPTY;
        }
    }
}
