/*
 *  Copyright 2019 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.content.type;

import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;

import org.ametys.cms.content.references.OutgoingReferences;
import org.ametys.cms.content.references.Referencer;
import org.ametys.cms.content.references.RichTextOutgoingReferencesExtractor;
import org.ametys.cms.data.RichText;
import org.ametys.cms.data.type.impl.RichTextRepositoryElementType;
import org.ametys.cms.transformation.docbook.DocbookOutgoingReferencesExtractor;

/**
 * Class for rich text type of elements stored in the repository
 */
public class RichTextContentElementType extends RichTextRepositoryElementType implements Referencer
{
    /** Rich text outgoing references extractor */
    protected RichTextOutgoingReferencesExtractor _richTextOutgoingReferencesExtractor;

    @Override
    public void service(ServiceManager manager) throws ServiceException
    {
        super.service(manager);
        _richTextOutgoingReferencesExtractor = (RichTextOutgoingReferencesExtractor) manager.lookup(DocbookOutgoingReferencesExtractor.ROLE);
    }
    
    public OutgoingReferences getOutgoingReferences(Object value)
    {
        if (value != null)
        {
            if (value instanceof RichText)
            {
                return _richTextOutgoingReferencesExtractor.getOutgoingReferences((RichText) value);
            }
            else if (value instanceof RichText[])
            {
                OutgoingReferences references = new OutgoingReferences();
                for (RichText richText : (RichText[]) value)
                {
                    OutgoingReferences richTextReferences = _richTextOutgoingReferencesExtractor.getOutgoingReferences(richText);
                    references.merge(richTextReferences);
                }
                return references;
            }
            else
            {
                throw new IllegalArgumentException("Try to get outgoing references of the non rich text value '" + value + "'");
            }
        }
        else
        {
            return OutgoingReferences.EMPTY;
        }
    }
}
