/*
 *  Copyright 2023 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.contenttype;

import org.apache.avalon.framework.configuration.Configuration;
import org.apache.avalon.framework.configuration.ConfigurationException;
import org.apache.commons.lang3.StringUtils;

import org.ametys.runtime.config.Config;
import org.ametys.runtime.config.ConfigManager;

/**
 * Content type overrides, based on a configuration parameter.
 * The overrides of these extensions are active only if the configuration parameter value is present, or if it is a <code>true</code> boolean
 */
public class ConfigBasedContentTypeOverrides extends StaticContentTypeOverrides
{
    @Override
    public void configure(Configuration configuration) throws ConfigurationException
    {
        Configuration configParamConfiguration = configuration.getChild("config-param");
        String configParamId = configParamConfiguration.getValue();
        
        boolean isActive;
        if (ConfigManager.getInstance().hasModelItem(configParamId))
        {
            Object value = Config.getInstance().getValue(configParamId);
            isActive = value instanceof Boolean
                    ? (Boolean) value
                    : value instanceof String
                        ? StringUtils.isNotEmpty((String) value)
                        : value != null;
        }
        else
        {
            // If the config parameter does not exist, log a warning but do not throw an exception, it could be on purpose (ex: an excluded feature)
            getLogger().warn("Unable to add some override configuration for content types '" + StringUtils.join(_overriddenContentTypeIds, ", ") + ". The configuration parameter '" + configParamId + "' is not defined.");
            isActive = false;
        }
        
        if (isActive)
        {
            super.configure(configuration);
        }
    }
}
