/*
 *  Copyright 2023 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.contenttype;

import java.util.Set;

import org.apache.avalon.framework.configuration.Configuration;

import org.ametys.runtime.plugin.component.PluginAware;

/**
 * Extension for content types' overrides
 */
public interface ContentTypeOverridesExtension extends PluginAware
{
    /**
     * Get override configuration of this extension
     * @return The override configuration
     */
    public Configuration getOverrideConfiguration();
    
    /**
     * Retrieves a Set of content types that have been overridden from this extension
     * @return the set of overridden content types identifiers
     */
    public Set<String> getOverriddenContentTypes();
    
    /**
     * Retrieves the name of the plugin declaring this extension
     * @return the name of the plugin declaring this extension
     */
    public String getPluginName();
}
