/*
 *  Copyright 2019 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.contenttype;

import java.util.Collections;
import java.util.HashSet;
import java.util.Set;

import org.apache.avalon.framework.component.Component;
import org.apache.avalon.framework.configuration.Configuration;
import org.apache.avalon.framework.configuration.ConfigurationException;

import org.ametys.runtime.plugin.ExtensionPoint;
import org.ametys.runtime.plugin.component.AbstractLogEnabled;

/**
 * List of the reserved words that cannot not be used as an attribute name
 */
public class ContentTypeReservedAttributeNameExtensionPoint extends AbstractLogEnabled implements ExtensionPoint<String>, Component
{
    /** The component role */
    public static final String ROLE = ContentTypeReservedAttributeNameExtensionPoint.class.getName();
    
    /** The forbidden keywords */
    protected Set<String> _reservedNames = new HashSet<>();
    
    public void addExtension(String id, String pluginName, String featureName, Configuration configuration) throws ConfigurationException
    {
        for (Configuration nameConfiguration : configuration.getChildren("name"))
        {
            try
            {
                _reservedNames.add(nameConfiguration.getValue());
            }
            catch (ConfigurationException e)
            {
                getLogger().warn("Ignoring the reserved word configuration", e);
            }
        }
    }

    public void initializeExtensions() throws Exception
    {
        // Nothing
    }

    public boolean hasExtension(String id)
    {
        return _reservedNames.contains(id);
    }

    public String getExtension(String id)
    {
        return hasExtension(id) ? id : null;
    }

    public Set<String> getExtensionsIds()
    {
        return Collections.unmodifiableSet(_reservedNames);
    }
}
