/*
 *  Copyright 2014 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.contenttype;

import java.util.Map;

import org.ametys.cms.repository.Content;
import org.ametys.runtime.model.View;
import org.ametys.runtime.parameter.Errors;

/**
 * Global validator for {@link Content}
 */
public interface ContentValidator
{
    /**
     * Set the content type
     * @param cTypeId The content type
     */
    public void setContentType(ContentType cTypeId);

    /**
     * Get the content type
     * @return ContentType
     */
    public ContentType getContentType();

     /**
     * Validates a content.
     * @param content the content to validate
     * @param errors the structure to populate if the validation failed.
     */
    public void validate(Content content, Errors errors);

    /**
     * Validates a content being edited
     * @param content the content to validate
     * @param values the values being set
     * @param view the view
     * @param errors the structure to populate if the validation failed.
     */
    public void validate(Content content, Map<String, Object> values, View view, Errors errors);
}

