/*
 *  Copyright 2011 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.contenttype;

import java.util.Map;

import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.avalon.framework.service.Serviceable;
import org.xml.sax.ContentHandler;
import org.xml.sax.ext.LexicalHandler;

import org.ametys.cms.repository.Content;
import org.ametys.plugins.repository.TraversableAmetysObject;

/**
 * Docbook implementation of {@link RichTextUpdater} 
 * Use the {@link DocbookUpdateHandlerExtensionPoint} extension points to update rich text fields based upon a serie of {@link DockbookUpdateHandler}
 */
public class DocbookRichTextUpdater implements RichTextUpdater, Serviceable
{
    /** Avalon role */
    public static final String ROLE = DocbookRichTextUpdater.class.getName();
    
    private DocbookUpdateHandlerExtensionPoint _docbookUpdaterEP;
    
    @Override
    public void service(ServiceManager smanager) throws ServiceException
    {
        _docbookUpdaterEP = (DocbookUpdateHandlerExtensionPoint) smanager.lookup(DocbookUpdateHandlerExtensionPoint.ROLE);
    }
    
    @Override
    public ContentHandler getContentHandler(ContentHandler ch, LexicalHandler lh, Map<String, Object> params)
    {
        ContentHandler contentHandler = ch;
        LexicalHandler lexicalHandler = lh; 
        
        for (String handlerRole : _docbookUpdaterEP.getExtensionsIds())
        {
            DockbookUpdateHandler handler = _docbookUpdaterEP.getExtension(handlerRole);
            
            handler.setCreatedContent((Content) params.get("createdContent"));
            handler.setInitialContent((Content) params.get("initialContent"));
            
            TraversableAmetysObject createdAO = (TraversableAmetysObject) params.get("createdAO");
            if (createdAO != null)
            {
                handler.setCreatedObject((TraversableAmetysObject) params.get("createdAO"));
            }
            
            TraversableAmetysObject initialAO = (TraversableAmetysObject) params.get("initialAO");
            if (initialAO != null)
            {
                handler.setInitialObject((TraversableAmetysObject) params.get("initialAO"));
            }
            
            handler.setContentHandler(contentHandler);
            handler.setLexicalHandler(lexicalHandler);
            
            contentHandler = handler;
            lexicalHandler = handler;
        }

        return contentHandler;
    }

}
