/*
 *  Copyright 2018 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.contenttype;

import java.util.Map;

import org.apache.avalon.framework.configuration.Configuration;
import org.apache.avalon.framework.configuration.ConfigurationException;

import org.ametys.cms.data.type.ModelItemTypeExtensionPoint;
import org.ametys.plugins.explorer.dublincore.DublinCoreMetadataProvider;
import org.ametys.runtime.i18n.I18nizableText;
import org.ametys.runtime.model.ElementDefinition;
import org.ametys.runtime.model.Enumerator;
import org.ametys.runtime.model.StaticEnumerator;
import org.ametys.runtime.parameter.Validator;
import org.ametys.runtime.plugin.component.ThreadSafeComponentManager;

/**
 * This class parses the dublin core attributes definition
 */
public class DublinCoreAttributeDefinitionParser extends ContentAttributeDefinitionParser
{
    /** The DublinCore attribute provider */
    protected DublinCoreMetadataProvider _dcProvider;
    
    /**
     * Creates a dublin core attribute definition parser.
     * @param contentAttributeTypeExtensionPoint the extension point to use to get available element types
     * @param enumeratorManager the enumerator component manager.
     * @param validatorManager the validator component manager.
     * @param dcProvider The DublinCore attribute provider
     */
    public DublinCoreAttributeDefinitionParser(ModelItemTypeExtensionPoint contentAttributeTypeExtensionPoint, ThreadSafeComponentManager<Enumerator> enumeratorManager, ThreadSafeComponentManager<Validator> validatorManager, DublinCoreMetadataProvider dcProvider)
    {
        super(contentAttributeTypeExtensionPoint, enumeratorManager, validatorManager);
        _dcProvider = dcProvider;
    }
    
    @Override
    protected void _parseAndSetEnumerator(String pluginName, String catalog, ElementDefinition definition, Configuration definitionConfig) throws ConfigurationException
    {
        super._parseAndSetEnumerator(pluginName, catalog, definition, definitionConfig);
        
        if (definition.getEnumerator() == null && _dcProvider.isEnumerated(definition.getName()))
        {
            StaticEnumerator<String> enumerator = new StaticEnumerator<>();
            
            Map<String, I18nizableText> entries = _dcProvider.getEntries(definition.getName());
            if (entries != null)
            {
                for (Map.Entry<String, I18nizableText> entry : entries.entrySet())
                {
                    enumerator.add(entry.getValue(), entry.getKey());
                }
               
            }
            definition.setEnumerator(enumerator);
        }
    }
}
