/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.contenttype;

import org.ametys.plugins.repository.data.type.ModelItemTypeConstants;
import org.ametys.runtime.model.type.ElementType;
import org.ametys.runtime.model.type.ModelItemType;

/** 
 * Metadata type
 * @deprecated Use {@link ElementType} instead
 */
@Deprecated
public enum MetadataType
{
    /** String type. */
    STRING,
    /** Multilingual string */
    MULTILINGUAL_STRING
    {
        @Override
        public String getId()
        {
            return super.getId().replaceAll("_", "-");
        }
    },
    /** Date type. */
    DATE,
    /** Date time type. */
    DATETIME,
    /** Long type. */
    LONG,
    /** Geocode type. */
    GEOCODE,
    /** Double type. */
    DOUBLE,
    /** Boolean type. */
    BOOLEAN,
    /** Composite type. */
    COMPOSITE,
    /** Binary type. */
    BINARY,
    /** Rich text type. */
    RICH_TEXT
    {
        @Override
        public String getId()
        {
            return super.getId().replaceAll("_", "-");
        }
    },
    /** User type. */
    USER,
    /** Reference type (Resources explorer / dn of a directory / ...). */
    REFERENCE,
    /** Reference to a content. */
    CONTENT,
    /** Sub-content. */
    SUB_CONTENT,
    /** File type, may be a binary or a reference (symbolic link). */
    FILE;
    
    /**
     * Retrieves the type identifier
     * @return the type identifier
     */
    public String getId()
    {
        return name();
    }
    
    /**
     * Retrieves the {@link MetadataType} corresponding to the given {@link ModelItemType}
     * @param type the {@link ModelItemType}
     * @return the {@link MetadataType} corresponding to the given {@link ModelItemType}
     */
    public static MetadataType fromModelItemType(ModelItemType type)
    {
        return fromModelItemTypeId(type.getId());
    }
    
    /**
     * Retrieves the {@link MetadataType} corresponding to the given {@link ModelItemType} id
     * @param typeId the {@link ModelItemType} id
     * @return the {@link MetadataType} corresponding to the given {@link ModelItemType} id
     */
    public static MetadataType fromModelItemTypeId(String typeId)
    {
        if (ModelItemTypeConstants.REPEATER_TYPE_ID.equals(typeId))
        {
            return COMPOSITE;
        }
        return MetadataType.valueOf(typeId.toUpperCase().replaceAll("-", "_"));
    }
}
