/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

package org.ametys.cms.contenttype;

import java.util.Map;

import org.xml.sax.ContentHandler;
import org.xml.sax.ext.LexicalHandler;

/**
 * A RichText updater is a class that gives the content handler responsible for updating rich text after a copy.
 */
public interface RichTextUpdater
{
    /**
     * This method returns the content handler to use to update the rich text after a copy of a content
     * @param ch the content handler to sax into
     * @param lh the lexical handler
     * @param params parameters need by the content handler
     * @return the content handler
     */
    ContentHandler getContentHandler (ContentHandler ch, LexicalHandler lh, Map<String, Object> params);
}
