/*
 *  Copyright 2013 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

package org.ametys.cms.contenttype;

import org.ametys.runtime.i18n.I18nizableText;

/**
 * This bean represents a semantic annotation tagging a part of a rich text content. 
 */
public class SemanticAnnotation
{
    private String _id;
    private I18nizableText _label;
    private I18nizableText _description;
    
    /**
     * Constructor
     * @param id The id
     * @param label The label
     * @param description The description
     */
    public SemanticAnnotation (String id, I18nizableText label, I18nizableText description)
    {
        _id = id;
        _label = label;
        _description = description;
    }
    
    /**
     * Returns the id of the semantic annotation
     * @return the id of the semantic annotation (typically its name)
     */
    public String getId()
    {
        return _id;
    }
    
    /**
     * Set the id of the semantic annotation
     * @param id the id of the semantic annotation (typically its name)
     */
    public void setId(String id)
    {
        this._id = id;
    }
    
    /**
     * Returns the label of the semantic annotation
     * @return the label of the semantic annotation
     */
    public I18nizableText getLabel()
    {
        return _label;
    }
    
    /**
     * Set the label of the semantic annotation
     * @param label the label of the semantic annotation
     */
    public void setLabel(I18nizableText label)
    {
        this._label = label;
    }
    
    /**
     * Returns the description of the semantic annotation
     * @return the description of the semantic annotation
     */
    public I18nizableText getDescription()
    {
        return _description;
    }
    
    /**
     * Set the description of the semantic annotation
     * @param description the description of the semantic annotation
     */
    public void setDescription(I18nizableText description)
    {
        this._description = description;
    }
    
    @Override
    public int hashCode()
    {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((_id == null) ? 0 : _id.hashCode());
        return result;
    }
    
    @Override
    public boolean equals(Object obj)
    {
        if (this == obj)
        {
            return true;
        }
        if (obj == null)
        {
            return false;
        }
        if (getClass() != obj.getClass())
        {
            return false;
        }
        SemanticAnnotation other = (SemanticAnnotation) obj;
        if (_id == null)
        {
            if (other._id != null)
            {
                return false;
            }
        }
        else if (!_id.equals(other._id))
        {
            return false;
        }
        return true;
    }
    
    @Override
    public String toString()
    {
        return _id;
    }
    
}
