/*
 *  Copyright 2023 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.contenttype;

import java.util.HashSet;
import java.util.Set;

import org.apache.avalon.framework.component.Component;
import org.apache.avalon.framework.configuration.Configurable;
import org.apache.avalon.framework.configuration.Configuration;
import org.apache.avalon.framework.configuration.ConfigurationException;
import org.apache.commons.lang3.StringUtils;

import org.ametys.runtime.plugin.component.AbstractLogEnabled;

/**
 * Default {@link ContentTypeOverridesExtension} that retrieves the configurations without any conditions
 */
public class StaticContentTypeOverrides extends AbstractLogEnabled implements ContentTypeOverridesExtension, Component, Configurable 
{
    /** The set of the overridden content types */
    protected Set<String> _overriddenContentTypeIds = new HashSet<>();
    
    /** The configuration to apply to override the content types */
    protected Configuration _configuration;
    
    private String _pluginName;

    @Override
    public Configuration getOverrideConfiguration() 
    {
        return _configuration;
    }

    @Override
    public void configure(Configuration configuration) throws ConfigurationException
    {
        Configuration contentTypesConf = configuration.getChild("content-types");
        
        for (Configuration contentTypeConf : contentTypesConf.getChildren("content-type"))
        {
            String id = contentTypeConf.getAttribute("id");
            _overriddenContentTypeIds.add(id);
        }
        
        _configuration = configuration;
        
        if (getLogger().isDebugEnabled())
        {
            getLogger().debug("Adding override configuration for content types '" + StringUtils.join(_overriddenContentTypeIds, ", ") + ".");
        }
    }
    
    @Override
    public Set<String> getOverriddenContentTypes() 
    {
        return _overriddenContentTypeIds;
    }

    @Override
    public void setPluginInfo(String pluginName, String featureName, String id)
    {
        _pluginName = pluginName;
    }
    
    public String getPluginName()
    {
        return _pluginName;
    }
}
