/*
 *  Copyright 2020 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.contenttype.validation;

import java.util.Optional;
import java.util.stream.Stream;

import org.ametys.cms.data.Reference;
import org.ametys.runtime.i18n.I18nizableText;
import org.ametys.runtime.parameter.DefaultValidator;
import org.ametys.runtime.parameter.Errors;

/**
 * This is an implementation of {@link DefaultValidator} for {@link Reference}.
 */
public class ReferenceValidator extends DefaultValidator
{
    /**
     * Default constructor for avalon
     */
    public ReferenceValidator()
    {
        super();
    }
    
    /**
     * Manual constructor
     * @param regexp The regexp to check or null
     * @param mandatory Is the value mandatory 
     */
    public ReferenceValidator(String regexp, boolean mandatory)
    {
        super(regexp, mandatory);
    }
    
    /**
     * Manual constructor
     * @param regexp The regexp to check or null
     * @param invalidText The error text to display
     * @param mandatory Is the value mandatory 
     */
    public ReferenceValidator(String regexp, I18nizableText invalidText, boolean mandatory)
    {
        super(regexp, invalidText, mandatory);
    }
    
    @Override
    public void validate(Object value, Errors errors)
    {
        boolean isArray = value != null && value.getClass().isArray();
        if (isArray)
        {
            assert value instanceof Reference[];
            Object[] internalValues = Stream.of((Reference[]) value)
                .map(Reference::getValue)
                .toArray();
            validateArrayValues(internalValues, errors); 
        }
        else
        {
            assert value instanceof Reference;
            String internalValue = Optional.ofNullable(value)
                .map(Reference.class::cast)
                .map(Reference::getValue)
                .orElse(null);
            validateSingleValue(internalValue, errors);
        }
    }
}
