/*
 *  Copyright 2019 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.data;

import java.io.ByteArrayOutputStream;
import java.io.IOException;

import org.apache.commons.codec.digest.DigestUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import org.ametys.plugins.repository.data.repositorydata.RepositoryData;

/**
 * Class representing a binary
 */
public class Binary extends NamedResource implements File
{
    /** The binary's logger */
    protected static Logger __logger = LoggerFactory.getLogger(Binary.class);

    /** the binary's hash */
    protected String _hash;
    
    /**
     * Default constructor
     */
    public Binary()
    {
        // Empty constructor
    }
    
    /**
     * Constructor to use when reading the binary from the repository
     * @param repositoryData the repository data containing the resource's data
     * @param hash the hash of the resource's data
     */
    public Binary(RepositoryData repositoryData, String hash)
    {
        super(repositoryData);
        _hash = hash;
    }
    
    @Override
    protected void closeOutputStream(ByteArrayOutputStream outputStream) throws IOException
    {
        super.closeOutputStream(outputStream);
        _hash = DigestUtils.sha1Hex(_buffer);
    }

    /**
     * Retrieves the hash of the resource's data
     * @return the hash of the resource's data
     */
    public String getHash()
    {
        return _hash;
    }
    
    public String getName()
    {
        return getFilename();
    }
}
