/*
 *  Copyright 2020 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.data;

import java.io.IOException;
import java.io.InputStream;

import org.apache.excalibur.source.Source;
import org.apache.excalibur.source.SourceNotFoundException;
import org.apache.excalibur.source.SourceValidity;
import org.apache.excalibur.source.impl.validity.TimeStampValidity;

import org.ametys.core.cocoon.source.NamedSource;
import org.ametys.core.util.DateUtils;

/**
 * {@link Source} representing a binary.
 */
public class BinarySource implements NamedSource
{
    private Binary _binary;
    private String _filename;
    private String _uri;
    private String _scheme;
    
    /**
     * Constructor.
     * @param binary the {@link Binary}.
     * @param filename the filename.
     * @param uri this source's uri.
     * @param scheme this source's uri's scheme
     */
    public BinarySource(Binary binary, String filename, String uri, String scheme)
    {
        _binary = binary;
        _filename = filename;
        _uri = uri;
        _scheme = scheme;
    }
    
    public boolean exists()
    {
        return _binary != null && _binary.getFilename().equals(_filename);
    }

    public InputStream getInputStream() throws IOException, SourceNotFoundException
    {
        return _binary.getInputStream();
    }

    public String getURI()
    {
        return _uri;
    }

    public String getScheme()
    {
        return _scheme;
    }

    public SourceValidity getValidity()
    {
        return new TimeStampValidity(getLastModified());
    }
    
    public String getName()
    {
        return _binary.getFilename();
    }

    public void refresh()
    {
        // does nothing
    }

    public String getMimeType()
    {
        return _binary.getMimeType();
    }

    public long getContentLength()
    {
        return _binary.getLength();
    }

    public long getLastModified()
    {
        return _binary != null ? DateUtils.asDate(_binary.getLastModificationDate()).getTime() : 0;
    }
}
