/*
 *  Copyright 2020 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.data;

import java.io.IOException;
import java.net.MalformedURLException;
import java.util.Map;

import org.apache.avalon.framework.context.Context;
import org.apache.avalon.framework.context.ContextException;
import org.apache.avalon.framework.context.Contextualizable;
import org.apache.avalon.framework.thread.ThreadSafe;
import org.apache.cocoon.components.ContextHelper;
import org.apache.cocoon.environment.Request;
import org.apache.excalibur.source.Source;
import org.apache.excalibur.source.SourceFactory;

import org.ametys.core.util.FilenameUtils;
import org.ametys.runtime.plugin.component.AbstractLogEnabled;

/**
 * {@link SourceFactory} for site parameters.
 */
public class BinarySourceFactory extends AbstractLogEnabled implements SourceFactory, ThreadSafe, Contextualizable
{
    /** source scheme */
    public static final String SCHEME = "binary";
    
    private Context _context;
    
    @Override
    public void contextualize(Context context) throws ContextException
    {
        _context = context;
    }
    
    public Source getSource(String location, Map parameters) throws IOException, MalformedURLException
    {
        String filename = location.substring((SCHEME + "://").length());
        
        Request request = ContextHelper.getRequest(_context);
        
        try
        {
            Binary binary = (Binary) request.getAttribute(Binary.class.getName());
    
            return new BinarySource(binary, FilenameUtils.decode(filename), location, SCHEME);
        }
        catch (Exception e)
        {
            getLogger().error("Unable to resolve binary data for uri " + location, e);
            
            // returns an unexisting Source
            return new BinarySource(null, FilenameUtils.decode(filename), location, SCHEME);
        }
    }

    public void release(Source source)
    {
        // nothing to do
    }
}
