/*
 *  Copyright 2020 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.data;

import java.util.Collection;
import java.util.HashSet;
import java.util.Set;

import org.ametys.cms.repository.ModifiableContent;
import org.ametys.plugins.repository.data.holder.values.SynchronizationResult;

/**
 * Result of a content synchronization
 */
public class ContentSynchronizationResult extends SynchronizationResult
{
    private Set<ModifiableContent> _modifiedContents = new HashSet<>();
    
    /**
     * Retrieves the contents that have been modified by invert relations management
     * @return the contents that have been modified by invert relations management
     */
    public Set<ModifiableContent> getModifiedContents()
    {
        return _modifiedContents;
    }
    
    /**
     * Add contents to the list of contents that have been modified by invert relations management
     * @param contents the contents to add
     */
    public void addModifiedContents(Collection<? extends ModifiableContent> contents)
    {
        _modifiedContents.addAll(contents);
    }
    
    @Override
    public void aggregateResult(SynchronizationResult result)
    {
        super.aggregateResult(result);
        
        if (result instanceof ContentSynchronizationResult)
        {
            _modifiedContents.addAll(((ContentSynchronizationResult) result).getModifiedContents());
        }
    }
}
