/*
 *  Copyright 2019 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.data;

import java.io.InputStream;
import java.time.ZonedDateTime;

/**
 * Class representing a file
 */
public interface File
{
    /**
     * Returns the data stream.
     * @return the data stream.
     */
    public InputStream getInputStream();
    
    /**
     * Returns the last modification date.
     * @return the last modification date.
     */
    public ZonedDateTime getLastModificationDate();
    
    /**
     * Sets the last modification date of the file's data
     * @param lastModificationDate the last modification date to set
     */
    public void setLastModificationDate(ZonedDateTime lastModificationDate);
    
    /**
     * Returns the length of the data stream.
     * @return the length of the data stream.
     */
    public long getLength();
    
    /**
     * Returns the data mime-type.
     * @return the data mime-type.
     */
    public String getMimeType();
    
    /**
     * Sets the mime type of the file's data
     * @param mimeType the mime type to set
     */
    public void setMimeType(String mimeType);
    
    /**
     * Retrieves the file's name
     * @return the file's name
     */
    public String getName();
}
