/*
 *  Copyright 2018 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.data;

import java.util.Objects;

/**
 * Class containing geographic coordinates
 */
public class Geocode
{
    /** The latitude identifier */
    public static final String LATITUDE_IDENTIFIER = "latitude";
    
    /** The longitude identifier */
    public static final String LONGITUDE_IDENTIFIER = "longitude";

    private Double _latitude;
    private Double _longitude;
    
    /**
     * Constructs a Geocode
     * @param latitude the latitude of the geocode
     * @param longitude the longitude of the geocode
     */
    public Geocode(Double latitude, Double longitude)
    {
        _latitude = latitude;
        _longitude = longitude;
    }
    
    /**
     * Retrieves the latitude
     * @return the latitude
     */
    public Double getLatitude()
    {
        return _latitude;
    }
    
    /**
     * Retrieves the longitude
     * @return the longitude
     */
    public Double getLongitude()
    {
        return _longitude;
    }

    @Override
    public int hashCode()
    {
        return Objects.hash(_latitude, _longitude);
    }

    @Override
    public boolean equals(Object obj)
    {
        if (this == obj)
        {
            return true;
        }
        if (!(obj instanceof Geocode))
        {
            return false;
        }
        Geocode other = (Geocode) obj;
        return Objects.equals(_latitude, other._latitude) && Objects.equals(_longitude, other._longitude);
    }
}
