/*
 *  Copyright 2023 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.data;

import java.util.HashMap;
import java.util.Map;
import java.util.stream.Stream;

import org.apache.avalon.framework.parameters.Parameters;
import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.cocoon.acting.ServiceableAction;
import org.apache.cocoon.environment.ObjectModelHelper;
import org.apache.cocoon.environment.Redirector;
import org.apache.cocoon.environment.Request;
import org.apache.cocoon.environment.SourceResolver;
import org.apache.commons.lang3.StringUtils;

import org.ametys.cms.data.ametysobject.ModelAwareDataAwareAmetysObject;
import org.ametys.plugins.repository.AmetysObject;
import org.ametys.plugins.repository.AmetysObjectResolver;

/**
 * Get the ametys object binary from attribute and put it in the request
 */
public class GetAmetysObjectBinaryAction extends ServiceableAction
{
    /** The ametys object resolver */
    protected AmetysObjectResolver _resolver;
    
    @Override
    public void service(ServiceManager serviceManager) throws ServiceException
    {
        super.service(serviceManager);
        _resolver = (AmetysObjectResolver) manager.lookup(AmetysObjectResolver.ROLE);
    }

    public Map<String, String> act(Redirector redirector, SourceResolver resolver, Map objectModel, String source, Parameters parameters) throws Exception
    {
        Map<String, String> result = new HashMap<>();
        Request request = ObjectModelHelper.getRequest(objectModel);
        
        AmetysObject ametysObject;
        String id = parameters.getParameter("id", null);
        String path = parameters.getParameter("path", null);
        String fileName = parameters.getParameter("fileName", null);
        
        if (id != null)
        {
            ametysObject = _resolver.resolveById(id);
        }
        else if (path != null)
        {
            path = path.replaceAll("%3A", ":");
            ametysObject = _resolver.resolveByPath(path);
        }
        else
        {
            ametysObject = (AmetysObject) request.getAttribute(AmetysObject.class.getName());
        }

        String attribute = parameters.getParameter("attribute", null);
        
        if (StringUtils.isNotBlank(attribute) && ametysObject instanceof ModelAwareDataAwareAmetysObject modelAwareDataAwareAmetysObject)
        {
            Binary binary = _getBinary(modelAwareDataAwareAmetysObject, attribute, fileName);
            request.setAttribute(Binary.class.getName(), binary);
        }
        
        
        return result;
    }
    
    private Binary _getBinary(ModelAwareDataAwareAmetysObject object, String attribute, String filename)
    {
        if (object.isMultiple(attribute))
        {
            // if multiple binary, take the first file with name equals to the filename
            Binary[] binaries = object.getValue(attribute, false, new Binary[0]);
            return Stream.of(binaries)
                .filter(b -> b.getFilename().equals(filename))
                .findFirst()
                .orElse(null);
        }
        
        return object.getValue(attribute);
    }
}

