/*
 *  Copyright 2020 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.data;

import java.util.Collections;
import java.util.Map;

import org.apache.avalon.framework.parameters.Parameters;
import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.cocoon.acting.ServiceableAction;
import org.apache.cocoon.environment.ObjectModelHelper;
import org.apache.cocoon.environment.Redirector;
import org.apache.cocoon.environment.Request;
import org.apache.cocoon.environment.SourceResolver;

import org.ametys.plugins.repository.AmetysObjectResolver;
import org.ametys.plugins.repository.data.ametysobject.ModelLessDataAwareAmetysObject;

/**
 * Cocoon action for retriebing a {@link Binary}.
 */
public class GetBinaryAction extends ServiceableAction
{
    private AmetysObjectResolver _resolver;
    
    @Override
    public void service(ServiceManager serviceManager) throws ServiceException
    {
        super.service(serviceManager);
        _resolver = (AmetysObjectResolver) manager.lookup(AmetysObjectResolver.ROLE);
    }

    public Map<String, String> act(Redirector redirector, SourceResolver resolver, Map objectModel, String source, Parameters parameters) throws Exception
    {
        Request request = ObjectModelHelper.getRequest(objectModel);
        
        String id = parameters.getParameter("objectId", null);
        String path = parameters.getParameter("path", null);
        
        int height = parameters.getParameterAsInteger("height", 0);
        int width = parameters.getParameterAsInteger("width", 0);
        int maxHeight = parameters.getParameterAsInteger("maxHeight", 0);
        int maxWidth = parameters.getParameterAsInteger("maxWidth", 0);
        
        ModelLessDataAwareAmetysObject object = _resolver.resolveById(id);
        Binary binary = object.getValue(path);
        
        request.setAttribute(Binary.class.getName(), binary);
        
        String filename = binary.getFilename();
        
        String baseName = org.apache.commons.io.FilenameUtils.getBaseName(filename);
        String extension = org.apache.commons.io.FilenameUtils.getExtension(filename);

        String uriArgument;
        
        if (height > 0 && width > 0)
        {
            uriArgument = '_' + String.valueOf(height) + 'x' + String.valueOf(width);
        }
        else if (maxHeight > 0 && maxWidth > 0)
        {
            uriArgument = "_max" + String.valueOf(maxHeight) + 'x' + String.valueOf(maxWidth);
        }
        else
        {
            uriArgument = "";
        }
        
        return Collections.singletonMap("filename", baseName + uriArgument + (extension.isEmpty() ? "" : "." + extension));
    }
}
