/*
 *  Copyright 2019 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.data;

import java.util.Objects;

/**
 * Class containing a reference
 */
public class Reference
{
    /** The value identifier */
    public static final String VALUE_IDENTIFIER = "value";
    /** The type identifier */
    public static final String TYPE_IDENTIFIER = "type";
    
    /** The default type */
    public static final String DEFAULT_TYPE = "__external";
    
    private String _value;
    private String _type;
    
    /**
     * Constructs a reference
     * @param value the value of the reference
     */
    public Reference(String value)
    {
        this(value, null);
    }
    
    /**
     * Constructs a reference
     * @param value the value of the reference
     * @param type the type of the reference. For example, the type of an URL is '__external'
     */
    public Reference(String value, String type)
    {
        _type = type != null ? type : DEFAULT_TYPE;
        _value = value;
    }

    /**
     * Retrieves the value
     * @return the value
     */
    public String getValue()
    {
        return _value;
    }

    /**
     * Retrieves the type
     * @return the type
     */
    public String getType()
    {
        return _type;
    }

    @Override
    public int hashCode()
    {
        return Objects.hash(_type, _value);
    }

    @Override
    public boolean equals(Object obj)
    {
        if (this == obj)
        {
            return true;
        }
        if (!(obj instanceof Reference))
        {
            return false;
        }
        Reference other = (Reference) obj;
        return Objects.equals(_type, other._type) && Objects.equals(_value, other._value);
    }
}
