/*
 *  Copyright 2022 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.data.holder.group;

import java.util.Optional;

import org.ametys.cms.data.holder.IndexableDataHolder;
import org.ametys.plugins.repository.data.holder.group.ModelAwareComposite;
import org.ametys.runtime.model.exception.BadDataPathCardinalityException;
import org.ametys.runtime.model.exception.BadItemTypeException;
import org.ametys.runtime.model.exception.UndefinedItemPathException;

/**
 * Interface for indexable composites
 */
public interface IndexableComposite extends ModelAwareComposite, IndexableDataHolder
{
    @Override
    public default IndexableComposite getComposite(String compositePath) throws IllegalArgumentException, UndefinedItemPathException, BadItemTypeException, BadDataPathCardinalityException
    {
        return getDefaultDataHolder().getComposite(compositePath);
    }

    @Override
    public default IndexableComposite getLocalComposite(String compositePath) throws IllegalArgumentException, UndefinedItemPathException, BadItemTypeException, BadDataPathCardinalityException
    {
        return getDefaultDataHolder().getLocalComposite(compositePath);
    }

    @Override
    public default IndexableComposite getExternalComposite(String compositePath) throws IllegalArgumentException, UndefinedItemPathException, BadItemTypeException, BadDataPathCardinalityException
    {
        return getDefaultDataHolder().getExternalComposite(compositePath);
    }

    @Override
    public default IndexableRepeater getRepeater(String repeaterPath) throws IllegalArgumentException, UndefinedItemPathException, BadItemTypeException, BadDataPathCardinalityException
    {
        return getDefaultDataHolder().getRepeater(repeaterPath);
    }

    @Override
    public default IndexableRepeater getLocalRepeater(String repeaterPath) throws IllegalArgumentException, UndefinedItemPathException, BadItemTypeException, BadDataPathCardinalityException
    {
        return getDefaultDataHolder().getLocalRepeater(repeaterPath);
    }

    @Override
    public default IndexableRepeater getExternalRepeater(String repeaterPath) throws IllegalArgumentException, UndefinedItemPathException, BadItemTypeException, BadDataPathCardinalityException
    {
        return getDefaultDataHolder().getExternalRepeater(repeaterPath);
    }
    
    @Override
    public IndexableDataHolder getDefaultDataHolder();
    
    @Override
    public default Optional<? extends IndexableDataHolder> getParentDataHolder()
    {
        return getDefaultDataHolder().getParentDataHolder();
    }
    
    @Override
    public default IndexableDataHolder getRootDataHolder()
    {
        return getDefaultDataHolder().getRootDataHolder();
    }
}
