/*
 *  Copyright 2022 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.data.holder.group;

import java.util.List;

import org.apache.solr.common.SolrInputDocument;

import org.ametys.cms.data.holder.IndexableDataHolder;
import org.ametys.cms.data.type.indexing.IndexableDataContext;
import org.ametys.plugins.repository.data.holder.group.ModelAwareRepeater;
import org.ametys.plugins.repository.data.holder.group.Repeater;
import org.ametys.runtime.model.exception.BadItemTypeException;

/**
 * Interface for indexable repeaters
 */
public interface IndexableRepeater extends ModelAwareRepeater
{
    /**
     * Indexes all data and properties of this {@link Repeater}
     * @param document the solr document representing th {@link Repeater}
     * @param rootDocument the solr document of the root object.
     * @param solrFieldPrefix the prefix of the solr field
     * @return additional solr documents that may have been created (ex: repeater entries)
     * @throws BadItemTypeException if the saxed value's type does not matches the stored data
     */
    public default List<SolrInputDocument> indexData(SolrInputDocument document, SolrInputDocument rootDocument, String solrFieldPrefix) throws BadItemTypeException
    {
        return indexData(document, rootDocument, solrFieldPrefix, IndexableDataContext.newInstance());
    }
    
    /**
     * Indexes all data and properties of this {@link Repeater}
     * @param document the solr document representing this {@link Repeater}
     * @param rootDocument the solr document of the root object.
     * @param solrFieldPrefix the prefix of the solr field
     * @param context The context of the data to index
     * @return additional solr documents that may have been created (ex: repeater entries)
     * @throws BadItemTypeException if the saxed value's type does not matches the stored data
     */
    public List<SolrInputDocument> indexData(SolrInputDocument document, SolrInputDocument rootDocument, String solrFieldPrefix, IndexableDataContext context) throws BadItemTypeException;
    
    @Override
    public List<? extends IndexableRepeaterEntry> getEntries();

    @Override
    public IndexableRepeaterEntry getEntry(int position);
    
    @Override
    public IndexableDataHolder getParentDataHolder();
    
    @Override
    public IndexableDataHolder getRootDataHolder();
}
