/*
 *  Copyright 2022 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.data.holder.group;

import java.util.Optional;

import org.ametys.cms.data.holder.ModifiableIndexableDataHolder;
import org.ametys.plugins.repository.data.holder.group.ModifiableModelAwareComposite;
import org.ametys.runtime.model.exception.BadDataPathCardinalityException;
import org.ametys.runtime.model.exception.BadItemTypeException;
import org.ametys.runtime.model.exception.UndefinedItemPathException;

/**
 * Interface for modifiable indexable composites
 */
public interface ModifiableIndexableComposite extends IndexableComposite, ModifiableModelAwareComposite, ModifiableIndexableDataHolder
{
    @Override
    public default ModifiableIndexableComposite getComposite(String compositePath) throws IllegalArgumentException, UndefinedItemPathException, BadItemTypeException, BadDataPathCardinalityException
    {
        return getDefaultDataHolder().getComposite(compositePath);
    }

    @Override
    public default ModifiableIndexableComposite getLocalComposite(String compositePath) throws IllegalArgumentException, UndefinedItemPathException, BadItemTypeException, BadDataPathCardinalityException
    {
        return getDefaultDataHolder().getLocalComposite(compositePath);
    }

    @Override
    public default ModifiableIndexableComposite getExternalComposite(String compositePath) throws IllegalArgumentException, UndefinedItemPathException, BadItemTypeException, BadDataPathCardinalityException
    {
        return getDefaultDataHolder().getExternalComposite(compositePath);
    }

    @Override
    public default ModifiableIndexableRepeater getRepeater(String repeaterPath) throws IllegalArgumentException, UndefinedItemPathException, BadItemTypeException, BadDataPathCardinalityException
    {
        return getDefaultDataHolder().getRepeater(repeaterPath);
    }

    @Override
    public default ModifiableIndexableRepeater getLocalRepeater(String repeaterPath) throws IllegalArgumentException, UndefinedItemPathException, BadItemTypeException, BadDataPathCardinalityException
    {
        return getDefaultDataHolder().getLocalRepeater(repeaterPath);
    }

    @Override
    public default ModifiableIndexableRepeater getExternalRepeater(String repeaterPath) throws IllegalArgumentException, UndefinedItemPathException, BadItemTypeException, BadDataPathCardinalityException
    {
        return getDefaultDataHolder().getExternalRepeater(repeaterPath);
    }
    
    @Override
    public default ModifiableIndexableComposite getComposite(String compositePath, boolean createNew) throws IllegalArgumentException, UndefinedItemPathException, BadItemTypeException, BadDataPathCardinalityException
    {
        return getDefaultDataHolder().getComposite(compositePath, createNew);
    }
    
    @Override
    public default ModifiableIndexableComposite getLocalComposite(String compositePath, boolean createNew) throws IllegalArgumentException, UndefinedItemPathException, BadItemTypeException, BadDataPathCardinalityException
    {
        return getDefaultDataHolder().getComposite(compositePath, createNew);
    }
    
    @Override
    public default ModifiableIndexableComposite getExternalComposite(String compositePath, boolean createNew) throws IllegalArgumentException, UndefinedItemPathException, BadItemTypeException, BadDataPathCardinalityException
    {
        return getDefaultDataHolder().getComposite(compositePath, createNew);
    }
    
    @Override
    public default ModifiableIndexableRepeater getRepeater(String repeaterPath, boolean createNew) throws IllegalArgumentException, UndefinedItemPathException, BadItemTypeException, BadDataPathCardinalityException
    {
        return getDefaultDataHolder().getRepeater(repeaterPath, createNew);
    }
    
    @Override
    public default ModifiableIndexableRepeater getLocalRepeater(String repeaterPath, boolean createNew) throws IllegalArgumentException, UndefinedItemPathException, BadItemTypeException, BadDataPathCardinalityException
    {
        return getDefaultDataHolder().getRepeater(repeaterPath, createNew);
    }
    
    @Override
    public default ModifiableIndexableRepeater getExternalRepeater(String repeaterPath, boolean createNew) throws IllegalArgumentException, UndefinedItemPathException, BadItemTypeException, BadDataPathCardinalityException
    {
        return getDefaultDataHolder().getRepeater(repeaterPath, createNew);
    }
    
    @Override
    public ModifiableIndexableDataHolder getDefaultDataHolder();
    
    @Override
    public default Optional<? extends ModifiableIndexableDataHolder> getParentDataHolder()
    {
        return getDefaultDataHolder().getParentDataHolder();
    }
    
    @Override
    public default ModifiableIndexableDataHolder getRootDataHolder()
    {
        return getDefaultDataHolder().getRootDataHolder();
    }
}
