/*
 *  Copyright 2018 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.data.holder.group.impl;

import java.util.Optional;

import org.ametys.cms.data.holder.IndexableDataHolder;
import org.ametys.cms.data.holder.group.IndexableComposite;
import org.ametys.cms.data.holder.impl.DefaultModelAwareDataHolder;
import org.ametys.plugins.repository.data.holder.DataHolder;
import org.ametys.plugins.repository.data.holder.group.Composite;
import org.ametys.plugins.repository.data.repositorydata.RepositoryData;
import org.ametys.runtime.model.ModelItemGroup;

/**
 * Class for model aware composites
 */
public class DefaultModelAwareComposite implements IndexableComposite
{
    /** The repository data of the repeater entry */
    protected RepositoryData _repositoryData;
    
    /** the default implementation of a {@link IndexableDataHolder} to use */
    protected IndexableDataHolder _defaultDataHolder;
    
    /** the definition of this composite */
    protected ModelItemGroup _definition;
    
    /**
     * Creates a model aware composite
     * @param repositoryData the repository data of the composite
     * @param parent the parent of the created {@link Composite}
     * @param root the root {@link DataHolder}
     * @param definition the definition of the composite
     */
    public DefaultModelAwareComposite(RepositoryData repositoryData, IndexableDataHolder parent, IndexableDataHolder root, ModelItemGroup definition)
    {
        _repositoryData = repositoryData;
        _defaultDataHolder = new DefaultModelAwareDataHolder(repositoryData, Optional.of(parent), Optional.of(root), definition);
        _definition = definition;
    }
    
    @Override
    public RepositoryData getRepositoryData()
    {
        return _repositoryData;
    }
    
    @Override
    public IndexableDataHolder getDefaultDataHolder()
    {
        return _defaultDataHolder;
    }
}
