/*
 *  Copyright 2018 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.data.holder.group.impl;

import java.util.Optional;

import org.ametys.cms.data.holder.ModifiableIndexableDataHolder;
import org.ametys.cms.data.holder.group.ModifiableIndexableComposite;
import org.ametys.cms.data.holder.impl.DefaultModifiableModelAwareDataHolder;
import org.ametys.plugins.repository.data.holder.DataHolder;
import org.ametys.plugins.repository.data.holder.ModifiableModelAwareDataHolder;
import org.ametys.plugins.repository.data.repositorydata.ModifiableRepositoryData;
import org.ametys.runtime.model.ModelItemGroup;

/**
 * Class for modifiable model aware composites
 */
public class DefaultModifiableModelAwareComposite extends DefaultModelAwareComposite implements ModifiableIndexableComposite
{
    /** The modifiable repository data of this composite */
    protected ModifiableRepositoryData _modifiableRepositoryData;
    
    /** the default implementation of a {@link ModifiableModelAwareDataHolder} to use */
    protected ModifiableIndexableDataHolder _modifiableDefaultDataHolder;
    
    /**
     * Creates a modifiable model aware composite
     * @param repositoryData the repository data of the composite
     * @param parent the parent of the created {@link DataHolder}
     * @param root the root {@link DataHolder}
     * @param definition the definition of the composite
     */
    public DefaultModifiableModelAwareComposite(ModifiableRepositoryData repositoryData, ModifiableIndexableDataHolder parent, ModifiableIndexableDataHolder root, ModelItemGroup definition)
    {
        super(repositoryData, parent, root, definition);
        _modifiableDefaultDataHolder = new DefaultModifiableModelAwareDataHolder(repositoryData, Optional.of(parent), Optional.of(root), definition);
        _modifiableRepositoryData = repositoryData;
    }
    
    @Override
    public ModifiableIndexableDataHolder getDefaultDataHolder()
    {
        return _modifiableDefaultDataHolder;
    }
    
    @Override
    public ModifiableRepositoryData getRepositoryData()
    {
        return _modifiableRepositoryData;
    }
}
