/*
 *  Copyright 2019 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.data.type.impl;

import org.ametys.cms.data.Binary;
import org.ametys.cms.data.type.ResourceElementTypeHelper;
import org.ametys.cms.data.type.indexing.impl.BinaryIndexableElementType;
import org.ametys.plugins.repository.RepositoryConstants;
import org.ametys.plugins.repository.data.repositorydata.ModifiableRepositoryData;
import org.ametys.plugins.repository.data.repositorydata.RepositoryData;
import org.ametys.plugins.repository.data.type.ComplexRepositoryElementType;

/**
 * Class for binary type of elements stored in the repository
 */
public class BinaryRepositoryElementType extends BinaryIndexableElementType implements ComplexRepositoryElementType<Binary>
{
    public boolean isSingleValueEmpty(RepositoryData singleValueData)
    {
        return ResourceElementTypeHelper.isResourceDataEmpty(singleValueData);
    }
    
    public Binary readSingleValue(RepositoryData singleValueData)
    {
        return ResourceElementTypeHelper.readBinaryData(singleValueData);
    }
    
    public void emptySingleValue(ModifiableRepositoryData parentData, String name)
    {
        ResourceElementTypeHelper.emptyResourceData(parentData, name, getRepositoryDataType());
    }

    public void writeSingleValue(ModifiableRepositoryData parentData, String name, Binary value)
    {
        ResourceElementTypeHelper.writeSingleBinaryValue(parentData, name, value);
    }
    
    @Override
    public boolean removeValueBeforeWritingIt()
    {
        return false;
    }
    
    public String getRepositoryDataType()
    {
        return RepositoryConstants.BINARY_NODETYPE;
    }
}
