/*
 *  Copyright 2018 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.data.type.impl;

import org.ametys.cms.data.Geocode;
import org.ametys.cms.data.type.indexing.impl.GeocodeIndexableElementType;
import org.ametys.plugins.repository.RepositoryConstants;
import org.ametys.plugins.repository.data.UnknownDataException;
import org.ametys.plugins.repository.data.repositorydata.ModifiableRepositoryData;
import org.ametys.plugins.repository.data.repositorydata.RepositoryData;
import org.ametys.plugins.repository.data.type.ComplexRepositoryElementType;
import org.ametys.runtime.model.exception.BadItemTypeException;

/**
 * Class for geocode type of elements stored in the repository
 */
public class GeocodeRepositoryElementType extends GeocodeIndexableElementType implements ComplexRepositoryElementType<Geocode>
{
    public boolean isSingleValueEmpty(RepositoryData geocodeData)
    {
        return !geocodeData.hasValue(Geocode.LATITUDE_IDENTIFIER) || !geocodeData.hasValue(Geocode.LONGITUDE_IDENTIFIER);
    }
    
    public Geocode readSingleValue(RepositoryData geocodeData) throws BadItemTypeException
    {
        Double latitude = _getDoubleValue(geocodeData, Geocode.LATITUDE_IDENTIFIER);
        Double longitude = _getDoubleValue(geocodeData, Geocode.LONGITUDE_IDENTIFIER);
        return (latitude != null && longitude != null) ? new Geocode(latitude, longitude) : null;
    }

    private Double _getDoubleValue(RepositoryData geocodeData, String name)
    {
        if (!geocodeData.hasValue(name))
        {
            return null;
        }
        else if (RepositoryData.DOUBLE_REPOSITORY_DATA_TYPE.equals(geocodeData.getType(name)))
        {
            return geocodeData.getDouble(name);
        }
        else
        {
            throw new BadItemTypeException("Try to get double value from the non double data '" + name + "' on '" + geocodeData + "'");
        }
    }
    
    public void writeSingleValue(ModifiableRepositoryData parentData, String name, Geocode value)
    {
        ModifiableRepositoryData geocodeData = parentData.addRepositoryData(name, getRepositoryDataType());
        
        if (value != null)
        {
            geocodeData.setValue(Geocode.LATITUDE_IDENTIFIER, value.getLatitude());
            geocodeData.setValue(Geocode.LONGITUDE_IDENTIFIER, value.getLongitude());
        }
    }
    
    public boolean isCompatible(RepositoryData parentData, String name) throws UnknownDataException
    {
        if (ComplexRepositoryElementType.super.isCompatible(parentData, name))
        {
            return true;
        }
        // TODO NEWATTRIBUTEAPI: This part of the test is here just to be compatible with the old compositeMetadata type. When all geocodes are migrated, remove this part of the test
        else if (RepositoryConstants.COMPOSITE_METADTA_NODETYPE.equals(parentData.getType(name)))
        {
            RepositoryData possibleGeocode = parentData.getRepositoryData(name);
            return possibleGeocode.getDataNames().size() == 2
                && possibleGeocode.hasValue(Geocode.LATITUDE_IDENTIFIER)
                && possibleGeocode.hasValue(Geocode.LONGITUDE_IDENTIFIER);
        }
        else
        {
            return false;
        }
    }
    
    public String getRepositoryDataType()
    {
        return RepositoryConstants.GEOCODE_NODETYPE;
    }
}
