/*
 *  Copyright 2019 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.data.type.impl;

import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.xml.sax.ContentHandler;

import org.ametys.cms.data.HTMLLocalMediaObjectHandler;
import org.ametys.cms.data.type.ModelItemTypeConstants;
import org.ametys.cms.transformation.RichTextTransformer;
import org.ametys.cms.transformation.html.HTMLTransformer;
import org.ametys.runtime.model.type.DataContext;

/**
 * Class for rich text type of elements stored in the repository
 * Generates HTML SAX events for the data of this type 
 */
public class HTMLRichTextRepositoryElementType extends RichTextRepositoryElementType
{
    @Override
    public void service(ServiceManager manager) throws ServiceException
    {
        super.service(manager);
        _richTextTransformer = (RichTextTransformer) manager.lookup(HTMLTransformer.ROLE);
    }
    
    @Override
    public String getId()
    {
        // the identifier of this type should be the same as its parent and not mention the html specificity
        return ModelItemTypeConstants.RICH_TEXT_ELEMENT_TYPE_ID;
    }
    
    @Override
    protected ContentHandler _getLocalMediaObjectContentHandler(ContentHandler contentHandler, DataContext context)
    {
        return new HTMLLocalMediaObjectHandler(contentHandler, context);
    }
}
