/*
 *  Copyright 2022 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.data.type.indexing;

import org.apache.solr.common.SolrInputDocument;

import org.ametys.runtime.model.type.ModelItemType;

/**
 * Interface for model item types that can be indexed
 */
public interface IndexableModelItemType extends ModelItemType
{
    /**
     * Index the given value in a solr document.
     * @param document the solr document to index into.
     * @param rootObjectDocument the solr document of the root object.
     * @param fieldName the name of the indexing field
     * @param value the value to index
     * @param context the context of the data to index. Can not be null.
     */
    public void indexValue(SolrInputDocument document, SolrInputDocument rootObjectDocument, String fieldName, Object value, IndexableDataContext context);
}
