/*
 *  Copyright 2022 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.data.type.indexing.impl;

import org.apache.solr.common.SolrInputDocument;

import org.ametys.cms.data.Binary;
import org.ametys.cms.data.type.AbstractBinaryElementType;
import org.ametys.cms.data.type.indexing.IndexableDataContext;
import org.ametys.cms.data.type.indexing.IndexableElementType;
import org.ametys.cms.data.type.indexing.IndexableElementTypeHelper;

/**
 * Class for binary type of elements that can be indexed
 */
public class BinaryIndexableElementType extends AbstractBinaryElementType implements IndexableElementType<Binary>
{
    public void indexSingleValue(SolrInputDocument document, SolrInputDocument rootObjectDocument, String fieldName, Binary value, IndexableDataContext context)
    {
        Binary valueToIndex = getSingleValueToIndex(value);
        IndexableElementTypeHelper.indexFileValue(document, rootObjectDocument, fieldName, valueToIndex, context, getLogger());
    }
    
    public void indexSingleValueForFullTextField(SolrInputDocument document, SolrInputDocument rootObjectDocument, Binary value, IndexableDataContext context)
    {
        IndexableElementTypeHelper.indexFulltextFileValue(document, rootObjectDocument, value, context, getLogger());
    }
    
    public String getSchemaType()
    {
        return null;
    }
}
