/*
 *  Copyright 2022 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.data.type.indexing.impl;

import java.time.ZoneOffset;
import java.time.ZonedDateTime;

import org.apache.solr.common.SolrInputDocument;

import org.ametys.cms.data.type.indexing.IndexableDataContext;
import org.ametys.cms.data.type.indexing.IndexableElementTypeHelper;
import org.ametys.cms.data.type.indexing.SortableIndexableElementType;
import org.ametys.core.model.type.AbstractDateTimeElementType;
import org.ametys.core.util.DateUtils;
import org.ametys.runtime.model.type.DataContext;

/**
 * Class for date time type of elements that can be indexed
 */
public class DateTimeIndexableElementType extends AbstractDateTimeElementType implements SortableIndexableElementType<ZonedDateTime>
{
    public void indexSingleValue(SolrInputDocument document, SolrInputDocument rootObjectDocument, String fieldName, ZonedDateTime value, IndexableDataContext context)
    {
        String valueToIndex = getSingleValueToIndex(value);
        document.addField(fieldName + getIndexingFieldSuffix(context), valueToIndex);
    }
    
    public void indexSingleValueForFullTextField(SolrInputDocument document, SolrInputDocument rootObjectDocument, ZonedDateTime value, IndexableDataContext context)
    {
        String valueToIndex = getSingleValueToIndex(value);
        IndexableElementTypeHelper.indexFulltextValue(rootObjectDocument, rootObjectDocument, valueToIndex, context);
    }
    
    @SuppressWarnings("unchecked")
    public <X> X getSingleValueToIndex(ZonedDateTime value)
    {
        return (X) DateUtils.zonedDateTimeToString(value, ZoneOffset.UTC);
    }
    
    public String getSortFieldSuffix()
    {
        return "_dt_sort";
    }

    public String getSchemaType()
    {
        return "pdate";
    }
    
    public String getIndexingFieldSuffix(DataContext context)
    {
        return "_dt";
    }
}
