/*
 *  Copyright 2022 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.data.type.indexing.impl;

import org.apache.solr.common.SolrInputDocument;

import org.ametys.cms.data.ExplorerFile;
import org.ametys.cms.data.File;
import org.ametys.cms.data.type.AbstractFileElementType;
import org.ametys.cms.data.type.indexing.IndexableDataContext;
import org.ametys.cms.data.type.indexing.IndexableElementType;
import org.ametys.cms.data.type.indexing.IndexableElementTypeHelper;
import org.ametys.plugins.explorer.resources.Resource;

/**
 * Class for file type of elements that can be indexed
 */
public class FileIndexableElementType extends AbstractFileElementType implements IndexableElementType<File>
{

    public void indexSingleValue(SolrInputDocument document, SolrInputDocument rootObjectDocument, String fieldName, File value, IndexableDataContext context)
    {
        File valueToIndex = getSingleValueToIndex(value);
        IndexableElementTypeHelper.indexFileValue(document, rootObjectDocument, fieldName, valueToIndex, context, getLogger());
        
        if (valueToIndex instanceof ExplorerFile explorerFile)
        {
            _indexSingleExplorerFileValueForFullTextField(document, rootObjectDocument, explorerFile, context);
        }
    }
    
    public void indexSingleValueForFullTextField(SolrInputDocument document, SolrInputDocument rootObjectDocument, File value, IndexableDataContext context)
    {
        IndexableElementTypeHelper.indexFulltextFileValue(document, rootObjectDocument, value, context, getLogger());
        
        File valueToIndex = getSingleValueToIndex(value);
        if (valueToIndex instanceof ExplorerFile explorerFile)
        {
            _indexSingleExplorerFileValueForFullTextField(document, rootObjectDocument, explorerFile, context);
        }
    }
    
    private void _indexSingleExplorerFileValueForFullTextField(SolrInputDocument document, SolrInputDocument rootObjectDocument, ExplorerFile value, IndexableDataContext context)
    {
        Resource resource = value.getResource();
        String[] subject = resource.getDCSubject();
        if (subject != null)
        {
            for (String keyword : subject)
            {
                IndexableElementTypeHelper.indexFulltextValue(document, rootObjectDocument, keyword, context);
            }
        }
        
        String description = resource.getDCDescription();
        if (description != null)
        {
            IndexableElementTypeHelper.indexFulltextValue(document, rootObjectDocument, description, context);
        }
    }
    
    public String getSchemaType()
    {
        return null;
    }

}
