/*
 *  Copyright 2022 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.data.type.indexing.impl;

import org.apache.solr.common.SolrInputDocument;

import org.ametys.cms.data.Geocode;
import org.ametys.cms.data.type.AbstractGeocodeElementType;
import org.ametys.cms.data.type.indexing.IndexableDataContext;
import org.ametys.cms.data.type.indexing.IndexableElementType;
import org.ametys.cms.data.type.indexing.IndexableElementTypeHelper;
import org.ametys.runtime.model.type.DataContext;

/**
 * Class for geocode type of elements that can be indexed
 */
public class GeocodeIndexableElementType extends AbstractGeocodeElementType implements IndexableElementType<Geocode>
{
    public void indexSingleValue(SolrInputDocument document, SolrInputDocument rootObjectDocument, String fieldName, Geocode value, IndexableDataContext context)
    {
        document.addField(fieldName + "$latitude_d", value.getLatitude());
        document.addField(fieldName + "$longitude_d", value.getLongitude());
        document.addField(fieldName + getIndexingFieldSuffix(context), value.getLatitude() + "," + value.getLongitude());
    }
    
    public void indexSingleValueForFullTextField(SolrInputDocument document, SolrInputDocument rootObjectDocument, Geocode value, IndexableDataContext context)
    {
        IndexableElementTypeHelper.indexFulltextValue(rootObjectDocument, rootObjectDocument, toString(value), context);
    }

    public String getSchemaType()
    {
        return "location_rpt";
    }
    
    public String getIndexingFieldSuffix(DataContext context)
    {
        return "_geo";
    }
}
