/*
 *  Copyright 2022 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.data.type.indexing.impl;

import org.apache.solr.common.SolrInputDocument;

import org.ametys.cms.data.type.indexing.IndexableDataContext;
import org.ametys.cms.data.type.indexing.IndexableElementTypeHelper;
import org.ametys.cms.data.type.indexing.SortableIndexableElementType;
import org.ametys.core.model.type.AbstractLongElementType;
import org.ametys.runtime.model.type.DataContext;

/**
 * Class for long type of elements that can be indexed
 */
public class LongIndexableElementType extends AbstractLongElementType implements SortableIndexableElementType<Long>
{
    public void indexSingleValue(SolrInputDocument document, SolrInputDocument rootObjectDocument, String fieldName, Long value, IndexableDataContext context)
    {
        Long valueToIndex = getSingleValueToIndex(value);

        document.addField(fieldName + getIndexingFieldSuffix(context), valueToIndex);
        if (isFacetable(context))
        {
            document.addField(fieldName + "_l_dv", valueToIndex);
        }
    }
    
    public void indexSingleValueForFullTextField(SolrInputDocument document, SolrInputDocument rootObjectDocument, Long value, IndexableDataContext context)
    {
        Long valueToIndex = getSingleValueToIndex(value);
        IndexableElementTypeHelper.indexFulltextValue(rootObjectDocument, rootObjectDocument, toString(valueToIndex), context);
    }
    
    public String getSortFieldSuffix()
    {
        return "_l_sort";
    }
    
    public String getSchemaType()
    {
        return "plong";
    }
    
    public String getIndexingFieldSuffix(DataContext context)
    {
        return "_l";
    }
}
