/*
 *  Copyright 2022 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.data.type.indexing.impl;

import java.util.Optional;

import org.apache.solr.common.SolrInputDocument;

import org.ametys.cms.data.Reference;
import org.ametys.cms.data.type.AbstractReferenceElementType;
import org.ametys.cms.data.type.indexing.IndexableDataContext;
import org.ametys.cms.data.type.indexing.IndexableElementTypeHelper;
import org.ametys.cms.data.type.indexing.SortableIndexableElementType;
import org.ametys.runtime.model.type.DataContext;

/**
 * Class for reference type of elements that can be indexed
 */
public class ReferenceIndexableElementType extends AbstractReferenceElementType implements SortableIndexableElementType<Reference>
{
    public void indexSingleValue(SolrInputDocument document, SolrInputDocument rootObjectDocument, String fieldName, Reference value, IndexableDataContext context)
    {
        String valueToIndex = getSingleValueToIndex(value);
        IndexableElementTypeHelper.indexStringValue(document, rootObjectDocument, fieldName, valueToIndex, context, getLogger());
    }
    
    public void indexSingleValueForFullTextField(SolrInputDocument document, SolrInputDocument rootObjectDocument, Reference value, IndexableDataContext context)
    {
        String valueToIndex = getSingleValueToIndex(value);
        IndexableElementTypeHelper.indexFulltextValue(rootObjectDocument, rootObjectDocument, valueToIndex, context);
    }
    
    @SuppressWarnings("unchecked")
    public <X> X getSingleValueToIndex(Reference value)
    {
        return (X) value.getValue();
    }
    
    public String getSortFieldSuffix()
    {
        return "_s_sort";
    }
    
    public String getSchemaType()
    {
        return "string";
    }
    
    public String getIndexingFieldSuffix(DataContext context)
    {
        return IndexableElementTypeHelper.getStringIndexingFieldSuffix(context);
    }
    
    public Optional<String> getWildcardFieldSuffix(DataContext context)
    {
        return Optional.of(IndexableElementTypeHelper.getStringWildcardFieldSuffix(context));
    }
    
    public Optional<String> getTextFieldSuffix(DataContext context)
    {
        return Optional.of(IndexableElementTypeHelper.getStringTextFieldSuffix(context));
    }
    
    public boolean isFacetable(DataContext context)
    {
        return IndexableElementTypeHelper.isStringDataFacetable(context);
    }
}
