/*
 *  Copyright 2022 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.data.type.indexing.impl;

import org.apache.commons.lang3.StringUtils;
import org.apache.solr.common.SolrInputDocument;

import org.ametys.cms.data.type.AbstractUserElementType;
import org.ametys.cms.data.type.indexing.IndexableDataContext;
import org.ametys.cms.data.type.indexing.IndexableElementTypeHelper;
import org.ametys.cms.data.type.indexing.SortableIndexableElementType;
import org.ametys.core.user.UserIdentity;
import org.ametys.runtime.model.type.DataContext;

/**
 * Class for user type of elements that can be indexed
 */
public class UserIndexableElementType extends AbstractUserElementType implements SortableIndexableElementType<UserIdentity>
{
    public void indexSingleValue(SolrInputDocument document, SolrInputDocument rootObjectDocument, String fieldName, UserIdentity value, IndexableDataContext context)
    {
        String identityAsString = getSingleValueToIndex(value);
        
        // Facets
        document.addField(fieldName + "_s_dv", identityAsString);
        // Dynamic fields
        document.addField(fieldName + getIndexingFieldSuffix(context), identityAsString);

        IndexableElementTypeHelper.indexFulltextValue(document, rootObjectDocument, identityAsString, context);
        
        String fullName = _helper.getUserFullName(value);
        if (StringUtils.isNotEmpty(fullName))
        {
            document.addField(fieldName + "_txt", fullName);
            IndexableElementTypeHelper.indexFulltextValue(document, rootObjectDocument, fullName, context);
        }
    }
    
    public void indexSingleValueForFullTextField(SolrInputDocument document, SolrInputDocument rootObjectDocument, UserIdentity value, IndexableDataContext context)
    {
        String identityAsString = getSingleValueToIndex(value);
        IndexableElementTypeHelper.indexFulltextValue(document, rootObjectDocument, identityAsString, context);
        
        String fullName = _helper.getUserFullName(value);
        if (StringUtils.isNotEmpty(fullName))
        {
            IndexableElementTypeHelper.indexFulltextValue(document, rootObjectDocument, fullName, context);
        }
    }
    
    @SuppressWarnings("unchecked")
    public <X> X getSingleValueToIndex(UserIdentity value)
    {
        return (X) UserIdentity.userIdentityToString(value);
    }
    
    public String getSortFieldSuffix()
    {
        return "_s_sort";
    }
    
    @SuppressWarnings("unchecked")
    public <X> X getSingleSortValueToIndex(UserIdentity value)
    {
        return (X) _helper.getUserSortableName(value);
    }
    
    public String getSchemaType()
    {
        return "string";
    }
    
    public String getIndexingFieldSuffix(DataContext context)
    {
        return "_s";
    }
    
    public boolean isFacetable(DataContext context)
    {
        return true;
    }
}
