/*
 *  Copyright 2021 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.duplicate.contents.attr;

import org.ametys.cms.search.query.Query;

/**
 * Represents the configuration for an attribute of content duplicate detection configuration
 * @param <T> The type of the attribute
 */
public interface DuplicateAttributeConfiguration<T>
{
    /**
     * Get the type of the attribute
     * @return the type of the attribute
     */
    public String getType();

    /**
     * Set the type of the attribute
     * @param type the type of the attribute
     */
    public void setType(String type);

    /**
     * Set the path of the attribute
     * @return the path of the attribute
     */
    public String getPath();

    /**
     * Set the path of the attribute
     * @param path the path of the attribute
     */
    public void setPath(String path);

    /**
     * Check if we should check for near duplicate
     * @return true if we should check for near duplicate
     */
    public boolean checkNearDuplicate();

    /**
     * Get the query to find duplicate of this attributes
     * @param value the value of the attribute
     * @param nearDuplicateQuery true if the query should check near duplicates
     * @return the query to find duplicate of this attributes
     */
    public Query getQuery(Object value, boolean nearDuplicateQuery);
}
