/*
 *  Copyright 2021 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.duplicate.contents.attr.impl;

import java.time.ZonedDateTime;

import org.apache.avalon.framework.configuration.Configuration;
import org.apache.avalon.framework.configuration.ConfigurationException;

import org.ametys.cms.duplicate.contents.attr.AbstractDuplicateAttributeConfiguration;
import org.ametys.cms.duplicate.contents.attr.DuplicateAttributeConfiguration;
import org.ametys.cms.search.query.DateQuery;
import org.ametys.cms.search.query.Query;
import org.ametys.core.util.date.AdaptableDate;

/**
 * Represents a {@link DuplicateAttributeConfiguration} for a {@link ZonedDateTime}
 */
public class DateTimeDuplicateAttributeConfiguration extends AbstractDuplicateAttributeConfiguration<ZonedDateTime>
{

    /**
     * Create a new DateTimeDuplicateAttributeConfiguration
     * @param configuration the configuration used to create the DuplicateAttributeConfiguration
     * @param attributeType the attribute type id
     * @throws ConfigurationException if the configuration is not valid.
     */
    public DateTimeDuplicateAttributeConfiguration(Configuration configuration, String attributeType) throws ConfigurationException
    {
        super(configuration, attributeType);
    }

    @Override
    protected Query getExistQuery()
    {
        return new DateQuery(_path);
    }

    @Override
    protected Query getDuplicateQuery(ZonedDateTime value)
    {
        return new DateQuery(_path, AdaptableDate.fromDateTime(value.toLocalDateTime()));
    }
}
