/*
 *  Copyright 2020 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.explorer;

import java.io.IOException;
import java.io.InputStream;

import org.apache.excalibur.source.Source;
import org.apache.excalibur.source.SourceNotFoundException;
import org.apache.excalibur.source.SourceValidity;
import org.apache.excalibur.source.impl.validity.TimeStampValidity;

import org.ametys.core.cocoon.source.NamedSource;
import org.ametys.plugins.explorer.resources.Resource;

/**
 * {@link Source} representing a {@link Resource}.
 */
public class AmetysResourceSource implements NamedSource
{
    private String _filename;
    private Resource _resource;
    
    private String _uri;
    
    /**
     * Constructor.
     * @param resource the {@link Resource}.
     * @param filename the local file name.
     * @param uri this source's uri.
     */
    public AmetysResourceSource(Resource resource, String filename, String uri)
    {
        _resource = resource;
        _filename = filename;
        _uri = uri;
    }
    
    public boolean exists()
    {
        return _resource != null;
    }

    public InputStream getInputStream() throws IOException, SourceNotFoundException
    {
        if (_resource == null)
        {
            throw new SourceNotFoundException("No resource found at " + _uri);
        }
        
        return _resource.getInputStream();
    }

    public String getURI()
    {
        return _uri;
    }

    public String getScheme()
    {
        return AmetysResourceSourceFactory.RESOURCE_SCHEME;
    }

    public SourceValidity getValidity()
    {
        return new TimeStampValidity(getLastModified());
    }
    
    public String getName()
    {
        return _filename;
    }

    public void refresh()
    {
        // does nothing
    }

    public String getMimeType()
    {
        return _resource.getMimeType();
    }

    public long getContentLength()
    {
        return _resource.getLength();
    }

    public long getLastModified()
    {
        return _resource != null ? _resource.getLastModified().getTime() : 0;
    }
}
