/*
 *  Copyright 2016 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.explorer;

import java.util.Map;
import java.util.Set;

import org.ametys.cms.repository.Content;
import org.ametys.plugins.explorer.ExplorerNode;
import org.ametys.plugins.explorer.resources.Resource;
import org.ametys.plugins.repository.AmetysObject;

/**
 * This DAO overrides {@link org.ametys.plugins.explorer.resources.actions.ExplorerResourcesDAO} to content attachments.
 */
public class ExplorerResourcesDAO extends org.ametys.plugins.explorer.resources.actions.ExplorerResourcesDAO
{
    @Override
    public Map<String, Object> getResourceProperties(Resource resource)
    {
        Map<String, Object> infos = super.getResourceProperties(resource);
        
        // Override 'rootOwnerType' if the resource in attached to a content
        if (_getParentContent(resource) != null)
        {
            infos.put("rootOwnerType", "content");
        }
        
        return infos;
    }
    
    @Override
    public Map<String, Object> getExplorerNodeProperties(ExplorerNode node)
    {
        Map<String, Object> infos = super.getExplorerNodeProperties(node);
        
        // Override 'rootOwnerType' if the node in attached to a content
        if (_getParentContent(node) != null)
        {
            infos.put("rootOwnerType", "content");
        }
        
        return infos;
    }
    
    @Override
    protected Set<String> getUserRights(ExplorerNode node)
    {
        Content parentContent = _getParentContent(node);
        if (parentContent != null)
        {
            return _rightManager.getUserRights(_currentUserProvider.getUser(), parentContent);
        }
        
        return super.getUserRights(node);
    }
    
    /**
     * Get the parent content of a resource or collection
     * @param ao The resource or collection
     * @return the parent content or null if the object is not part of content attachments
     */
    protected Content _getParentContent (AmetysObject ao)
    {
        AmetysObject parent = ao.getParent();
        while (parent != null)
        {
            if (parent instanceof Content)
            {
                return (Content) parent;
            }
            parent = parent.getParent();
        }
        return null;
    }
}
