/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.explorer;

import java.io.IOException;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.Set;

import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.cocoon.ProcessingException;
import org.apache.cocoon.environment.ObjectModelHelper;
import org.apache.cocoon.generation.ServiceableGenerator;
import org.apache.cocoon.xml.AttributesImpl;
import org.apache.cocoon.xml.XMLUtils;
import org.xml.sax.SAXException;

import org.ametys.core.right.RightManager;
import org.ametys.core.user.CurrentUserProvider;
import org.ametys.core.user.UserIdentity;
import org.ametys.plugins.explorer.resources.ModifiableResourceCollection;
import org.ametys.plugins.explorer.resources.Resource;
import org.ametys.plugins.repository.AmetysObjectResolver;
import org.ametys.plugins.repository.ModifiableAmetysObject;
import org.ametys.plugins.repository.UnknownAmetysObjectException;


/**
 * SAX the explorer nodes information
 */
public class ResourceInformationGenerator extends ServiceableGenerator
{
    private AmetysObjectResolver _resolver;

    private RightManager _rightManager;

    private CurrentUserProvider _userProvider;

    @Override
    public void service(ServiceManager serviceManager) throws ServiceException
    {
        super.service(serviceManager);

        _resolver = (AmetysObjectResolver) serviceManager.lookup(AmetysObjectResolver.ROLE);
        _rightManager = (RightManager) serviceManager.lookup(RightManager.ROLE);
        _userProvider = (CurrentUserProvider) serviceManager.lookup(CurrentUserProvider.ROLE);
    }

    @SuppressWarnings("unchecked")
    @Override
    public void generate() throws IOException, SAXException, ProcessingException
    {
        Map<String, Object> jsParameters = (Map<String, Object>) objectModel.get(ObjectModelHelper.PARENT_CONTEXT);
        
        List<String> ids = null;
        Object idParam = jsParameters.get("id");
        if (idParam instanceof String)
        {
            ids = new ArrayList<>();
            ids.add((String) idParam);
        }
        else
        {
            ids = (List<String>) idParam;
        }

        contentHandler.startDocument();
        XMLUtils.startElement(contentHandler, "resources");

        for (String id : ids)
        {
            try
            {
                Resource resource = (Resource) _resolver.resolveById(id);
                
                AttributesImpl attrs = new AttributesImpl();
                attrs.addCDATAAttribute("id", resource.getId());
                attrs.addCDATAAttribute("name", resource.getName());
                attrs.addCDATAAttribute("path", resource.getResourcePath());
                attrs.addCDATAAttribute("size", String.valueOf(resource.getLength()));
                attrs.addCDATAAttribute("isModifiable", String.valueOf(resource instanceof ModifiableAmetysObject));
                attrs.addCDATAAttribute("canCreateChild", String.valueOf(resource instanceof ModifiableResourceCollection));
                
                XMLUtils.startElement(contentHandler, "resource", attrs);
                _saxUserRights(resource);
                XMLUtils.endElement(contentHandler, "resource");
            }
            catch (UnknownAmetysObjectException e)
            {
                getLogger().warn("The resource of id '" + id + "' does not exist anymore", e);
            }
            
        }

        XMLUtils.endElement(contentHandler, "resources");
        contentHandler.endDocument();
    }

    private void _saxUserRights(Resource resource) throws SAXException
    {
        UserIdentity user = _userProvider.getUser();
        Set<String> rights = _rightManager.getUserRights(user, resource);
        
        XMLUtils.startElement(contentHandler, "user-rights");

        for (String rightID : rights)
        {
            AttributesImpl rightAttr = new AttributesImpl();
            rightAttr.addCDATAAttribute("id", rightID);
            XMLUtils.createElement(contentHandler, "right", rightAttr);
        }
        XMLUtils.endElement(contentHandler, "user-rights");
    }
}
