/*
 *  Copyright 2016 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.fo;

import java.util.Enumeration;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Map.Entry;

import org.apache.cocoon.environment.ObjectModelHelper;
import org.apache.cocoon.environment.Request;
import org.apache.commons.lang3.StringUtils;
import org.xml.sax.SAXException;

import org.ametys.core.ui.dispatcher.DispatchGenerator;
import org.ametys.plugins.repository.provider.RequestAttributeWorkspaceSelector;

/**
 * The purpose of this action is to handle front office requests.
 * These requests are usually AJAX requests coming from services.
 * The processing is loosely based on the {@link DispatchGenerator}
 */
public class FODispatchGenerator extends DispatchGenerator
{
    @Override
    protected void _dispatching(Map<String, Object> requestBody, Map<String, Object> contextAsMap) throws SAXException
    {
        contentHandler.startDocument();
        
        Map<String, Object> attributes = _requestAttributesHelper.saveRequestAttributes();
        contextAsMap.putAll(transmitAttributes(attributes));
        
        Request request = ObjectModelHelper.getRequest(objectModel);
        String currentWorkspace = RequestAttributeWorkspaceSelector.getForcedWorkspace(request);
        
        try
        {
            RequestAttributeWorkspaceSelector.setForcedWorkspace(request, "default");
            // Handle one sub request from FO
            _dispatchingSubRequest(requestBody, contextAsMap, "0");
        }
        finally 
        {
            RequestAttributeWorkspaceSelector.setForcedWorkspace(request, currentWorkspace);
        }
        
        _requestAttributesHelper.restoreRequestAttributes(attributes);
        
        contentHandler.endDocument();
    }
    
    @Override
    protected void _removeRequestAttributes()
    {
        // WORKSPACES-147 Possible WorkspacesFoRequestGenerator request attributes
        // FIXME Cannot remove request attributes, because necessary FO attributes like Web:FrontOffice:UserIdentity will be removed.
    }
    
    @Override
    protected void _handleFiles (Map<String, Object> requestParameters, String parameterKey)
    {
        Map<String, Object> uploadedFiles = _extractFiles();
        
        if (requestParameters != null && !uploadedFiles.isEmpty())
        {
            @SuppressWarnings("unchecked")
            List<Object> callableParameters = (List) requestParameters.get("parameters");
            
            if (callableParameters != null)
            {
                // Replace file parameters by real files
                for (Entry<String, Object> entry : uploadedFiles.entrySet())
                {
                    String fileIndex = StringUtils.substringAfter(entry.getKey(), "file-");
                    if (fileIndex.contains("-"))
                    {
                        int parameterIndex = Integer.parseInt(StringUtils.substringBefore(fileIndex, "-"));
                        int arrayIndex = Integer.parseInt(StringUtils.substringAfter(fileIndex, "-"));
                        @SuppressWarnings("unchecked")
                        List<Object> params = (List<Object>) callableParameters.get(parameterIndex);
                        params.remove(arrayIndex);
                        params.add(arrayIndex, entry.getValue());
                    }
                    else
                    {
                        int parameterIndex = Integer.parseInt(fileIndex);
                        
                        callableParameters.remove(parameterIndex);
                        callableParameters.add(parameterIndex, entry.getValue());
                    }
                }
            }
        }
    }
    
    private Map<String, Object> _extractFiles()
    {
        Request request = ObjectModelHelper.getRequest(objectModel);
        
        Map<String, Object> files = new HashMap<>();
        
        // Extract the optional list of uploaded files
        Enumeration paramNames = request.getParameterNames();
        while (paramNames.hasMoreElements())
        {
            String paramName = (String) paramNames.nextElement();
            if (paramName.startsWith("file-"))
            {
                files.put(paramName, request.get(paramName));
            }
        }
        
        return files;
    }
}
