/*
 *  Copyright 2023 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.group.directory;

import java.util.List;
import java.util.stream.Collectors;

import org.ametys.core.group.directory.GroupDirectory;
import org.ametys.core.user.population.UserPopulation;

/**
 * Implementation of a {@link GroupDirectory} based on user's populations restricted to '/application' context
 *
 */
public class UserPopulationsGroupDirectory extends org.ametys.plugins.core.impl.group.directory.UserPopulationsGroupDirectory
{
    private static final String __APPLICATION_CONTEXT = "/application";
    
    @Override
    protected List<UserPopulation> getAvailableUserPopulationsForContext()
    {
        List<UserPopulation> availableUserPopulations = _populationContextHelper.getUserPopulationsOnContext(__APPLICATION_CONTEXT, false)
            .stream()
            .map(_userPopulationDAO::getUserPopulation)
            .collect(Collectors.toList());
        
        return availableUserPopulations.isEmpty() ? super.getAvailableUserPopulationsForContext() : availableUserPopulations;
    }
    
}
