/*
 *  Copyright 2017 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.indexing;

import java.util.HashMap;
import java.util.Map;

import javax.jcr.RepositoryException;

import org.apache.avalon.framework.configuration.Configuration;
import org.apache.avalon.framework.configuration.ConfigurationException;
import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.LoggerFactory;

import org.ametys.plugins.core.impl.schedule.StaticRunnable;
import org.ametys.plugins.repository.provider.AbstractRepository;
import org.ametys.plugins.repository.provider.JackrabbitRepository;

/**
 * A {@link Runnable} for reloading Solr ACL caches for given workspaces (only for segments not already in cache).
 */
public class ReloadSolrAclCachesForCoresRunnable extends StaticRunnable
{
    private JackrabbitRepository _repository;

    @Override
    public void service(ServiceManager manager) throws ServiceException
    {
        super.service(manager);
        _repository = (JackrabbitRepository) manager.lookup(AbstractRepository.ROLE);
    }
    
    @Override
    protected void _configureParameterValues(Configuration paramConfigs) throws ConfigurationException
    {
        // Do nothing
    }
    
    @Override
    public Map<String, Object> getParameterValues()
    {
        Map<String, Object> params = new HashMap<>();
        try
        {
            String[] workspaces = _repository.getWorkspaces();
            params.put(ReloadSolrAclCachesForCoresSchedulable.WORKSPACE_KEY, StringUtils.join(workspaces, ','));
        }
        catch (RepositoryException e)
        {
            LoggerFactory.getLogger(ReloadSolrAclCachesForCoresRunnable.class).error("", e);
        }
        
        return params;
    }
}
