/*
 *  Copyright 2017 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.indexing;

import java.io.IOException;

import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.commons.lang3.StringUtils;
import org.apache.solr.client.solrj.SolrServerException;
import org.quartz.JobDataMap;
import org.quartz.JobExecutionContext;

import org.ametys.cms.content.indexing.solr.SolrIndexer;
import org.ametys.core.schedule.Schedulable;
import org.ametys.core.schedule.progression.ContainerProgressionTracker;
import org.ametys.plugins.core.impl.schedule.AbstractStaticSchedulable;
import org.ametys.plugins.core.schedule.Scheduler;

/**
 * A {@link Schedulable} job for reloading Solr ACL caches for given workspaces (only for segments not already in cache).
 */
public class ReloadSolrAclCachesForCoresSchedulable extends AbstractStaticSchedulable
{
    /** Parameter for workspace */
    public static final String WORKSPACE_KEY = "workspaces";
    
    private static final String __JOBDATAMAP_WORKSPACE_KEY = Scheduler.PARAM_VALUES_PREFIX + WORKSPACE_KEY;
    
    /** The Solr indexer */
    protected SolrIndexer _solrIndexer;

    @Override
    public void service(ServiceManager manager) throws ServiceException
    {
        super.service(manager);
        _solrIndexer = (SolrIndexer) manager.lookup(SolrIndexer.ROLE);
    }
    
    @Override
    public void execute(JobExecutionContext context, ContainerProgressionTracker progressionTracker) throws Exception
    {
        JobDataMap jobDataMap = context.getJobDetail().getJobDataMap();
        String workspaceNames = jobDataMap.getString(__JOBDATAMAP_WORKSPACE_KEY);
        for (String workspaceName : StringUtils.split(workspaceNames, ","))
        {
            try
            {
                _solrIndexer.reloadAclCache(workspaceName, true);
            }
            catch (IOException | SolrServerException e)
            {
                // Don't re-throw the exception
                getLogger().warn(String.format("Error reloading Solr ACL cache for workspace '%s'. Maybe Solr server is not started up.", workspaceName), e);
            }
        }
    }
}
