/*
 *  Copyright 2015 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.indexing;

import javax.jcr.RepositoryException;

import org.ametys.core.schedule.progression.ContainerProgressionTracker;
import org.ametys.core.ui.Callable;

/**
 * Component indexing a workspace.
 */
public interface WorkspaceIndexer
{
    /** The component role. */
    public static final String ROLE = WorkspaceIndexer.class.getName();

    /**
     * Index all the workspaces.
     * @throws IndexingException If an error occurs while indexing.
     */
    @Callable
    void indexAllWorkspaces() throws IndexingException;

    /**
     * Index all the workspaces.
     * @param progressionTracker The progression of the indexation
     * @throws IndexingException If an error occurs while indexing.
     */
    void indexAllWorkspaces(ContainerProgressionTracker progressionTracker) throws IndexingException;
    
    /**
     * Index a workspace.
     * @param workspaceName The workspace name.
     * @throws IndexingException If an error occurs while indexing the workspace.
     */
    @Callable
    void index(String workspaceName) throws IndexingException;
    
    /**
     * Index a workspace.
     * @param workspaceName The workspace name.
     * @param progressionTracker The progression tracker
     * @throws IndexingException If an error occurs while indexing the workspace.
     */
    void index(String workspaceName, ContainerProgressionTracker progressionTracker) throws IndexingException;

    /**
     * Get the workspaces labels
     * @return The list of labels
     * @throws RepositoryException If an error occurs
     */
    String[] getWorkspacesNames() throws RepositoryException;
}
