/*
 *  Copyright 2016 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.indexing.explorer;

import java.util.Map;

import org.apache.avalon.framework.logger.AbstractLogEnabled;
import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.avalon.framework.service.Serviceable;

import org.ametys.cms.content.indexing.solr.SolrIndexer;
import org.ametys.core.observation.Event;
import org.ametys.core.observation.Observer;
import org.ametys.plugins.explorer.ObservationConstants;
import org.ametys.plugins.explorer.resources.ResourceCollection;
import org.ametys.plugins.explorer.resources.ResourceHelper;
import org.ametys.plugins.repository.AmetysObjectResolver;

/**
 * Observer in charge for removing deleted contents from the Solr server.
 */
public class SolrUnindexResourceObserver extends AbstractLogEnabled implements Observer, Serviceable
{
    
    /** The Solr indexer. */
    protected SolrIndexer _solrIndexer;
    
    /** The AmetysObject resolver. */
    protected AmetysObjectResolver _resolver;
    
    @Override
    public void service(ServiceManager serviceManager) throws ServiceException
    {
        _resolver = (AmetysObjectResolver) serviceManager.lookup(AmetysObjectResolver.ROLE);
        _solrIndexer = (SolrIndexer) serviceManager.lookup(SolrIndexer.ROLE);
    }
    
    @Override
    public boolean supports(Event event)
    {
        return event.getId().equals(ObservationConstants.EVENT_RESOURCE_DELETED)
            || event.getId().equals(ObservationConstants.EVENT_COLLECTION_DELETED);
    }
    
    @Override
    public int getPriority(Event event)
    {
        return 0;
    }
    
    @Override
    public void observe(Event event, Map<String, Object> transientVars) throws Exception
    {
        if (event.getId().equals(ObservationConstants.EVENT_RESOURCE_DELETED))
        {
            String resourceId = (String) event.getArguments().get(ObservationConstants.ARGS_ID);
            if (resourceId != null)
            {
                _solrIndexer.unindexResource(resourceId);
            }
        }
        else if (event.getId().equals(ObservationConstants.EVENT_COLLECTION_DELETED))
        {
            String parentId = (String) event.getArguments().get(ObservationConstants.ARGS_PARENT_ID);
            String collectionPath = (String) event.getArguments().get(ObservationConstants.ARGS_EXPLORER_PATH);
            
            ResourceCollection parent = _resolver.resolveById(parentId);
            
            String rootId = ResourceHelper.getResourceRoot(parent).getId();
            
            _solrIndexer.unindexResourcesByPath(rootId, collectionPath);
        }
    }
    
}
