/*
 *  Copyright 2016 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.indexing.solr;

import java.util.Collection;

import org.apache.solr.common.SolrInputDocument;

import org.ametys.cms.search.solr.schema.SchemaDefinition;
import org.ametys.plugins.repository.AmetysObject;

/**
 * Index additional properties.
 */
public interface AdditionalPropertyIndexer
{
    
    /**
     * Get the object/document types supported by this indexer.
     * @return The object or document types supported by this indexer.
     */
    Collection<String> getSupportedTypes();
    
    /**
     * Index additional object properties in the corresponding document.
     * @param object The object to index.
     * @param document The destination document.
     */
    void index(AmetysObject object, SolrInputDocument document);
    
    /**
     * Get the schema definitions used by this indexer.
     * @return The schema definitions used by this indexer.
     */
    Collection<SchemaDefinition> getSchemaDefinitions();
    
}
