/*
 *  Copyright 2016 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.indexing.solr;

import java.util.Collection;
import java.util.Collections;

import org.ametys.runtime.plugin.ExtensionPoint;
import org.ametys.runtime.plugin.component.AbstractThreadSafeComponentExtensionPoint;

import com.google.common.collect.HashMultimap;
import com.google.common.collect.Multimap;

/**
 * {@link ExtensionPoint} for registering {@link AdditionalPropertyIndexer}s.
 */
public class AdditionalPropertyIndexerExtensionPoint extends AbstractThreadSafeComponentExtensionPoint<AdditionalPropertyIndexer>
{
    
    /** The extension point role. */
    public static final String ROLE = AdditionalPropertyIndexerExtensionPoint.class.getName();
    
    private Multimap<String, AdditionalPropertyIndexer> _extensionsByType;
    
    @Override
    public void initializeExtensions() throws Exception
    {
        super.initializeExtensions();
        
        _extensionsByType = HashMultimap.create();
        for (String id : getExtensionsIds())
        {
            AdditionalPropertyIndexer indexer = getExtension(id);
            
            for (String type : indexer.getSupportedTypes())
            {
                _extensionsByType.put(type, indexer);
            }
        }
    }
    
    /**
     * Get the additional property indexers for the given type.
     * @param type The type.
     * @return The additional property indexers for the given type.
     */
    public Collection<AdditionalPropertyIndexer> getIndexers(String type)
    {
        return Collections.unmodifiableCollection(_extensionsByType.get(type));
    }
    
}
