/*
 *  Copyright 2016 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.indexing.solr;

import java.util.ArrayList;
import java.util.Collection;
import java.util.List;

import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.avalon.framework.service.Serviceable;

import org.ametys.cms.search.solr.schema.SchemaDefinition;
import org.ametys.cms.search.solr.schema.SchemaDefinitionProvider;
import org.ametys.runtime.plugin.component.AbstractLogEnabled;

/**
 * Provides all the schema elements defined by additional property indexers.
 */
public class AdditionalPropertyIndexerSchemaDefinitionProvider extends AbstractLogEnabled implements SchemaDefinitionProvider, Serviceable
{
    
    /** The additional property indexer extension point. */
    protected AdditionalPropertyIndexerExtensionPoint _additionalPropertyIndexerEP;
    
    @Override
    public void service(ServiceManager manager) throws ServiceException
    {
        _additionalPropertyIndexerEP = (AdditionalPropertyIndexerExtensionPoint) manager.lookup(AdditionalPropertyIndexerExtensionPoint.ROLE);
    }
    
    @Override
    public Collection<SchemaDefinition> getDefinitions()
    {
        List<SchemaDefinition> definitions = new ArrayList<>();
        
        for (String id : _additionalPropertyIndexerEP.getExtensionsIds())
        {
            AdditionalPropertyIndexer indexer = _additionalPropertyIndexerEP.getExtension(id);
            
            definitions.addAll(indexer.getSchemaDefinitions());
        }
        
        return definitions;
    }

}
