/*
 *  Copyright 2016 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.indexing.solr;

import org.apache.solr.client.solrj.SolrClient;

import org.ametys.cms.indexing.IndexingException;
import org.ametys.core.schedule.progression.ContainerProgressionTracker;
import org.ametys.runtime.i18n.I18nizableText;

/**
 * Provides additional documents when indexing a workspace.
 */
public interface DocumentProvider
{
    /**
     * The label of the document provider
     * @return The label
     */
    I18nizableText getLabel();
    
    /**
     * Index additional documents for the given workspace.
     * @param workspaceName The workspace name.
     * @param solrClient The solr client to use
     * @throws IndexingException If an error occurs indexing the documents.
     */
    void indexDocuments(String workspaceName, SolrClient solrClient) throws IndexingException;
    
    /**
     * Index additional documents for the given workspace.
     * @param workspaceName The workspace name.
     * @param solrClient The solr client to use
     * @param progressionTracker The progression tracker
     * @throws IndexingException If an error occurs indexing the documents.
     */
    void indexDocuments(String workspaceName, SolrClient solrClient, ContainerProgressionTracker progressionTracker) throws IndexingException;
}
