/*
 *  Copyright 2017 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.indexing.solr;

import java.io.IOException;
import java.util.Collection;

import org.apache.solr.client.solrj.SolrClient;
import org.apache.solr.client.solrj.SolrRequest;
import org.apache.solr.client.solrj.response.SolrResponseBase;
import org.apache.solr.common.params.ModifiableSolrParams;
import org.apache.solr.common.params.SolrParams;
import org.apache.solr.common.util.ContentStream;

/**
 * {@link SolrRequest} to reload the ACL Solr cache
 */
public class ReloadAclCacheRequest extends SolrRequest<SolrResponseBase>
{
    /** If true, only the segments which are not already in cache are computed */
    protected boolean _checkIfNecessary;

    /**
     * Default constructor
     */
    public ReloadAclCacheRequest()
    {
        this(false);
    }
    
    /**
     * Default constructor
     * @param checkIfNecessary true to check if the reload is necessary for each segment (i.e. reload only the segments not already in cache)
     */
    public ReloadAclCacheRequest(boolean checkIfNecessary)
    {
        super(METHOD.GET, "/reloadAclCache");
        _checkIfNecessary = checkIfNecessary;
    }
    
    @Override
    public SolrParams getParams()
    {
        ModifiableSolrParams params = new ModifiableSolrParams();
        params.add("checkIfNecessary", String.valueOf(_checkIfNecessary));
        return params;
    }

    @Override
    public Collection<ContentStream> getContentStreams() throws IOException
    {
        return null;
    }

    @Override
    protected SolrResponseBase createResponse(SolrClient client)
    {
        return new SolrResponseBase();
    }
    
    @Override
    public String getRequestType()
    {
        return SolrRequestType.ADMIN.toString();
    }
}
