/*
 *  Copyright 2019 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.indexing.solr;

import static java.lang.annotation.ElementType.TYPE_USE;
import static java.lang.annotation.RetentionPolicy.RUNTIME;

import java.lang.annotation.Inherited;
import java.lang.annotation.Retention;
import java.lang.annotation.Target;

import org.ametys.cms.content.indexing.solr.SolrIndexer;
import org.ametys.core.right.AccessController;
import org.ametys.core.right.RightContextConvertor;
import org.ametys.core.right.RightManager;

/**
 * This annotation (on Class or Interface) is a marker for context objects on which any change of
 * profile assignment ensures that there is no indexed object (neither the given object nor any other object in the whole application)
 * that is affected in its own {@link RightManager#getReadAccessAllowedUsers read access} computing.
 * 
 * <br><b>Be careful.</b> Being an object not indexed in Solr does <b>not</b> mean that
 * it is uninfluential on any other indexed object (it can have influence through
 * {@link RightContextConvertor} or {@link AccessController}).
 * 
 * <br>This is a way to avoid an expensive and useless {@link SolrIndexer#reloadAclCache Solr AclCache reload}
 * in some cases.
 */
@Retention(RUNTIME)
@Target(TYPE_USE)
@Inherited
public @interface SolrAclCacheUninfluentialObject
{
    // Empty
}

