/*
 *  Copyright 2017 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.indexing.solr;

import java.io.IOException;
import java.util.Collection;

import org.apache.solr.client.solrj.SolrClient;
import org.apache.solr.client.solrj.SolrRequest;
import org.apache.solr.client.solrj.response.SolrResponseBase;
import org.apache.solr.common.params.ModifiableSolrParams;
import org.apache.solr.common.params.SolrParams;
import org.apache.solr.common.util.ContentStream;

/**
 * {@link SolrRequest} to update the value of a core property
 */
public class UpdateCorePropertyRequest extends SolrRequest<SolrResponseBase>
{
    private String _key;
    private String _value;

    /**
     * Default constructor
     * @param key The property key to update
     * @param value The new value to set
     */
    public UpdateCorePropertyRequest(String key, String value)
    {
        super(METHOD.GET, "/updateCoreProperty");
        _key = key;
        _value = value;
    }
    
    @Override
    public SolrParams getParams()
    {
        ModifiableSolrParams params = new ModifiableSolrParams();
        params.add("key", _key);
        params.add("value", _value);
        return params;
    }

    @Override
    public Collection<ContentStream> getContentStreams() throws IOException
    {
        return null;
    }

    @Override
    protected SolrResponseBase createResponse(SolrClient client)
    {
        return new SolrResponseBase();
    }
    
    @Override
    public String getRequestType()
    {
        return SolrRequestType.ADMIN.toString();
    }
}
