/*
 *  Copyright 2012 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

package org.ametys.cms.languages;

import org.ametys.runtime.i18n.I18nizableText;

/**
 * A language representation
 */
public class Language
{
    private String _code;
    private I18nizableText _label;

    /**
     * Creates a language 
     * @param code The code of the language
     * @param label The label of the language
     */
    public Language(String code, I18nizableText label)
    {
        _code = code;
        _label = label;
    }
    
    /**
     * Get the language code
     * @return The code
     */
    public String getCode()
    {
        return _code;
    }
    
    /**
     * Get the language label
     * @return The label
     */
    public I18nizableText getLabel()
    {
        return _label;
    }
    
    /**
     * Get the small icon flag image
     * @return The path relative to the webapps
     */
    public String getSmallIcon()
    {
        return getIcon("small");
    }
    
    /**
     * Get the medium icon flag image
     * @return The path relative to the webapps
     */
    public String getMediumIcon()
    {
        return getIcon("medium");
    }
    
    /**
     * Get the large icon flag image
     * @return The path relative to the webapps
     */
    public String getLargeIcon()
    {
        return getIcon("large");
    }
    
    private String getIcon(String size)
    {
        if (_label.isI18n() && _label.getCatalogue().startsWith("plugin."))
        {
            return "/plugins/" + _label.getCatalogue().substring("plugin.".length()) + "/resources/img/flag/" + size + "/flag-" + _code + ".png";
        }
        else
        {
            return "/plugins/cms/resources_flag/" + size + "/flag-" + _code + ".png";
        }
    }
}
