/*
 *  Copyright 2013 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.languages;

import java.util.Collections;
import java.util.HashMap;
import java.util.Map;

import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.avalon.framework.service.Serviceable;

import org.ametys.runtime.i18n.I18nizableText;
import org.ametys.runtime.model.Enumerator;

/**
 * Languages enumerator
 *
 */
public class LanguageEnumerator implements Enumerator<String>, Serviceable, org.ametys.runtime.parameter.Enumerator
{
    private LanguagesManager _languageManager;
    
    @Override
    public void service(ServiceManager manager) throws ServiceException
    {
        _languageManager = (LanguagesManager) manager.lookup(LanguagesManager.ROLE);
    }
    
    @Override
    public I18nizableText getEntry(String value) throws Exception
    {
        Map<String, Language> languages = _languageManager.getAvailableLanguages();
        
        if (languages.containsKey(value))
        {
            return languages.get(value).getLabel();
        }
        else
        {
            return new I18nizableText("");
        }
    }
    
    @Override
    public Map<Object, I18nizableText> getEntries() throws Exception
    {
        return (Map<Object, I18nizableText>) (Object) getTypedEntries();
    }
    
    @Override
    public Map<String, I18nizableText> getTypedEntries() throws Exception
    {
        Map<String, I18nizableText> entries = new HashMap<>();
        
        Map<String, Language> languages = _languageManager.getAvailableLanguages();
        for (Language lang : languages.values())
        {
            entries.put(lang.getCode(), lang.getLabel());
        }
        
        return entries;
    }
    
    @Override
    // TODO NEWATTRIBUTEAPI: remove this method when org.ametys.runtime.parameter.Enumerator will be removed
    public Map<String, Object> getConfiguration()
    {
        return Collections.EMPTY_MAP;
    }
}
