/*
 *  Copyright 2018 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.model;

import org.apache.avalon.framework.configuration.Configuration;
import org.apache.avalon.framework.configuration.ConfigurationException;
import org.apache.avalon.framework.service.ServiceManager;

import org.ametys.cms.data.type.ModelItemTypeConstants;
import org.ametys.runtime.model.ElementDefinition;
import org.ametys.runtime.model.Enumerator;
import org.ametys.runtime.model.Model;
import org.ametys.runtime.model.ModelItem;
import org.ametys.runtime.model.ModelItemGroup;
import org.ametys.runtime.model.type.ModelItemType;
import org.ametys.runtime.model.type.ModelItemTypeExtensionPoint;
import org.ametys.runtime.parameter.Validator;
import org.ametys.runtime.plugin.component.ThreadSafeComponentManager;

/**
 * {@link ElementDefinition} parser from an XML configuration.
 */
public class ElementDefinitionParser extends org.ametys.runtime.model.ElementDefinitionParser
{
    /**
     * Creates an element definition parser.
     * @param modelItemTypeExtensionPoint the extension point to use to get available element types
     * @param enumeratorManager the enumerator component manager.
     * @param validatorManager the validator component manager.
     */
    public ElementDefinitionParser(ModelItemTypeExtensionPoint modelItemTypeExtensionPoint, ThreadSafeComponentManager<Enumerator> enumeratorManager, ThreadSafeComponentManager<Validator> validatorManager)
    {
        super(modelItemTypeExtensionPoint, enumeratorManager, validatorManager);
    }
    
    @Override
    @SuppressWarnings("unchecked")
    public <T extends ModelItem> T parse(ServiceManager serviceManager, String pluginName, String catalog, Configuration definitionConfig, Model model, ModelItemGroup parent) throws ConfigurationException
    {
        ElementDefinition definition = (ElementDefinition) super.parse(serviceManager, pluginName, catalog, definitionConfig, model, parent);
        
        if (definition instanceof ContentElementDefinition contentElementDefinition)
        {
            contentElementDefinition.setContentTypeId(_parseContentTypeId(definitionConfig));
        }
        
        return (T) definition;
    }
    
    @Override
    protected ElementDefinition _createModelItem(Configuration definitionConfig) throws ConfigurationException
    {
        ModelItemType type = _parseType(definitionConfig);
        if (ModelItemTypeConstants.CONTENT_ELEMENT_TYPE_ID.equals(type.getId()))
        {
            return new DefaultContentElementDefinition();
        }
        else
        {
            return super._createModelItem(definitionConfig);            
        }
    }
    
    /**
     * Parses the content type identifier attribute.
     * @param itemConfig the item configuration to use.
     * @return the identifier of the content type or <code>null</code> if none defined.
     * @throws ConfigurationException if the defined content type des not exist
     */
    protected String _parseContentTypeId(Configuration itemConfig) throws ConfigurationException
    {
        return itemConfig.getAttribute("contentType", null);
    }
}
