/*
 *  Copyright 2018 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.model.parsing;

import org.apache.avalon.framework.configuration.Configuration;
import org.apache.avalon.framework.configuration.ConfigurationException;
import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;

import org.ametys.cms.model.ContentRestrictedRepeaterDefinition;
import org.ametys.cms.model.restrictions.ContentRestrictedModelItemHelper;
import org.ametys.plugins.repository.model.parsing.RepeaterDefinitionParser;
import org.ametys.runtime.model.Model;
import org.ametys.runtime.model.ModelItem;
import org.ametys.runtime.model.ModelItemGroup;
import org.ametys.runtime.model.type.ModelItemTypeExtensionPoint;

/**
 * This class parses the content restricted repeater definition
 */
public class ContentRestrictedRepeaterDefinitionParser extends RepeaterDefinitionParser
{
    /**
     * Creates a content restricted repeater definition parser.
     * @param modelItemTypeExtensionPoint the extension point to use to get available model items types
     */
    public ContentRestrictedRepeaterDefinitionParser(ModelItemTypeExtensionPoint modelItemTypeExtensionPoint)
    {
        super(modelItemTypeExtensionPoint);
    }
    
    @Override
    @SuppressWarnings("unchecked")
    public <T extends ModelItem> T parse(ServiceManager serviceManager, String pluginName, String catalog, Configuration definitionConfig, Model model, ModelItemGroup parent) throws ConfigurationException
    {
        ContentRestrictedRepeaterDefinition definition = (ContentRestrictedRepeaterDefinition) super.parse(serviceManager, pluginName, catalog, definitionConfig, model, parent);
        
        try
        {
            ContentRestrictedModelItemHelper restrictedModelItemHelper = (ContentRestrictedModelItemHelper) serviceManager.lookup(ContentRestrictedModelItemHelper.ROLE);
            definition.setRestrictions(restrictedModelItemHelper._parseRestrictions(definitionConfig));
        }
        catch (ServiceException e)
        {
            throw new ConfigurationException("Unable to resolve restrictions on the element '" + definition.getName() + "'.", e);
        }
        
        return (T) definition;
    }

    @Override
    protected ContentRestrictedRepeaterDefinition _createModelItem(Configuration itemConfig) throws ConfigurationException
    {
        return new ContentRestrictedRepeaterDefinition();
    }
}
