/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.model.restrictions;

import org.ametys.runtime.model.ModelItem;

/**
 * Interface for model items with restrictions
 * @param <T> Type of object on which the restrictions are applied
 */
public interface RestrictedModelItem<T> extends ModelItem
{
    /**
     * Determines if the object can be read by the definition
     * @param object the object
     * @return true if the object can be read by the definition, false otherwise
     */
    public boolean canRead(T object);
    
    /**
     * Determines if the object can be written by the definition
     * @param object the object
     * @return true if the object can be written by the definition, false otherwise
     */
    public boolean canWrite(T object);
    
}
