/*
 *  Copyright 2018 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.model.restrictions;

import java.util.Arrays;
import java.util.HashSet;
import java.util.Set;

/**
 * Restrictions provided with a restricted model item.
 */
public class Restrictions
{
    /** Cannot read status. */
    private boolean _cannotRead;
    /** Cannot write status. */
    private boolean _cannotWrite;
    /** Read right ids. */
    private Set<String> _readRightIds = new HashSet<>();
    /** Read workflow step ids. */
    private Set<String> _writeRightIds = new HashSet<>();
    /** Write right ids. */
    private Set<Integer> _readWorkflowfStepIds = new HashSet<>();
    /** Write workflow step ids. */
    private Set<Integer> _writeWorkflowfStepIds = new HashSet<>();
    
    /**
     * Retrieves the cannot read status of the restrictions
     * @return the cannot read
     */
    public boolean cannotRead()
    {
        return _cannotRead;
    }
    
    /**
     * Sets the cannot read status
     * @param cannotRead the cannot read status to set
     */
    public void setCannotRead(boolean cannotRead)
    {
        _cannotRead = cannotRead;
    }
    
    /**
     * Retrieves the cannot write status of the restrictions
     * @return the cannot write
     */
    public boolean cannotWrite()
    {
        return _cannotWrite;
    }
    
    /**
     * Sets the cannot write status
     * @param cannotWrite the cannot write status to set
     */
    public void setCannotWrite(boolean cannotWrite)
    {
        _cannotWrite = cannotWrite;
    }
    
    /**
     * Retrieves the read rights identifiers
     * @return the read rights identifiers
     */
    public Set<String> getReadRightIds()
    {
        return _readRightIds;
    }
    
    /**
     * Add identifiers for read rights
     * @param readRightIds the read right identifiers to add
     */
    public void addReadRightIds(String... readRightIds)
    {
        this._readRightIds.addAll(Arrays.asList(readRightIds));
    }
    
    /**
     * Retrieves the write rights identifiers
     * @return the write rights identifiers
     */
    public Set<String> getWriteRightIds()
    {
        return _writeRightIds;
    }
    
    /**
     * Add identifiers for write rights
     * @param writeRightIds the write right identifiers to add
     */
    public void addWriteRightIds(String... writeRightIds)
    {
        _writeRightIds.addAll(Arrays.asList(writeRightIds));
    }
    
    /**
     * Retrieves the read workflow step identifiers
     * @return the read workflow step identifiers
     */
    public Set<Integer> getReadWorkflowfStepIds()
    {
        return _readWorkflowfStepIds;
    }
    
    /**
     * Add identifiers for read workflow step
     * @param readWorkflowfStepIds read workflow step identifiers to add
     */
    public void addReadWorkflowfStepIds(Integer... readWorkflowfStepIds)
    {
        _readWorkflowfStepIds.addAll(Arrays.asList(readWorkflowfStepIds));
    }
    
    /**
     * Retrieves the write workflow step identifiers
     * @return the write workflow step identifiers
     */
    public Set<Integer> getWriteWorkflowfStepIds()
    {
        return _writeWorkflowfStepIds;
    }
    
    /**
     * Add identifiers for write workflow step
     * @param writeWorkflowfStepIds write workflow step identifiers to add
     */
    public void addWriteWorkflowfStepIds(Integer... writeWorkflowfStepIds)
    {
        _writeWorkflowfStepIds.addAll(Arrays.asList(writeWorkflowfStepIds));
    }
}
