/*
 *  Copyright 2017 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.remote;

import java.util.HashSet;
import java.util.Set;
import java.util.regex.Pattern;

import org.apache.avalon.framework.configuration.Configurable;
import org.apache.avalon.framework.configuration.Configuration;
import org.apache.avalon.framework.configuration.ConfigurationException;

/**
 * Static implementation of a {@link RemoteUrl}
 *
 */
public class StaticRemoteUrl implements RemoteUrl, Configurable
{
    Set<Pattern> _patterns;
    
    @Override
    public void configure(Configuration configuration) throws ConfigurationException
    {
        _patterns = new HashSet<>();
        
        Configuration patternsConfig = configuration.getChild("patterns");
        
        for (Configuration patternConfig : patternsConfig.getChildren("pattern"))
        {
            _patterns.add(Pattern.compile(patternConfig.getValue()));
        }
    }
    
    @Override
    public Set<Pattern> getAllowedUrls()
    {
        return _patterns;
    }

}
