/*
 *  Copyright 2021 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

package org.ametys.cms.repository;

import java.time.ZonedDateTime;
import java.util.List;

import org.ametys.cms.repository.comment.Comment;
import org.ametys.plugins.repository.AmetysRepositoryException;

/**
 * A commentable ametys object
 */
public interface CommentableAmetysObject
{
    /**
     * Creates a comment
     * @return The new comment
     */
    public Comment createComment();
    
    /**
     * Creates a comment with the given id and creation date
     * This method allow to create a comment from existing data (ex: data import from archive) 
     * The id is not generated here, the source is trusted. Be careful using this method
     * @param commentId the comment's id
     * @param creationDate the comment's creation date
     * @return the new comment
     */
    public Comment createComment(String commentId, ZonedDateTime creationDate);
    
    /**
     * Get a comment
     * @param commentId The comment
     * @return The comment
     * @throws AmetysRepositoryException if  error occurs
     */
    public Comment getComment(String commentId) throws AmetysRepositoryException;

    /**
     * Get the list of available comments (validated, not validated, both or none :))
     * @param includeNotValidatedComments true to get the non validated comments.
     * @param includeValidatedComments true to get the validated comment.
     * @return A non null list of comments on the ametys object.
     * @throws AmetysRepositoryException if an error occurred
     */
    public List<Comment> getComments(boolean includeNotValidatedComments, boolean includeValidatedComments) throws AmetysRepositoryException;
}
