/*
 *  Copyright 2012 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.repository;

import java.time.ZonedDateTime;

import javax.jcr.Node;

import org.ametys.plugins.repository.AmetysRepositoryException;
import org.ametys.plugins.repository.RepositoryIntegrityViolationException;
import org.ametys.plugins.repository.metadata.MetadataAwareAmetysObjectHelper;

/**
 * Default implementation of a {@link Content}, also versionable, lockable and workflow-aware.
 * @param <F> the actual type of factory.
 */
public class DefaultWorkflowAwareContent<F extends DefaultWorkflowAwareContentFactory> extends DefaultContent<F> implements WorkflowAwareContent
{
    /**
     * Creates a JCR-based Content.
     * @param node the JCR Node backing this Content.
     * @param parentPath the parent path in the Ametys hierarchy.
     * @param factory the corresponding {@link ContentFactory}.
     */
    public DefaultWorkflowAwareContent(Node node, String parentPath, F factory)
    {
        super(node, parentPath, factory);
    }
    
    @Override
    public long getWorkflowId() throws AmetysRepositoryException
    {
        return WorkflowAwareContentHelper.getWorkflowId(this);
    }
    
    @Override
    public void setWorkflowId(long workflowId) throws AmetysRepositoryException
    {
        WorkflowAwareContentHelper.setWorkflowId(this, workflowId);
    }
    
    @Override
    public long getCurrentStepId() throws AmetysRepositoryException
    {
        return WorkflowAwareContentHelper.getCurrentStepId(this);
    }
    
    @Override
    public void setCurrentStepId (long stepId) throws AmetysRepositoryException
    {
        WorkflowAwareContentHelper.setCurrentStepId(this, stepId);
    }
    
    @Override
    public ZonedDateTime getProposalDate() throws AmetysRepositoryException
    {
        return WorkflowAwareContentHelper.getProposalDate(this);
    }
    
    @Override
    public void setProposalDate(ZonedDateTime proposalDate) throws AmetysRepositoryException
    {
        WorkflowAwareContentHelper.setProposalDate(this, proposalDate);
    }
    
    @Override
    public void remove() throws AmetysRepositoryException, RepositoryIntegrityViolationException
    {
        MetadataAwareAmetysObjectHelper.removeSubObjects(this);
        
        super.remove();
    }
    
}
