/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.repository;

import java.util.Date;

import org.apache.commons.lang.time.FastDateFormat;

import org.ametys.plugins.repository.query.expression.Expression;

/**
 * Constructs an {@link Expression} testing the existence of a particular step on the workflow history.
 */
public class HistoryStepExpression implements Expression
{
    private int _step;
    private Date _startBefore;
    private Date _startAfter;

    /**
     * Creates the expression.
     * @param stepId the workflow step
     */
    public HistoryStepExpression(int stepId)
    {
        _step = stepId;
    }
    
    /**
     * Creates the expression.
     * @param stepId the workflow step
     * @param startAfter the beginning Date
     * @param startBefore the ending Date
     */
    public HistoryStepExpression(int stepId, Date startAfter, Date startBefore)
    {
        _step = stepId;
        _startBefore = startBefore;
        _startAfter = startAfter;
    }
    
    public String build()
    {
        StringBuilder sb = new StringBuilder("(oswf:historyStep/@oswf:stepId = ");
        sb.append(_step);
        
        if (_startAfter != null)
        {
            sb.append(" and oswf:historyStep/@oswf:startDate >= xs:dateTime('" + FastDateFormat.getInstance("yyyy-MM-dd'T'HH:mm:ss.SSSZZ").format(_startAfter) + "')");
        }
        
        if (_startBefore != null)
        {
            sb.append(" and oswf:historyStep/@oswf:startDate <= xs:dateTime('" + FastDateFormat.getInstance("yyyy-MM-dd'T'HH:mm:ss.SSSZZ").format(_startBefore) + "')");
        }
        sb.append(")");
        return sb.toString();
    }
}
