/*
 *  Copyright 2013 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.repository;

import org.ametys.plugins.repository.AmetysRepositoryException;
import org.ametys.plugins.repository.RepositoryConstants;
import org.ametys.plugins.repository.query.expression.Expression;

/**
 * Constructs an {@link Expression} corresponding to a language comparison.
 */
public class LanguageExpression implements Expression
{
    private Operator _operator;
    private String[] _values;

    /**
     * Creates the expression.
     * @param operator the operator to make the comparison (only Operator.EQ and Operator.NE allowed)
     * @param value the tag value 
     */
    public LanguageExpression(Operator operator, String value)
    {
        if (Operator.EQ != operator && Operator.NE != operator)
        {
            throw new AmetysRepositoryException("Test operator '" + "' is unknown for test's expression.");
        }

        _operator = operator;
        _values = new String[]{value};
    }
    
    /**
     * Creates the expression.
     * @param operator the operator to make the comparison (only Operator.EQ and Operator.NE allowed)
     * @param values the tags value in a array
     */
    public LanguageExpression(Operator operator, String[] values)
    {
        if (Operator.EQ != operator && Operator.NE != operator)
        {
            throw new AmetysRepositoryException("Test operator '" + "' is unknown for test's expression.");
        }

        _operator = operator;
        _values = values;
    }
    

    @Override
    public String build()
    {
        StringBuilder sb = new StringBuilder();
        
        sb.append('(');
        for (int i = 0; i < _values.length; i++)
        {
            if (i != 0)
            {
                sb.append(" or ");
            }
            sb.append("@" + RepositoryConstants.NAMESPACE_PREFIX_INTERNAL + ':' + DefaultContent.METADATA_LANGUAGE + " " + _operator + "'" + _values[i].replaceAll("'", "''") + "'");
        }
        sb.append(')');
        
        return sb.toString();
    }

}
