/*
 *  Copyright 2012 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.repository;

import javax.jcr.Node;

import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;

import org.ametys.cms.content.ContentExtractor;
import org.ametys.plugins.repository.AmetysObjectFactory;
import org.ametys.plugins.repository.AmetysRepositoryException;
import org.ametys.plugins.repository.jcr.LockComponent;

/**
 * {@link AmetysObjectFactory} handling {@link Content}.
 */
public class ModifiableContentFactory extends ContentFactory
{
    private LockComponent _lockComponent;
    private ServiceManager _serviceManager;
    private ContentExtractor _contentExtractor;
    
    @Override
    public void service(ServiceManager manager) throws ServiceException
    {
        super.service(manager);
        _serviceManager = manager;
    }
    
    @Override
    public ModifiableDefaultContent getAmetysObject(Node node, String parentPath) throws AmetysRepositoryException
    {
        return new ModifiableDefaultContent<>(node, parentPath, this);
    }
    
    LockComponent getLockComponent()
    {
        // lazy initialization to prevent chicken/egg scenario on startup
        if (_lockComponent == null)
        {
            try
            {
                _lockComponent = (LockComponent) _serviceManager.lookup(LockComponent.ROLE);
            }
            catch (ServiceException e)
            {
                throw new AmetysRepositoryException("Caught an exception while retrieving LockComponent", e);
            }
        }
        
        return _lockComponent;
    }
    
    ContentExtractor getContentExtractor()
    {
        if (_contentExtractor == null)
        {
            try
            {
                _contentExtractor = (ContentExtractor) _manager.lookup(ContentExtractor.CMS_CONTENT_EXTACTOR_ROLE);
            }
            catch (ServiceException e)
            {
                throw new IllegalStateException("Unable to get ContentExtractor", e);
            }
        }
        
        return _contentExtractor;
    }
}
