/*
 *  Copyright 2018 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.repository;

import java.util.List;

import org.ametys.core.user.UserIdentity;

/**
 * Interface to handle reactions on object
 *
 */
public interface ReactionableObject
{
    
    /** Reaction type. */
    public enum ReactionType
    {
        /** Like */
        LIKE
    }
    
    /**
     * Add the user reaction
     * @param user the user
     * @param reactionType the reaction type
     */
    public void addReaction(UserIdentity user, ReactionType reactionType);
    
    /**
     * Remove the user reaction
     * @param user the user
     * @param reactionType the reaction type
     */
    public void removeReaction(UserIdentity user, ReactionType reactionType);
    
    /**
     * Get the list of users who react
     * @param reactionType the reaction type
     * @return the list of users
     */
    public List<UserIdentity> getReactionUsers(ReactionType reactionType);
    
    
}
