/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.repository;

import java.time.ZonedDateTime;

import org.ametys.plugins.repository.AmetysRepositoryException;
import org.ametys.plugins.workflow.repository.WorkflowAwareAmetysObject;

/**
 * {@link Content} abstraction defined by the following additional property:
 * <dl>
 *   <dt>workflowId
 *   <dd>the id of the workflow instance associated with the content
 * </dl>
 */
public interface WorkflowAwareContent extends Content, WorkflowAwareAmetysObject
{
    /**
     * Retrieves the date at which the content was proposed for validation,
     * i.e. put in a workflow step in which it's awaiting validation.
     * @return the date at which the content was proposed for validation.
     * @throws AmetysRepositoryException if an error occurs.
     */
    ZonedDateTime getProposalDate() throws AmetysRepositoryException;
    
    /**
     * Set the date at which the content was proposed for validation, i.e.
     * put in a workflow step in which it's awaiting validation.
     * @param proposalDate the date at which the content was proposed for validation, or null to remove it.
     * @throws AmetysRepositoryException if an error occurs.
     */
    void setProposalDate(ZonedDateTime proposalDate) throws AmetysRepositoryException;
    
}

