/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

package org.ametys.cms.repository.comment;

import org.ametys.cms.repository.ModifiableContentHelper;
import org.ametys.plugins.repository.query.expression.Expression;

/**
 * Expression to search for comments
 */
public class CommentExpression implements Expression
{
    private boolean _includeValidated;
    private boolean _includeNonValidated;

    /**
     * Constructor. Parameters can not be both false.
     * @param includeValidated will request contents with validated comments 
     * @param includeNonValidated will request contents with non validated comments 
     */
    public CommentExpression(boolean includeValidated, boolean includeNonValidated)
    {
        this._includeValidated = includeValidated;
        this._includeNonValidated = includeNonValidated;
        
        if (!includeValidated && !includeNonValidated)
        {
            throw new IllegalArgumentException("Can not create a comment expression to search for no comments");
        }
    }

    public String build()
    {
        if (_includeValidated && _includeNonValidated)
        {
            return "ametys-internal:unversioned/ametys:" + ModifiableContentHelper.METADATA_COMMENTS + "/*/@jcr:primaryType = 'ametys:compositeMetadata'";
        }
        else if (_includeValidated)
        {
            return "ametys-internal:unversioned/ametys:" + ModifiableContentHelper.METADATA_COMMENTS + "/*/@ametys:validated = true()";
        }
        else if (_includeNonValidated)
        {
            return "ametys-internal:unversioned/ametys:" + ModifiableContentHelper.METADATA_COMMENTS + "/*/@ametys:validated = false()";
        }
        else
        {
            return "not(ametys-internal:unversioned/ametys:" + ModifiableContentHelper.METADATA_COMMENTS + "/*/@jcr:primaryType = 'ametys:compositeMetadata')";
        }
    }
}
