/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

package org.ametys.cms.repository.comment.actions;

import java.util.Collections;
import java.util.HashMap;
import java.util.Map;

import org.apache.avalon.framework.parameters.Parameters;
import org.apache.cocoon.environment.ObjectModelHelper;
import org.apache.cocoon.environment.Redirector;
import org.apache.cocoon.environment.Request;
import org.apache.cocoon.environment.SourceResolver;
import org.apache.commons.lang.StringUtils;

import org.ametys.cms.repository.comment.CommentsDAO;
import org.ametys.core.cocoon.ActionResultGenerator;

/**
 * Sends the comment for a given post
 */
public class AddCommentAction extends AbstractCommentAction
{
    /** The request parameter name for author name */
    public static final String PARAMETER_AUTHOR_NAME = "name";
    /** The request parameter name for author email */
    public static final String PARAMETER_AUTHOR_EMAIL = "email";
    /** The request parameter name for author email to hide */
    public static final String PARAMETER_AUTHOR_HIDEEMAIL = "hide-email";
    /** The request parameter name for author url */
    public static final String PARAMETER_AUTHOR_URL = "url";
    /** The request parameter name for content */
    public static final String PARAMETER_CONTENTTEXT = "text";
    /** The request parameter name for captcha */
    public static final String PARAMETER_CAPTCHA_KEY = "captcha-key";
    /** The request parameter name for captcha */
    public static final String PARAMETER_CAPTCHA_VALUE = "captcha-value";

    @Override
    public Map act(Redirector redirector, SourceResolver resolver, Map objectModel, String source, Parameters parameters) throws Exception
    {
        Request request = ObjectModelHelper.getRequest(objectModel);

        String contentId = request.getParameter(PARAMETER_CONTENTID);
        if (StringUtils.isBlank(contentId))
        {
            throw new IllegalArgumentException("Missing or empty 'content-id' parameter to add a comment");
        }
        
        String commentId  = request.getParameter(PARAMETER_COMMENTID);
        
        Map<String, Object> formValues = new HashMap<>();
        formValues.put(CommentsDAO.FORM_AUTHOR_NAME, request.getParameter(PARAMETER_AUTHOR_NAME));
        formValues.put(CommentsDAO.FORM_AUTHOR_EMAIL, request.getParameter(PARAMETER_AUTHOR_EMAIL));
        formValues.put(CommentsDAO.FORM_AUTHOR_URL, request.getParameter(PARAMETER_AUTHOR_URL));
        formValues.put(CommentsDAO.FORM_AUTHOR_HIDEEMAIL, request.getParameter(PARAMETER_AUTHOR_HIDEEMAIL) != null);
        formValues.put(CommentsDAO.FORM_CONTENTTEXT, request.getParameter(PARAMETER_CONTENTTEXT));
        formValues.put(CommentsDAO.FORM_CAPTCHA_KEY, request.getParameter(PARAMETER_CAPTCHA_KEY));
        formValues.put(CommentsDAO.FORM_CAPTCHA_VALUE, request.getParameter(PARAMETER_CAPTCHA_VALUE));
        
        Map<String, Object> results = _commentsDAO.addComment(contentId, commentId, formValues, Collections.EMPTY_MAP);
        
        if (!results.containsKey("errors"))
        {
            boolean published = (boolean) results.get("published");
            results.put("redirect", request.getHeader("Referer") + (published ? "?last-comment=highlight#" +  (String) results.get("commentId") + "-" + contentId : ""));
        }

        request.setAttribute(ActionResultGenerator.MAP_REQUEST_ATTR, results);
        return EMPTY_MAP;
    }
}
