/*
 *  Copyright 2018 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

package org.ametys.cms.repository.comment.actions;

import java.util.Map;

import org.apache.avalon.framework.parameters.Parameters;
import org.apache.cocoon.environment.ObjectModelHelper;
import org.apache.cocoon.environment.Redirector;
import org.apache.cocoon.environment.Request;
import org.apache.cocoon.environment.SourceResolver;
import org.apache.commons.lang.StringUtils;

import org.ametys.core.cocoon.ActionResultGenerator;

/**
 * Report a comment
 */
public class ReportCommentAction extends AbstractCommentAction
{
    @Override
    public Map act(Redirector redirector, SourceResolver resolver, Map objectModel, String source, Parameters parameters) throws Exception
    {
        Request request = ObjectModelHelper.getRequest(objectModel);

        String contentId = request.getParameter(PARAMETER_CONTENTID);
        if (StringUtils.isBlank(contentId))
        {
            throw new IllegalArgumentException("Missing or empty 'content-id' parameter to like a comment");
        }
        
        String commentId = request.getParameter(PARAMETER_COMMENTID);
        if (StringUtils.isBlank(commentId))
        {
            throw new IllegalArgumentException("Missing or empty 'comment-id' parameter to like a comment");
        }
        
        Map<String, Object> results = _commentsDAO.reportComment(contentId, commentId);
        results.put("redirect", request.getHeader("Referer") + "?last-comment=highlight#" + commentId);

        request.setAttribute(ActionResultGenerator.MAP_REQUEST_ATTR, results);
        return EMPTY_MAP;
    }
}
