/*
 *  Copyright 2024 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.repository.comment.contributor;

import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.commons.lang.StringUtils;

import org.ametys.cms.ObservationConstants;
import org.ametys.cms.content.ContentHelper;
import org.ametys.cms.repository.Content;
import org.ametys.core.observation.Event;
import org.ametys.runtime.config.Config;
import org.ametys.runtime.i18n.I18nizableText;

/**
 * Observer to send mails to mentioned users in contributor comments of {@link Content}
 */
public class NotifyContentMentionsObserver extends AbstractNotifyMentionsObserver<Content>
{
    /** The content helper */
    protected ContentHelper _contentHelper;
    
    @Override
    public void service(ServiceManager manager) throws ServiceException
    {
        super.service(manager);
        _contentHelper = (ContentHelper) manager.lookup(ContentHelper.ROLE);
    }

    public boolean supports(Event event)
    {
        return event.getId().equals(ObservationConstants.EVENT_CONTENT_CONTRIBUTOR_COMMENT_ADDED);
    }
    
    @Override
    protected String _getAmetysObjectTitle(Content content)
    {
        return _contentHelper.getTitle(content);
    }
    
    @Override
    protected LinkToAmetysObject _getLinkToAmetysObject(Content content)
    {
        String contentUrl = _getContentUrl(content);
        return new LinkToAmetysObject(contentUrl, new I18nizableText("plugin.cms", "PLUGINS_CMS_CONTENT_THREAD_MENTION_MAIL_LINK_TITLE"));
    }
    
    /**
     * Get the URL to the given content tool.
     * @param content the content.
     * @return the content URL.
     */
    protected String _getContentUrl(Content content)
    {
        return _getRequestUri() + "/index.html?uitool=uitool-content,id:%27" + content.getId() + "%27";
    }
    
    /**
     * Get the request URI.
     * @return the full request URI.
     */
    protected String _getRequestUri()
    {
        return StringUtils.stripEnd(StringUtils.removeEndIgnoreCase(Config.getInstance().getValue("cms.url"), "index.html"), "/");
    }
    
    @Override
    protected String _getLanguage(Content content)
    {
        return content.getLanguage();
    }
}
