/*
 *  Copyright 2017 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.rights;

import java.util.Collection;
import java.util.Map;

import org.apache.avalon.framework.parameters.Parameters;
import org.apache.cocoon.acting.ServiceableAction;
import org.apache.cocoon.environment.ObjectModelHelper;
import org.apache.cocoon.environment.Redirector;
import org.apache.cocoon.environment.Request;
import org.apache.cocoon.environment.SourceResolver;
import org.apache.commons.collections.CollectionUtils;

import org.ametys.core.util.StringUtils;
import org.ametys.runtime.authentication.AccessDeniedException;

/**
 * Action called to check client ip is allowed.
 */
public class CheckIpAction extends ServiceableAction
{
    @Override
    public Map act(Redirector redirector, SourceResolver resolver, Map objectModel, String source, Parameters parameters) throws Exception
    {
        Request request = ObjectModelHelper.getRequest(objectModel);
        
        // Verify the IP address
        String allowedIpsAsString = parameters.getParameter("allowedIps", "");
        Collection<String> allowedIps = StringUtils.stringToCollection(allowedIpsAsString);
        
        // The real client IP may have been put in the non-standard "X-Forwarded-For" request header, in case of reverse proxy
        String xff = request.getHeader("X-Forwarded-For");
        Collection<String> remoteIps = StringUtils.stringToCollection(xff);
        remoteIps.add(request.getRemoteAddr());
        
        if (!allowedIps.isEmpty() && !CollectionUtils.containsAny(allowedIps, remoteIps))
        {
            throw new AccessDeniedException("IP '" + org.apache.commons.lang3.StringUtils.join(remoteIps, ", ") + "' is not an authorized IP (" + allowedIpsAsString + ")");
        }
        
        return EMPTY_MAP;
    }
}
