/*
 *  Copyright 2016 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.rights;

import java.util.HashSet;
import java.util.Map;
import java.util.Set;

import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.commons.lang3.StringUtils;

import org.ametys.cms.contenttype.ContentType;
import org.ametys.cms.contenttype.ContentTypeExtensionPoint;
import org.ametys.core.right.RightAssignmentContext;
import org.ametys.plugins.core.impl.right.StringRightAssignmentContext;
import org.ametys.runtime.i18n.I18nizableText;

/**
 * {@link RightAssignmentContext} for assign rights to a {@link ContentType}
 */
public class ContentTypeRightAssignmentContext extends StringRightAssignmentContext
{
    /** The content type extension point */
    protected ContentTypeExtensionPoint _contentTypeExtensionPoint;

    @Override
    public void service(ServiceManager smanager) throws ServiceException
    {
        super.service(smanager);
        _contentTypeExtensionPoint = (ContentTypeExtensionPoint) smanager.lookup(ContentTypeExtensionPoint.ROLE);
    }
    
    @Override
    public Set<Object> getParentContexts(Object context)
    {
        if (Content2ContentTypeRightContextConvertor.CONTENT_TYPE_RIGHT_CONTEXT_PREFIX.equals(context))
        {
            return null;
        }
        else
        {
            Set<Object> parents = new HashSet<>();
            
            String ctypeId = StringUtils.substringAfter((String) context, Content2ContentTypeRightContextConvertor.CONTENT_TYPE_RIGHT_CONTEXT_PREFIX + "/");
            ContentType contentType = _contentTypeExtensionPoint.getExtension(ctypeId);
            
            String[] supertypeIds = contentType.getSupertypeIds();
            for (int i = 0; i < supertypeIds.length; i++)
            {
                parents.add(Content2ContentTypeRightContextConvertor.CONTENT_TYPE_RIGHT_CONTEXT_PREFIX + "/" + supertypeIds[i]);
            }
            
            if (parents.size() == 0)
            {
                parents.add(Content2ContentTypeRightContextConvertor.CONTENT_TYPE_RIGHT_CONTEXT_PREFIX);
            }
            
            return parents;
        }
    }
    
    @Override
    public boolean isSupportedContext(Object context, Map<String, Object> contextualParameters)
    {
        if (context instanceof String str)
        {
            if (Content2ContentTypeRightContextConvertor.CONTENT_TYPE_RIGHT_CONTEXT_PREFIX.equals(str))
            {
                return true;
            }
            else
            {
                String ctypeId = StringUtils.substringAfter((String) context, Content2ContentTypeRightContextConvertor.CONTENT_TYPE_RIGHT_CONTEXT_PREFIX + "/");
                ContentType contentType = _contentTypeExtensionPoint.getExtension(ctypeId);
                return contentType != null && !contentType.isReferenceTable();
            }
        }
        return false;
    }
    
    @Override
    public ContextInfo getContextInfo(Object context)
    {
        I18nizableText contextLabel = null;
        boolean isRoot = false;
        if (Content2ContentTypeRightContextConvertor.CONTENT_TYPE_RIGHT_CONTEXT_PREFIX.equals(context))
        {
            contextLabel = new I18nizableText("plugin.cms", "PLUGINS_CMS_RIGHT_ASSIGNMENT_CONTEXT_CONTENTTYPE_ROOT_CONTEXT_LABEL");
            isRoot = true;
        }
        else
        {
            String ctypeId = StringUtils.substringAfter((String) context, Content2ContentTypeRightContextConvertor.CONTENT_TYPE_RIGHT_CONTEXT_PREFIX + "/");
            ContentType contentType = _contentTypeExtensionPoint.getExtension(ctypeId);
            if (contentType != null)
            {
                contextLabel = contentType.getLabel();
            }
        }
        if (contextLabel == null)
        {
            throw new IllegalStateException("This context is not supported by this right assignment context");
        }
        return new ContextInfo(getId(), _label, (String) context, contextLabel, isRoot);
    }
}
