/*
 *  Copyright 2017 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.rights;

import java.util.Collections;
import java.util.Set;

import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;

import org.ametys.cms.content.ContentHelper;
import org.ametys.cms.repository.Content;
import org.ametys.plugins.core.impl.right.AbstractHierarchicalAccessController;
import org.ametys.runtime.i18n.I18nizableText;

/**
 * Content access controller for reference table
 */
public class ReferenceTableAccessController extends AbstractHierarchicalAccessController<Object>
{
    /** The context for simple contents */
    public static final String CONTEXT = "/reference-tables";
    /** The helper for contents */
    protected ContentHelper _contentHelper;

    @Override
    public void service(ServiceManager manager) throws ServiceException
    {
        super.service(manager);
        _contentHelper = (ContentHelper) manager.lookup(ContentHelper.ROLE);
    }
    
    public I18nizableText getLabel()
    {
        return new I18nizableText("plugin.cms", "PLUGINS_CMS_REFERENCE_TABLE_ACCESS_CONTROLLER_LABEL");
    }
    
    @Override
    public boolean isSupported(Object object)
    {
        return object instanceof Content && _contentHelper.isReferenceTable((Content) object)
                || CONTEXT.equals(object);
    }
    
    @Override
    protected Set<Object> _getParents(Object object)
    {
        if (object instanceof Content)
        {
            return Collections.singleton(CONTEXT);
        }
        else
        {
            return null;
        }
    }
    
    @Override
    protected Set< ? extends Object> _convertWorkspaceToRootRightContexts(Set<Object> workspacesContexts)
    {
        if (workspacesContexts.contains("/cms"))
        {
            // no need to list the root of simple contents as it is the same as the ContentAccessController
            return Collections.singleton(CONTEXT);
        }
        return null;
    }
}
