/*
 *  Copyright 2017 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.rights.solrchecking;

import org.apache.cocoon.environment.Request;

import org.ametys.core.right.RightManager;
import org.ametys.plugins.repository.AmetysObject;
import org.ametys.runtime.plugin.component.AbstractThreadSafeComponentExtensionPoint;

/**
 * Extension point used by {@link AllowedUsersByObjectAction} before ({@link #beforeGettingAllowedUsers(AmetysObject, Request)}) 
 * and after ({@link #afterGettingAllowedUsers(AmetysObject, Request)}) calling {@link RightManager#getReadAccessAllowedUsers(Object)}
 * for doing additional operations (for instance, setting some request attributes needed by the {@link RightManager}).
 */
public class AllowedUsersActionAdditionalOperationsExtensionPoint extends AbstractThreadSafeComponentExtensionPoint<AllowedUsersActionAdditionalOperations>
{
    /** Avalon Role */
    public static final String ROLE = AllowedUsersActionAdditionalOperationsExtensionPoint.class.getName();
    
    /**
     * Do additional operations before {@link AllowedUsersByObjectAction} calls {@link RightManager#getReadAccessAllowedUsers(Object)}
     * @param ametysObject The AmetysObject which will be passed to {@link RightManager#getReadAccessAllowedUsers(Object)}
     * @param request The current request
     */
    void beforeGettingAllowedUsers(AmetysObject ametysObject, Request request)
    {
        getExtensionsIds().stream().map(this::getExtension).forEach(ext -> 
        {
            try
            {
                ext.beforeGettingAllowedUsers(ametysObject, request);
            }
            catch (Exception e)
            {
                getLogger().error("An exception occured in 'beforeGettingAllowedUsers' with " + ext, e);
            }
        });
    }
    
    /**
     * Do additional operations after {@link AllowedUsersByObjectAction} calls {@link RightManager#getReadAccessAllowedUsers(Object)}
     * @param ametysObject The AmetysObject which will be passed to {@link RightManager#getReadAccessAllowedUsers(Object)}
     * @param request The current request
     */
    void afterGettingAllowedUsers(AmetysObject ametysObject, Request request)
    {
        getExtensionsIds().stream().map(this::getExtension).forEach(ext -> 
        {
            try
            {
                ext.afterGettingAllowedUsers(ametysObject, request);
            }
            catch (Exception e)
            {
                getLogger().error("An exception occured in 'afterGettingAllowedUsers' with " + ext, e);
            }
        });
    }
}
