/*
 *  Copyright 2018 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.rights.solrchecking;

import org.apache.avalon.framework.component.Component;
import org.apache.avalon.framework.context.Context;
import org.apache.avalon.framework.context.ContextException;
import org.apache.avalon.framework.context.Contextualizable;
import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.avalon.framework.service.Serviceable;
import org.apache.cocoon.components.ContextHelper;
import org.apache.cocoon.environment.Request;

import org.ametys.core.right.AllowedUsers;
import org.ametys.core.right.RightManager;
import org.ametys.plugins.repository.AmetysObject;

/**
 * Helper for Read ACL
 */
public class ReadAccessHelper implements Component, Serviceable, Contextualizable
{
    /** Avalon role. */
    public static final String ROLE = ReadAccessHelper.class.getName();
    
    /** The right manager */
    protected RightManager _rightManager;
    /** The Extension Point for doing additonal operations before and after calling {@link RightManager#getReadAccessAllowedUsers(Object)} */
    protected AllowedUsersActionAdditionalOperationsExtensionPoint _allowedUsersActionAdditionalOperationsEP;
    
    private Context _context;
    
    @Override
    public void service(ServiceManager manager) throws ServiceException
    {
        _rightManager = (RightManager) manager.lookup(RightManager.ROLE);
        _allowedUsersActionAdditionalOperationsEP = (AllowedUsersActionAdditionalOperationsExtensionPoint) manager.lookup(AllowedUsersActionAdditionalOperationsExtensionPoint.ROLE);
    }
    
    @Override
    public void contextualize(Context context) throws ContextException
    {
        _context = context;
    }
    
    /**
     * Gets the allowed users for read-access to the given object
     * @param ametysObject The object to test
     * @return the allowed users for read-access to the given object
     */
    public AllowedUsers allowedUsers(AmetysObject ametysObject)
    {
        Request request = ContextHelper.getRequest(_context);
        
        _allowedUsersActionAdditionalOperationsEP.beforeGettingAllowedUsers(ametysObject, request);
        AllowedUsers allowedUsersObj = _rightManager.getReadAccessAllowedUsers(ametysObject);
        _allowedUsersActionAdditionalOperationsEP.afterGettingAllowedUsers(ametysObject, request);
        
        return allowedUsersObj;
    }
}
