/*
 *  Copyright 2018 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.scripts;

import java.util.Collection;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Optional;
import java.util.stream.Collectors;

import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;

import org.ametys.cms.repository.Content;
import org.ametys.plugins.core.ui.script.ScriptExecArguments;
import org.ametys.plugins.core.ui.script.StaticConfigurableScriptBinding;
import org.ametys.plugins.repository.AmetysObjectResolver;

/**
 * CMS script binding, provides variables to the script tool, and a configuration file for the functions. 
 */
public class CmsScriptBinding extends StaticConfigurableScriptBinding
{
    private AmetysObjectResolver _resolver;
    
    @Override
    public void service(ServiceManager manager) throws ServiceException
    {
        super.service(manager);
        _resolver = (AmetysObjectResolver) manager.lookup(AmetysObjectResolver.ROLE);
    }
    
    @Override
    public Map<String, Object> getVariables(ScriptExecArguments execArgs)
    {
        Map<String, Object> variables = new HashMap<>();

        Collection<String> selection = Optional.of(execArgs)
                .filter(CmsScriptExecArguments.class::isInstance)
                .map(CmsScriptExecArguments.class::cast)
                .flatMap(CmsScriptExecArguments::selection)
                .orElse(null);

        List<Content> contents = null;
        if (selection != null)
        {
            contents = selection.stream()
                      .map(id -> _resolver.resolveById(id))
                      .filter(Content.class::isInstance)
                      .map(Content.class::cast)
                      .collect(Collectors.toList());
        }
        variables.put("__internal_content_selection", contents);
        
        return variables;
    }
}
