/*
 *  Copyright 2019 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.scripts;

import java.util.Collection;
import java.util.Map;
import java.util.Optional;

import org.ametys.plugins.core.ui.script.ScriptExecArguments;

/**
 * Enriches {@link ScriptExecArguments} with some arguments needed by {@link CmsScriptHandler}
 */
public interface CmsScriptExecArguments extends ScriptExecArguments
{
    /**
     * The id of search model for searching contents in CMS ScriptTool
     * @return The id of search model for searching contents in CMS ScriptTool
     */
    Optional<String> searchModelId();
    
    /**
     * The current selection of contents
     * @return The current selection of contents
     */
    Optional<Collection<String>> selection();
    
    /**
     * The default implementation for {@link CmsScriptExecArguments}
     * <br>Must be constructed from a {@link Map} containing at least the key "script", and optionally the keys "model" and "selection"
     */
    static class Impl implements CmsScriptExecArguments
    {
        private Map<String, Object> _arguments;
        Impl(Map<String, Object> arguments)
        {
            _arguments = arguments;
        }
        
        @Override
        public String script()
        {
            return (String) _arguments.get("script");
        }

        @Override
        public Optional<String> searchModelId()
        {
            return Optional.of(_arguments)
                    .map(args -> args.get("model"))
                    .filter(String.class::isInstance)
                    .map(String.class::cast);
        }

        @Override
        public Optional<Collection<String>> selection()
        {
            return Optional.of(_arguments)
                    .map(args -> args.get("selection"))
                    .filter(Collection.class::isInstance)
                    .map(Collection.class::cast);
        }
    }
}
