/*
 *  Copyright 2019 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.scripts;

import java.nio.file.Path;
import java.time.Instant;
import java.time.temporal.ChronoUnit;

import org.apache.avalon.framework.activity.Initializable;
import org.quartz.JobExecutionContext;

import org.ametys.cms.schedule.AbstractDeleteFilesSchedulable;
import org.ametys.core.schedule.Schedulable;
import org.ametys.runtime.config.Config;

/**
 * A {@link Schedulable} job for deleting report files older than 30 minutes
 */
public class DeleteReportsSchedulable extends AbstractDeleteFilesSchedulable implements Initializable
{
    private long _longevity;
    private Path _rootPath;
    
    @Override
    public void initialize() throws Exception
    {
        _rootPath = ReportLocationAction.getScriptReportDirectory();
        _longevity = Config.getInstance().getValue("org.ametys.plugin.cms.delete.reports.longevity");
    }
    
    @Override
    protected DeleteFilesConfiguration _getConfiguration(JobExecutionContext context)
    {
        DeleteFilesConfiguration configuration = new DeleteFilesConfiguration(_rootPath);
        configuration.setAgeLimit(Instant.now().minus(_longevity, ChronoUnit.MINUTES));
        return configuration;
    }
}
