/*
 *  Copyright 2016 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.scripts;

import java.io.File;
import java.nio.file.Files;
import java.nio.file.Path;
import java.util.HashMap;
import java.util.Map;

import org.apache.avalon.framework.parameters.Parameters;
import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.cocoon.acting.ServiceableAction;
import org.apache.cocoon.environment.Redirector;
import org.apache.cocoon.environment.SourceResolver;

import org.ametys.core.user.CurrentUserProvider;
import org.ametys.core.user.UserIdentity;
import org.ametys.runtime.util.AmetysHomeHelper;

/**
 * Get a solr query string from a search tool.
 */
public class ReportLocationAction extends ServiceableAction
{
    /** The current user provider impl */
    protected CurrentUserProvider _currentUserProvider;
    
    @Override
    public void service(ServiceManager smanager) throws ServiceException
    {
        super.service(smanager);
        _currentUserProvider = (CurrentUserProvider) smanager.lookup(CurrentUserProvider.ROLE);
    }

    /**
     * Get the script report directory
     * @return The exiting report directory
     */
    public static final Path getScriptReportDirectory()
    {
        File ametysHomeTemp = AmetysHomeHelper.getAmetysHomeTmp();
        File scriptReportDirectory = new File(ametysHomeTemp, "exports");
        scriptReportDirectory.mkdirs();
        
        if (!scriptReportDirectory.isDirectory())
        {
            throw new RuntimeException("Cannot create the directory " + scriptReportDirectory.getAbsolutePath());
        }
        
        return scriptReportDirectory.toPath();
    }
    
    @Override
    public Map act(Redirector redirector, SourceResolver resolver, Map objectModel, String source, Parameters parameters) throws Exception
    {
        String populationId = parameters.getParameter("populationId");
        String login = parameters.getParameter("login");
        
        UserIdentity currentUser = _currentUserProvider.getUser();
        if (!currentUser.getPopulationId().equals(populationId) || !currentUser.getLogin().equals(login))
        {
            throw new IllegalAccessException(currentUser.toString() +  " tryed to download report of " + login + "#" + populationId);
        }
        
        Path populationIdPath = getScriptReportDirectory().resolve(populationId);
        //check if there is a folder for the requested population id
        if (Files.isDirectory(populationIdPath))
        {
            Path loginPath = populationIdPath.resolve(login);
            //check if there is a folder for the requested population id
            if (Files.isDirectory(loginPath))
            {
                HashMap<String, Object> result = new HashMap<>();
                result.put("location", loginPath.toUri().toString());
                return result;
            }
        }
        
        return EMPTY_MAP;
    }

}

