/*
 *  Copyright 2016 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.search;

import java.util.List;

import org.apache.commons.lang3.StringUtils;

/**
 * Represents a search field.
 */
public interface SearchField
{
    
    /**
     * Get the search field name.
     * @return The search field name.
     */
    String getName();
    
    /**
     * Get the sort field corresponding to this field.
     * @return The sort field.
     */
    String getSortField();
    
    /**
     * Get the facet field corresponding to this field.
     * @return The facet field.
     */
    String getFacetField();
    
    /**
     * Indicates if the search field is joined
     * @return <code>true</code> if the search field is joined
     */
    boolean isJoined();
    
    /**
     * Gets the joined paths
     * @return the joined paths
     */
    List<String> getJoinedPaths();
    
    /**
     * Get the facet function corresponding to this field.
     * @return The facet function.
     */
    default String getFacetFunction()
    {
        String facetField = getFacetField();
        if (facetField == null)
        {
            return null; // not facetable
        }
        
        List<String> joinedPaths = getJoinedPaths();
        if (isJoined())
        {
            return StringUtils.join(joinedPaths, "->") + "," + facetField;
        }
        else
        {
            return null;
        }
    }
    
}
