/*
 *  Copyright 2016 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.search;

import java.util.Map;
import java.util.Optional;

import org.ametys.plugins.repository.AmetysObject;
import org.ametys.plugins.repository.AmetysObjectIterable;

/**
 * Interface representing the results of a search.
 * @param <A> the actual type of {@link AmetysObject}s. 
 */
public interface SearchResults<A extends AmetysObject>
{
    /**
     * Get the {@link Iterable} of the search results.
     * @return A {@link SearchResultsIterable} on the {@link SearchResult}.
     */
    SearchResultsIterable<SearchResult<A>> getResults();
    
    /**
     * Get the {@link AmetysObject} results
     * @return An {@link AmetysObjectIterable} on the results.
     */
    AmetysObjectIterable<A> getObjects();
    
    /**
     * Get the result IDs.
     * @return An {@link Iterable} on the content IDs.
     */
    Iterable<String> getObjectIds();
    
    /**
     * Get the facet results as a Map, indexed by faceted criterion ID.<br>
     * The Map values are represented by a Map of value -&gt; result count.
     * @return the facet results.
     */
    Map<String, Map<String, Integer>> getFacetResults();
    
    /**
     * Get the total number of search results.
     * @return the total number of results matching the search (whatever the limit): the iterable
     * may contain less objects than this count.
     */
    long getTotalCount();
    
    /**
     * Get the maximum score of all the results.
     * @return the maximum score of all the results.
     */
    float getMaxScore();
    
    /**
     * Gets the response debug map if available
     * @return the response debug map if available
     */
    Optional<Map<String, Object>> getDebugMap();
}
