/*
 *  Copyright 2015 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.search;

/**
 * Class representing a sort criterion.
 */
public class Sort
{
    
    /**
     * Sort order.
     */
    public enum Order
    {
        /** Ascending sort order. */
        ASC,
        /** Descending sort order. */
        DESC
    }
    
    /** The sort field. */
    protected String _field;
    
    /** The sort order. */
    protected Order _order;
    
    private SearchField _searchField;
    
    /**
     * Build a new Sort criterion.
     * @param field The sort field as a String.
     * @param order The sort order.
     */
    public Sort(String field, Order order)
    {
        this._field = field;
        this._order = order;
    }
    
    /**
     * Build a new Sort criterion.
     * @param field The sort field as a {@link SearchField}.
     * @param order The sort order.
     */
    public Sort(SearchField field, Order order)
    {
        this._searchField = field;
        this._order = order;
    }
    
    /**
     * Get the sort field.
     * @return The sort field.
     */
    public String getField()
    {
        return _field != null ? _field : _searchField.getSortField();
    }
    
    /**
     * Set the sort field.
     * @param field The sort field.
     */
    public void setField(String field)
    {
        this._field = field;
    }
    
    /**
     * Get the sort order.
     * @return The sort order.
     */
    public Order getOrder()
    {
        return _order;
    }
    
    /**
     * Set the sort order.
     * @param order The sort order.
     */
    public void setOrder(Order order)
    {
        this._order = order;
    }
    
}
