/*
 *  Copyright 2013 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.search.cocoon;

import java.io.IOException;
import java.util.Locale;

import org.apache.avalon.framework.context.Context;
import org.apache.avalon.framework.context.ContextException;
import org.apache.avalon.framework.context.Contextualizable;
import org.apache.cocoon.ProcessingException;
import org.apache.cocoon.components.ContextHelper;
import org.apache.cocoon.environment.Request;
import org.apache.cocoon.generation.ServiceableGenerator;
import org.apache.cocoon.i18n.I18nUtils;
import org.apache.cocoon.xml.AttributesImpl;
import org.apache.cocoon.xml.XMLUtils;
import org.apache.commons.lang3.StringUtils;
import org.xml.sax.SAXException;

import org.ametys.cms.repository.Content;
import org.ametys.runtime.model.ModelViewItem;
import org.ametys.runtime.model.ViewHelper;
import org.ametys.runtime.model.ViewItem;
import org.ametys.runtime.model.ViewItemAccessor;
import org.ametys.runtime.model.ViewItemContainer;
import org.ametys.runtime.model.type.DataContext;

/**
 * Generate contents returned by the {@link SearchAction}.
 */
public class ContentDocGenerator extends ServiceableGenerator implements Contextualizable
{
    /** Context */
    protected Context _context;

    public void generate() throws IOException, SAXException, ProcessingException
    {
        Request request = ContextHelper.getRequest(_context);
        Content content = (Content) request.getAttribute(Content.class.getName());
        
        ViewItemContainer resultItems = (ViewItemContainer) request.getAttribute("resultItems");

        contentHandler.startDocument();
        
        XMLUtils.startElement(contentHandler, "content");
        
        XMLUtils.startElement(contentHandler, "fields");
        ViewItemContainer uiResultItems = (ViewItemContainer) request.getAttribute("uiResultItems");
        _saxColumns(uiResultItems);
        XMLUtils.endElement(contentHandler, "fields");
        
        Locale defaultLocale = getDefaultLocale(request);
        
        AttributesImpl attrs = new AttributesImpl();
        attrs.addCDATAAttribute("id", content.getId());
        attrs.addCDATAAttribute("name", content.getName());
        attrs.addCDATAAttribute("title", content.getTitle(defaultLocale));
        if (content.getLanguage() != null)
        {
            attrs.addCDATAAttribute("language", content.getLanguage());
        }
        XMLUtils.startElement(contentHandler, "content", attrs);
        
        DataContext context = DataContext.newInstance()
                                         .withLocale(defaultLocale)
                                         .withEmptyValues(false);
        content.dataToSAX(contentHandler, resultItems, context);
        
        XMLUtils.endElement(contentHandler, "content");
        
        XMLUtils.endElement(contentHandler, "content");
        contentHandler.endDocument();
    }

    public void contextualize(Context context) throws ContextException
    {
        _context = context;
    }
    
    /**
     * Get the default locale to use to sax localized values
     * @param request the request
     * @return the default locale
     */
    protected Locale getDefaultLocale(Request request)
    {
        String lang = parameters.getParameter("lang", request.getParameter("lang"));
        return StringUtils.isNotEmpty(lang) ? new Locale(lang) : I18nUtils.findLocale(objectModel, "locale", null, Locale.getDefault(), true);
    }
    
    private void _saxColumns(ViewItemAccessor viewItemAccessor) throws SAXException
    {
        for (ViewItem viewItem : viewItemAccessor.getViewItems())
        {
            if (viewItem instanceof ViewItemAccessor itemAccessor && !itemAccessor.getViewItems().isEmpty())
            {
                _saxColumns(itemAccessor);
            }
            else if (viewItem instanceof ModelViewItem modelViewItem)
            {
                AttributesImpl attrs = new AttributesImpl();
                attrs.addCDATAAttribute("id", ViewHelper.getModelViewItemPath(modelViewItem));
                attrs.addCDATAAttribute("type", modelViewItem.getDefinition().getType().getId());
                
                XMLUtils.startElement(contentHandler, "field", attrs);
                modelViewItem.getLabel().toSAX(contentHandler);
                XMLUtils.endElement(contentHandler, "field");
            }
        }
    }
}
