/*
 *  Copyright 2017 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.search.cocoon;

import java.util.ArrayList;
import java.util.List;

import org.ametys.cms.repository.Content;

/**
 * Object created to group content, according to a metadata
 */
public class GroupSearchContent
{
    private List<GroupSearchContent> _subList = new ArrayList<>();
    private List<Content> _contents = new ArrayList<>();
    private String _groupName;
    private String _fieldPath;
    
    /**
     * Create a new empty group, only used for root
     */
    public GroupSearchContent()
    {
        this._fieldPath = "";
        this._groupName = "";
    }
    /**
     * Create a group, named after a metadataPath/name
     * @param fieldPath path of the field used to create this group and siblings
     * @param groupName value of the field for this group
     */
    public GroupSearchContent(String fieldPath, String groupName)
    {
        this._fieldPath = fieldPath;
        this._groupName = groupName;
    }

    /**
     * Add a sub group in this group
     * @param subList sub-group
     */
    public void addToSubList(GroupSearchContent subList)
    {
        _subList.add(subList);
    }
    /**
     * Add contents in this group
     * @param contents contents to add
     */
    public void addContents(List<Content> contents)
    {
        _contents.addAll(contents);
    }
    /**
     * Add a content in this group
     * @param content content to add
     */
    public void addContent(Content content)
    {
        _contents.add(content);
    }
    /**
     * Get the sub groups in this group
     * @return list of groups
     */
    public List<GroupSearchContent> getSubList()
    {
        return _subList;
    }

    /**
     * Get the list of contents in this group
     * @return list of contents in this group
     */
    public List<Content> getContents()
    {
        return _contents;
    }

    /**
     * Get the value of the metadata (as a String) used to create this group
     * @return Metadata value as a string
     */
    public String getGroupName()
    {
        return _groupName;
    }

    /**
     * Get the metadataPath that was used to create this group
     * @return metadataPath
     */
    public String getGroupFieldPath()
    {
        return _fieldPath;
    }
}
