/*
 *  Copyright 2015 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.search.cocoon;

import java.util.List;
import java.util.Map;
import java.util.Optional;

import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.cocoon.environment.Request;

import org.ametys.cms.contenttype.ContentTypesHelper;
import org.ametys.cms.search.model.SearchModel;
import org.ametys.plugins.repository.AmetysObjectResolver;

/**
 * Specific search action for the SelectContent widget.
 */
public class SelectContentSearchAction extends SearchAction
{
    /** The Ametys object resolver. */
    protected AmetysObjectResolver _resolver;
    
    /** The content types helper */
    protected ContentTypesHelper _contentTypesHelper;
    
    @Override
    public void service(ServiceManager serviceManager) throws ServiceException
    {
        super.service(serviceManager);
        _resolver = (AmetysObjectResolver) serviceManager.lookup(AmetysObjectResolver.ROLE);
        _contentTypesHelper = (ContentTypesHelper) serviceManager.lookup(ContentTypesHelper.ROLE);
    }
    
    @Override
    protected void doSearch(Request request, SearchModel model, int offset, int maxResults, Map<String, Object> jsParameters, Map<String, Object> contextualParameters) throws Exception
    {
        if (jsParameters.get("id") != null)
        {
            // Don't do a standard search, use the provided ID list.
            @SuppressWarnings("unchecked")
            List<String> contentIds = (List<String>) jsParameters.get("id");
            request.setAttribute(SEARCH_CONTENTS, contentIds);
        }
        else
        {
            Optional<String> isArchivedContentSearch = model.getContentTypes(contextualParameters)
                .stream()
                .filter(id -> _contentTypesHelper.isArchivedContentType(id))
                .findAny();
            
            if (isArchivedContentSearch.isPresent())
            {
                @SuppressWarnings("unchecked")
                Map<String, Object> values = (Map<String, Object>) jsParameters.get("values");
                values.put("metadata-archived-eq", false);
            }
            
            super.doSearch(request, model, offset, maxResults, jsParameters, contextualParameters);
        }
    }
}
