/*
 *  Copyright 2015 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.search.model;

import org.ametys.cms.contenttype.MetadataType;
import org.ametys.runtime.parameter.Enumerator;

/**
 * This interface represents a Field in the search paradigm.
 */
public interface Field
{
    
    // TODO getFieldId() ?
    
    /**
     * Get the field type.
     * @return the field type.
     */
    MetadataType getType();
    
    /**
     * Get the multiple status of the field.
     * @return <code>true</code> if the field can have multiple values, <code>false</code> otherwise.
     */
    boolean isMultiple();
    
    /**
     * Get the field Enumerator.
     * @return the field Enumerator, or null.
     */
    Enumerator getEnumerator();
    
    /**
     * In case of a Content reference field, the content type ID.
     * @return the content type ID.
     */
    String getContentTypeId();

}
