/*
 *  Copyright 2022 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.search.query;

import java.util.Objects;

/**
 * Abstract class for queries wrapping another query.
 */
public abstract class AbstractWrapperQuery implements Query
{
    private Query _query;
    
    /**
     * Build a wrapper query.
     * @param query the wrapped query.
     */
    public AbstractWrapperQuery(Query query)
    {
        _query = query;
    }
    
    /**
     * Get the sub query.
     * @return the sub query.
     */
    public Query getSubQuery()
    {
        return _query;
    }

    @Override
    public int hashCode()
    {
        return Objects.hash(_query);
    }

    @Override
    public boolean equals(Object obj)
    {
        if (this == obj)
        {
            return true;
        }
        
        if (obj == null || getClass() != obj.getClass())
        {
            return false;
        }
        
        AbstractWrapperQuery other = (AbstractWrapperQuery) obj;
        return Objects.equals(_query, other._query);
    }
}
