/*
 *  Copyright 2014 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.search.query;

import org.apache.commons.lang3.BooleanUtils;

/**
 * Represents a {@link Query} testing a boolean field.
 */
public class BooleanQuery extends AbstractOperatorQuery<Boolean>
{
    /**
     * Build a BooleanQuery testing the existence of the field.
     * @param fieldPath the field's path
     */
    public BooleanQuery(String fieldPath)
    {
        this(fieldPath, Operator.EXISTS, null);
    }
    
    /**
     * Build a BooleanQuery.
     * @param fieldPath the field's path
     * @param value the value.
     */
    public BooleanQuery(String fieldPath, Boolean value)
    {
        this(fieldPath, Operator.EQ, value);
    }
    
    /**
     * Build a BooleanQuery.
     * @param fieldPath the field's path
     * @param op the operator.
     * @param value the value.
     */
    public BooleanQuery(String fieldPath, Operator op, Boolean value)
    {
        super(fieldPath + "_b", op, value);
    }
    
    @Override
    public String build() throws QuerySyntaxException
    {
        Operator operator = getOperator();
        Boolean isTrue = BooleanUtils.isTrue(getValue());
        
        StringBuilder query = new StringBuilder();
        
        // "field != true" or "field == false" => test "not true".
        boolean appendNegation = operator == Operator.NE && isTrue || operator == Operator.EQ && !isTrue; 
        if (appendNegation)
        {
            NotQuery.appendNegation(query);
        }
        
        query.append(getFieldName()).append(':')
             .append(operator == Operator.EXISTS ? QueryHelper.EXISTS_VALUE : "true");
        
        return query.toString();
    }
}
