/*
 *  Copyright 2019 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.search.query;

import java.util.Map;
import java.util.Optional;

import org.apache.commons.lang3.StringUtils;

/**
 * Wraps another {@link Query}, but giving to each matching document a nil score (score with a value of 0).
 * <br>Thus, it will act as in a fq (filter query), and the given query will be cached in the filter cache. 
 */
public class ConstantNilScoreQuery extends AbstractWrapperQuery
{
    /**
     * Build a ConstantNilScoreQuery object.
     * @param query The wrapped query
     */
    public ConstantNilScoreQuery(Query query)
    {
        super(query);
    }
    
    @Override
    public String build() throws QuerySyntaxException
    {
        String clause = getSubQuery().build();
        StringBuilder sb = new StringBuilder()
                .append("filter(")
                .append(clause)
                .append(")");
        return sb.toString();
    }
    
    public Optional<Object> buildAsJson() throws QuerySyntaxException
    {
        return getSubQuery().buildAsJson()
            .map(q -> Map.of("bool", Map.of("filter", q)));
    }
    
    @Override
    public String toString(int indent)
    {
        final String thisLineIndent = StringUtils.repeat(' ', indent);
        final int subIndent = indent + 2;
        final String subLineIndent = StringUtils.repeat(' ', subIndent);
        final String q = subLineIndent + "[Q]\n" + getSubQuery().toString(subIndent + 2) + "\n" + subLineIndent + "[/Q]";
        return thisLineIndent + "[CONSTANT_NIL_SCORE]\n" + q + "\n" + thisLineIndent + "[/CONSTANT_NIL_SCORE]";
    }
}
