/*
 *  Copyright 2017 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.search.query;

import java.util.Arrays;
import java.util.List;

import org.ametys.cms.content.indexing.solr.SolrFieldNames;

/**
 * Query testing the contentId of a resource (content attachment).
 */
public class ContentAttachmentQuery extends AbstractMultivaluedQuery<String>
{
    /**
     * Create an ContentAttachmentQuery which searches on resources attached to the given content.
     * @param contentIds the content ids
     */
    public ContentAttachmentQuery(String... contentIds)
    {
        this(Arrays.asList(contentIds));
    }
    
    /**
     * Create an ContentAttachmentQuery which searches on resources attached to the given content.
     * @param contentIds the content ids
     */
    public ContentAttachmentQuery(List<String> contentIds)
    {
        super(SolrFieldNames.ATTACHMENT_CONTENT_ID, Operator.EQ, LogicalOperator.OR, contentIds);
    }
}
