/*
 *  Copyright 2014 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.search.query;

import java.util.Arrays;

import org.ametys.cms.content.indexing.solr.SolrFieldNames;

/**
 * Represents a {@link Query} testing the content language.
 */
public class ContentLanguageQuery extends AbstractMultivaluedQuery<String>
{
    /**
     * Build a ContentLanguageQuery to test if the contentLanguage property exists.
     */
    public ContentLanguageQuery()
    {
        this(Operator.EXISTS);
    }
    
    /**
     * Build a ContentLanguageQuery.
     * @param value the language equality to test.
     */
    public ContentLanguageQuery(String value)
    {
        this(Operator.EQ, value);
    }
    
    /**
     * Build a ContentLanguageQuery.
     * @param values the languages to test.
     */
    public ContentLanguageQuery(String... values)
    {
        this(Operator.EQ, values);
    }
    
    /**
     * Build a ContentLanguageQuery.
     * @param operator the operator.
     * @param value the language code.
     */
    public ContentLanguageQuery(Operator operator, String value)
    {
        this(operator, LogicalOperator.OR, new String[] {value});
    }
    
    /**
     * Build a ContentLanguageQuery.
     * @param operator the operator.
     * @param values the language codes.
     */
    public ContentLanguageQuery(Operator operator, String... values)
    {
        this(operator, LogicalOperator.OR, values);
    }
    
    /**
     * Build a ContentLanguageQuery.
     * @param operator the operator.
     * @param logicalOperator the logical operator.
     * @param values the language codes.
     */
    public ContentLanguageQuery(Operator operator, LogicalOperator logicalOperator, String... values)
    {
        super(SolrFieldNames.CONTENT_LANGUAGE, operator, logicalOperator, Arrays.asList(values));
    }
}
