/*
 *  Copyright 2014 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.search.query;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collection;

import org.ametys.cms.content.indexing.solr.SolrFieldNames;

/**
 * Represents a {@link Query} testing the content types of contents.
 */
public class ContentTypeQuery extends AbstractMultivaluedQuery<String>
{
    /**
     * Build a ContentTypeQuery.
     * @param ids the content type ids.
     */
    public ContentTypeQuery(String... ids)
    {
        this(Operator.EQ, ids);
    }
    
    /**
     * Build a ContentTypeQuery.
     * @param ids the content type ids.
     */
    public ContentTypeQuery(Collection<String> ids)
    {
        this(Operator.EQ, ids);
    }
    
    /**
     * Build a ContentTypeQuery.
     * @param operator the operator.
     * @param ids the content type ids.
     */
    public ContentTypeQuery(Operator operator, String... ids)
    {
        this(operator, Arrays.asList(ids));
    }
    
    /**
     * Build a ContentTypeQuery.
     * @param operator the operator.
     * @param ids the content type ids.
     */
    public ContentTypeQuery(Operator operator, Collection<String> ids)
    {
        super(SolrFieldNames.ALL_CONTENT_TYPES, operator, LogicalOperator.OR, new ArrayList<>(ids));
    }
}
