/*
 *  Copyright 2014 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.search.query;

import java.time.LocalDate;

import org.ametys.cms.content.indexing.solr.SolrFieldNames;
import org.ametys.core.util.date.AdaptableDate;

/**
 * Represents a {@link Query} testing the creation date of a content.
 */
public class CreationDateQuery extends AbstractDateOperatorQuery
{
    /**
     * Build a CreationDateQuery.
     * @param value the value.
     */
    public CreationDateQuery(LocalDate value)
    {
        this(AdaptableDate.fromDate(value));
    }
    
    /**
     * Build a CreationDateQuery.
     * @param value the value.
     */
    public CreationDateQuery(AdaptableDate value)
    {
        this(Operator.EQ, value);
    }

    /**
     * Build a CreationDateQuery.
     * @param op the operator.
     * @param value the value.
     */
    public CreationDateQuery(Operator op, LocalDate value)
    {
        this(Operator.EQ, AdaptableDate.fromDate(value));
    }
    
    /**
     * Build a CreationDateQuery.
     * @param op the operator.
     * @param value the value.
     */
    public CreationDateQuery(Operator op, AdaptableDate value)
    {
        super(SolrFieldNames.CREATION_DATE, op, value);
    }
}
