/*
 *  Copyright 2019 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.search.query;

import java.time.LocalDate;

import org.ametys.core.util.date.AdaptableDate;

/**
 * Represents a {@link Query} testing a date field.
 */
public class DateQuery extends AbstractDateOperatorQuery
{
    /**
     * Build a DateQuery testing the existence of the field.
     * @param fieldPath the field path.
     */
    public DateQuery(String fieldPath)
    {
        this(fieldPath, Operator.EXISTS, (AdaptableDate) null);
    }
    
    /**
     * Build a DateQuery.
     * @param fieldPath the field's path
     * @param value the value.
     */
    public DateQuery(String fieldPath, LocalDate value)
    {
        this(fieldPath, AdaptableDate.fromDate(value));
    }
    
    /**
     * Build a DateQuery.
     * @param fieldPath the field's path
     * @param value the value.
     */
    public DateQuery(String fieldPath, AdaptableDate value)
    {
        this(fieldPath, Operator.EQ, value);
    }
    
    /**
     * Build a DateQuery.
     * @param fieldPath the field's path
     * @param op the operator.
     * @param value the value.
     */
    public DateQuery(String fieldPath, Operator op, LocalDate value)
    {
        this(fieldPath, op, AdaptableDate.fromDate(value));
    }
    
    /**
     * Build a DateQuery.
     * @param fieldPath the field's path
     * @param op the operator.
     * @param value the value.
     */
    public DateQuery(String fieldPath, Operator op, AdaptableDate value)
    {
        super(fieldPath + "_dt", op, value);
    }
}
