/*
 *  Copyright 2014 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.search.query;

/**
 * Represents a {@link Query} testing a double field.
 */
public class DoubleQuery extends AbstractOperatorQuery<Double>
{
    /**
     * Build a DoubleQuery testing the existence of the field.
     * @param fieldPath the field path
     */
    public DoubleQuery(String fieldPath)
    {
        this(fieldPath, Operator.EXISTS, null);
    }
    
    /**
     * Build a DoubleQuery.
     * @param fieldPath the field's path
     * @param value the value.
     */
    public DoubleQuery(String fieldPath, Double value)
    {
        this(fieldPath, Operator.EQ, value);
    }
    
    /**
     * Build a DoubleQuery.
     * @param fieldPath the field's path
     * @param op the operator.
     * @param value the value.
     */
    public DoubleQuery(String fieldPath, Operator op, Double value)
    {
        super(fieldPath + "_d", op, value);
    }
}
