/*
 *  Copyright 2015 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.search.query;

import java.time.LocalDate;

import org.ametys.cms.content.indexing.solr.SolrFieldNames;
import org.ametys.core.util.date.AdaptableDate;

/**
 * Query on the Dublin Core date metadata.
 */
public class DublinCoreDateQuery extends AbstractDateOperatorQuery
{
    /**
     * Create a query on the Dublin Core date metadata with EQ operator.
     * @param value The value to test.
     */
    public DublinCoreDateQuery(LocalDate value)
    {
        this(AdaptableDate.fromDate(value));
    }
    
    /**
     * Create a query on the Dublin Core date metadata with EQ operator.
     * @param value The value to test.
     */
    public DublinCoreDateQuery(AdaptableDate value)
    {
        this(value, Operator.EQ);
    }
    
    /**
     * Create a query on the Dublin Core date metadata.
     * @param value The value to test.
     * @param operator The binary operator to use, can be one of EQ, NE, GT, GE, LT and LE.
     */
    public DublinCoreDateQuery(LocalDate value, Operator operator)
    {
        this(AdaptableDate.fromDate(value), operator);
    }
    
    /**
     * Create a query on the Dublin Core date metadata.
     * @param value The value to test.
     * @param operator The binary operator to use, can be one of EQ, NE, GT, GE, LT and LE.
     */
    public DublinCoreDateQuery(AdaptableDate value, Operator operator)
    {
        super(SolrFieldNames.DC_DATE, operator, value);
    }
}
