/*
 *  Copyright 2016 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.search.query;

import org.apache.solr.client.solrj.util.ClientUtils;

import org.ametys.cms.content.indexing.solr.SolrFieldNames;

/**
 * Represents a {@link Query} testing the resource file name.
 */
public class FilenameQuery extends AbstractOperatorQuery<String>
{
    /**
     * Build a filename query.
     * @param value the value.
     */
    public FilenameQuery(String value)
    {
        this(Operator.EQ, value);
    }
    
    /**
     * Build a filename query.
     * @param op the operator.
     * @param value the value.
     */
    public FilenameQuery(Operator op, String value)
    {
        super(SolrFieldNames.FILENAME, op, value);
    }
    
    @Override
    public String valueForQuery(String value)
    {
        return ClientUtils.escapeQueryChars(value);
    }
}
