/*
 *  Copyright 2019 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.search.query;

import java.time.LocalDate;

import org.ametys.cms.search.solr.field.FirstValidationSearchField;
import org.ametys.core.util.date.AdaptableDate;

/**
 * Represents a {@link Query} testing the first validation date of a content.
 */
public class FirstValidationDateQuery extends AbstractDateOperatorQuery
{
    /**
     * Build a FirstValidationDateQuery.
     * @param value the value.
     */
    public FirstValidationDateQuery(LocalDate value)
    {
        this(AdaptableDate.fromDate(value));
    }
    
    /**
     * Build a FirstValidationDateQuery.
     * @param value the value.
     */
    public FirstValidationDateQuery(AdaptableDate value)
    {
        this(Operator.EQ, value);
    }
    
    /**
     * Build a FirstValidationDateQuery.
     * @param op the operator.
     * @param value the value.
     */
    public FirstValidationDateQuery(Operator op, LocalDate value)
    {
        this(op, AdaptableDate.fromDate(value));
    }
    
    /**
     * Build a FirstValidationDateQuery.
     * @param op the operator.
     * @param value the value.
     */
    public FirstValidationDateQuery(Operator op, AdaptableDate value)
    {
        super(FirstValidationSearchField.NAME, op, value);
    }
}
