/*
 *  Copyright 2021 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.search.query;

import java.util.Map;

/**
 * Represents a {@link Query} testing a geocode field.
 */
public class GeocodeQuery extends AbstractOperatorQuery<Map<String, Integer>>
{
    /**
     * Build a Geocode testing the existence of the field.
     * @param fieldPath the field path
     */
    public GeocodeQuery(String fieldPath)
    {
        this(fieldPath, Operator.EXISTS, null);
    }
    
    /**
     * Build a Geocode query.
     * @param fieldPath the field's path
     * @param operator the operator.
     * @param value the value.
     */
    public GeocodeQuery(String fieldPath, Operator operator, Map<String, Integer> value)
    {
        super(fieldPath + "_geo", operator, value);

        if (Operator.EQ != operator && Operator.NE != operator && Operator.EXISTS != operator)
        {
            throw new IllegalArgumentException("Test operator '" + operator + "' is unknown for test's expression.");
        }
    }
    
    @Override
    public String build() throws QuerySyntaxException
    {
        Operator operator = getOperator();
        Map<String, Integer> value = getValue();
        
        StringBuilder query = new StringBuilder();
        
        if (operator == Operator.EXISTS)
        {
            query.append(getFieldName()).append(":*");
            return query.toString();
        }
        
        if (operator == Operator.NE)
        {
            NotQuery.appendNegation(query);
        }
        
        query.append(getFieldName()).append(":[")
        .append(value.get("latitude")).append(",").append(value.get("longitude"))
        .append(" TO ")
        .append(value.get("latitude")).append(",").append(value.get("longitude"))
        .append("]");
        return query.toString();
    }
}
