/*
 *  Copyright 2020 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.search.query;

import java.util.Map;
import java.util.Optional;

import org.apache.commons.lang.StringUtils;
import org.apache.solr.client.solrj.util.ClientUtils;

/**
 * Isolate a query by wrapping it. Used for special cases to force Solr to distinguish specific parts of the global query.
 */
public class IsolateQuery extends AbstractWrapperQuery
{
    /**
     * Isolate a query.
     * @param query the wrapped {@link Query}.
     */
    public IsolateQuery(Query query)
    {
        super(query);
    }
    
    public String build() throws QuerySyntaxException
    {
        String build = getSubQuery().build();
        if (StringUtils.isBlank(build))
        {
            build = new MatchAllQuery().build();
        }
        
        StringBuilder sb = new StringBuilder()
                .append("{!isolate v=\"")
                .append(ClientUtils.escapeQueryChars(build))
                .append("\"}");
        return sb.toString();
    }
    
    public Optional<Object> buildAsJson() throws QuerySyntaxException
    {
        Optional<Object> json = getSubQuery().buildAsJson();
        if (json.isPresent() && json.get() instanceof String jsonStr && StringUtils.isBlank(jsonStr))
        {
            json = new MatchAllQuery().buildAsJson();
        }
        
        return json.map(q -> Map.of("isolate", Map.of("query", q)));
    }
}
