/*
 *  Copyright 2014 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.search.query;

/**
 * Represents a {@link Query} testing a long field.
 */
public class LongQuery extends AbstractOperatorQuery<Long>
{
    /**
     * Build a LongQuery testing the existence of the field.
     * @param fieldPath the field path
     */
    public LongQuery(String fieldPath)
    {
        this(fieldPath, Operator.EXISTS, null);
    }
    
    /**
     * Build a LongQuery.
     * @param fieldPath the field's path
     * @param value the value.
     */
    public LongQuery(String fieldPath, Long value)
    {
        this(fieldPath, Operator.EQ, value);
    }
    
    /**
     * Build a LongQuery.
     * @param fieldPath the field's path
     * @param op the operator.
     * @param value the value.
     */
    public LongQuery(String fieldPath, Operator op, Long value)
    {
        super(fieldPath + "_l", op, value);
    }
}
