/*
 *  Copyright 2016 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.search.query;

/**
 * Represents a {@link Query} testing a long range.
 */
public class LongRangeQuery extends AbstractRangeQuery<Long>
{
    /**
     * Build a long range query.
     * @param fieldPath The field path.
     * @param lower The lower end of the range.
     * @param upper The upper end of the range.
     */
    public LongRangeQuery(String fieldPath, long lower, long upper)
    {
        this(fieldPath, lower, upper, true, true);
    }
    
    /**
     * Build a long range query.
     * @param fieldPath The field path.
     * @param lower The lower end of the range.
     * @param upper The upper end of the range.
     * @param includeLower Whether to include the lower end or not.
     * @param includeUpper Whether to include the upper end or not.
     */
    public LongRangeQuery(String fieldPath, long lower, long upper, boolean includeLower, boolean includeUpper)
    {
        super(fieldPath + "_l", lower, upper, includeLower, includeUpper);
    }
    
    @Override
    public String lowerBoundForQuery(Long value)
    {
        if (value == null || value == Long.MIN_VALUE)
        {
            return "*";
        }
        
        return super.lowerBoundForQuery(value);
    }
    
    @Override
    public String upperBoundForQuery(Long value)
    {
        if (value == null || value == Long.MAX_VALUE)
        {
            return "*";
        }
        
        return super.upperBoundForQuery(value);
    }
}
