/*
 *  Copyright 2020 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.search.query;

import org.ametys.cms.content.indexing.solr.SolrFieldNames;
import org.ametys.cms.content.indexing.solr.SolrResourceGroupedMimeTypes;

/**
 * MIME-Type group Query
 * <br>See {@link SolrResourceGroupedMimeTypes}
 */
public class MimeTypeGroupQuery extends AbstractOperatorQuery<String>
{
    /**
     * Creates a MIME-Type group Query
     * @param groupMimeType The group MIME-Type to test
     */
    public MimeTypeGroupQuery(String groupMimeType)
    {
        super(SolrFieldNames.RESOURCE_MIME_TYPE_GROUP, Operator.EQ, groupMimeType);
        
        if (!SolrResourceGroupedMimeTypes.isValidGroup(groupMimeType))
        {
            throw new IllegalArgumentException(groupMimeType + " is not a valid group of MIME-Type.");
        }
    }
}
