/*
 *  Copyright 2019 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.search.query;

import java.lang.reflect.Field;
import java.lang.reflect.Modifier;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.util.stream.Collectors;

import org.apache.commons.lang3.StringUtils;

final class QueryDebugger
{
    private QueryDebugger()
    { }
    
    static final String toDebugString(Query query, int indent)
    {
        String toStr;
        try
        {
            toStr = query.getClass().getSimpleName()
                + "("
                + _getFields(query).stream()
                    .filter(QueryDebugger::_showField)
                    .map(f -> _fieldToString(f, query))
                    .collect(Collectors.joining(","))
                + ")";
        }
        catch (Exception e)
        {
            toStr = query.toString();
        }
        return StringUtils.repeat(' ', indent) + toStr;
    }
    
    private static final List<Field> _getFields(Query query)
    {
        List<Field> fields = new ArrayList<>();
        for (Class< ? > clazz = query.getClass(); clazz != null; clazz = clazz.getSuperclass())
        {
            fields.addAll(Arrays.asList(clazz.getDeclaredFields()));
        }
        return fields;
    }
    
    private static final boolean _showField(Field f)
    {
        return !Modifier.isStatic(f.getModifiers());
    }
    
    private static final String _fieldToString(Field f, Query query)
    {
        try
        {
            f.setAccessible(true);
            Object val = f.get(query);
            String strVal = val != null && val.getClass().isArray()
                    ? Arrays.toString((Object[]) val)
                    : String.valueOf(val);
            return f.getName() + ":" + strVal;
        }
        catch (Exception e)
        {
            return "";
        }
    }
}
