/*
 *  Copyright 2015 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.search.query;

import org.ametys.runtime.i18n.I18nizableText;

/**
 * Thrown when the query syntax is invalid.
 */
public class QuerySyntaxException extends Exception
{
    
    /** An internationalized detail message. */
    protected I18nizableText _i18nMessage;
    
    /**
     * Constructs a new exception with the specified detail message.
     * @param message the detail message.
     */
    public QuerySyntaxException(String message)
    {
        this(message, (I18nizableText) null);
    }
    
    /**
     * Constructs a new exception with the specified detail message and cause.
     * @param message the detail message.
     * @param cause the cause.
     */
    public QuerySyntaxException(String message, Throwable cause)
    {
        this(message, cause, null);
    }
    
    /**
     * Constructs a new exception with the specified cause.
     * @param cause the specified cause.
     */
    public QuerySyntaxException(Throwable cause)
    {
        this(cause, null);
    }
    
    /**
     * Constructs a new exception with the specified detail message.
     * @param message the detail message.
     * @param i18nMessage the internationalized detail message.
     */
    public QuerySyntaxException(String message, I18nizableText i18nMessage)
    {
        super(message);
        _i18nMessage = i18nMessage;
    }
    
    /**
     * Constructs a new exception with the specified detail message and cause.
     * @param message the detail message.
     * @param cause the cause.
     * @param i18nMessage the internationalized detail message.
     */
    public QuerySyntaxException(String message, Throwable cause, I18nizableText i18nMessage)
    {
        super(message, cause);
        _i18nMessage = i18nMessage;
    }
    
    /**
     * Constructs a new exception with the specified cause.
     * @param cause the specified cause.
     * @param i18nMessage the internationalized detail message.
     */
    public QuerySyntaxException(Throwable cause, I18nizableText i18nMessage)
    {
        super(cause);
        _i18nMessage = i18nMessage;
    }
    
    /**
     * Get the internationalized detail message.
     * @return the internationalized detail message.
     */
    public I18nizableText getI18nMessage()
    {
        return _i18nMessage;
    }
    
}
