/*
 *  Copyright 2016 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.search.query;

import org.apache.commons.lang.StringUtils;
import org.apache.solr.client.solrj.util.ClientUtils;

import org.ametys.cms.content.indexing.solr.SolrFieldNames;

/**
 * Represents a {@link Query} testing the resource location.
 */
public class ResourceLocationQuery extends AndQuery
{
    /**
     * Build a resource location query finding resources in a specific root.
     * @param rootId The root id.
     */
    public ResourceLocationQuery(String rootId)
    {
        this(rootId, null);
    }
    
    /**
     * Build a resource location query testing the resource under a folder in a specific root.
     * @param rootId The root id.
     * @param path The folder path.
     */
    public ResourceLocationQuery(String rootId, String path)
    {
        // (path:\/folder\/* AND resourceRootId:"collection://xxx")
        super(() -> SolrFieldNames.PATH + ":" + ClientUtils.escapeQueryChars(StringUtils.defaultString(path)) + "\\/*",
            () -> SolrFieldNames.RESOURCE_ROOT_ID + ":\"" + rootId + "\"");
    }
}
