/*
 *  Copyright 2016 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.search.query;

import java.util.Arrays;
import java.util.List;

import org.apache.solr.client.solrj.util.ClientUtils;

import org.ametys.core.user.UserIdentity;

/**
 * {@link Query} testing users.
 */
public class UsersQuery extends AbstractMultivaluedQuery<UserIdentity>
{
    /**
     * Build a user query.
     * @param fieldPath the field's path
     * @param users The users to test.
     */
    public UsersQuery(String fieldPath, UserIdentity... users)
    {
        this(fieldPath, Arrays.asList(users));
    }
    
    /**
     * Build a user query.
     * @param fieldPath the field's path
     * @param users The users to test.
     */
    public UsersQuery(String fieldPath, List<UserIdentity> users)
    {
        this(fieldPath, Operator.EQ, users);
    }
    
    /**
     * Build a user query.
     * @param fieldPath the field's path
     * @param operator The query operator (can be EQ or NE).
     * @param users The users to test.
     */
    public UsersQuery(String fieldPath, Operator operator, UserIdentity... users)
    {
        this(fieldPath, operator, Arrays.asList(users));
    }
    
    /**
     * Build a user query.
     * @param fieldPath the field's path
     * @param operator The query operator (can be EQ or NE).
     * @param users The users to test.
     */
    public UsersQuery(String fieldPath, Operator operator, List<UserIdentity> users)
    {
        super(fieldPath, operator, LogicalOperator.OR, users);
    }
    
    @Override
    public String singleValueForQuery(UserIdentity user)
    {
        return ClientUtils.escapeQueryChars(UserIdentity.userIdentityToString(user));
    }
}
