/*
 *  Copyright 2014 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.search.query;

import java.util.Arrays;

import org.ametys.cms.search.solr.field.WorkflowStepSearchField;

/**
 * Represents a {@link Query} testing the current workflow step of a content.
 * It can only be used to search on the current step.
 */
public class WorkflowStepQuery extends AbstractMultivaluedQuery<Integer>
{
    /**
     * Build a WorkflowStepQuery.
     * @param value the step id to test.
     */
    public WorkflowStepQuery(int value)
    {
        this(new int[] {value});
    }
    
    /**
     * Build a WorkflowStepQuery.
     * @param values the step IDs to test.
     */
    public WorkflowStepQuery(int... values)
    {
        this(Operator.EQ, values);
    }
    
    /**
     * Build a WorkflowStepQuery.
     * @param operator the operator.
     * @param value the step id to test.
     */
    public WorkflowStepQuery(Operator operator, int value)
    {
        this(operator, new int[] {value});
    }
    
    /**
     * Build a WorkflowStepQuery.
     * @param operator the operator.
     * @param values the step IDs to test.
     */
    public WorkflowStepQuery(Operator operator, int... values)
    {
        this(operator, LogicalOperator.OR, values);
    }
    
    /**
     * Build a WorkflowStepQuery.
     * @param operator the operator.
     * @param logicalOperator the logical operator.
     * @param values the step IDs to test.
     */
    public WorkflowStepQuery(Operator operator, LogicalOperator logicalOperator, int... values)
    {
        super(WorkflowStepSearchField.NAME, operator, logicalOperator, Arrays.stream(values).boxed().toList());
    }
}
