/*
 *  Copyright 2018 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.search.solr;

import java.io.IOException;
import java.util.Optional;

import org.apache.solr.client.solrj.SolrClient;
import org.apache.solr.client.solrj.SolrServerException;
import org.apache.solr.client.solrj.response.UpdateResponse;
import org.slf4j.Logger;

/**
 * Default update {@link SolrClient} which uses the Solr default Update Request Processor chain
 */
public class DefaultUpdateClient extends AbstractAmetysConcurrentUpdateClient
{
    /**
     * Constructor
     * @param solrServerUrl The Solr server URL
     * @param solrSocketTimeout The Solr socket timeout (in millis)
     * @param collectionName The name of the collection, on which operations will be allowed. Operations on other collections will be forbidden.
     * @param queueSize The buffer size before the documents are sent to the server
     * @param threadCount The number of background threads used to empty the queue
     * @param logger internal logger
     */
    public DefaultUpdateClient(String solrServerUrl, Optional<Integer> solrSocketTimeout, String collectionName, int queueSize, int threadCount, Logger logger)
    {
        super(solrServerUrl, solrSocketTimeout, collectionName, queueSize, threadCount, logger);
    }
    
    @Override
    public UpdateResponse commit() throws SolrServerException, IOException
    {
        throw new CommitNotAllowedException();
    }
    
    @Override
    public UpdateResponse commit(boolean waitFlush, boolean waitSearcher) throws SolrServerException, IOException
    {
        throw new CommitNotAllowedException();
    }
    
    @Override
    public UpdateResponse commit(boolean waitFlush, boolean waitSearcher, boolean softCommit) throws SolrServerException, IOException
    {
        throw new CommitNotAllowedException();
    }
    
    @Override
    public UpdateResponse commit(String collection) throws SolrServerException, IOException
    {
        throw new CommitNotAllowedException();
    }
    
    @Override
    public UpdateResponse commit(String collection, boolean waitFlush, boolean waitSearcher) throws SolrServerException, IOException
    {
        throw new CommitNotAllowedException();
    }
    
    @Override
    public UpdateResponse commit(String collection, boolean waitFlush, boolean waitSearcher, boolean softCommit) throws SolrServerException, IOException
    {
        throw new CommitNotAllowedException();
    }
    
    static class CommitNotAllowedException extends RuntimeException
    {
        CommitNotAllowedException()
        {
            super("Commit is not allowed with the default update client.");
        }
    }
}
