/*
 *  Copyright 2018 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.search.solr;

import java.io.IOException;
import java.util.Optional;

import org.apache.solr.client.solrj.SolrClient;
import org.apache.solr.client.solrj.SolrRequest;
import org.apache.solr.client.solrj.SolrServerException;
import org.apache.solr.client.solrj.request.UpdateRequest;
import org.apache.solr.common.params.UpdateParams;
import org.apache.solr.common.util.NamedList;
import org.slf4j.Logger;

/**
 * Update {@link SolrClient} which uses the Solr `noAutoCommit` Update Request Processor chain, so as to not trigger the autoCommit mechanism.
 */
public class NoAutoCommitUpdateClient extends AbstractAmetysConcurrentUpdateClient
{
    private static final String __UPDATE_CHAIN_NAME = "noAutoCommit";
    
    /**
     * Constructor
     * @param solrServerUrl The Solr server URL
     * @param solrSocketTimeout The Solr socket timeout (in millis)
     * @param collectionName The name of the collection, on which operations will be allowed. Operations on other collections will be forbidden.
     * @param queueSize The buffer size before the documents are sent to the server
     * @param threadCount The number of background threads used to empty the queue
     * @param logger internal logger
     */
    public NoAutoCommitUpdateClient(String solrServerUrl, Optional<Integer> solrSocketTimeout, String collectionName, int queueSize, int threadCount, Logger logger)
    {
        super(solrServerUrl, solrSocketTimeout, collectionName, queueSize, threadCount, logger);
    }
    
    @Override
    public NamedList<Object> request(SolrRequest request, String collection) throws SolrServerException, IOException
    {
        _setUpdateRequestProcessorChain(request);
        return super.request(request, collection);
    }
    
    private void _setUpdateRequestProcessorChain(SolrRequest request)
    {
        if (request instanceof UpdateRequest)
        {
            ((UpdateRequest) request).setParam(UpdateParams.UPDATE_CHAIN, __UPDATE_CHAIN_NAME);
        }
    }
}
