/*
 *  Copyright 2016 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.search.solr;

import org.apache.solr.common.SolrDocument;

import org.ametys.cms.content.indexing.solr.SolrFieldNames;
import org.ametys.cms.search.SearchResult;
import org.ametys.plugins.repository.AmetysObject;
import org.ametys.plugins.repository.AmetysObjectResolver;

class SolrDocumentResult<AO extends AmetysObject> implements SearchResult<AO>
{
    private SolrDocument _document;
    private AmetysObjectResolver _resolver;
    
    public SolrDocumentResult(SolrDocument document, AmetysObjectResolver resolver)
    {
        _document = document;
        _resolver = resolver;
    }
    
    @Override
    public AO getObject()
    {
        String id = (String) _document.getFieldValue(SolrFieldNames.ID);
        return _resolver.resolveById(id);
    }
    
    @Override
    public float getScore()
    {
        Float score = (Float) _document.getFieldValue("score");
        return score != null ? score.floatValue() : 0;
    }
}
