/*
 *  Copyright 2016 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.search.solr;

import java.util.Iterator;

import org.apache.solr.client.solrj.response.QueryResponse;
import org.apache.solr.common.SolrDocument;
import org.apache.solr.common.SolrDocumentList;

import org.ametys.cms.content.indexing.solr.SolrFieldNames;

/**
 * Provides an iterator over the IDs of the objects in a solr {@link QueryResponse}.
 */
public class SolrResponseIdIterable implements Iterable<String>
{
    private SolrDocumentList _docList;
    
    /**
     * Buid the IdIterable.
     * @param docList The solr response document list.
     */
    public SolrResponseIdIterable(SolrDocumentList docList)
    {
        this._docList = docList;
    }
    
    @Override
    public Iterator<String> iterator()
    {
        // Return a forwarding iterator.
        return new DocListIdIterator(_docList);
    }
    
    /**
     * Iterator over the IDs of the objects in a SolrDocumentList.
     */
    protected class DocListIdIterator implements Iterator<String>
    {
        private Iterator<SolrDocument> _docIterator;
        
        /**
         * Build a DocListIdIterator.
         * @param docList the solr socument list.
         */
        public DocListIdIterator(SolrDocumentList docList)
        {
            this._docIterator = docList.iterator();
        }
        
        @Override
        public boolean hasNext()
        {
            return _docIterator.hasNext();
        }
        
        @Override
        public String next()
        {
            return (String) _docIterator.next().getFieldValue(SolrFieldNames.ID);
        }
    }
}
