/*
 *  Copyright 2016 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.search.solr;

import java.util.Iterator;

import org.apache.solr.client.solrj.response.QueryResponse;
import org.apache.solr.common.SolrDocument;
import org.apache.solr.common.SolrDocumentList;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import org.ametys.cms.search.SearchResult;
import org.ametys.cms.search.SearchResultsIterable;
import org.ametys.cms.search.SearchResultsIterator;
import org.ametys.plugins.repository.AmetysObject;
import org.ametys.plugins.repository.AmetysObjectIterable;
import org.ametys.plugins.repository.AmetysObjectResolver;

/**
 * {@link AmetysObjectIterable} backed by a solr {@link QueryResponse}.
 * @param <A> the actual type of {@link AmetysObject}s.
 */
public class SolrResponseIterable<A extends AmetysObject> implements SearchResultsIterable<SearchResult<A>>
{
    static final Logger __LOGGER = LoggerFactory.getLogger(SolrResponseIdIterable.class);

    AmetysObjectResolver _resolver;
    private SolrDocumentList _docList;
    private SolrResponseIterator _lastIterator;
    
    /**
     * Build a SolrResponseIterable.
     * @param docList The solr response document list.
     * @param resolver The Ametys object resolver.
     */
    public SolrResponseIterable(SolrDocumentList docList, AmetysObjectResolver resolver)
    {
        _docList = docList;
        _resolver = resolver;
    }
    
    @Override
    public SearchResultsIterator<SearchResult<A>> iterator()
    {
        _lastIterator = new SolrResponseIterator<>(_docList.iterator(), _docList.size());
        return _lastIterator;
    }
    
    @Override
    public long getSize()
    {
        if (_lastIterator == null)
        {
            return _docList.size();
        }
        else
        {
            // Some documents may represent unexisting ametys objects (due to indexation issues, etc.) so we need to subtract the number of errors found
            return _lastIterator.getSize();
        }
    }
    
    class SolrResponseIterator<AO extends AmetysObject> extends AbstractResponseIterator<SearchResult<AO>>
    {
        public SolrResponseIterator(Iterator<SolrDocument> it, long size)
        {
            super(it, size, _resolver, __LOGGER);
        }
        
        @Override
        protected SearchResult<AO> _setNextObject(SolrDocument document, String id)
        {
            return new SolrDocumentResult<>(document, _resolver);
        }
    }
}
