/*
 *  Copyright 2016 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.search.solr.field;

import java.util.HashMap;
import java.util.Map;

import org.ametys.cms.content.indexing.solr.SolrFieldNames;

/**
 * Dublin Core search field.
 */
public class DublinCoreSearchField extends AbstractNoJoinSystemSearchField
{
    
    private static final Map<String, String> NAME_TO_FIELD = new HashMap<>();
    static
    {
        NAME_TO_FIELD.put("title", SolrFieldNames.DC_TITLE);
        NAME_TO_FIELD.put("creator", SolrFieldNames.DC_CREATOR);
        NAME_TO_FIELD.put("subject", SolrFieldNames.DC_SUBJECT);
        NAME_TO_FIELD.put("description", SolrFieldNames.DC_DESCRIPTION);
        NAME_TO_FIELD.put("publisher", SolrFieldNames.DC_PUBLISHER);
        NAME_TO_FIELD.put("contributor", SolrFieldNames.DC_CONTRIBUTOR);
        NAME_TO_FIELD.put("date", SolrFieldNames.DC_DATE);
        NAME_TO_FIELD.put("type", SolrFieldNames.DC_TYPE);
        NAME_TO_FIELD.put("format", SolrFieldNames.DC_FORMAT);
        NAME_TO_FIELD.put("identifier", SolrFieldNames.DC_IDENTIFIER);
        NAME_TO_FIELD.put("source", SolrFieldNames.DC_SOURCE);
        NAME_TO_FIELD.put("language", SolrFieldNames.DC_LANGUAGE);
        NAME_TO_FIELD.put("relation", SolrFieldNames.DC_RELATION);
        NAME_TO_FIELD.put("coverage", SolrFieldNames.DC_COVERAGE);
        NAME_TO_FIELD.put("rights", SolrFieldNames.DC_RIGHTS);
    }
    
    /** The Dublin Core metadata name. */
    protected String _metadata;
    
    /**
     * Build a Dublin Core search field.
     * @param dcMetadata The Dublin Core metadata name.
     */
    public DublinCoreSearchField(String dcMetadata)
    {
        if (!NAME_TO_FIELD.containsKey(dcMetadata))
        {
            throw new IllegalArgumentException(dcMetadata + " is not a valid Dublin Core metadata.");
        }
        
        _metadata = dcMetadata;
    }
    
    @Override
    public String getName()
    {
        return NAME_TO_FIELD.get(_metadata);
    }
    
    @Override
    public String getSortField()
    {
        return getName() + "_sort";
    }
    
    @Override
    public String getFacetField()
    {
        return getName() + "_dv";
    }

}
