/*
 *  Copyright 2017 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.search.solr.field;

import java.util.List;

import org.apache.commons.collections4.CollectionUtils;
import org.apache.commons.lang3.StringUtils;

import org.ametys.cms.search.SearchField;

/**
 * SearchField 
 */
public class JoinedSystemSearchField implements SearchField
{   
    /** The join paths */
    protected List<String> _joinPaths;
    /** The reference search field */
    protected SearchField _refSearchField;

    /**
     * Build a JoinedSystemSearchField
     * @param joinPaths The join field paths. Must not be null or empty.
     * @param refSearchField The reference search field. Must not be joined.
     */
    public JoinedSystemSearchField(List<String> joinPaths, SearchField refSearchField)
    {
        if (CollectionUtils.isEmpty(joinPaths))
        {
            throw new IllegalArgumentException("The join path must not be empty.");
        }
        if (refSearchField.isJoined())
        {
            throw new IllegalArgumentException("The passed reference search field must not already be a joined search field.");
        }
        _joinPaths = joinPaths;
        _refSearchField = refSearchField;
    }
    
    @Override
    public String getName()
    {
        return StringUtils.join(_joinPaths, '/') + '/' + _refSearchField.getName();
    }
    
    @Override
    public boolean isJoined()
    {
        return true;
    }
    
    private String _getJoinedPath()
    {
        return StringUtils.join(_joinPaths, "->");
    }
    
    @Override
    public String getSortField()
    {
        String refSortField = _refSearchField.getSortField();
        return refSortField != null ? "ametys(" + _getJoinedPath() + "," + refSortField + ")" : null;
    }

    @Override
    public String getFacetField()
    {
        return _refSearchField.getFacetField();
    }
    
    @Override
    public List<String> getJoinedPaths()
    {
        return _joinPaths;
    }
}
