/*
 *  Copyright 2016 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.search.solr.field;

import org.ametys.cms.content.indexing.solr.SolrFieldNames;

/**
 * Mixin type search field.
 */
public class MixinTypeSearchField extends AbstractNoJoinSystemSearchField
{
    
    /** The mixin types field name. */
    public static final String NAME = "mixinTypes";
    
    /** The "all mixin types" field name. */
    public static final String NAME_ALL = "allMixinTypes";
    
    /** True to include all hierarchy, false otherwise. */
    protected boolean _includeAll;
    
    /**
     * Build a mixin type search field.
     * @param includeAll <code>true</code> to include all hierarchy, <code>false</code> otherwise.
     */
    public MixinTypeSearchField(boolean includeAll)
    {
        _includeAll = includeAll;
    }
    
    @Override
    public String getName()
    {
        return _includeAll ? NAME_ALL : NAME;
    }
    
    @Override
    public String getSortField()
    {
        return _includeAll ? SolrFieldNames.ALL_MIXIN_TYPES : SolrFieldNames.MIXIN_TYPES + "_sort";
    }
    
    @Override
    public String getFacetField()
    {
        return _includeAll ? SolrFieldNames.ALL_MIXIN_TYPES : SolrFieldNames.MIXIN_TYPES + "_dv";
    }

}
