/*
 *  Copyright 2016 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.search.solr.field;

import java.util.List;
import java.util.Locale;
import java.util.Optional;

import org.apache.avalon.framework.context.Context;
import org.apache.cocoon.components.ContextHelper;
import org.apache.commons.lang3.StringUtils;

import org.ametys.cms.search.cocoon.SearchAction;

/**
 * String generic search field.
 */
public class MultilingualStringSearchField extends AbstractModelItemSearchField
{
    private Optional<Context> _context;

    /**
     * Build a multilingual string search field.
     * @param path The field path.
     * @param context The context
     */
    public MultilingualStringSearchField(String path, Optional<Context> context)
    {
        super(path);
        _context = context;
    }
    
    /**
     * Build a multilingual string search field.
     * @param joinPaths The join field paths
     * @param finalPath The final field path.
     * @param context The context
     */
    public MultilingualStringSearchField(List<String> joinPaths, String finalPath, Optional<Context> context)
    {
        super(joinPaths, finalPath);
        _context = context;
    }

    @Override
    protected String _getSortFieldSuffix()
    {
        return getCurrentLanguage(_context)
                .map("_"::concat)
                .orElse(StringUtils.EMPTY)
                + "_s_sort";
    }
    
    /**
     * Gets the current language
     * @param context The context
     * @return the current language
     */
    protected static Optional<String> getCurrentLanguage(Optional<Context> context)
    {
        return context
                .map(ContextHelper::getRequest)
                .map(r -> r.getAttribute(SearchAction.SEARCH_LOCALE))
                .filter(Locale.class::isInstance)
                .map(Locale.class::cast)
                .map(Locale::getLanguage);
    }
    
    @Override
    protected String _getFacetFieldSuffix()
    {
        return "_s_dv";
    }

}
