/*
 *  Copyright 2016 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.search.solr.field;

import org.ametys.cms.content.indexing.solr.SolrFieldNames;

/**
 * Tags search field.
 */
public class TagSearchField extends AbstractNoJoinSystemSearchField
{
    /** True to include all hierarchy, false otherwise. */
    protected boolean _autoposting;
    
    /**
     * Build a tag search field with no autoposting
     */
    public TagSearchField()
    {
        this(false);
    }
    
    /**
     * Build a tag search field.
     * @param withAutoposting <code>true</code> to search with autoposting.
     */
    public TagSearchField(boolean withAutoposting)
    {
        _autoposting = withAutoposting;
    }
    
    @Override
    public String getName()
    {
        return _autoposting ? SolrFieldNames.ALL_TAGS : SolrFieldNames.TAGS;
    }
    
    @Override
    public String getSortField()
    {
        // Not sortable.
        return null;
    }
    
    @Override
    public String getFacetField()
    {
        return _autoposting ? SolrFieldNames.ALL_TAGS : SolrFieldNames.TAGS + "_dv";
    }

}
