/*
 *  Copyright 2016 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.search.solr.schema;

import java.util.Arrays;
import java.util.Map;

import org.apache.solr.client.solrj.request.schema.SchemaRequest;

/**
 * Represents a copy field definition in a solr schema.
 */
public class CopyFieldDefinition implements SchemaDefinition
{
    
    /** The source field. */
    protected String _source;
    
    /** The destination field. */
    protected String _destination;
    
    /**
     * Build a copy field definition.
     * @param source The source field.
     * @param destination The destination field.
     */
    public CopyFieldDefinition(String source, String destination)
    {
        this._source = source;
        this._destination = destination;
    }
    
    /**
     * Build a copy field definition from a map of attributes.
     * @param attributes the Map of attributes.
     */
    public CopyFieldDefinition(Map<String, Object> attributes)
    {
        this._source = (String) attributes.get("source");
        this._destination = (String) attributes.get("dest");
    }
    
    /**
     * Get the source field.
     * @return The source field.
     */
    public String getSource()
    {
        return _source;
    }
    
    /**
     * Set the source field.
     * @param source the source field.
     */
    public void setSource(String source)
    {
        this._source = source;
    }
    
    /**
     * Get the destination field.
     * @return The destination field.
     */
    public String getDestination()
    {
        return _destination;
    }
    
    /**
     * Set the destination field.
     * @param destination the destination field.
     */
    public void setDestination(String destination)
    {
        this._destination = destination;
    }
    
    public SchemaRequest.Update getSchemaUpdate()
    {
        return new SchemaRequest.AddCopyField(getSource(), Arrays.asList(getDestination()));
    }

    public boolean exists(SchemaFields schemaFields)
    {
        return schemaFields.hasCopyField(getSource(), getDestination());
    }
}
