/*
 *  Copyright 2016 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.search.solr.schema;

/**
 * A copy field identifier (source and destination).
 */
public class CopyFieldId
{
    /** The copy field source. */
    protected String _source;
    
    /** The copy field destination. */
    protected String _destination;
    
    /**
     * Build a copy field.
     * @param source The copy field source.
     * @param destination The copy field destination.
     */
    public CopyFieldId(String source, String destination)
    {
        this._source = source;
        this._destination = destination;
    }
    
    /**
     * Get the copy field source.
     * @return The copy field source.
     */
    public String getSource()
    {
        return _source;
    }
    
    /**
     * Set the copy field source.
     * @param source The copy field source to set.
     */
    public void setSource(String source)
    {
        this._source = source;
    }
    
    /**
     * Get the copy field destination.
     * @return The copy field destination.
     */
    public String getDestination()
    {
        return _destination;
    }
    
    /**
     * Set the copy field destination.
     * @param destination The copy field destination to set.
     */
    public void setDestination(String destination)
    {
        this._destination = destination;
    }
    
    @Override
    public String toString()
    {
        return "{source=" + _source + ", destination=" + _destination + "}";
    }
    
    @Override
    public int hashCode()
    {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((_destination == null) ? 0 : _destination.hashCode());
        result = prime * result + ((_source == null) ? 0 : _source.hashCode());
        return result;
    }

    @Override
    public boolean equals(Object obj)
    {
        if (this == obj)
        {
            return true;
        }
        if (obj == null)
        {
            return false;
        }
        if (getClass() != obj.getClass())
        {
            return false;
        }
        CopyFieldId other = (CopyFieldId) obj;
        if (_destination == null)
        {
            if (other._destination != null)
            {
                return false;
            }
        }
        else if (!_destination.equals(other._destination))
        {
            return false;
        }
        if (_source == null)
        {
            if (other._source != null)
            {
                return false;
            }
        }
        else if (!_source.equals(other._source))
        {
            return false;
        }
        return true;
    }
}
