/*
 *  Copyright 2024 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.search.solr.schema;

import org.apache.solr.client.solrj.request.schema.SchemaRequest;

/**
 * Represents a field type definition in a solr schema.
 */
public class FieldTypeDefinition implements SchemaDefinition
{
    /** The field type name. */
    protected String _name;
    
    /** The field type. */
    protected org.apache.solr.client.solrj.request.schema.FieldTypeDefinition _type;

    /**
     * Build a field type definition from a map of attributes.
     * @param fieldTypeDefinition the field type definition.
     */
    public FieldTypeDefinition(org.apache.solr.client.solrj.request.schema.FieldTypeDefinition fieldTypeDefinition)
    {
        this._name = (String) fieldTypeDefinition.getAttributes().get("name");
        this._type = fieldTypeDefinition;
    }    
    /**
     * Get the field name.
     * @return The field name.
     */
    public String getName()
    {
        return _name;
    }
    
    /**
     * Set the field name.
     * @param name the field name.
     */
    public void setName(String name)
    {
        this._name = name;
    }
    
    /**
     * Get the field type.
     * @return The field type.
     */
    public org.apache.solr.client.solrj.request.schema.FieldTypeDefinition getType()
    {
        return _type;
    }

    /**
     * Set the field type.
     * @param type the field type.
     */
    public void setType(org.apache.solr.client.solrj.request.schema.FieldTypeDefinition type)
    {
        this._type = type;
    }
    
    public SchemaRequest.Update getSchemaUpdate()
    {
        return new SchemaRequest.AddFieldType(getType());
    }

    public boolean exists(SchemaFields schemaFields)
    {
        return schemaFields.hasFieldType(getName());
    }
}
