/*
 *  Copyright 2016 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.search.solr.schema;

import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import java.util.Map;

import org.apache.avalon.framework.configuration.Configurable;
import org.apache.avalon.framework.configuration.Configuration;
import org.apache.avalon.framework.configuration.ConfigurationException;
import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.avalon.framework.service.Serviceable;
import org.apache.excalibur.source.SourceResolver;
import org.apache.solr.client.solrj.response.schema.SchemaRepresentation;

import org.ametys.runtime.plugin.component.AbstractLogEnabled;

/**
 * Reads a given schema fragment file and provides the definitions defined in it.
 */
public class StaticSchemaDefinitionProvider extends AbstractLogEnabled implements SchemaDefinitionProvider, Configurable, Serviceable
{
    
    /** The source resolver. */
    protected SourceResolver _sourceResolver;
    
    /** The schema helper. */
    protected SchemaHelper _schemaHelper;
    
    private String _schemaLocation;
    
    @Override
    public void service(ServiceManager manager) throws ServiceException
    {
        _sourceResolver = (SourceResolver) manager.lookup(SourceResolver.ROLE);
        _schemaHelper = (SchemaHelper) manager.lookup(SchemaHelper.ROLE);
    }
    
    @Override
    public void configure(Configuration configuration) throws ConfigurationException
    {
        _schemaLocation = configuration.getChild("schema").getAttribute("location");
    }
    
    @Override
    public Collection<SchemaDefinition> getDefinitions()
    {
        SchemaRepresentation schema = _schemaHelper.getSchema(_schemaLocation);
        
        return getDefinitions(schema);
    }
    
    /**
     * Get the definitions from the given schema representation.
     * @param schema The schema representation.
     * @return The collection of schema definitions defined in the schema.
     */
    protected Collection<SchemaDefinition> getDefinitions(SchemaRepresentation schema)
    {
        List<SchemaDefinition> definitions = new ArrayList<>();
        
        for (org.apache.solr.client.solrj.request.schema.FieldTypeDefinition fieldType : schema.getFieldTypes())
        {
            definitions.add(new FieldTypeDefinition(fieldType));
        }
        
        for (Map<String, Object> attributes : schema.getFields())
        {
            definitions.add(new FieldDefinition(attributes));
        }
        
        for (Map<String, Object> attributes : schema.getDynamicFields())
        {
            definitions.add(new DynamicFieldDefinition(attributes));
        }
        
        for (Map<String, Object> attributes : schema.getCopyFields())
        {
            definitions.add(new CopyFieldDefinition(attributes));
        }
        
        return definitions;
    }
}
