/*
 *  Copyright 2016 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.search.solr.schema;

import java.util.ArrayList;
import java.util.Collection;
import java.util.List;

import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.avalon.framework.service.Serviceable;

import org.ametys.cms.search.model.SystemProperty;
import org.ametys.cms.search.model.SystemPropertyExtensionPoint;
import org.ametys.runtime.plugin.component.AbstractLogEnabled;

/**
 * Provides all the schema elements defined by system properties.
 */
public class SystemPropertySchemaDefinitionProvider extends AbstractLogEnabled implements SchemaDefinitionProvider, Serviceable
{
    
    /** The system property extension point. */
    protected SystemPropertyExtensionPoint _sysPropEP;
    
    @Override
    public void service(ServiceManager manager) throws ServiceException
    {
        _sysPropEP = (SystemPropertyExtensionPoint) manager.lookup(SystemPropertyExtensionPoint.ROLE);
    }
    
    @Override
    public Collection<SchemaDefinition> getDefinitions()
    {
        List<SchemaDefinition> definitions = new ArrayList<>();
        
        for (String id : _sysPropEP.getExtensionsIds())
        {
            SystemProperty property = _sysPropEP.getExtension(id);
            
            definitions.addAll(property.getSchemaDefinitions());
        }
        
        return definitions;
    }

}
