/*
 *  Copyright 2022 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.search.systemprop;

import java.time.ZonedDateTime;

import org.ametys.cms.data.ametysobject.ModelAwareDataAwareAmetysObject;
import org.ametys.cms.search.model.SystemProperty;
import org.ametys.runtime.model.type.ModelItemTypeConstants;

/**
 * Abstract class providing base functionality for a date time-typed {@link SystemProperty}.
 * @param <X> type of ametys object supported by this property
 */
public abstract class AbstractDateTimeSystemProperty<X extends ModelAwareDataAwareAmetysObject> extends AbstractSystemProperty<ZonedDateTime, X>
{
    @Override
    public boolean isMultiple()
    {
        return false;
    }
    
    @Override
    public boolean isSortable()
    {
        return true;
    }
    
    @Override
    public String getCriterionWidget()
    {
        return "edition.date";
    }

    @Override
    protected String _getTypeId()
    {
        return ModelItemTypeConstants.DATETIME_TYPE_ID;
    }
}
