/*
 *  Copyright 2015 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.search.systemprop;

import java.util.Map;

import org.ametys.cms.data.type.ModelItemTypeConstants;
import org.ametys.cms.data.ametysobject.ModelAwareDataAwareAmetysObject;
import org.ametys.cms.search.model.SystemProperty;
import org.ametys.cms.search.query.Query;
import org.ametys.cms.search.query.Query.Operator;
import org.ametys.cms.search.query.UsersQuery;
import org.ametys.core.user.UserIdentity;

/**
 * Abstract class providing base functionality for a user-typed {@link SystemProperty}.
 * @param <X> type of ametys object supported by this property
 */
public abstract class AbstractUserSystemProperty<X extends ModelAwareDataAwareAmetysObject> extends AbstractSystemProperty<UserIdentity, X>
{
    @Override
    public String getRenderer()
    {
        return "Ametys.plugins.cms.search.SearchGridHelper.renderUser";
    }
    
    @Override
    public Query getQuery(Object value, Operator operator, String language, Map<String, Object> contextualParameters)
    {
        return new UsersQuery(_getSolrFieldName(), operator, operator != Operator.EXISTS ? parseUserArray(value) : new UserIdentity[] {});
    }
    
    /**
     * Get the Solr field name
     * @return the field name
     */
    protected abstract String _getSolrFieldName();
    
    /**
     * Get the value as {@link UserIdentity}
     * @param ametysObject the ametys object
     * @return the user identity
     */
    protected abstract UserIdentity _getUserIdentityValue(X ametysObject);
    
    @Override
    public Object getValue(X ametysObject)
    {
        return _getUserIdentityValue(ametysObject);
    }
    
    @Override
    public Object getSortValue(X content)
    {
        UserIdentity user = (UserIdentity) getValue(content);
        if (user != null)
        {
            return _userHelper.getUserSortableName(user);
        }
        
        return user;
    }
    
    @Override
    protected String _getTypeId()
    {
        return ModelItemTypeConstants.USER_ELEMENT_TYPE_ID;
    }
}
