/*
 *  Copyright 2015 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.search.systemprop;

import org.ametys.cms.content.indexing.solr.SolrFieldNames;
import org.ametys.cms.repository.Content;
import org.ametys.cms.search.SearchField;
import org.ametys.cms.search.model.SystemProperty;
import org.ametys.cms.search.solr.field.ContributorSearchField;
import org.ametys.core.user.UserIdentity;

/**
 * {@link SystemProperty} which represents the last contributor of a content.
 */
public class ContributorSystemProperty extends AbstractUserSystemProperty<Content>
{
    @Override
    public boolean isMultiple()
    {
        return false;
    }
    
    @Override
    public boolean isSortable()
    {
        return true;
    }
    
    @Override
    protected String _getSolrFieldName()
    {
        return SolrFieldNames.CONTENT_LAST_CONTRIBUTOR;
    }
    
    @Override
    protected UserIdentity _getUserIdentityValue(Content content)
    {
        return content.getLastContributor();
    }
    
    @Override
    public SearchField getSearchField()
    {
        return new ContributorSearchField();
    }
}
