/*
 *  Copyright 2015 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.search.systemprop;

import java.util.Map;

import org.ametys.cms.repository.Content;
import org.ametys.cms.search.SearchField;
import org.ametys.cms.search.model.SystemProperty;
import org.ametys.cms.search.query.CreationDateQuery;
import org.ametys.cms.search.query.Query;
import org.ametys.cms.search.query.Query.Operator;
import org.ametys.cms.search.solr.field.CreationDateSearchField;

/**
 * {@link SystemProperty} which represents the creation date of a content.
 */
public class CreationDateSystemProperty extends AbstractDateTimeSystemProperty<Content>
{
    @Override
    public Query getQuery(Object value, Operator operator, String language, Map<String, Object> contextualParameters)
    {
        return new CreationDateQuery(operator, operator != Operator.EXISTS ? parseDate(value) : null);
    }
    
    @Override
    public SearchField getSearchField()
    {
        return new CreationDateSearchField();
    }
    
    @Override
    public Object getValue(Content content)
    {
        return content.getCreationDate();
    }
}
