/*
 *  Copyright 2015 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.search.systemprop;

import java.util.Map;

import org.apache.avalon.framework.configuration.Configuration;
import org.apache.avalon.framework.configuration.ConfigurationException;

import org.ametys.cms.repository.Content;
import org.ametys.cms.search.SearchField;
import org.ametys.cms.search.model.SystemProperty;
import org.ametys.cms.search.query.FullTextQuery;
import org.ametys.cms.search.query.Query;
import org.ametys.cms.search.query.Query.Operator;
import org.ametys.runtime.model.type.ModelItemTypeConstants;

/**
 * {@link SystemProperty} which represents the full textual content of a Content.
 */
public class FulltextSystemProperty extends AbstractSystemProperty<String, Content>
{
    /** True for a stemmed full-text search, false otherwise. */
    protected boolean _stemmed;
    
    @Override
    public void configure(Configuration configuration) throws ConfigurationException
    {
        super.configure(configuration);
        _stemmed = configuration.getChild("stemmed").getValueAsBoolean(false);
    }
    
    @Override
    public boolean isMultiple()
    {
        return false;
    }
    
    @Override
    public boolean isDisplayable()
    {
        return false;
    }
    
    @Override
    public boolean isSortable()
    {
        return false;
    }
    
    @Override
    public Query getQuery(Object value, Operator operator, String language, Map<String, Object> contextualParameters)
    {
        return new FullTextQuery((String) value, language, _stemmed ? Operator.SEARCH_STEMMED : Operator.SEARCH);
    }
    
    @Override
    public SearchField getSearchField()
    {
        // No value to index, not sortable: the field won't be used.
        return null;
    }
    
    @Override
    public Object getValue(Content content)
    {
        // No real "value" to return here.
        // The values are indexed separately, while walking the content attribute tree.
        return null;
    }

    @Override
    protected String _getTypeId()
    {
        return ModelItemTypeConstants.STRING_TYPE_ID;
    }
}
