/*
 *  Copyright 2023 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.search.systemprop;

import java.util.Map;

import org.apache.commons.lang3.ArrayUtils;

import org.ametys.cms.CmsConstants;
import org.ametys.cms.repository.Content;
import org.ametys.cms.search.SearchField;
import org.ametys.cms.search.model.SystemProperty;
import org.ametys.cms.search.query.HasLiveVersionQuery;
import org.ametys.cms.search.query.Query;
import org.ametys.cms.search.query.Query.Operator;
import org.ametys.cms.search.solr.field.HasLiveVersionSearchField;
import org.ametys.plugins.repository.version.VersionAwareAmetysObject;
import org.ametys.runtime.model.type.ModelItemTypeConstants;

/**
 * {@link SystemProperty} which indicate if the content has a live version. The current version or a past one.
 */
public class HasLiveVersionSystemProperty extends AbstractSystemProperty<Boolean, Content>
{
    public Query getQuery(Object value, Operator operator, String language, Map<String, Object> contextualParameters)
    {
        boolean state = parseBoolean(value);
        return new HasLiveVersionQuery(operator, state);
    }

    public SearchField getSearchField()
    {
        return new HasLiveVersionSearchField();
    }

    public Object getValue(Content ametysObject)
    {
        if (ametysObject instanceof VersionAwareAmetysObject versionAware)
        {
            String[] labels = versionAware.getAllLabels();
            if (ArrayUtils.contains(labels, CmsConstants.LIVE_LABEL))
            {
                return true;
            }
        }
        return false;
    }

    @Override
    protected String _getTypeId()
    {
        return ModelItemTypeConstants.BOOLEAN_TYPE_ID;
    }

}
