/*
 *  Copyright 2013 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.search.ui.model;

import java.util.Optional;

import org.ametys.runtime.model.ModelItem;
import org.ametys.runtime.model.ModelViewItem;

/**
 * This class represents a result column.
 * @param <T> type of the referenced model item
 */
public interface SearchUIColumn<T extends ModelItem> extends ModelViewItem<T>
{
    /**
     * The column's width
     * @return The width
     */
    public int getWidth();
    
    /**
     * Set the column's width
     * @param width The width to set
     */
    public void setWidth (int width);
    
    /**
     * Determines if the column is hidden by default
     * @return <code>true</code> if the column is hidden by default  
     */
    public boolean isHidden();
    
    /**
     * Set the hidden property
     * @param hidden <code>true</code> to hidden the columns by default
     */
    public void setHidden (boolean hidden);
    
    /**
     * Determines if the property is editable
     * @return <code>true</code> if the property is editable
     */
    public boolean isEditable();
    
    /**
     * Set the editable property
     * @param editable <code>true</code> to authorized edition
     */
    public void setEditable (boolean editable);
    
    /**
     * Determines if the column is sortable
     * @return <code>true</code> if the column is sortable
     */
    public boolean isSortable();
    
    /**
     * Set the sortable property
     * @param sortable <code>true</code> to authorized sort
     */
    public void setSortable (boolean sortable);
    
    /**
     * Determines if sort is allowed on multiple join
     * @return <code>true</code> if sort is allowed on multiple join, <code>false</code> otherwise
     */
    public boolean allowSortOnMultipleJoin();
    
    /**
     * Set the allowSortOnMultipleJoin property
     * @param allowSortOnMultipleJoin <code>true</code> to authorized sort on multiple join
     */
    public void setAllowSortOnMultipleJoin(boolean allowSortOnMultipleJoin);
    
    /**
     * If the column should be the default sorter 'ASC' or 'DESC'. Null otherwise. 
     * @return 'ASC', 'DESC' or null
     */
    public String getDefaultSorter();
    
    /**
     * Set the default sorter property
     * @param defaultSorter If the column should be a default sorter, 'ASC' for ascending 'DESC' for descending. Null otherwise.
     */
    public void setDefaultSorter(Optional<String> defaultSorter);
    
    /**
     * Get the JS class name for renderer
     * @return The renderer
     */
    public String getRenderer();
    
    /**
     * Set the JS class name for renderer
     * @param renderer The renderer
     */
    public void setRenderer(Optional<String> renderer);
    
    /**
     * Get the JS class name for converting field's value
     * @return The convert JS class name
     */
    public String getConverter();
    
    /**
     * Set the JS class name for converting field's value
     * @param converter The convert JS class name
     */
    public void setConverter(Optional<String> converter);
}
