/*
 *  Copyright 2013 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.search.ui.model;

import java.util.Map;

import org.ametys.cms.search.model.SearchCriterion;
import org.ametys.cms.search.model.SearchModel;
import org.ametys.runtime.i18n.I18nizableText;
import org.ametys.runtime.parameter.Validator;

/**
 * This class represents a search criterion of a {@link SearchModel}
 */
public interface SearchUICriterion extends SearchCriterion
{
    /**
     * Get the field identifier.
     * Used to match standard, advanced and faceted criterion (even if the operator is different), whatever their ID is.
     * @return the field identifier.
     */
    String getFieldId();
    
    /**
     * Get the group of the search criterion
     * @return <code>null</code> if the search criterion does not belong to any group, the name of the group otherwise
     */
    I18nizableText getGroup();
    
    /**
     * Get the JS class name to execute on 'init' event
     * @return the JS class name to execute on 'init' event
     */
    String getInitClassName();
    
    /**
     * Get the JS class name to execute on 'submit' event
     * @return the JS class name to execute on 'submit' event
     */
    String getSubmitClassName();
    
    /**
     * Get the JS class name to execute on 'change' event
     * @return the JS class name to execute on 'change' event
     */
    String getChangeClassName();
    
    /**
     * Determines if the criterion is hidden
     * @return <code>true</code> if the criterion is hidden
     */
    boolean isHidden();
    
    /**
     * Retrieves the widget to use for rendering.
     * @return the widget or <code>null</code> if none is defined.
     */
    String getWidget();
    
    /**
     * Get the widget's parameters
     * @return the widget's parameters
     */
    Map<String, I18nizableText> getWidgetParameters();
    
    /**
     * Retrieves the validator.
     * @return the validator or <code>null</code> if none is defined.
     */
    Validator getValidator();

    /**
     * Retrieves the default value.<br>
     * If the criterion is hidden, this represents a fixed value for the criterion.
     * @return the default value or <code>null</code> if none is defined.
     */
    Object getDefaultValue();
    
//    /**
//     * Get the fixed value of the criterion (in case of a hidden criterion).
//     * @return the fixed value of the criterion or <code>null</code> if none is defined.
//     */
//    Object getValue();
}
