/*
 *  Copyright 2023 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.search.ui.model.impl;

import java.util.Map;

import org.apache.avalon.framework.configuration.Configuration;
import org.apache.avalon.framework.configuration.ConfigurationException;

import org.ametys.cms.contenttype.MetadataType;
import org.ametys.cms.search.query.Query;
import org.ametys.cms.search.query.Query.Operator;

/**
 * Search criterion based on a solr query.
 * This criterion will always be hidden in the client and provide the query passed in configuration to the search factory.
 */
public class SolrFilterSearchUICriterion extends AbstractCustomSearchUICriterion
{
    private String _query;

    @Override
    public void configure(Configuration configuration) throws ConfigurationException
    {
        super.configure(configuration);
        _query = configuration.getChild("query").getValue();
        // The rendering of this criterion makes no sense.
        setHidden(true);
    }
    
    @Override
    public MetadataType getType()
    {
        // Just provide a random value here. This will have no impact whatsoever has the criterion must be hidden
        return MetadataType.STRING;
    }

    public String getFieldId()
    {
        // Here again, this shouldn't have any use
        return getId();
    }

    public Operator getOperator()
    {
        // Exists allow to always include the query in QueryBuilder
        return Operator.EXISTS;
    }

    public Query getQuery(Object value, Operator customOperator, Map<String, Object> allValues, String language, Map<String, Object> contextualParameters)
    {
        return () -> _query;
    }
}
