/*
 *  Copyright 2012 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.source;

import java.io.IOException;
import java.net.MalformedURLException;
import java.util.Map;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

import org.apache.avalon.framework.context.Context;
import org.apache.avalon.framework.context.ContextException;
import org.apache.avalon.framework.context.Contextualizable;
import org.apache.avalon.framework.logger.AbstractLogEnabled;
import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.avalon.framework.service.Serviceable;
import org.apache.cocoon.components.ContextHelper;
import org.apache.cocoon.environment.Request;
import org.apache.excalibur.source.Source;
import org.apache.excalibur.source.SourceFactory;

/**
 * This source factory defines an overridable way to retrieve resources (mainly XSL files).
 * Use: view://path_to_file
 */
public class ViewSourceFactory extends AbstractLogEnabled implements SourceFactory, Serviceable, Contextualizable
{
    private static final Pattern __SOURCE_PATTERN = Pattern.compile("^[\\w]+:([^:]+:)?//(.*)$");
    
    /** The view selector. */
    protected ViewSelector _viewSelector;
    /** The context */
    protected Context _context;
    
    @Override
    public void service(ServiceManager manager) throws ServiceException
    {
        _viewSelector = (ViewSelector) manager.lookup(ViewSelector.ROLE);
    }
    
    @Override
    public void contextualize(Context context) throws ContextException
    {
        _context = context;
    }
    
    @Override
    public Source getSource(String location, Map parameters) throws IOException, MalformedURLException
    {
        Matcher m = __SOURCE_PATTERN.matcher(location);
        if (!m.matches())
        {
            throw new MalformedURLException("URI must be like protocol://path/to/resource. Location was '" + location + "'");
        }
        
        Request request = ContextHelper.getRequest(_context);
        String pluginName = m.group(1);
        if (pluginName == null)
        {
            pluginName = (String) request.getAttribute("pluginName");
        }
        else
        {
            pluginName = pluginName.substring(0, pluginName.length() - 1);
        }
        
        String fileLocation = m.group(2);
        
        return _viewSelector.getSource(pluginName, fileLocation);
    }
    
    @Override
    public void release(Source source)
    {
        // Nothing to do.
    }

}
