/*
 *  Copyright 2022 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.tag;

import java.util.Map;

import org.apache.commons.lang.StringUtils;

import org.ametys.cms.color.AbstractColorsComponent;

/**
 * This class represent a CMS Tag
 */
public class ColorableCMSTag extends CMSTag implements ColorableTag
{
    private String _color;
    private AbstractColorsComponent _colorsComponent;

    /**
     * Constructor
     * @param cmsTag the CMS tag
     * @param color the color
     * @param colorsComponent the colors component
     */
    public ColorableCMSTag(CMSTag cmsTag, String color, AbstractColorsComponent colorsComponent)
    {
        super(cmsTag.getId(), cmsTag.getName(), cmsTag.getParent(), cmsTag.getTitle(), cmsTag.getDescription(), cmsTag.getVisibility(), cmsTag.getTarget());
        _color = color;
        _colorsComponent = colorsComponent;
    }
    
    @Override
    public String getColor(boolean withDefaultValue)
    {
        if (!withDefaultValue)
        {
            return _color;
        }
        
        Map<String, Map<String, String>> colors = _colorsComponent.getColors();
        if (StringUtils.isNotEmpty(_color) && colors.containsKey(_color))
        {
            return _color;
        }
        else
        {
            String color = _getParentColor((ColorableCMSTag) getParent());
            return StringUtils.isNotBlank(color) ? color : _colorsComponent.getDefaultKey();
        }
    }
    
    private String _getParentColor(ColorableCMSTag parentTag)
    {
        if (parentTag == null)
        {
            return null;
        }
        
        String color = parentTag.getColor(true);
        return StringUtils.isNotBlank(color) ? color : _getParentColor((ColorableCMSTag) parentTag.getParent());
    }
    
    @Override
    public AbstractColorsComponent getColorComponent()
    {
        return _colorsComponent;
    }
}
