/*
 *  Copyright 2022 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.tag;

import org.ametys.cms.color.AbstractColorsComponent;

/**
 * Interface for colorable Tag
 */
public interface ColorableTag extends Tag
{
    /**
     * Get the color index in the component palete
     * @param withDefaultValue <code>true</code> if we want to get first the color of the parent then the default value
     * @return the color. Can be null if withDefaultValue is <code>false</code>
     */
    public String getColor(boolean withDefaultValue);
    
    
    /**
     * Get the color component
     * @return the color component
     */
    public AbstractColorsComponent getColorComponent();
    
    /**
     * Get the color css class
     * @return the color css class
     */
    public default String getColorCSSClassPrefix()
    {
        return getColorComponent().getColorCSSClassPrefix();
    }
    
}
