/*
 *  Copyright 2018 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.tag;

import java.util.Collection;
import java.util.List;
import java.util.Map;

import org.ametys.runtime.i18n.I18nizableText;

/**
 * This interface represents a tag provider. <br>
 * @param <T> the tag class
 */
public interface TagProvider<T extends Tag>
{
    /**
     * Returns the provider's id.
     * @return the provider's id.
     */
    public String getId();
    
    /**
     * Returns the provider's label.
     * @return the provider's label.
     */
    public I18nizableText getLabel();
    
    /**
     * Returns the provider's description.
     * @return the provider's description.
     */
    public I18nizableText getDescription ();
    
    /**
     * Returns the provider's tags.
     * @param contextualParameters contextual parameters
     * @return the provider's tags.
     */
    public Map<String, T> getTags (Map<String, Object> contextualParameters);
    
    /**
     * Returns the provider's tag.
     * @param tagName The tag name
     * @param contextualParameters contextual parameters
     * @return the provider's tag.
     */
    public T getTag(String tagName, Map<String, Object> contextualParameters);
    
    /**
     * Returns the <strong>direct</strong> children of the provider's tag.
     * @param tagName The tag name
     * @param contextualParameters contextual parameters
     * @return the provider's tag.
     */
    public Collection<T> getTags(String tagName, Map<String, Object> contextualParameters);
    
    /**
     * Determines if the tag exists.
     * @param tagName The tag unique name
     * @param contextualParameters contextual parameters
     * @return true if the tag exists.
     */
    public boolean hasTag (String tagName, Map<String, Object> contextualParameters);
    
    /**
     * Get the list of CSS urls link to the provider
     * @param contextualParameters contextual parameters
     * @return the list of CSS urls
     */
    public List<String> getCSSUrls(Map<String, Object> contextualParameters);

}
