/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.tag;

import java.util.Set;

import org.ametys.runtime.plugin.component.AbstractThreadSafeComponentExtensionPoint;

/**
 * This class is in charge to load and initialize tag target types.
 */
public class TagTargetTypeExtensionPoint extends AbstractThreadSafeComponentExtensionPoint<TagTargetType>
{
    /** Avalon Role */
    public static final String ROLE = TagTargetTypeExtensionPoint.class.getName();
    
    /**
     * Get the target type corresponding to the given name
     * @param name The type's name
     * @return the target type or null if not found
     */
    public TagTargetType getTagTargetType(String name)
    {
        Set<String> extensionsIds = getExtensionsIds();
        
        for (String id : extensionsIds)
        {
            TagTargetType tagTargetType = getExtension(id);
            if (tagTargetType.getName().equals(name))
            {
                return tagTargetType;
            }
        }
        
        return null;
    }
}
