/*
 *  Copyright 2018 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.tag;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Set;

import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.commons.lang3.StringUtils;

import org.ametys.cms.tag.jcr.AbstractJCRTagsDAO;
import org.ametys.cms.tag.jcr.CMSJCRTagProvider;
import org.ametys.cms.tag.jcr.JCRTagsDAO;
import org.ametys.core.ui.Callable;

/**
 * DAO for manipulating tags
 *
 */
public class TagsDAO extends AbstractTagsDAO
{
    /** The Avalon role */
    public static final String ROLE = TagsDAO.class.getName();

    /** The attribute name for the target type */
    public static final String TARGET_TYPE_ATTRIBUTE_NAME = "target";
    
    /** Target types */
    protected TagTargetTypeExtensionPoint _targetTypeEP;
    
    /** The JCR tags DAO */
    protected JCRTagsDAO _jcrTagsDAO;
    
    @Override
    public void service(ServiceManager manager) throws ServiceException
    {
        super.service(manager);
        _targetTypeEP = (TagTargetTypeExtensionPoint) manager.lookup(TagTargetTypeExtensionPoint.ROLE);
        _jcrTagsDAO = (JCRTagsDAO) manager.lookup(JCRTagsDAO.ROLE);
    }
    
    @Override
    public String getTagProviderEPRole()
    {
        return TagProviderExtensionPoint.ROLE;
    }
    
    @Override
    protected AbstractJCRTagsDAO _getTagJCRDAO()
    {
        return _jcrTagsDAO;
    }
    
    /**
     * Get the existing target types
     * @return the target types
     */
    @Callable
    public List<Map<String, Object>> getTargetTypes ()
    {
        List<Map<String, Object>> targetTypes = new ArrayList<>();
        
        Set<String> ids = _targetTypeEP.getExtensionsIds();
        
        for (String id : ids)
        {
            TagTargetType type = _targetTypeEP.getExtension(id);
            
            Map<String, Object> type2json = new HashMap<>();
            type2json.put("name", type.getName());
            type2json.put("label", type.getLabel());
            type2json.put("description", type.getDescription());
            
            targetTypes.add(type2json);
        }
        
        return targetTypes;
    }
    
    @Override
    protected String _getFilteredTagName(TagProvider<? extends Tag> tagProvider, String tagName, Map<String, Object> otherParameters, Map<String, Object> contextualParameters)
    {
        String targetType = (String) otherParameters.get(TARGET_TYPE_ATTRIBUTE_NAME);
        if (StringUtils.isNotEmpty(targetType))
        {
            CMSTag tag = (CMSTag) tagProvider.getTag(tagName, contextualParameters);
            if (tag.getTarget().getName().equals(targetType))
            {
                return tagName;
            }
        }
        else
        {
            return tagName;
        }
        
        return null;
    }

    @Override
    protected List<TagProvider<? extends Tag>> getCustomTagProvider()
    {
        List<TagProvider<? extends Tag>> providers = new ArrayList<>();
        providers.add(_tagProviderExtPt.getExtension(CMSJCRTagProvider.class.getName()));
        
        return providers;
    }
}
