/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.tag.jcr;

import javax.jcr.Node;

import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;

import org.ametys.cms.tag.TagTargetTypeExtensionPoint;
import org.ametys.plugins.repository.AmetysObjectFactory;
import org.ametys.plugins.repository.AmetysRepositoryException;
import org.ametys.plugins.repository.RepositoryConstants;

/**
 * {@link AmetysObjectFactory} for creating {@link CMSJCRTag}.
 */
public class CMSTagFactory extends AbstractColorableCMSTagFactory
{
    /** JCR nodetype for resources collection */
    @SuppressWarnings("hiding")
    public static final String TAG_NODETYPE = RepositoryConstants.NAMESPACE_PREFIX + ":cmstag";
    
    /** The tag target type extension point */
    protected TagTargetTypeExtensionPoint _targetTypeEP;
    
    @Override
    public void service(ServiceManager manager) throws ServiceException
    {
        super.service(manager);
        _targetTypeEP = (TagTargetTypeExtensionPoint) manager.lookup(TagTargetTypeExtensionPoint.ROLE);
    }
    
    @Override
    public CMSJCRTag getAmetysObject(Node node, String parentPath) throws AmetysRepositoryException
    {
        return new CMSJCRTag(node, parentPath, this);
    }
    
    /**
     * Get the tag target type extension point
     * @return the tag target type extension point
     */
    public TagTargetTypeExtensionPoint getTagProviderEP()
    {
        return _targetTypeEP;
    }
}
