/*
 *  Copyright 2012 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.transformation;

import java.io.IOException;
import java.util.Map;

import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.cocoon.ProcessingException;
import org.apache.cocoon.environment.ObjectModelHelper;
import org.apache.cocoon.generation.ServiceableGenerator;
import org.apache.excalibur.xml.dom.DOMSerializer;
import org.w3c.dom.Document;
import org.xml.sax.SAXException;

/**
 * Generator to sax a DOM document.
 */
public class DOMGenerator extends ServiceableGenerator
{
    private DOMSerializer _domSerializer;
    
    @Override
    public void service(ServiceManager sManager) throws ServiceException
    {
        super.service(sManager);
        _domSerializer = (DOMSerializer) sManager.lookup(DOMSerializer.ROLE);
    }
    
    @Override
    public void generate() throws IOException, SAXException, ProcessingException
    {
        Map parentContextParameters = (Map) objectModel.get(ObjectModelHelper.PARENT_CONTEXT);
        if (parentContextParameters == null)
        {
            throw new ProcessingException("Missing parent context");
        }
        
        Document document = (Document) parentContextParameters.get("source");
        
        if (document == null)
        {
            throw new ProcessingException("Missing source parent context attr");
        }
        
        _domSerializer.serialize(document, contentHandler, lexicalHandler);
    }
}
