/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.transformation;

import java.io.IOException;
import java.util.Map;

import org.apache.avalon.framework.parameters.Parameters;
import org.apache.cocoon.ProcessingException;
import org.apache.cocoon.environment.SourceResolver;
import org.apache.cocoon.transformation.AbstractTransformer;
import org.xml.sax.Attributes;
import org.xml.sax.SAXException;
import org.xml.sax.helpers.AttributesImpl;

/**
 * Transformer "hierarchying" flat docbook input 
 */
public class HierarchizeTransformer extends AbstractTransformer
{
    /** Tag for section */
    public static final String TAG_SECTION = "section";
    
    /** Root tag */
    public static final String TAG_ARTICLE = "article";
    
    private int _level;

    public void setup(SourceResolver resolver, Map objectModel, String src, Parameters par) throws ProcessingException, SAXException, IOException
    {
        _level = 0;
    }

    @Override
    public void startElement(String uri, String localName, String qName, Attributes atts) throws SAXException
    {
        if (!TAG_SECTION.equals(localName))
        {
            contentHandler.startElement(uri, localName, qName, atts);
            return;
        }
        
        int currentLevel = Integer.parseInt(atts.getValue("level"));
        
        int previousLevel = _level;
        
        if (currentLevel == previousLevel)
        {
            contentHandler.endElement("", TAG_SECTION, TAG_SECTION);
        }
        else if (currentLevel > previousLevel)
        {
            for (int i = previousLevel + 1; i < currentLevel; i++)
            {
                AttributesImpl attrsSection = new AttributesImpl(atts);
                attrsSection.removeAttribute(attrsSection.getIndex("level"));
                
                contentHandler.startElement("", TAG_SECTION, TAG_SECTION, attrsSection);
                contentHandler.startElement("", "title", "title", new AttributesImpl());
                contentHandler.endElement("", "title", "title");
            }
        }
        else
        {
            for (int i = previousLevel; i >= currentLevel; i--)
            {
                contentHandler.endElement("", TAG_SECTION, TAG_SECTION);
            }
        }
               
        AttributesImpl attrsSection = new AttributesImpl(atts);
        attrsSection.removeAttribute(attrsSection.getIndex("level"));

        _level = currentLevel;
        contentHandler.startElement("", TAG_SECTION, TAG_SECTION, attrsSection);
    }
    
    @Override
    public void endElement(String uri, String localName, String qName) throws SAXException
    {
        if (TAG_ARTICLE.equals(localName))
        {
            int lastLevel = _level;
            
            for (int i = lastLevel; i > 0; i--)
            {
                contentHandler.endElement("", TAG_SECTION, TAG_SECTION);
            }
            
            contentHandler.endElement(uri, localName, qName);
        }
        else if (!TAG_SECTION.equals(localName))
        {
            contentHandler.endElement(uri, localName, qName);
            return;
        }
    }
}
