/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.transformation;

import java.io.IOException;

import org.xml.sax.ContentHandler;
import org.xml.sax.SAXException;

import org.ametys.cms.data.RichText;
import org.ametys.plugins.repository.AmetysRepositoryException;
import org.ametys.plugins.repository.metadata.ModifiableRichText;
import org.ametys.runtime.model.type.DataContext;

/**
 * Transform back and forth between a {@link String} and a {@link RichText}.
 */
public interface RichTextTransformer
{
    /**
     * Transform a {@link String} into a {@link ModifiableRichText}.
     * @param source the source.
     * @param dest the {@link ModifiableRichText} to populate.
     * @throws AmetysRepositoryException if an error occurs.
     * @throws IOException if an error occurs.
     * @deprecated use {@link #transform(String, RichText)} instead
     */
    @Deprecated
    void transform(String source, ModifiableRichText dest) throws AmetysRepositoryException, IOException;
    
    /**
     * Transform a {@link String} into a {@link RichText}.
     * @param source the source.
     * @param dest the {@link RichText} to populate.
     * @throws AmetysRepositoryException if an error occurs.
     * @throws IOException if an error occurs.
     */
    void transform (String source, RichText dest) throws AmetysRepositoryException, IOException;
    
    /**
     * Transform a {@link ModifiableRichText} into a {@link StringBuilder}.
     * @param source the source.
     * @param dest the {@link StringBuilder} to populate.
     * @throws AmetysRepositoryException if an error occurs.
     * @throws IOException if an error occurs.
     * @deprecated use {@link #transformForEditing(RichText, DataContext, StringBuilder)} instead
     */
    @Deprecated
    void transformForEditing(ModifiableRichText source, StringBuilder dest) throws AmetysRepositoryException, IOException;
    
    /**
     * Transform a {@link RichText} into a {@link StringBuilder}.
     * @param source the source.
     * @param dataContext the context of the rich text
     * @param dest the {@link StringBuilder} to populate.
     * @throws AmetysRepositoryException if an error occurs.
     * @throws IOException if an error occurs.
     */
    void transformForEditing(RichText source, DataContext dataContext, StringBuilder dest) throws AmetysRepositoryException, IOException;
    
    /**
     * SAXes a {@link org.ametys.plugins.repository.metadata.RichText} into a {@link ContentHandler} for rendering purposes.
     * @param source the source.
     * @param handler the {@link StringBuilder} to populate.
     * @throws AmetysRepositoryException if an error occurs.
     * @throws SAXException if an error occurs.
     * @throws IOException if an error occurs.
     * @deprecated use {@link #transformForRendering(RichText, ContentHandler)} instead
     */
    @Deprecated
    void transformForRendering(org.ametys.plugins.repository.metadata.RichText source, ContentHandler handler) throws AmetysRepositoryException, SAXException, IOException;
    
    /**
     * SAXes a {@link RichText} into a {@link ContentHandler} for rendering purposes.
     * @param source the source.
     * @param handler the {@link StringBuilder} to populate.
     * @throws AmetysRepositoryException if an error occurs.
     * @throws SAXException if an error occurs.
     * @throws IOException if an error occurs.
     */
    void transformForRendering(RichText source, ContentHandler handler) throws AmetysRepositoryException, SAXException, IOException;
}
