/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.transformation;

import java.util.HashMap;
import java.util.Map;

import org.ametys.runtime.plugin.component.AbstractThreadSafeComponentExtensionPoint;

/**
 * Extension point for {@link URIResolver}s.
 */
public class URIResolverExtensionPoint extends AbstractThreadSafeComponentExtensionPoint<URIResolver>
{
    /** Avalon Role */
    public static final String ROLE = URIResolverExtensionPoint.class.getName();

    private Map<String, URIResolver> _types = new HashMap<>();
    @Override
    public void initializeExtensions() throws Exception
    {
        super.initializeExtensions();
        
        for (String id : getExtensionsIds())
        {
            URIResolver resolver = getExtension(id);
            _types.put(resolver.getType(), resolver);
        }
    }
    
    /**
     * Returns the {@link URIResolver} corresponding to the given type.
     * @param type the type.
     * @return the {@link URIResolver} or <code>null</code> if not found.
     */
    public URIResolver getResolverForType(String type)
    {
        return _types.get(type);
    }
}
