/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.transformation;

import java.io.IOException;
import java.io.StringReader;
import java.util.Map;

import org.apache.avalon.framework.service.ServiceException;
import org.apache.cocoon.ProcessingException;
import org.apache.cocoon.environment.ObjectModelHelper;
import org.apache.cocoon.generation.Generator;
import org.apache.cocoon.generation.ServiceableGenerator;
import org.apache.excalibur.xml.sax.SAXParser;
import org.xml.sax.InputSource;
import org.xml.sax.SAXException;

/**
 * {@link Generator} which uses a string from parent context
 * and SAX it.
 * TODO use NekoHTML in case of an invalid XML input.
 */
public class XhtmlGenerator extends ServiceableGenerator
{
    public void generate() throws IOException, SAXException, ProcessingException
    {
        SAXParser parser = null;
        
        try
        {
            Map parentContextParameters = (Map) objectModel.get(ObjectModelHelper.PARENT_CONTEXT);
            
            if (parentContextParameters == null)
            {
                throw new ProcessingException("Missing parent context");
            }

            String xmlSource = (String) parentContextParameters.get("source");
            
            if (xmlSource == null)
            {
                throw new ProcessingException("Missing source parent context attr");
            }
            
            InputSource inputSource = new InputSource(new StringReader("<body>" + xmlSource + "</body>"));
            parser = (SAXParser) this.manager.lookup(SAXParser.ROLE);
            parser.parse(inputSource, super.xmlConsumer);
        }
        catch (ServiceException e)
        {
            throw new ProcessingException("Unable to get a SAX parser", e);
        }
        finally
        {
            this.manager.release(parser);
        }
    }
}
