/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.transformation.docbook;

/**
 * This class represent a enhancement to docbook 
 */
public class DocbookEnhancer
{
    private String _htmleditor2DocbookXSLT;
    private String _docbook2HTMLEditorXSLT;
    private String _docbook2outgoingReferencesXSLT;
    private String _docbook2HTMLXSLT;
    private String _docbook2HTMLHandler;
    private String _htmleditor2docbookHandler;
    private String _docbook2htmleditorHandler;
    
    /**
     * Create a docbook enhancer
     * @param pluginName The name of the plugin declaring the enhancer
     * @param htmleditor2DocbookXSLT The fullpath to the xslt file or relative to the current plugin
     * @param docbook2HTMLEditorXSLT The fullpath to the xslt file or relative to the current plugin
     * @param docbook2HTMLXSLT The fullpath to the xslt file or relative to the current plugin
     * @param docbook2outgoingReferencesXSLT The fullpath to the xslt file or relative to the current plugin
     * @param docbook2HTMLHandler The role of a component that implements EnhancementTransformer
     * @param htmleditor2DocbookHandler The role of a component that implements EnhancementTransformer
     * @param docbook2htmleditorHandler The role of a component that implements EnhancementTransformer
     */
    public DocbookEnhancer(String pluginName, String htmleditor2DocbookXSLT, String docbook2HTMLEditorXSLT, String docbook2HTMLXSLT, String docbook2outgoingReferencesXSLT, String docbook2HTMLHandler, String htmleditor2DocbookHandler, String docbook2htmleditorHandler)
    {
        if (htmleditor2DocbookXSLT != null && htmleditor2DocbookXSLT.indexOf("://") == -1 && !htmleditor2DocbookXSLT.startsWith("/"))
        {
            _htmleditor2DocbookXSLT = "plugin:" + pluginName + "://" + htmleditor2DocbookXSLT;
        }
        else
        {
            _htmleditor2DocbookXSLT = htmleditor2DocbookXSLT;
        }

        if (docbook2HTMLEditorXSLT != null && docbook2HTMLEditorXSLT.indexOf("://") == -1 && !docbook2HTMLEditorXSLT.startsWith("/"))
        {
            _docbook2HTMLEditorXSLT = "plugin:" + pluginName + "://" + docbook2HTMLEditorXSLT;
        }
        else
        {
            _docbook2HTMLEditorXSLT = docbook2HTMLEditorXSLT;
        }

        if (docbook2HTMLXSLT != null && docbook2HTMLXSLT.indexOf("://") == -1 && !docbook2HTMLXSLT.startsWith("/"))
        {
            _docbook2HTMLXSLT = "plugin:" + pluginName + "://" + docbook2HTMLXSLT;
        }
        else
        {
            _docbook2HTMLXSLT = docbook2HTMLXSLT;
        }
        
        if (docbook2outgoingReferencesXSLT != null && docbook2outgoingReferencesXSLT.indexOf("://") == -1 && !docbook2outgoingReferencesXSLT.startsWith("/"))
        {
            _docbook2outgoingReferencesXSLT = "plugin:" + pluginName + "://" + docbook2outgoingReferencesXSLT;
        }
        else
        {
            _docbook2outgoingReferencesXSLT = docbook2outgoingReferencesXSLT;
        }
        
        _docbook2HTMLHandler = docbook2HTMLHandler;
        _htmleditor2docbookHandler = htmleditor2DocbookHandler;
        _docbook2htmleditorHandler = docbook2htmleditorHandler;
    }
    
    /**
     * Get the xslt to use when transforming from htmleditor to docbook
     * @return The fullpath to a xslt file
     */
    public String getHTMLEditor2DocbookXSLT()
    {
        return _htmleditor2DocbookXSLT;
    }

    /**
     * Get the xslt to use when transforming from docbook to htmleditor 
     * @return The fullpath to a xslt file
     */
    public String getDocbook2HTMLEditorXSLT()
    {
        return _docbook2HTMLEditorXSLT;
    }

    /**
     * Get the xslt to use when transforming from docbook to html
     * @return The fullpath to a xslt file
     */
    public String getDocbook2HTMLXSLT()
    {
        return _docbook2HTMLXSLT;
    }
    
    /**
     * Get the xslt to use when transforming from docbook to html
     * @return The fullpath to a xslt file
     */
    public String getDocbook2outgoingReferencesXSLT()
    {
        return _docbook2outgoingReferencesXSLT;
    }
    
    /**
     * Get the component role to use when transforming from docbook to html
     * @return The component role
     */
    public String getDocbook2HTMLHandler()
    {
        return _docbook2HTMLHandler;
    }

    /**
     * Get the component role to use when transforming from htmleditor to docbook
     * @return The component role
     */
    public String getHTMLEditor2DocbookHandler()
    {
        return _htmleditor2docbookHandler;
    }

    /**
     * Get the component role to use when transforming from docbook to htmleditor
     * @return The component role
     */
    public String getDocbook2HTMLEditorHandler()
    {
        return _docbook2htmleditorHandler;
    }
}
