/*
 *  Copyright 2011 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

package org.ametys.cms.transformation.dom;

import java.util.HashMap;
import java.util.Map;

import org.w3c.dom.Node;

import org.ametys.core.util.dom.AbstractWrappingAmetysElement;
import org.ametys.core.util.dom.AmetysAttribute;

/**
 * DOM element representing a tag.
 */
public class TagElement extends AbstractWrappingAmetysElement<String>
{
    /**
     * Constructor.
     * @param name the tag name.
     */
    public TagElement(String name)
    {
        super(name);
    }

    @Override
    public String getTagName()
    {
        return "tag";
    }
    
    @Override
    protected Map<String, AmetysAttribute> _lookupAttributes()
    {
        Map<String, AmetysAttribute> result = new HashMap<>();
        
        result.put("name", new AmetysAttribute("name", "name", null, _object, this));
        
        return result;
    }
    
    @Override
    public boolean hasChildNodes()
    {
        return false;
    }
    
    @Override
    public Node getFirstChild()
    {
        return null;
    }
    
    @Override
    public Node getNextSibling()
    {
        return null;
    }
}
