/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.transformation.html;

import java.io.ByteArrayInputStream;
import java.io.IOException;
import java.io.InputStream;

import org.apache.excalibur.source.Source;
import org.apache.excalibur.source.SourceNotFoundException;
import org.apache.excalibur.source.SourceValidity;
import org.apache.excalibur.source.impl.validity.NOPValidity;

/**
 * Source based upon a string
 */
public class HTMLEnhancementSource implements Source
{
    private String _content;
    private String _location;
    
    /**
     * Build a source
     * @param location The source location
     * @param content The source content
     */
    public HTMLEnhancementSource(String location, String content)
    {
        _content = content;
        _location = location;
    }
    
    @Override
    public boolean exists()
    {
        return true;
    }

    @Override
    public long getContentLength()
    {
        return _content.length();
    }

    @Override
    public InputStream getInputStream() throws IOException, SourceNotFoundException
    {
        byte[] contentAsBytes = _content.getBytes("UTF-8");
        InputStream is = new ByteArrayInputStream(contentAsBytes);
        return is;
    }

    @Override
    public long getLastModified()
    {
        return -1;
    }

    @Override
    public String getMimeType()
    {
        return "text/xml";
    }

    @Override
    public String getScheme()
    {
        return _location.substring(0, _location.indexOf(":"));
    }

    @Override
    public String getURI()
    {
        return _location;
    }

    @Override
    public SourceValidity getValidity()
    {
        return new NOPValidity();
    }

    @Override
    public void refresh()
    {
        // empty
    }

}
