/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.transformation.html;

/**
 * This class represent a enhancement to html 
 */
public class HTMLEnhancer
{
    private String _htmleditor2HtmlXSLT;
    private String _html2HTMLEditorXSLT;
    private String _html2HTMLXSLT;
    private String _html2outgoingReferencesXSLT;
    private String _html2HTMLHandler;
    private String _htmleditor2HTMLHandler;
    private String _html2HTMLEditorHandler;
    
    /**
     * Create a HTML enhancer
     * @param pluginName The name of the plugin declaring the enhancer
     * @param htmleditor2HtmlXSLT The fullpath to the xslt file or relative to the current plugin
     * @param html2HTMLEditorXSLT The fullpath to the xslt file or relative to the current plugin
     * @param html2HTMLXSLT The fullpath to the xslt file or relative to the current plugin
     * @param html2outgoingReferencesXSLT The fullpath to the xslt file or relative to the current plugin
     * @param html2HTMLHandler The role of a component that implements EnhancementHandler
     * @param htmleditor2HTMLHandler The role of a component that implements HTMLEditionHandler
     * @param html2HTMLEditorHandler The role of a component that implements HTMLEditionHandler
     */
    public HTMLEnhancer(String pluginName, String htmleditor2HtmlXSLT, String html2HTMLEditorXSLT, String html2HTMLXSLT, String html2outgoingReferencesXSLT, String html2HTMLHandler, String htmleditor2HTMLHandler, String html2HTMLEditorHandler)
    {
        if (htmleditor2HtmlXSLT != null && htmleditor2HtmlXSLT.indexOf("://") == -1 && !htmleditor2HtmlXSLT.startsWith("/"))
        {
            _htmleditor2HtmlXSLT = "plugin:" + pluginName + "://" + htmleditor2HtmlXSLT;
        }
        else
        {
            _htmleditor2HtmlXSLT = htmleditor2HtmlXSLT;
        }

        if (html2HTMLEditorXSLT != null && html2HTMLEditorXSLT.indexOf("://") == -1 && !html2HTMLEditorXSLT.startsWith("/"))
        {
            _html2HTMLEditorXSLT = "plugin:" + pluginName + "://" + html2HTMLEditorXSLT;
        }
        else
        {
            _html2HTMLEditorXSLT = html2HTMLEditorXSLT;
        }

        if (html2HTMLXSLT != null && html2HTMLXSLT.indexOf("://") == -1 && !html2HTMLXSLT.startsWith("/"))
        {
            _html2HTMLXSLT = "plugin:" + pluginName + "://" + html2HTMLXSLT;
        }
        else
        {
            _html2HTMLXSLT = html2HTMLXSLT;
        }
        
        if (html2outgoingReferencesXSLT != null && html2outgoingReferencesXSLT.indexOf("://") == -1 && !html2outgoingReferencesXSLT.startsWith("/"))
        {
            _html2outgoingReferencesXSLT = "plugin:" + pluginName + "://" + html2outgoingReferencesXSLT;
        }
        else
        {
            _html2outgoingReferencesXSLT = html2outgoingReferencesXSLT;
        }
        
        _html2HTMLHandler = html2HTMLHandler;
        _htmleditor2HTMLHandler = htmleditor2HTMLHandler;
        _html2HTMLEditorHandler = html2HTMLEditorHandler;
    }
    
    /**
     * Get the xslt to use when transforming from htmleditor to html
     * @return The fullpath to a xslt file
     */
    public String getHTMLEditor2HtmlX()
    {
        return _htmleditor2HtmlXSLT;
    }

    /**
     * Get the xslt to use when transforming from html to htmleditor 
     * @return The fullpath to a xslt file
     */
    public String getHtml2HTMLEditorXSLT()
    {
        return _html2HTMLEditorXSLT;
    }

    /**
     * Get the xslt to use when transforming from html to outgoing references 
     * @return The fullpath to a xslt file
     */
    public String getHtml2outgoingReferencesXSLT()
    {
        return _html2outgoingReferencesXSLT;
    }

    /**
     * Get the xslt to use when transforming from html to html
     * @return The fullpath to a xslt file
     */
    public String getHtml2HTMLXSLT()
    {
        return _html2HTMLXSLT;
    }
    
    /**
     * Get the component role to use when transforming from html to html
     * @return The component role
     */
    public String getHtml2HTMLHandler()
    {
        return _html2HTMLHandler;
    }

    /**
     * Get the component role to use when transforming from htmleditor to html
     * @return The component role
     */
    public String getHtmleditor2HTMLHandler()
    {
        return _htmleditor2HTMLHandler;
    }

    /**
     * Get the component role to use when transforming from html to htmleditor
     * @return The component role
     */
    public String getHtml2HTMLEditorHandler()
    {
        return _html2HTMLEditorHandler;
    }
}
