/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.transformation.htmledition;

import java.io.IOException;
import java.util.Map;

import org.apache.avalon.excalibur.pool.Recyclable;
import org.apache.avalon.framework.parameters.Parameters;
import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.avalon.framework.service.Serviceable;
import org.apache.cocoon.ProcessingException;
import org.apache.cocoon.environment.SourceResolver;
import org.apache.cocoon.transformation.Transformer;
import org.apache.cocoon.xml.XMLConsumer;
import org.xml.sax.Attributes;
import org.xml.sax.ContentHandler;
import org.xml.sax.Locator;
import org.xml.sax.SAXException;
import org.xml.sax.ext.LexicalHandler;

import org.ametys.cms.transformation.docbook.DocbookEnhancementExtensionPoint;

/**
 * This cocoon transformer use the DocbookEnhancementExtensionPoint to be based upon a serie of EnhancementHandler
 */
public class HTMLEditorHandlers2DocbookTransformer implements Transformer, Serviceable, Recyclable
{
    /** The service manager */
    protected ServiceManager _manager;
    /** The content handler */
    protected ContentHandler _contentHandler;
    /** The lexical handler */
    protected LexicalHandler _lexicalHandler;
    /** The htmledition extension point */
    protected HTMLEditionHandlerExtensionPoint _htmlEditionExtensionPoint;
    /** The docbook enhancement extension point */
    protected DocbookEnhancementExtensionPoint _docbookEnhancementExtensionPoint;
    
    @Override
    public void recycle()
    {
        _contentHandler = null;
        _lexicalHandler = null;
    }
    
    @Override
    public void setConsumer(XMLConsumer consumer)
    {
        _contentHandler = consumer;
        _lexicalHandler = consumer;
        
        for (String handlerRole : _docbookEnhancementExtensionPoint.getHTMLEditor2DocbookHandlers())
        {
            AbstractHTMLEditionHandler handler = _htmlEditionExtensionPoint.getExtension(handlerRole);
            
            handler.setContentHandler(_contentHandler);
            _contentHandler = handler;
            
            handler.setLexicalHandler(_lexicalHandler);
            _lexicalHandler = handler;
        }
    }

    public void service(ServiceManager manager) throws ServiceException
    {
        _manager = manager;
        _htmlEditionExtensionPoint = (HTMLEditionHandlerExtensionPoint) manager.lookup(HTMLEditionHandlerExtensionPoint.ROLE);
        _docbookEnhancementExtensionPoint = (DocbookEnhancementExtensionPoint) manager.lookup(DocbookEnhancementExtensionPoint.ROLE);
    }

    @Override
    public void setup(SourceResolver resolver, Map objectModel, String src, Parameters par) throws ProcessingException, SAXException, IOException
    {
        // empty
    }

    @Override
    public void startDocument() throws SAXException
    {
        _contentHandler.startDocument();
    }
    @Override
    public void endDocument() throws SAXException
    {
        _contentHandler.endDocument();
    }

    @Override
    public void startElement(String uri, String localName, String qName, Attributes atts) throws SAXException
    {
        _contentHandler.startElement(uri, localName, qName, atts);
    }
    @Override
    public void endElement(String uri, String localName, String qName) throws SAXException
    {
        _contentHandler.endElement(uri, localName, qName);
    }

    @Override
    public void characters(char[] ch, int start, int length) throws SAXException
    {
        _contentHandler.characters(ch, start, length);
    }
    @Override
    public void ignorableWhitespace(char[] ch, int start, int length) throws SAXException
    {
        _contentHandler.ignorableWhitespace(ch, start, length);
    }

    @Override
    public void startPrefixMapping(String prefix, String uri) throws SAXException
    {
        _contentHandler.startPrefixMapping(prefix, uri);
    }
    @Override
    public void endPrefixMapping(String prefix) throws SAXException
    {
        _contentHandler.endPrefixMapping(prefix);
    }

    @Override
    public void processingInstruction(String target, String data) throws SAXException
    {
        _contentHandler.processingInstruction(target, data);
    }

    @Override
    public void setDocumentLocator(Locator locator)
    {
        _contentHandler.setDocumentLocator(locator);
    }

    @Override
    public void skippedEntity(String name) throws SAXException
    {
        _contentHandler.skippedEntity(name);
    }

    @Override
    public void comment(char[] ch, int start, int length) throws SAXException
    {
        _lexicalHandler.comment(ch, start, length);
    }

    @Override
    public void startCDATA() throws SAXException
    {
        _lexicalHandler.startCDATA();
    }
    @Override
    public void endCDATA() throws SAXException
    {
        _lexicalHandler.endCDATA();
    }

    @Override
    public void startDTD(String name, String publicId, String systemId) throws SAXException
    {
        _lexicalHandler.startDTD(name, publicId, systemId);
    }
    @Override
    public void endDTD() throws SAXException
    {
        _lexicalHandler.endDTD();
    }

    @Override
    public void startEntity(String name) throws SAXException
    {
        _lexicalHandler.startEntity(name);
    }
    @Override
    public void endEntity(String name) throws SAXException
    {
        _lexicalHandler.endEntity(name);
    }
}
