/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.transformation.xslt;

import java.util.regex.Matcher;
import java.util.regex.Pattern;

/**
 * This class provides a helper for the in-line editor
 */
public final class InlineEditorHelper
{
    private InlineEditorHelper()
    {
        // empty
    }
    
    /**
     * Retrieves the value of a CSS property in the given HTML element style attribute
     * @param style The value of the HTML element style attribute (for example : "text-align:center; float:left; color: #000;")
     * @param parameter The CSS property ("text-align", "float", "color", ...)
     * @return the value of the given CSS property or empty String if not found
     */
    public static String getStyleValue(String style, String parameter)
    {
        return getStyleValue(style, parameter, "");
    }

    /**
     * Retrieves the value of a CSS property in the given HTML element style attribute
     * @param style The value of the HTML element style attribute (for example : "text-align:center; float:left; color: #000;")
     * @param parameter The CSS property ("text-align", "float", "color", ...)
     * @param defaultValue The default value return if style is empty
     * @return the value of the given CSS property or empty String if not found
     */
    public static String getStyleValue(String style, String parameter, String defaultValue)
    {
        if (style == null || "".equals(style))
        {
            return defaultValue;
        }
        
        Pattern pattern = Pattern.compile(parameter + "\\s*:\\s*([^;]*)");
        Matcher matcher = pattern.matcher(style);
        
        if (matcher.find())
        {
            String result = matcher.group(1);
            return result == null ? defaultValue : result.trim();
        }
        else
        {
            return defaultValue;
        }
    }
}
