/*
 *  Copyright 2019 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.user;

import java.util.Map;

import org.apache.avalon.framework.parameters.Parameters;
import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.cocoon.acting.ServiceableAction;
import org.apache.cocoon.environment.ObjectModelHelper;
import org.apache.cocoon.environment.Redirector;
import org.apache.cocoon.environment.Request;
import org.apache.cocoon.environment.SourceResolver;

import org.ametys.core.cocoon.JSonReader;
import org.ametys.core.user.CurrentUserProvider;
import org.ametys.core.user.UserIdentity;
import org.ametys.plugins.core.user.UserHelper;

/**
 * Get the current user to JSON format
 *
 */
public class GetCurrentUserAction extends ServiceableAction
{
    private UserHelper _userHelper;
    private CurrentUserProvider _userProvider;

    @Override
    public void service(ServiceManager smanager) throws ServiceException
    {
        _userProvider = (CurrentUserProvider) smanager.lookup(CurrentUserProvider.ROLE);
        _userHelper = (UserHelper) smanager.lookup(UserHelper.ROLE);
    }
    
    public Map act(Redirector redirector, SourceResolver resolver, Map objectModel, String source, Parameters parameters) throws Exception
    {
        UserIdentity currentUser = _userProvider.getUser();
        
        if (currentUser != null)
        {
            Map<String, Object> user2json = _userHelper.user2json(currentUser, true);
            
            Request request = ObjectModelHelper.getRequest(objectModel);
            request.setAttribute(JSonReader.OBJECT_TO_READ, user2json);
        }
        
        return EMPTY_MAP;
    }

}
