/*
 *  Copyright 2020 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.welcome;

import java.util.HashMap;
import java.util.Map;

import org.apache.avalon.framework.parameters.Parameters;
import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.cocoon.acting.ServiceableAction;
import org.apache.cocoon.environment.ObjectModelHelper;
import org.apache.cocoon.environment.Redirector;
import org.apache.cocoon.environment.Request;
import org.apache.cocoon.environment.SourceResolver;

/**
 * Action to get the XSLT file for welcome tool text
 */
public class WelcomeAction extends ServiceableAction
{
    /** The key for rendering  language */
    public static final String RESULT_RENDERINGLANGUAGE = "renderingLanguage";
    
    /** Welcome helper */
    protected WelcomeHelper _welcomeHelper;
    
    @Override
    public void service(ServiceManager smanager) throws ServiceException
    {
        super.service(smanager);
        _welcomeHelper = (WelcomeHelper) smanager.lookup(WelcomeHelper.ROLE);
    }
    
    public Map act(Redirector redirector, SourceResolver resolver, Map objectModel, String source, Parameters parameters) throws Exception
    {
        String language = parameters.getParameter("language", "");
        
        Request request = ObjectModelHelper.getRequest(objectModel);
        request.setAttribute(RESULT_RENDERINGLANGUAGE, language);
        
        String xsltPath = _welcomeHelper.getXsltPath(parameters);
        
        Map<String, Object> result = new HashMap<>();
        result.put("xsltPath", xsltPath);
        return result;
    }
    

}
