/*
 *  Copyright 2020 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.welcome;

import java.util.Collections;
import java.util.List;
import java.util.Map;

import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.commons.lang3.StringUtils;

import org.ametys.core.ui.ClientSideElement;
import org.ametys.core.ui.StaticClientSideElement;

/**
 * {@link ClientSideElement} for the welcome button tool.
 * If there is no XSLT file for welcome tool text, the button is not present.
 */
public class WelcomeButtonClientSideElement extends StaticClientSideElement
{
    /** Welcome helper */
    protected WelcomeHelper _welcomeHelper;
    
    @Override
    public void service(ServiceManager smanager) throws ServiceException
    {
        super.service(smanager);
        _welcomeHelper = (WelcomeHelper) smanager.lookup(WelcomeHelper.ROLE);
    }
    
    @Override
    public List<Script> getScripts(boolean ignoreRights, Map<String, Object> contextParameters)
    {
        String xsltPath = _welcomeHelper.getXsltPath(contextParameters);
        if (StringUtils.isNotBlank(xsltPath))
        {
            return super.getScripts(ignoreRights, contextParameters);
        }
        else
        {
            // No available XSLT file
            return Collections.EMPTY_LIST;
        }
        
    }
}
