/*
 *  Copyright 2020 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.welcome;

import java.io.IOException;
import java.util.HashMap;
import java.util.Map;

import org.apache.avalon.framework.component.Component;
import org.apache.avalon.framework.parameters.Parameters;
import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.avalon.framework.service.Serviceable;
import org.apache.excalibur.source.SourceResolver;

import org.ametys.runtime.plugin.component.AbstractLogEnabled;

/**
 * Helper for the welcome button / tool / page
 */
public class WelcomeHelper extends AbstractLogEnabled implements Serviceable, Component
{
    /** The Avalon role */
    public static final String ROLE = WelcomeHelper.class.getName();
    
    /** Root path for che welcome folder */
    private static final String __WELCOME_DIRECTORY_ROOT_PATH = "context://WEB-INF/param/welcome/";
    
    /** Source Resolver */
    protected SourceResolver _resolver;
    
    public void service(ServiceManager manager) throws ServiceException
    {
        _resolver = (SourceResolver) manager.lookup(SourceResolver.ROLE);
    }
    
    /**
     * Get the path of XSLT file for the welcome tool or null if not found
     * @param parameters the sitemap parameters
     * @return the XSLT file path or null if not found
     */
    public String getXsltPath(Parameters parameters)
    {
        Map<String, Object> map = new HashMap<>();
        for (String name : parameters.getNames())
        {
            map.put(name, parameters.getParameter(name, ""));
        }
        return getXsltPath(map);
    }
    
    /**
     * Get the path of XSLT file for the welcome tool or null if not found
     * @param contextualParameters the contextual parameters
     * @return the XSLT file path or null if not found
     */
    public String getXsltPath(Map<String, Object> contextualParameters)
    {
        String language = (String) contextualParameters.get("language");
        
        String languagePath = __WELCOME_DIRECTORY_ROOT_PATH + "index_" + language + ".xsl";

        try
        {
            if (_resolver.resolveURI(languagePath).exists())
            {
                return languagePath;
            }
            else if (_resolver.resolveURI(__WELCOME_DIRECTORY_ROOT_PATH + "index.xsl").exists())
            {
                return __WELCOME_DIRECTORY_ROOT_PATH + "index.xsl";
            }
        }
        catch (IOException e)
        {
            getLogger().warn("Unable to retrieve XSLT file for welcome tool", e);
        }
        
        return null;
    }
}
