/*
 *  Copyright 2020 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.welcome;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.commons.lang3.StringUtils;

import org.ametys.core.ui.ClientSideElementHelper;
import org.ametys.core.ui.StaticClientSideElement;

/**
 * A StaticClientSideElement that override getScript to return canDisplayWelcomeTool to true/false if something can be displayed in the welcome tool
 */
public class WelcomeToolClientSideElement extends StaticClientSideElement
{
    /** Welcome helper */
    protected WelcomeHelper _welcomeHelper;
    
    @Override
    public void service(ServiceManager smanager) throws ServiceException
    {
        super.service(smanager);
        _welcomeHelper = (WelcomeHelper) smanager.lookup(WelcomeHelper.ROLE);
    }
    
    @Override
    public List<Script> getScripts(boolean ignoreRights, Map<String, Object> contextParameters)
    {
        List<Script> scripts = super.getScripts(ignoreRights, contextParameters);
        List<Script> clonedScripts = new ArrayList<>();
        
        String xsltPath = _welcomeHelper.getXsltPath(contextParameters);
        boolean canDisplayWelcomeTool = StringUtils.isNotBlank(xsltPath);
        
        for (Script script : scripts)
        {
            Script scriptClone = ClientSideElementHelper.cloneScript(script);

            scriptClone.getParameters().put("canDisplayWelcomeTool", canDisplayWelcomeTool);
            clonedScripts.add(scriptClone);
        }
        
        return clonedScripts;
    }
}
