/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.workflow;

import java.util.Map;

import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;

import org.ametys.cms.content.ContentHelper;
import org.ametys.cms.repository.Content;
import org.ametys.cms.repository.WorkflowAwareContent;
import org.ametys.plugins.workflow.AbstractWorkflowComponent;

import com.opensymphony.workflow.WorkflowException;

/**
 * Abstract class for easily retrieving environment components
 * in a condition or a function and especially a content.
 */
public abstract class AbstractContentWorkflowComponent extends AbstractWorkflowComponent
{
    /** Constant for storing the content into the transient variables map. */
    public static final String CONTENT_KEY = Content.class.getName();
    
    /** Constant for storing the content's state (has changed or not) into the transient varaibles map. */
    public static final String HAS_CHANGED_KEY = "content.has.changed";

    /** The content helper */
    protected ContentHelper _contentHelper;
    
    @Override
    public void service(ServiceManager smanager) throws ServiceException
    {
        super.service(smanager);
        _contentHelper = (ContentHelper) smanager.lookup(ContentHelper.ROLE);
    }
    /**
     * Retrieve the content associated with the workflow.
     * @param transientVars the parameters from the call.
     * @return the content.
     * @throws WorkflowException if the content is not found.
     */
    protected WorkflowAwareContent getContent(Map transientVars) throws WorkflowException
    {
        WorkflowAwareContent content = (WorkflowAwareContent) transientVars.get(CONTENT_KEY);
        
        if (content == null)
        {
            throw new WorkflowException("Unable to retrieve content");
        }
        
        // Found in transient variables map
        return content;
    }
}
