/*
 *  Copyright 2011 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.workflow;

import java.util.LinkedHashMap;
import java.util.Map;

import org.ametys.runtime.parameter.Errors;

/**
 * Object for storing binding and validation errors.
 */
public class AllErrors
{
    private Map<String, Errors> _allErrors = new LinkedHashMap<>();
    
    /**
     * Test if there is at least one error.
     * @return <code>true</code> if there is at least one error,
     *         <code>false</code> otherwise.
     */
    public boolean hasErrors()
    {
        return !_allErrors.isEmpty();
    }
    
    /**
     * Retrieves the errors.
     * @return the errors.
     */
    public Map<String, Errors> getAllErrors()
    {
        return _allErrors;
    }
    
    /**
     * Add an error.
     * @param metadataPath the metadata path or <code>null</code>
     *        if global to the content.
     * @param errors the errors.
     */
    public void addError(String metadataPath, Errors errors)
    {
        _allErrors.put(metadataPath, errors);
    }
    
    @Override
    public String toString()
    {
        return _allErrors.toString();
    }
}
