/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.workflow;

import java.util.List;
import java.util.Map;

import org.ametys.plugins.workflow.EnhancedFunction;
import org.ametys.plugins.workflow.store.AmetysStep;
import org.ametys.plugins.workflow.support.WorkflowHelper.WorkflowVisibility;
import org.ametys.runtime.i18n.I18nizableText;

import com.opensymphony.module.propertyset.PropertySet;
import com.opensymphony.workflow.WorkflowException;

/**
 * Function setting the user comment into the step before it's stored.
 */
public class CommentStepFunction implements EnhancedFunction
{
    @Override
    public void execute(Map transientVars, Map args, PropertySet ps) throws WorkflowException
    {
        String comment = (String) transientVars.get("comment");
        
        if (comment != null && comment.length() > 0)
        {
            AmetysStep step = (AmetysStep) ((List) transientVars.get("currentSteps")).get(0);
            
            step.setProperty("comment", comment);
        }
    }
    
    @Override
    public FunctionType getFunctionExecType()
    {
        return FunctionType.POST;
    }

    @Override
    public I18nizableText getLabel()
    {
        return new I18nizableText("plugin.cms", "PLUGINS_CMS_COMMENT_STEP_FUNCTION_LABEL");
    }
    
    @Override
    public List<WorkflowVisibility> getVisibilities()
    {
        List<WorkflowVisibility> visibilities = EnhancedFunction.super.getVisibilities();
        visibilities.add(WorkflowVisibility.USER);
        return visibilities;
    }
}
