/*
 *  Copyright 2021 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.workflow;

import org.ametys.cms.repository.Content;
import org.ametys.runtime.authentication.AccessDeniedException;
import org.ametys.runtime.model.ModelItem;

/**
 * Exception representing an error while editing a content.
 */
public class EditContentAccessDeniedException extends AccessDeniedException
{
    private Content _content;
    private ModelItem _modelItem;
    
    /**
     * Constructs a new {@link EditContentAccessDeniedException}. Message is automatically built.
     * @param content the content on which the exception occurs
     * @param modelItem the model item on which the exception occurs
     */
    public EditContentAccessDeniedException(Content content, ModelItem modelItem)
    {
        super("The current user has no right to edit attribute " + modelItem.getPath() + " on the content " + content.toString());
        _content = content;
        _modelItem = modelItem;
    }
    
    /**
     * Get the content which the exception appears on.
     * @return the content
     */
    public Content getContent()
    {
        return _content;
    }
    
    /**
     * Get the model item which the exception appears on.
     * @return the model item
     */
    public ModelItem getModelItem()
    {
        return _modelItem;
    }
}
