/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.workflow;

import java.util.Map;

import org.apache.commons.lang.ArrayUtils;

import org.ametys.cms.CmsConstants;
import org.ametys.plugins.repository.version.VersionableAmetysObject;
import org.ametys.plugins.workflow.EnhancedCondition;
import org.ametys.runtime.i18n.I18nizableText;

import com.opensymphony.module.propertyset.PropertySet;
import com.opensymphony.workflow.WorkflowException;

/**
 * OSWorkflow condition for testing if a content has been published.
 */
public class HasLiveLabelCondition extends AbstractContentWorkflowComponent implements EnhancedCondition
{
    public boolean passesCondition(Map transientVars, Map args, PropertySet ps) throws WorkflowException
    {
        VersionableAmetysObject versionableContent = (VersionableAmetysObject) getContent(transientVars);
         
        if (ArrayUtils.contains(versionableContent.getAllLabels(), CmsConstants.LIVE_LABEL))
        {
            return true;
        }
         
        return false;
    }

    @Override
    public I18nizableText getLabel()
    {
        return new I18nizableText("plugin.cms", "PLUGINS_CMS_HAS_LIVE_LABEL_CONDITION_LABEL");
    }
}
