/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.workflow;

import com.opensymphony.workflow.FunctionProvider;
import com.opensymphony.workflow.WorkflowException;

/**
 * {@link WorkflowException} which can be thrown in a {@link FunctionProvider}
 * if the input is invalid.<p>
 * <b>This is an validation error which will be handled in a special manner.</b>
 */
public class InvalidInputWorkflowException extends WorkflowException
{
    private final AllErrors _allErrors;
    
    /**
     * Constructs a new  invalid input workflow exception with the specified
     * detail message.
     * @param allErrors The initial errors
     * @param message The detail message. 
     */
    public InvalidInputWorkflowException(String message, AllErrors allErrors)
    {
        super(message);
        _allErrors = allErrors;
    }
    
    /**
     * Constructs a new  invalid input workflow exception with the specified
     * detail message and cause.
     * @param message The detail message.
     * @param allErrors The initial errors
     * @param cause The cause.
     */
    public InvalidInputWorkflowException(String message, AllErrors allErrors, Throwable cause)
    {
        super(message, cause);
        _allErrors = allErrors;
    }
    
    /**
     * Constructs a new invalid input workflow exception with the specified
     * cause.
     * @param allErrors The initial errors
     * @param cause The cause.
     */
    public InvalidInputWorkflowException(AllErrors allErrors, Throwable cause)
    {
        super(cause);
        _allErrors = allErrors;
    }
    
    /**
     * Get the errors that initiate the exception
     * @return The errors
     */
    public AllErrors getErrors()
    {
        return _allErrors;
    }
}
