/*
 *  Copyright 2011 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.workflow;

import java.util.Map;

import javax.jcr.RepositoryException;

import org.ametys.cms.repository.WorkflowAwareContent;
import org.ametys.runtime.i18n.I18nizableText;

import com.opensymphony.module.propertyset.PropertySet;
import com.opensymphony.workflow.WorkflowException;

/**
 * OS workflow function to set the current step id
 */
public class SetCurrentStepIdAndNotifyFunction extends AbstractContentFunction
{
    
    @Override
    public void execute(Map transientVars, Map args, PropertySet ps) throws WorkflowException
    {
        WorkflowAwareContent content = getContent(transientVars);
        
        try
        {
            // Add the lock token to the current session if the content is locked.
            _addLockToken(content);
            // Set the current step ID property.
            _setCurrentStepIdAndNotify(content, transientVars);
        }
        catch (RepositoryException e)
        {
            throw new WorkflowException("Unable to add a lock token to the current session.", e);
        }
    }
    
    @Override
    public FunctionType getFunctionExecType()
    {
        return FunctionType.POST;
    }
    
    @Override
    public I18nizableText getLabel()
    {
        return new I18nizableText("plugin.cms", "PLUGINS_CMS_SET_CURRENT_STEP_ID_AND_NOTIFY_FUNCTION_LABEL");
    }
}
