/*
 *  Copyright 2011 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.workflow;

import java.io.IOException;
import java.util.Map;

import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.cocoon.ProcessingException;
import org.apache.cocoon.generation.ServiceableGenerator;
import org.apache.cocoon.xml.AttributesImpl;
import org.apache.cocoon.xml.XMLUtils;
import org.xml.sax.SAXException;

import org.ametys.cms.workflow.WorkflowTasksComponent.Task;

/**
 * Generates the tasks list
 *
 */
public class TasksGenerator extends ServiceableGenerator
{
    /** The workflow task component */
    protected WorkflowTasksComponent _tasksManager;
    
    @Override
    public void service(ServiceManager serviceManager) throws ServiceException
    {
        super.service(serviceManager);
        _tasksManager = (WorkflowTasksComponent) serviceManager.lookup(WorkflowTasksComponent.ROLE);
    }
    
    @Override
    public void generate() throws IOException, SAXException, ProcessingException
    {
        contentHandler.startDocument();
        XMLUtils.startElement(contentHandler, "tasks");
        
        Map<String, Task> tasks = _tasksManager.getTasks();
        
        for (Task task : tasks.values())
        {
            AttributesImpl attrs = new AttributesImpl();
            attrs.addCDATAAttribute("id", task.getId());
            attrs.addCDATAAttribute("length", String.valueOf(task.getLength()));
            
            _saxAdditionalAttributes(task, attrs);
            
            XMLUtils.startElement(contentHandler, "task", attrs);
            task.getLabel().toSAX(contentHandler);
            XMLUtils.endElement(contentHandler, "task");
        }
        
        XMLUtils.endElement(contentHandler, "tasks");
        contentHandler.endDocument();
    }
    
    /**
     * SAX additional attributes
     * @param task the task
     * @param attrs the attributes
     * @throws SAXException If an error occurred
     */
    protected void _saxAdditionalAttributes(Task task, AttributesImpl attrs) throws SAXException
    {
        // Nothing
    }

}
