/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.workflow;

import java.util.Map;

import org.ametys.core.user.UserIdentity;
import org.ametys.plugins.repository.AmetysRepositoryException;
import org.ametys.plugins.repository.lock.LockHelper;
import org.ametys.plugins.repository.lock.LockableAmetysObject;
import org.ametys.plugins.workflow.EnhancedFunction;
import org.ametys.runtime.i18n.I18nizableText;

import com.opensymphony.module.propertyset.PropertySet;
import com.opensymphony.workflow.WorkflowException;

/**
 * OSWorkflow function to unlock a content.
 */
public class UnlockContentFunction extends AbstractContentWorkflowComponent implements EnhancedFunction
{
    public void execute(Map transientVars, Map args, PropertySet ps) throws WorkflowException
    {
        _logger.info("Performing edit workflow function");

        // Retrieve current content
        LockableAmetysObject content = (LockableAmetysObject) getContent(transientVars);
        
        try
        {
            if (content.isLocked())
            {
                UserIdentity user = getUser(transientVars);
                boolean sameUser = LockHelper.isLockOwner(content, user);
                
                if (sameUser)
                {
                    if (_logger.isDebugEnabled())
                    {
                        _logger.debug(String.format("Content: %s is locked by current user, unlocking it", content));
                    }
                    
                    content.unlock();
                }
                else
                {
                    if (_logger.isDebugEnabled())
                    {
                        _logger.debug(String.format("Content: %s is locked by user: %s, preventing from unlocking it", content, content.getLockOwner()));
                    }
                    throw new WorkflowException(String.format("User %s tried to unlock content %s but he is not the lock owner %s", user, content, content.getLockOwner()));
                }
            }
        }
        catch (AmetysRepositoryException e)
        {
            throw new WorkflowException(String.format("Unable to unlock content %s", content));
        }
    }
    
    @Override
    public I18nizableText getLabel()
    {
        return new I18nizableText("plugin.cms", "PLUGINS_CMS_UNLOCK_CONTENT_FUNCTION_LABEL");
    }

}
