/*
 *  Copyright 2017 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.workflow;

import java.util.List;
import java.util.Map;

import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;

import org.ametys.cms.repository.WorkflowAwareContent;
import org.ametys.plugins.workflow.component.WorkflowArgument;
import org.ametys.plugins.workflow.support.WorkflowElementDefinitionHelper;
import org.ametys.plugins.workflow.support.WorkflowProvider;
import org.ametys.plugins.workflow.support.WorkflowProvider.AmetysObjectWorkflow;
import org.ametys.runtime.i18n.I18nizableText;

import com.opensymphony.module.propertyset.PropertySet;
import com.opensymphony.workflow.WorkflowException;
import com.opensymphony.workflow.spi.Step;

/**
 * This OSWorkflow condition checks all content metadata are valid ONLY if the content is in validation step.
 */
public class ValidationStepCondition extends ValidateContentCondition
{
    private WorkflowProvider _workflowProvider;

    @Override
    public void service(ServiceManager manager) throws ServiceException
    {
        super.service(manager);
        _workflowProvider = (WorkflowProvider) manager.lookup(WorkflowProvider.ROLE);
    }
    
    @Override
    public boolean passesCondition(Map transientVars, Map args, PropertySet ps) throws WorkflowException
    {
        int step = Integer.parseInt((String) args.get("validation-step"));
        
        WorkflowAwareContent content = getContent(transientVars);
        AmetysObjectWorkflow workflow = _workflowProvider.getAmetysObjectWorkflow(content);
        
        long workflowId = content.getWorkflowId();
        
        List<Step> currentSteps = workflow.getCurrentSteps(workflowId);
        for (Step currentStep : currentSteps)
        {
            if (currentStep.getStepId() != step)
            {
                // Content is not in validation step, do not check attributes
                return true;
            }
        }
        
        return super.passesCondition(transientVars, args, ps);
    }
    @Override
    public List<WorkflowArgument> getArguments()
    {
        return List.of(
            WorkflowElementDefinitionHelper.getElementDefinition(
                "validation-step",
                new I18nizableText("plugin.cms", "PLUGINS_CMS_VALIDATION_STEP_CONDITION_ARGUMENT_LABEL"),
                new I18nizableText("plugin.cms", "PLUGINS_CMS_VALIDATION_STEP_CONDITION_ARGUMENT_DESCRIPTION"),
                true,
                false
            )
        );
    }
    
    @Override
    public I18nizableText getLabel()
    {
        return new I18nizableText("plugin.cms", "PLUGINS_CMS_VALIDATION_STEP_CONDITION_LABEL");
    }
}
