/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.workflow;

import java.io.IOException;

import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.cocoon.ProcessingException;
import org.apache.cocoon.xml.AttributesImpl;
import org.apache.cocoon.xml.XMLUtils;
import org.apache.commons.lang.StringUtils;
import org.xml.sax.SAXException;

import org.ametys.core.user.User;
import org.ametys.core.user.UserManager;
import org.ametys.core.util.cocoon.AbstractCurrentUserProviderServiceableGenerator;

/**
 * Workflow tasks generator.
 */
public class WorkflowTasksGenerator extends AbstractCurrentUserProviderServiceableGenerator
{
    /** The Users Manager. */
    protected UserManager _userManager;
    /** The task component */
    protected WorkflowTasksComponent _tasksManager;
    
    @Override
    public void service(ServiceManager serviceManager) throws ServiceException
    {
        super.service(serviceManager);
        _userManager = (UserManager) serviceManager.lookup(UserManager.ROLE);
        _tasksManager = (WorkflowTasksComponent) serviceManager.lookup(WorkflowTasksComponent.ROLE);
    }
    
    public void generate() throws IOException, SAXException, ProcessingException
    {
        String login = parameters.getParameter("login", "");
        String populationId = parameters.getParameter("populationId", "");
        if (StringUtils.isEmpty(login) || StringUtils.isEmpty(populationId))
        {
            login = _getCurrentUser().getLogin();
            populationId = _getCurrentUser().getPopulationId();
        }
        
        User user = _userManager.getUser(populationId, login);
        
        if (user == null)
        {
            getLogger().error("Unknown user : " + login);
            throw new IllegalStateException("Unknown user : " + login);
        }
        
        AttributesImpl attrs = new AttributesImpl();
        attrs.addCDATAAttribute("user", user.getFullName());
        attrs.addCDATAAttribute("username", login);
        attrs.addCDATAAttribute("email", user.getEmail());
        
        contentHandler.startDocument();
        XMLUtils.startElement(contentHandler, "todo-list", attrs);
        
        long begin = System.currentTimeMillis();
        saxTasks (user);
        
        attrs.clear();
        attrs.addCDATAAttribute("time", String.valueOf(System.currentTimeMillis() - begin));
        
        XMLUtils.createElement(contentHandler, "render", attrs);
        
        XMLUtils.endElement(contentHandler, "todo-list");
        contentHandler.endDocument();
    }
    
    /**
     * SAX tasks
     * @param user the user
     * @throws SAXException If an error occurred
     */
    protected void saxTasks (User user) throws SAXException
    {
        String taskId = parameters.getParameter("taskId", "");
        if (StringUtils.isEmpty(taskId))
        {
            _tasksManager.toSAX(contentHandler, user);
        }
        else
        {
            _tasksManager.toSAX(contentHandler, user, taskId);
        }
    }
}
