/*
 *  Copyright 2018 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.workflow.extensions;

import java.util.HashMap;
import java.util.Map;
import java.util.Set;

import org.apache.avalon.framework.configuration.Configuration;
import org.apache.avalon.framework.configuration.ConfigurationException;
import org.apache.commons.lang3.StringUtils;

import org.ametys.runtime.plugin.ExtensionPoint;

/**
 * Abstract extension point for workflow functions  
 */
public abstract class AbstractFunctionsExtensionPoint implements ExtensionPoint<String>
{
    private Map<String, String> _extensions = new HashMap<>();
    
    public void addExtension(String id, String pluginName, String featureName, Configuration configuration) throws ConfigurationException
    {
        String componentRole = configuration.getChild("component").getValue(null);
        if (StringUtils.isBlank(componentRole))
        {
            throw new ConfigurationException("No 'component' attribute found to denote the component to call", configuration);
        }
        
        _extensions.put(id, componentRole);
    }

    public void initializeExtensions() throws Exception
    {
        // Nothing
    }

    public boolean hasExtension(String id)
    {
        return _extensions.containsKey(id);
    }

    public String getExtension(String id)
    {
        return _extensions.get(id);
    }

    public Set<String> getExtensionsIds()
    {
        return _extensions.keySet();
    }
}
