/*
 *  Copyright 2022 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.workflow.history;

import java.util.Optional;

import org.ametys.runtime.i18n.I18nizableText;

/**
 * Object representing a description step
 */
public class DescriptionStep 
{
    private I18nizableText _description;
    private Optional<String> _smallIcon;
    private Optional<String> _mediumIcon;
    private Optional<String> _largeIcon;
    private String _status;
    
    /**
     * The constructor for a workflow action
     */
    public DescriptionStep()
    {
        _smallIcon = Optional.empty();
        _mediumIcon = Optional.empty();
        _largeIcon = Optional.empty();
    }
    
    /**
     * Get the description of the step
     * @return the description
     */
    public I18nizableText getDescription()
    {
        return this._description;
    }
    
    /**
     * Set the description of the step
     * @param description the description
     */
    public void setDescription(I18nizableText description)
    {
        this._description = description;
    }
    
    /**
     * Get the small icon of the step
     * @return the small icon of the step
     */
    public Optional<String> getSmallIcon()
    {
        return this._smallIcon;
    }
    
    /**
     * Set the small icon of the step
     * @param smallIcon the small icon of the step. Can be null.
     */
    public void setSmallIcon(String smallIcon)
    {
        this._smallIcon = Optional.ofNullable(smallIcon);
    }
    
    /**
     * Get the medium icon of the step
     * @return the medium icon of the step
     */
    public Optional<String> getMediumIcon()
    {
        return this._mediumIcon;
    }
    
    /**
     * Set the medium icon of the step
     * @param mediumIcon the medium icon of the step. Can be null.
     */
    public void setMediumIcon(String mediumIcon)
    {
        this._mediumIcon = Optional.ofNullable(mediumIcon);
    }
    
    /**
     * Get the large icon of the step
     * @return the large icon of the step
     */
    public Optional<String> getLargeIcon()
    {
        return this._largeIcon;
    }
    
    /**
     * Set the large icon of the step
     * @param largeIcon the large icon of the step. Can be null.
     */
    public void setLargeIcon(String largeIcon)
    {
        this._largeIcon = Optional.ofNullable(largeIcon);
    }

    /**
     * Get the step status
     * @return the step status
     */
    public String getStatus()
    {
        return this._status;
    }
    
    /**
     * Set the step status
     * @param status the status
     */
    public void setStatus(String status)
    {
        this._status = status;
    }
    
}
