/*
 *  Copyright 2022 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.workflow.history;

import java.util.Optional;

import org.ametys.runtime.i18n.I18nizableText;

/**
 * Object representing a workflow action
 */
public class WorkflowAction 
{
    private int _id;
    private I18nizableText _label;
    private Optional<String> _smallIcon;
    private Optional<String> _mediumIcon;
    private Optional<String> _largeIcon;
    
    /**
     * The constructor for a workflow action
     * @param id the id of the action
     */
    public WorkflowAction(int id)
    {
        this._id = id;
        _smallIcon = Optional.empty();
        _mediumIcon = Optional.empty();
        _largeIcon = Optional.empty();
    }
    
    /**
     * Get the id of the action
     * @return the id of the action
     */
    public int getId()
    {
        return this._id;
    }
    
    /**
     * Get the label of the action
     * @return the label of the action
     */
    public I18nizableText getLabel()
    {
        return this._label;
    }
    
    /**
     * Set the label of the action
     * @param label the label
     */
    public void setLabel(I18nizableText label)
    {
        this._label = label;
    }
    
    /**
     * Get the small icon of the action
     * @return the small icon of the action
     */
    public Optional<String> getSmallIcon()
    {
        return this._smallIcon;
    }
    
    /**
     * Set the small icon of the action
     * @param smallIcon the small icon of the action. Can be null.
     */
    public void setSmallIcon(String smallIcon)
    {
        this._smallIcon = Optional.ofNullable(smallIcon);
    }
    
    /**
     * Get the medium icon of the action
     * @return the medium icon of the action
     */
    public Optional<String> getMediumIcon()
    {
        return this._mediumIcon;
    }
    
    /**
     * Set the medium icon of the action
     * @param mediumIcon the medium icon of the action. Can be null.
     */
    public void setMediumIcon(String mediumIcon)
    {
        this._mediumIcon = Optional.ofNullable(mediumIcon);
    }
    
    /**
     * Get the large icon of the action
     * @return the large icon of the action
     */
    public Optional<String> getLargeIcon()
    {
        return this._largeIcon;
    }
    
    /**
     * Set the large icon of the action
     * @param largeIcon the large icon of the action. Can be null.
     */
    public void setLargeIcon(String largeIcon)
    {
        this._largeIcon = Optional.ofNullable(largeIcon);
    }
    
}
