/*
 *  Copyright 2022 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.workflow.history;

import java.util.ArrayList;
import java.util.HashSet;
import java.util.List;
import java.util.Set;

/**
 * Object representing a workflow history
 */
public class WorkflowHistory 
{
    private List<HistoryStep> _steps;
    private Set<String> _validatedVersions;
    
    /**
     * The constructor
     */
    public WorkflowHistory()
    {
        this._steps = new ArrayList<>();
        this._validatedVersions = new HashSet<>();
    }
    
    /**
     * Get the list of step
     * @return the list of step
     */
    public List<HistoryStep> getSteps()
    {
        return this._steps;
    }
    
    /**
     * Add the step
     * @param step the step
     */
    public void addStep(HistoryStep step)
    {
        this._steps.add(step);
    }

    /**
     * Get the validated versions
     * @return the validated versions
     */
    public Set<String> getValidatedVersions()
    {
        return this._validatedVersions;
    }
    
    /**
     * Add a validated version
     * @param versionName the version name
     */
    public void addValidatedVersion(String versionName)
    {
        _validatedVersions.add(versionName);
    }
}
