<?xml version="1.0" encoding="UTF-8"?>
<!--
   Copyright 2010 Anyware Services

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
   -->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
                              xmlns:docbook="http://docbook.org/ns/docbook" 
                              xmlns:i18n="http://apache.org/cocoon/i18n/2.1" 
                              xmlns:cms="http://ametys.org/cms/3.0"
                              xmlns:resolver="org.ametys.cms.transformation.xslt.ResolveURIComponent"
						      xmlns:ametys="org.ametys.cms.transformation.xslt.AmetysXSLTHelper"
                              extension-element-prefixes="cms" 
                              exclude-result-prefixes="docbook resolver ametys">
    
    <xsl:import href="docbookenhancement://docbook2html.xsl"/>
    <xsl:import href="plugin:core://stylesheets/helper/text.xsl"/>
    <xsl:import href="view://stylesheets/utils.xsl"/>
    <xsl:import href="view://pages/comments/helper/comments_3.3.xsl"/>
    <xsl:import href="view://stylesheets/helper/common.xsl"/>
    
    <!-- The CSS classname that will be set on the surrounding DIV element -->
    <xsl:variable name="common-content-css-class-name" />
    <!-- The name of content -->
    <xsl:variable name="common-content-name" />

	<xsl:variable name="uri-prefix">
        <xsl:call-template name="get-uri-prefix"/>
    </xsl:variable>
	
    <xsl:template match="/">
        <xsl:apply-templates select="view/content|content"/>
    </xsl:template>
    
    <!-- Overridable template to provide the uri prefix. -->
    <xsl:template name="get-uri-prefix">
        <xsl:value-of select="ametys:uriPrefix()"/>
    </xsl:template>
    
    <!-- +
         | STRUCTURE
         + -->

    <!-- The common template to call to build your service structure -->   
    <xsl:template match="content">
        <html>
            <head>
                <xsl:call-template name="common-content-head"/>        
            </head>
            <body id="default"> 
                <xsl:call-template name="common-content-body"/>
            </body>
        </html>
   </xsl:template>
   
    <!-- +
         | HEAD
         + -->
   
   <!-- The template called in the HEAD tag. -->
   <xsl:template name="common-content-head">
        <xsl:call-template name="common-content-head-title"/>
        <xsl:call-template name="common-content-head-css"/>
        <xsl:call-template name="common-content-head-js"/>
        <xsl:call-template name="common-content-head-other"/>
        <xsl:call-template name="common-content-metadata-dublin-core"/>
        <xsl:call-template name="common-content-metadata-other"/> 
   </xsl:template>

   <!-- Override this template to add specific title -->
   <xsl:template name="common-content-head-title"/>   
   
   <!-- Override this template to add stuff in the head (but JS or CSS) -->
   <xsl:template name="common-content-head-other"/>

   <!-- Override this template to add CSS -->
   <xsl:template name="common-content-head-css"/>
   
   <!-- Override this template to add JS -->
   <xsl:template name="common-content-head-js"/> 
   
   <!-- Template used by content for balise title -->
   <xsl:template name="common-content-head-title-content">
   		<xsl:param name="title" select="metadata/title"/>
   
        <title><xsl:value-of select="$title"/></title>
   </xsl:template>    
   
    <!-- +
         | METADATA
         + -->   

    <!-- Dublin core metadata -->
    <!-- Dublin core metadata -->
    <xsl:template name="common-content-metadata-dublin-core">
        <xsl:if test="dublin-core-metadata/node()[name() = 'subject' and normalize-space(.) != '']">
            <meta name="DC.subject">
                <xsl:attribute name="content"> 
                     <xsl:for-each select="dublin-core-metadata/node()[name() = 'subject' and normalize-space(.) != '']">
                        <xsl:value-of select="."/><xsl:if test="not(position()=last())"><xsl:text>, </xsl:text></xsl:if>
                     </xsl:for-each>
                </xsl:attribute>
            </meta>
        </xsl:if>
        
    	<xsl:call-template name="common-content-metadata-convert-to-meta">
    		<xsl:with-param name="prefix" select="'DC.'"/>
    		<xsl:with-param name="data" select="dublin-core-metadata/node()[name() != 'subject' and normalize-space(.) != '']"/>
    	</xsl:call-template>
                
        <!-- Dublin Core -->
        <link rel="meta" href="{$uri-prefix}/plugins/cms/dublincore/content.rdf?contentId={@id}" />    
    </xsl:template>  

    <!-- Other metadata -->
    <xsl:template name="common-content-metadata-other">
		<xsl:call-template name="common-content-metadata-other-default"/>
    </xsl:template>   

    <xsl:template name="common-content-metadata-other-default">
    	<xsl:call-template name="common-content-metadata-convert-to-meta">
    		<xsl:with-param name="prefix" select="''"/>
    		<xsl:with-param name="data" select="metadata/*[name() != 'dc']"/>
    	</xsl:call-template>
    	
        <!-- Last modififications -->
        <meta name="createdAtRaw" content="{@createdAt}" />    
        <meta name="lastModificationRaw" content="{@lastModifiedAt}" />    
        <meta name="lastContributor" content="{@lastContributor}" />    
        <xsl:if test="@lastValidatedAt">
            <meta name="lastValidatedAtRaw" content="{@lastValidatedAt}" />    
        </xsl:if>
	</xsl:template>
	    
    <xsl:template name="common-content-metadata-convert-to-meta">
    	<xsl:param name="prefix"/>
    	<xsl:param name="data"/>
    	
    	<xsl:for-each select="$data">
    		<xsl:choose>
    			<!-- composite -->
    			<!-- FIXME CMS-3643 ContentGenerator metadata type -->
    			<xsl:when test="* and not(@mime-type)">
    				<xsl:call-template name="common-content-metadata-convert-to-meta">
    					<xsl:with-param name="prefix">
    						<xsl:value-of select="$prefix"/>
    						<xsl:value-of select="name()"/><xsl:text>/</xsl:text>
    					</xsl:with-param>
    					<xsl:with-param name="data" select="*"/>
    				</xsl:call-template>
    			</xsl:when>
    			
    			<xsl:otherwise>
    				<xsl:variable name="name" select="name()"/>
					<xsl:for-each select="@*">
	   					<meta name="{$prefix}{$name};{name()}" content="{.}"/>
					</xsl:for-each>
    			
	    			<xsl:if test="normalize-space(.) != ''">
	   					<meta name="{$prefix}{name()}" content="{.}"/>
	    			</xsl:if>
    			</xsl:otherwise>
    		</xsl:choose>
    	</xsl:for-each>
    </xsl:template>

   <!-- +
         | BODY
         + -->
    <!-- The content HTML structure -->
    <xsl:template name="common-content-body">
        <div class="ametys-cms-content {$common-content-css-class-name} wrapper">
            <xsl:call-template name="common-content-body-title"/>
            
            <xsl:call-template name="common-content-body-content"/>
        </div>            
    </xsl:template>
   
   
   <!-- +
         | BODY ELEMENTS
         + -->
    <!-- Vue main -->
    <xsl:template name="common-content-body-title-content">
        <xsl:param name="title" select="metadata/title"/>
        <xsl:param name="subtitle" select="metadata/document-subtitle"/>
        
        <h1 class="ametys-content-title-1">
        	<span class="content-title summary"><xsl:value-of select="$title"/></span>
            <xsl:if test="$subtitle != ''">
                <span class="content-subtitle"><xsl:value-of select="$subtitle"/></span>
            </xsl:if>
        </h1>
    </xsl:template>
    
    <!-- Illustration big size -->
    <xsl:template name="common-content-body-image-bigsize">
        <xsl:param name="image" select="metadata/illustration/image"/>
        <xsl:param name="alternative" select="metadata/illustration/alt-text"/>
        <xsl:param name="maxWidth" select="'150'"/>
        <xsl:param name="maxHeight" select="'150'"/>
        <xsl:param name="class" select="'big'"/>
        <xsl:param name="type" select="'bounded'"/>
        
        <xsl:call-template name="common-content-body-image">
            <xsl:with-param name="image" select="$image"/>
            <xsl:with-param name="alternative" select="$alternative"/>
            <xsl:with-param name="maxWidth" select="$maxWidth"/>
            <xsl:with-param name="maxHeight" select="$maxHeight"/>
            <xsl:with-param name="class" select="$class"/>
            <xsl:with-param name="type" select="$type"/>
        </xsl:call-template>
    </xsl:template>
    
    <!-- Illustration small size -->
    <xsl:template name="common-content-body-image-smallsize">
        <xsl:param name="image" select="metadata/illustration/image"/>
        <xsl:param name="alternative" select="metadata/illustration/alt-text"/>
        <xsl:param name="maxWidth" select="'100'"/>
        <xsl:param name="maxHeight" select="'100'"/>
        <xsl:param name="class" select="'small'"/>
        <xsl:param name="type" select="'bounded'"/>
        
        <xsl:call-template name="common-content-body-image">
            <xsl:with-param name="image" select="$image"/>
            <xsl:with-param name="alternative" select="$alternative"/>
            <xsl:with-param name="maxWidth" select="$maxWidth"/>
            <xsl:with-param name="maxHeight" select="$maxHeight"/>
            <xsl:with-param name="class" select="$class"/>
            <xsl:with-param name="type" select="$type"/>
        </xsl:call-template>
    </xsl:template>
    
    <!-- Template used to display the content illustration -->
    <xsl:template name="common-content-body-image">
        <xsl:param name="image"/>
        <xsl:param name="alternative"/>
        <xsl:param name="maxWidth"/>
        <xsl:param name="maxHeight"/>
        <xsl:param name="class"/>
        <xsl:param name="type"/>
        
        <xsl:if test="$image">
            <div class="content-illustration {$class}">
                <img alt="{$alternative}">
                    <xsl:attribute name="src">
	                    <xsl:choose>
	                        <xsl:when test="$type = 'cropped'"><xsl:value-of select="resolver:resolveCroppedImage($image/@type, $image/@uri, $maxHeight, $maxWidth)"/></xsl:when>
	                        <xsl:otherwise><xsl:value-of select="resolver:resolveBoundedImage($image/@type, $image/@uri, $maxHeight, $maxWidth)"/></xsl:otherwise>
	                    </xsl:choose>
                    </xsl:attribute>
                </img>
            </div>
        </xsl:if>        
    </xsl:template>  
    
    <!-- Template used for the rich content -->
    <xsl:template name="common-content-body-content-rich">
        <xsl:param name="level" select="0"/>
        <xsl:param name="content" select="metadata/content"/>

        <xsl:if test="cms:isNotRichTextEmpty($content)">
	       	<xsl:variable name="raw-is-title-visible">
			    <xsl:call-template name="common-content-body-title-content"/>
			</xsl:variable>
	        
	        <xsl:variable name="truelevel">
		    	<xsl:choose>
		    		<xsl:when test="string-length($raw-is-title-visible) &gt; 0"><xsl:value-of select="2 + number($level)"/></xsl:when>
		    		<xsl:otherwise><xsl:value-of select="1 + number($level)"/></xsl:otherwise>
		    	</xsl:choose>
			</xsl:variable>
				    
            <xsl:apply-templates select="$content/docbook:article">
                <xsl:with-param name="level" select="$truelevel"/>
            </xsl:apply-templates>
        </xsl:if>    
    </xsl:template>

    <!-- Contact, Publish date... -->
    <xsl:template name="common-content-body-meta">
    	<xsl:if test="metadata/contact/name or metadata/contact/mail or @lastValidatedAt">
    		<div class="meta">
    			<xsl:call-template name="common-content-body-contact"/>
		    	<xsl:call-template name="common-content-body-publish-date"/>
	    	</div>
    	</xsl:if>
    </xsl:template>
    
    <!-- Template used to display the contact -->
    <xsl:template name="common-content-body-contact">
        <xsl:if test="metadata/contact/name or metadata/contact/mail">
            <p class="content-contact">
                <i18n:text i18n:key="CONTENT_VIEW_CONTACT" i18n:catalogue="plugin.cms"/>
                <xsl:text> </xsl:text>
                <xsl:if test="metadata/contact/name"><xsl:value-of select="metadata/contact/name"/></xsl:if>
                <xsl:if test="metadata/contact/name and metadata/contact/mail"><xsl:text> (</xsl:text></xsl:if>
                <xsl:if test="metadata/contact/mail">
                    <xsl:call-template name="mail-antispam">
                        <xsl:with-param name="mail" select="metadata/contact/mail"></xsl:with-param>
                    </xsl:call-template>
                </xsl:if>
                <xsl:if test="metadata/contact/name and metadata/contact/mail"><xsl:text>)</xsl:text></xsl:if>
            </p>
        </xsl:if>    
    </xsl:template>
    
    <xsl:template name="common-content-body-publish-date">
        <xsl:if test="@lastValidatedAt">
            <p class="content-published-date">
                <i18n:text i18n:key="CONTENT_VIEW_LASTPUBLICATIONDATE" i18n:catalogue="plugin.cms"/>
                <xsl:text> </xsl:text> 
                <xsl:call-template name="common-utils-date-pattern">
                    <xsl:with-param name="date" select="@lastValidatedAt"/>
                </xsl:call-template>                
            </p>          
        </xsl:if>
    </xsl:template>    
    
    <xsl:template name="common-content-body-comments">
        <!-- Comments -->
		<xsl:call-template name="comments"/>
    </xsl:template>
    <xsl:template name="comment-class">
    	<xsl:call-template name="common-utils-class"/>
	</xsl:template>
	<xsl:template name="comment-form-showhint">
        <p class="mandatory-hint">
        	<i18n:text i18n:key="CONTENT_VIEW_FORM_MANDATORY_LABEL" i18n:catalogue="plugin.cms"/>
        </p>
	</xsl:template>	
	<xsl:template name="comment-form-manadtorymarker">
		<span class="mandatory-marker"><i18n:text i18n:key="CONTENT_VIEW_FORM_MANDATORY_FIELD" i18n:catalogue="plugin.cms"/></span>
	</xsl:template>	

    <!-- Abstract -->
    <xsl:template name="common-content-body-simpletext">
        <xsl:param name="css-class-name" />
        <xsl:param name="text" />
        <xsl:param name="defaultText" />
        <xsl:param name="maxDefaultTextSize" />

        <p>
            <xsl:attribute name="class"><xsl:value-of select="$css-class-name"/></xsl:attribute>
            <xsl:call-template name="common-utils-simpletext">
                <xsl:with-param name="text" select="$text"/>                
                <xsl:with-param name="defaultText" select="$defaultText"/>                
                <xsl:with-param name="maxDefaultTextSize" select="$maxDefaultTextSize"/>                
            </xsl:call-template>            
        </p>
    </xsl:template>
    
    <!-- Link read more -->
    <xsl:template name="common-content-body-readmore">
    </xsl:template> 
    
    <!-- Link used for the view link -->
    <xsl:template name="common-content-body-link">
        <xsl:param name="title" select="metadata/title"/>
        
        <xsl:value-of select="$title"/>
    </xsl:template>
            
</xsl:stylesheet>
