<?xml version="1.0" encoding="UTF-8"?>
<!--
   Copyright 2022 Anyware Services

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
   -->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
                              xmlns:i18n="http://apache.org/cocoon/i18n/2.1" 
                              xmlns:cms="http://ametys.org/cms/3.0"
                              xmlns:dateutils="org.ametys.core.util.DateUtils"
                              xmlns:datetime="http://ametys.org/datetime/4.2"
                              xmlns:zoneid="java.time.ZoneId"
                              xmlns:func="http://exslt.org/functions"
                              xmlns:ical="http://ametys.org/cms/ical"
                              extension-element-prefixes="cms">
    
    <xsl:import href="plugin:core://stylesheets/helper/datetime.xsl"/>
    
    <xsl:variable name="nl"><xsl:text>&#13;&#10;</xsl:text></xsl:variable>
    <xsl:variable name="nlstr"><xsl:text>\\n</xsl:text></xsl:variable>
    
    <xsl:template match="/">
        <xsl:apply-templates select="view/content|content"/>
    </xsl:template>
    
    <xsl:template match="content">
        <xsl:text>BEGIN:VCALENDAR</xsl:text><xsl:value-of select="$nl"/>
        <xsl:text>VERSION:2.0</xsl:text><xsl:value-of select="$nl"/>
        <xsl:text>PRODID:-//Ametys/calendar//NONSGML v1.0//EN</xsl:text><xsl:value-of select="$nl"/>
        <xsl:apply-templates select="." mode="vevent-content"/>
        <xsl:text>END:VCALENDAR</xsl:text>
    </xsl:template>
    
    <xsl:template match="*" mode="vevent-content">
        <xsl:text>BEGIN:VEVENT</xsl:text><xsl:value-of select="$nl"/>
        <xsl:apply-templates select="." mode="vevent-uid"/>
        <xsl:apply-templates select="." mode="vevent-created"/>
        <xsl:apply-templates select="." mode="vevent-lastModified"/>
        <xsl:apply-templates select="." mode="vevent-dtstart"/>
        <xsl:apply-templates select="." mode="vevent-dtend"/>
        <xsl:apply-templates select="." mode="vevent-summary"/>
        <xsl:apply-templates select="." mode="vevent-description"/>
        <xsl:apply-templates select="." mode="vevent-location"/>
        <xsl:apply-templates select="." mode="vevent-categories"/>
        <xsl:apply-templates select="." mode="vevent-url"/>
        <xsl:text>END:VEVENT</xsl:text><xsl:value-of select="$nl"/>
    </xsl:template>
    
    <xsl:template match="*" mode="vevent-uid">
        <xsl:text>UID:</xsl:text><xsl:value-of select="@id"/><xsl:value-of select="$nl"/>
    </xsl:template>
    
    <xsl:template match="*" mode="vevent-created">
        <xsl:text>CREATED:</xsl:text>
        <xsl:value-of select="datetime:icalFormat(@createdAt)"/>
        <xsl:value-of select="$nl"/>
    </xsl:template>
    
    <xsl:template match="*" mode="vevent-lastModified">
        <xsl:text>LAST-MODIFIED:</xsl:text>
        <xsl:value-of select="datetime:icalFormat(@lastModifiedAt)"/>
        <xsl:value-of select="$nl"/>
    </xsl:template>
    
    <xsl:template match="*" mode="vevent-dtstart"/>
    
    <xsl:template match="*" mode="vevent-dtend"/>
    
    <xsl:template match="*" mode="vevent-summary">
        <xsl:text>SUMMARY:</xsl:text>
        <xsl:value-of select="metadata/title"/>
        <xsl:value-of select="$nl"/>
    </xsl:template>
    
    <xsl:template match="*" mode="vevent-description"/>
    
    <xsl:template match="*" mode="vevent-location"/>
    
    <xsl:template match="*" mode="vevent-categories"/>
    
    <xsl:template match="*" mode="vevent-url"/>
    
</xsl:stylesheet>
