<?xml version="1.0" encoding="UTF-8"?>
<!--
   Copyright 2018 Anyware Services

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
   -->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                              xmlns:docbook="http://docbook.org/ns/docbook" 
                              xmlns:resolver="org.ametys.cms.transformation.xslt.ResolveURIComponent"
                              xmlns:i18n="http://apache.org/cocoon/i18n/2.1" 
                              xmlns:ametys="org.ametys.cms.transformation.xslt.AmetysXSLTHelper"
                              exclude-result-prefixes="docbook ametys">
                              
    <xsl:import href="view://stylesheets/content/common.xsl"/>
    
    <!-- Used in common.xsl -->
    <xsl:variable name="common-content-name">default-content</xsl:variable>
    
    <xsl:variable name="common-content-css-class-name">default-content</xsl:variable>
    
    <!-- +
         | HEAD
         + -->

    <!-- Used in common.xsl -->
    <xsl:template name="common-content-head-title">
        <xsl:call-template name="common-content-head-title-content"/>
    </xsl:template> 
    
    <xsl:template match="*[@entryCount = '0']" mode="metadata">
        <!-- Do not display empty repeater -->
    </xsl:template>
    
    <xsl:template match="*" mode="metadata">
        <xsl:param name="margin" select="0"/>
        
        <xsl:variable name="local-name" select="local-name()"/>
        <xsl:variable name="fullModelPath" select="@fullModelPath"/>
        <xsl:variable name="type" select="/content/fields/field[@id=$fullModelPath]/@type"/>
        <xsl:variable name="label" select="/content/fields/field[@id=$fullModelPath]"/>
        
        <xsl:if test="not(preceding-sibling::*[local-name() = $local-name])">
            <div style="margin-left: {$margin}px">
                <xsl:attribute name="class">field <xsl:call-template name="common-utils-class"/></xsl:attribute>
                
                <strong><xsl:value-of select="$label"/></strong><br/>
                
                <xsl:for-each select="current()|following-sibling::*[local-name() = $local-name]">
                    <xsl:choose>
                        <xsl:when test="$type = 'date'">
                            <xsl:call-template name="display-date-metadata"/>
                        </xsl:when>
                         <xsl:when test="$type = 'datetime'">
                            <xsl:call-template name="display-datetime-metadata"/>
                        </xsl:when>
                        <xsl:when test="docbook:article">
                            <xsl:call-template name="display-richtext-metadata"/>
                        </xsl:when>
                        <xsl:when test="@id and @title">
                            <xsl:call-template name="display-content-metadata"/>
                        </xsl:when>
                        <xsl:when test="@type and @filename">
                            <xsl:call-template name="display-file-metadata"/>
                        </xsl:when>
                        <xsl:when test="@longitude and @latitude">
                            <xsl:call-template name="display-geocode-metadata"/>
                        </xsl:when>
                        <xsl:when test="@type = '__external'">
                            <a class="external" onclick="window.open('{.}'); return false;" title="" href="{.}"><xsl:value-of select="."/></a>
                        </xsl:when>
                        <xsl:when test="$type = 'geocode'">
                            <xsl:call-template name="display-geocode-metadata"/>
                        </xsl:when>
                        <xsl:when test="$type = 'boolean'">
                            <xsl:choose>
                                <xsl:when test="text() = 'true'"><i18n:text i18n:key="PLUGINS_CMS_SEARCH_EXPORT_BOOLEAN_TRUE" i18n:catalogue="plugin.cms"/></xsl:when>
                                <xsl:when test="text() = 'false'"><i18n:text i18n:key="PLUGINS_CMS_SEARCH_EXPORT_BOOLEAN_FALSE" i18n:catalogue="plugin.cms"/></xsl:when>
                            </xsl:choose>
                        </xsl:when>
                        <xsl:when test="*">
                            <xsl:apply-templates select="*" mode="metadata">
                                <xsl:with-param name="margin" select="10"/>
                            </xsl:apply-templates>
                        </xsl:when>
                        <xsl:otherwise>
                            <xsl:value-of select="."/>
                        </xsl:otherwise>
                    </xsl:choose>
                    <xsl:if test="position() != last()"><br/></xsl:if>
                </xsl:for-each>
                
                <div style="clear: both"/>
            </div>
        </xsl:if>
    </xsl:template>
        
    <xsl:template name="display-content-metadata">
        <xsl:variable name="contentId" select="@id" />
        
        <xsl:choose>
            <xsl:when test="ametys:isReferenceTableContent(@id)">
                <xsl:value-of select="@title"/>
            </xsl:when>
            <xsl:otherwise>
                <a href="{resolver:resolve ('content', @id)}"><xsl:value-of select="@title"/></a>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    
    <xsl:template name="display-richtext-metadata">
        <xsl:apply-templates select="docbook:article">
            <xsl:with-param name="level" select="2"/>
        </xsl:apply-templates>
    </xsl:template>
    
    <xsl:template name="display-file-metadata">
        <a href="{resolver:resolve(@type, @path, 'true')}" title="{@filename} ({@size})"><xsl:value-of select="@filename"/></a>
    </xsl:template>
    
    <xsl:template name="display-geocode-metadata">
        <xsl:value-of select="concat(substring-before(@latitude, '.'), '.', substring(substring-after(@latitude, '.'), 1, 4))"/><xsl:text>°N , </xsl:text><xsl:value-of select="concat(substring-before(@longitude, '.'), '.', substring(substring-after(@longitude, '.'), 1, 4))"/><xsl:text>°E</xsl:text>
        <br/><a external="external" href="https://maps.google.com/maps?q={@latitude},{@longitude}&amp;z=30&amp;ll={@latitude},{@longitude}"><i18n:text i18n:key="CONTENT_VIEW_GOOGLEMAPS_LINK" i18n:catalogue="plugin.cms"/></a>
    </xsl:template>
    
    <xsl:template name="display-date-metadata">
        <i18n:date src-pattern="yyyy-MM-dd'T'HH:mm:ss" pattern="long" value="{.}"/>
    </xsl:template>
    
    <xsl:template name="display-datetime-metadata">
        <i18n:date src-pattern="yyyy-MM-dd'T'HH:mm:ss" pattern="long" value="{.}"/>
        <xsl:text> </xsl:text>
        <i18n:time pattern="short" src-pattern="yyyy-MM-dd'T'HH:mm:ss" value="{.}"/>
    </xsl:template>
    
    <!-- +
         | BODY
         + -->
    <!-- Used in common.xsl -->
    <xsl:template name="common-content-body-title">
        <xsl:call-template name="common-content-body-title-content"/>
    </xsl:template>
    
    <xsl:template name="common-content-body-content">
        <xsl:apply-templates select="metadata/*[local-name() != 'title']" mode="metadata"/>
    </xsl:template>
</xsl:stylesheet>