<?xml version="1.0" encoding="UTF-8"?>
<!--
   Copyright 2010 Anyware Services

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
   -->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
                              xmlns:i18n="http://apache.org/cocoon/i18n/2.1" 
                              xmlns:resolver="org.ametys.cms.transformation.xslt.ResolveURIComponent"
                              xmlns:ametys="org.ametys.cms.transformation.xslt.AmetysXSLTHelper"
							  xmlns:docbook="http://docbook.org/ns/docbook" 
                              exclude-result-prefixes="docbook ametys resolver">
    
    <xsl:import href="view://stylesheets/default-content-utils.xsl"/>
    
    <xsl:template name="common-content-head">
        <title><xsl:value-of select="content/@title"/></title>
    </xsl:template>
    
    <xsl:template name="common-content-body">
        <xsl:apply-templates select="content/*" mode="metadata"/>
    </xsl:template>
    
    <xsl:template match="*" mode="metadata">
        <xsl:param name="margin" select="0"/>
        
        <xsl:variable name="local-name" select="local-name()"/>
        <xsl:variable name="fullModelPath" select="@fullModelPath"/>
        <xsl:variable name="type" select="/content/fields/field[@id=$fullModelPath]/@type"/>
        
        <xsl:if test="not(preceding-sibling::*[local-name() = $local-name])">
            <p style="margin-left: {$margin}px">
                <xsl:apply-templates select="." mode="field-label"/>
                <xsl:for-each select="current()|following-sibling::*[local-name() = $local-name]">
                	<xsl:choose>
                        <xsl:when test="$type = 'date'">
                            <xsl:call-template name="display-date-metadata"/>
                        </xsl:when>
                         <xsl:when test="$type = 'datetime'">
                            <xsl:call-template name="display-datetime-metadata"/>
                        </xsl:when>
    	                <xsl:when test="$type='rich-text' and docbook:article">
    	                    <div class="richText"><xsl:call-template name="display-richtext-metadata"/></div>
    	                </xsl:when>
    	                <xsl:when test="$type = 'content'">
    	                	<xsl:call-template name="display-content-metadata"/>
    	                </xsl:when>
    	                <xsl:when test="@type and @filename">
    	                	<xsl:call-template name="display-file-metadata"/>
    	                </xsl:when>
    	                <xsl:when test="$type = 'geocode'">
    	                	<xsl:call-template name="display-geocode-metadata"/>
    	                </xsl:when>
                        <xsl:when test="$type = 'boolean'">
                            <xsl:choose>
                                <xsl:when test="text() = 'true'"><i18n:text i18n:key="PLUGINS_CMS_SEARCH_EXPORT_BOOLEAN_TRUE" i18n:catalogue="plugin.cms"/></xsl:when>
                                <xsl:when test="text() = 'false'"><i18n:text i18n:key="PLUGINS_CMS_SEARCH_EXPORT_BOOLEAN_FALSE" i18n:catalogue="plugin.cms"/></xsl:when>
                            </xsl:choose>
                        </xsl:when>
                        <xsl:when test="@type = '__external'">
                            <a class="external" onclick="window.open('{.}'); return false;" title="" href="{.}"><xsl:value-of select="."/></a>
                        </xsl:when>
    	                <xsl:when test="*">
    	                    <xsl:apply-templates select="*" mode="metadata">
    	                        <xsl:with-param name="margin" select="10"/>
    	                    </xsl:apply-templates>
    	                </xsl:when>
    	                <xsl:otherwise>
    	                   <xsl:value-of select="."/>
    	                </xsl:otherwise>
                	</xsl:choose>
                    <xsl:if test="position() != last()">
                        <xsl:apply-templates select="." mode="value-seperator"/>
                    </xsl:if>
               	</xsl:for-each>
            </p>
		</xsl:if>
    </xsl:template>

    <xsl:template match="*" mode="field-label">
        <xsl:variable name="fullModelPath" select="@fullModelPath"/>
        <xsl:variable name="label" select="//content/fields/field[@id=$fullModelPath]"/>
        <xsl:variable name="type" select="//content/fields/field[@id=$fullModelPath]/@type"/>
        
        <xsl:if test="$label">
            <xsl:choose>
                <xsl:when test="$type='rich-text' and docbook:article">
                    <strong><xsl:value-of select="$label"/></strong><br/>
                </xsl:when>
                <xsl:otherwise>
                    <strong><xsl:value-of select="$label"/> : </strong>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:if>
    </xsl:template>
    
     <xsl:template match="*" mode="value-seperator">
        <xsl:variable name="fullModelPath" select="@fullModelPath"/>
        <xsl:variable name="type" select="//content/fields/field[@id=$fullModelPath]/@type"/>
        
        <xsl:choose>
            <xsl:when test="$type='rich-text' and docbook:article">
                <br/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:text>, </xsl:text>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    
    <xsl:template name="display-content-metadata">
    	<xsl:variable name="contentId" select="@id" />
    	
    	<xsl:value-of select="@title"/>
    </xsl:template>
	
</xsl:stylesheet>
