<?xml version="1.0" encoding="UTF-8"?>
<!--
   Copyright 2010 Anyware Services

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
   -->
<xsl:stylesheet version="1.0" 
				xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
				xmlns:docbook="http://docbook.org/ns/docbook" 
			    xmlns:i18n="http://apache.org/cocoon/i18n/2.1"
			    xmlns:math="http://exslt.org/math"
			    xmlns:ametys="org.ametys.cms.transformation.xslt.AmetysXSLTHelper"
                xmlns:func="http://exslt.org/functions"
                xmlns:cms="http://ametys.org/cms/3.0"
                exclude-result-prefixes="docbook"
                extension-element-prefixes="math func cms">
    
    <xsl:import href="plugin:core://stylesheets/helper/common.xsl"/> 
    
    <xsl:variable name="uniqueId" select="concat('ametys_', substring-after(math:random(), '.'))"/>
    <xsl:variable name="captcha-plugin">cms</xsl:variable>
    
    <xsl:variable name="uri-prefix">
        <xsl:call-template name="get-uri-prefix"/>
    </xsl:variable>
    
    <xsl:template name="get-uri-prefix">
        <xsl:value-of select="ametys:uriPrefix()"/>
    </xsl:template>
    
	<xsl:template name="mail-antispam">
		<xsl:param name="mail"/>
		<xsl:param name="class"/>
		<xsl:param name="text"/>
		<xsl:param name="title"/>
		<xsl:param name="apply-templates">false</xsl:param>
		<xsl:param name="id">M<xsl:value-of select="substring-after(math:random(), '.')"/></xsl:param>
		
		<xsl:variable name="mailClean">
			<xsl:choose>
				<xsl:when test="starts-with($mail,'mailto:')">
					<xsl:value-of select="substring-after($mail, 'mailto:')"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$mail"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		
		<xsl:variable name="divId">M<xsl:value-of select="substring-after(math:random(), '.')"/></xsl:variable>
		<xsl:variable name="spanId">M<xsl:value-of select="substring-after(math:random(), '.')"/></xsl:variable>
			
		<a id="{$divId}">
			<xsl:if test="$class != ''">
				<xsl:attribute name="class"><xsl:value-of select="$class"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="$title != ''">
				<xsl:attribute name="title"><xsl:value-of select="$title"/></xsl:attribute>
			</xsl:if>

			<xsl:choose>
				<xsl:when test="$apply-templates = 'true' and not(count(text()) = 1 and count(node()) = 1 and text() = $mailClean)">
					<xsl:apply-templates/>
				</xsl:when>
				<xsl:when test="$text != ''">
					<xsl:copy-of select="$text"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="substring-before($mailClean, '@')"/>
					<span style="position: absolute; left: -1000px; top: -1000px;"><xsl:text> </xsl:text></span>
					<xsl:text>@</xsl:text>
					<span style="position: absolute; left: -1000px; top: -1000px;"><xsl:text> </xsl:text></span>
					<xsl:value-of select="substring-after($mailClean, '@')"/>
				</xsl:otherwise>
			</xsl:choose>
			
			<span id="{$spanId}">
				<xsl:choose>
					<xsl:when test="$apply-templates = 'true'">
						<xsl:if test="text() = $mailClean"><xsl:attribute name="style">display: none;</xsl:attribute></xsl:if>
					</xsl:when>
					<xsl:when test="$text != ''">
						<xsl:if test="$text = $mailClean"><xsl:attribute name="style">display: none;</xsl:attribute></xsl:if>
					</xsl:when>
					<xsl:otherwise>
						<xsl:attribute name="style">display: none;</xsl:attribute>
					</xsl:otherwise>
				</xsl:choose>
				<xsl:text> (</xsl:text><xsl:value-of select="substring-before($mailClean, '@')"/>
				<span style="position: absolute; left: -1000px; top: -1000px;"><xsl:text> </xsl:text></span>
				<xsl:text>@</xsl:text>
				<span style="position: absolute; left: -1000px; top: -1000px;"><xsl:text> </xsl:text></span>
				<xsl:value-of select="substring-after($mailClean, '@')"/>
				<xsl:text>)</xsl:text>
			</span>
		</a>
			
	    <script type="text/javascript">
	    
	    	var a = document.createElement('a');
	    	var div = document.getElementById('<xsl:value-of select="$divId"/>');
	    	div.parentNode.insertBefore(a, div);
	    	
	    	while (div.childNodes.length > 1)
	    	{
	    		a.appendChild(div.childNodes[0]);
	    	}
	    	
	    	div.parentNode.removeChild(div);
	    	
			var <xsl:value-of select="$id"/>="<xsl:value-of select="substring-before($mailClean, '@')"/>";
			<xsl:value-of select="$id"/> +="@";
			<xsl:value-of select="$id"/> +="<xsl:value-of select="substring-after($mailClean, '@')"/>";
			<xsl:text>
			</xsl:text>
			
			a.setAttribute('href', 'mailto:' + <xsl:value-of select="$id"/>);
			<xsl:if test="$class != ''">
				a.setAttribute('class', '<xsl:value-of select="$class"/>');
			</xsl:if>
			<xsl:if test="$title != ''">
				a.setAttribute('title', '<xsl:value-of select="$title"/>');
			</xsl:if>	
			<xsl:text>
			</xsl:text>
		
		</script>
	</xsl:template>
	
    <!--
        Truncate a HTML (or text) block to a given maximum length, adding an ellipsis if needed.
        This function keeps whole words, i.e. never cuts the last word in two.
        Parameters:
            content - the root node of the HTML block to truncate.
            length - the maximum number of characters (default: 200).
            ellipsis - the text to add to the end of the block if the content was truncated (default: '...').
     -->
    <xsl:template name="truncate">
        <xsl:param name="content"/>
        <xsl:param name="length" select="200"/>
        <xsl:param name="ellipsis">...</xsl:param>
        <!-- "Internal" parameters used only for recursion. -->
        <xsl:param name="size">0</xsl:param>
        <xsl:param name="somethingremoved">false</xsl:param>
        <xsl:param name="iftoolong"/>
        <xsl:param name="initial">true</xsl:param>
        
        <xsl:choose>
            <!-- Filter unwanted content (video, query, html expert...) -->
            <xsl:when test="name($content) = 'html:htmlexpert' or name($content) = 'ametys:dataquery' or name($content) = 'docbook:videoobject' or name($content) = 'html:form' or name($content) = 'html:toc'">
                <xsl:call-template name="truncate">
                    <xsl:with-param name="content" select="$content/following-sibling::node()[1]"/>
                    <xsl:with-param name="length" select="$length" />
                    <xsl:with-param name="ellipsis" select="$ellipsis" />
                    <xsl:with-param name="size" select="number($size)"/>
                    <xsl:with-param name="iftoolong" select="$iftoolong"/>
                    <xsl:with-param name="somethingremoved" select="'true'"/>
                    <xsl:with-param name="initial" select="'false'"/>
                </xsl:call-template>
            </xsl:when>
            
            <xsl:otherwise>
                
                <xsl:variable name="computed-text">
                    <xsl:for-each select="$content//text()"><xsl:value-of select="."/></xsl:for-each>
                </xsl:variable>
                <xsl:variable name="text">
                    <xsl:choose>
                        <xsl:when test="string-length(normalize-space($computed-text)) != 0"><xsl:value-of select="$computed-text"/></xsl:when>
                        <xsl:otherwise><xsl:value-of select="$content"/></xsl:otherwise>
                    </xsl:choose>
                </xsl:variable>
                
                <xsl:if test="string-length(normalize-space($content)) != 0">
                    <xsl:choose>
                        <xsl:when test="local-name($content) = ''">
                            <xsl:call-template name="no-wrap-text">
                                <xsl:with-param name="text" select="$text" />
                                <xsl:with-param name="length" select="$length" />
                                <xsl:with-param name="size" select="$size" />
                            </xsl:call-template>
                            <xsl:if test="$length - $size &lt; string-length($text)">
                                <xsl:value-of select="$ellipsis"/>
                            </xsl:if>
                        </xsl:when>
                        <xsl:otherwise>
                            <xsl:call-template name="truncate">
                                <xsl:with-param name="content" select="$content/node()[1]"/>
                                <xsl:with-param name="length" select="$length" />
                                <xsl:with-param name="ellipsis" select="$ellipsis" />
                                <xsl:with-param name="size" select="number($size)"/>
                                <xsl:with-param name="iftoolong" select="$iftoolong"/>
                                <xsl:with-param name="somethingremoved" select="'true'"/>
                                <xsl:with-param name="initial" select="'false'"/>
                            </xsl:call-template>
                        </xsl:otherwise>
                    </xsl:choose>
                </xsl:if>
                
                <xsl:if test="local-name($content) = 'para' or local-name($content) = 'title' or (local-name($content) = 'phrase' and $content/@role='linebreak')">
                    <br/>
                </xsl:if>
                
                <xsl:if test="number($size) + string-length($text) &lt; $length and count($content/following-sibling::node()) != 0">
                    <xsl:call-template name="truncate">
                        <xsl:with-param name="content" select="$content/following-sibling::node()[1]"/>
                        <xsl:with-param name="length" select="$length" />
                        <xsl:with-param name="ellipsis" select="$ellipsis" />
                        <xsl:with-param name="size" select="number($size) + string-length($text)"/>
                        <xsl:with-param name="iftoolong" select="$iftoolong"/>
                        <xsl:with-param name="somethingremoved" select="$somethingremoved"/>
                        <xsl:with-param name="initial" select="'false'"/>
                    </xsl:call-template>
                </xsl:if>
            </xsl:otherwise>
        </xsl:choose>
        
        <xsl:if test="$initial = 'true'">
            <xsl:variable name="cumuled">
                <xsl:for-each select="$content/..//text()"><xsl:value-of select="."/></xsl:for-each>
            </xsl:variable>
            
            <xsl:if test="(count($content/../p | $content/../*/p) != count($content/../* | $content/../*/*) or string-length($cumuled) &gt;= $length)">
                <xsl:copy-of select="$iftoolong"/>
            </xsl:if>
        </xsl:if>
        
    </xsl:template>
    
    <xsl:template name="no-wrap-text">
        <xsl:param name="text" />
        <xsl:param name="length" />
        <xsl:param name="size" />
        
        <xsl:variable name="first-length"><xsl:value-of select="string-length($text)" /></xsl:variable>
        
        <xsl:choose>
            <xsl:when test="number($first-length) + number($size) &lt; number($length)">
                <xsl:value-of select="substring($text, 0, number($length) - number($size))"/>
            </xsl:when>
            
            <xsl:otherwise>
                <xsl:value-of select="ametys:splitText($text, ' ,.:(?!;', number($length) - number($size))" />
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    
    <func:function name="cms:isNotRichTextEmpty">
        <xsl:param name="meta"/>
        <func:result select="$meta/docbook:article/* and not(normalize-space($meta/docbook:article/docbook:para) = '&#160;' and count($meta/docbook:article/*) = 1 and not($meta/docbook:article/*))"/>
    </func:function>
    
</xsl:stylesheet>
