<?xml version="1.0" encoding="UTF-8"?>
<!--
   Copyright 2010 Anyware Services

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
   -->
<xsl:stylesheet version="1.0" xmlns:docbook="http://docbook.org/ns/docbook" 
                              xmlns:html="http://www.w3.org/1999/xhtml" 
                              xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
                              xmlns:i18n="http://apache.org/cocoon/i18n/2.1"
                              xmlns:xlink="http://www.w3.org/1999/xlink" 
                              xmlns:uri="org.ametys.core.util.URIUtils" 
                              xmlns:resolver="org.ametys.cms.transformation.xslt.ResolveURIComponent"
                              xmlns:htmlexpertresolver="org.ametys.cms.transformation.xslt.HTMLExpertLinkResolver" 
                              xmlns:fo="http://www.w3.org/1999/XSL/Format" 
                              xmlns:ametys="org.ametys.core.util.AmetysXSLTHelper"
                              exclude-result-prefixes="docbook xlink uri resolver html ametys">

    <!-- cst = dpi/2.54 -->
    <!-- cm * cst = px -->
    <xsl:variable name="TheConstant">28.34</xsl:variable>

    <xsl:template name="break-line">
        <fo:block />
    </xsl:template>

    <xsl:template match="docbook:article">
        <xsl:param name="level" select="1" />
        
        <fo:block>
            <xsl:call-template name="content-body-style"/>
            
            <xsl:apply-templates>
                <xsl:with-param name="level" select="$level" />
            </xsl:apply-templates>
        </fo:block>
    </xsl:template>

    <xsl:template match="docbook:section">
        <xsl:param name="level" />
        
        <!-- Table of contents references -->
        <xsl:variable name="ref"><xsl:call-template name="section-reference"/></xsl:variable>
        
        <fo:block id="{generate-id()}-toc-{$ref}" role="internal-chapter"/>
        
        <xsl:if test="docbook:title">
           	<fo:block>
           		<xsl:call-template name="title-style">
       				<xsl:with-param name="level" select="$level"/>
       			</xsl:call-template>
       			
       			<xsl:apply-templates select="docbook:title" />
           	</fo:block>
        </xsl:if>
        
        <xsl:apply-templates select="docbook:para|docbook:table|docbook:orderedlist|docbook:itemizedlist" />
        
        <xsl:apply-templates select="docbook:section">
            <xsl:with-param name="level" select="$level+1" />
        </xsl:apply-templates>
    </xsl:template>
    
    <xsl:template match="docbook:para">
        <fo:block>
        	<xsl:call-template name="para-style">
        		<xsl:with-param name="class" select="@class"/>
        	</xsl:call-template>
        	
            <xsl:if test="@align != ''">
                <xsl:attribute name="text-align"><xsl:value-of select="@align" /></xsl:attribute>
            </xsl:if>
           
           	<xsl:apply-templates />
        </fo:block>
    </xsl:template>
    
    <xsl:template match="docbook:subscript">
    	<fo:inline>
    		<xsl:call-template name="subscript"/>
        	<xsl:apply-templates />
        </fo:inline>
    </xsl:template>
    
    <xsl:template match="docbook:supscript">
    	<fo:inline>
    		<xsl:call-template name="supscript"/>
        	<xsl:apply-templates />
        </fo:inline>
    </xsl:template>

    <xsl:template match="docbook:para" mode="listitem">
        <xsl:if test="@align != ''">
            <xsl:attribute name="text-align"><xsl:value-of select="@align" /></xsl:attribute>
        </xsl:if>
        
        <xsl:apply-templates />
    </xsl:template>

    <xsl:template match="docbook:phrase[@role='linebreak']">
        <xsl:call-template name="break-line" />
    </xsl:template>

    <xsl:template match="docbook:emphasis">
        <xsl:choose>
            <xsl:when test="@role='strong'">
                <fo:inline font-weight="bold">
                    <xsl:apply-templates />
                </fo:inline>
            </xsl:when>
            <xsl:otherwise>
                <fo:inline font-style="italic">
                    <xsl:apply-templates />
                </fo:inline>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>

    <xsl:template match="docbook:abbrev">
        <xsl:apply-templates />
    </xsl:template>

    <xsl:template match="docbook:acronym">
        <xsl:apply-templates />
    </xsl:template>

    <xsl:template match="docbook:quote">
        <xsl:apply-templates />
    </xsl:template>

    <xsl:template match="docbook:foreignphrase">
        <xsl:apply-templates />
    </xsl:template>

    <xsl:template name="orderedlist">
        <fo:list-block>
        	<xsl:call-template name="ol-style">
        		<xsl:with-param name="mark" select="@mark"/>
        	</xsl:call-template>
        	
            <xsl:apply-templates select="docbook:listitem|docbook:orderedlist|docbook:itemizedlist" mode="ol" />
        </fo:list-block>
    </xsl:template>

    <xsl:template name="itemizedlist">
        <fo:list-block>
        
        	<xsl:call-template name="ul-style">
        		<xsl:with-param name="mark" select="@mark"/>
        	</xsl:call-template>
        	
            <xsl:apply-templates select="docbook:listitem|docbook:orderedlist|docbook:itemizedlist" mode="ul" />
        </fo:list-block>
    </xsl:template>

    <xsl:template match="docbook:orderedlist">
        <xsl:call-template name="orderedlist" />
    </xsl:template>

    <xsl:template match="docbook:itemizedlist">
        <xsl:call-template name="itemizedlist" />
    </xsl:template>

    <xsl:template match="docbook:orderedlist" mode="ol">
        <fo:list-item>
            <fo:list-item-label>
                <fo:block></fo:block>
            </fo:list-item-label>
            <fo:list-item-body start-indent="body-start()">
                <xsl:call-template name="orderedlist" />
            </fo:list-item-body>
        </fo:list-item>
    </xsl:template>

    <xsl:template match="docbook:orderedlist" mode="ul">
        <fo:list-item>
            <fo:list-item-label>
                <fo:block></fo:block>
            </fo:list-item-label>
            <fo:list-item-body start-indent="body-start()">
                <xsl:call-template name="orderedlist" />
            </fo:list-item-body>
        </fo:list-item>
    </xsl:template>

    <xsl:template match="docbook:listitem" mode="ol">
        <fo:list-item>
            <fo:list-item-label>
                <fo:block>
                    <xsl:choose>
                        <xsl:when test="../@numeration = 'loweralpha'"><xsl:number format="a"/></xsl:when>
                        <xsl:when test="../@numeration = 'lowerroman'"><xsl:number format="i"/></xsl:when>
                        <xsl:when test="../@numeration = 'upperalpha'"><xsl:number format="A"/></xsl:when>
                        <xsl:when test="../@numeration = 'upperroman'"><xsl:number format="I"/></xsl:when>
                        <xsl:otherwise><xsl:number /></xsl:otherwise>
                    </xsl:choose>
                    <xsl:call-template name="ol-list-item-decorator"/>
                </fo:block>
            </fo:list-item-label>
            <fo:list-item-body start-indent="body-start()-5mm">
                <xsl:apply-templates />
            </fo:list-item-body>
        </fo:list-item>
    </xsl:template>
    
    <xsl:template name="ol-list-item-decorator">.</xsl:template>

    <xsl:template match="docbook:listitem" mode="ul">
        <fo:list-item>
            <fo:list-item-label>
                <fo:block>&#x2022;</fo:block>
            </fo:list-item-label>
            <fo:list-item-body start-indent="body-start()-5mm">
                <xsl:apply-templates />
            </fo:list-item-body>
        </fo:list-item>
    </xsl:template>

    <xsl:template match="docbook:itemizedlist" mode="ol">
        <fo:list-item>
            <fo:list-item-label>
                <fo:block></fo:block>
            </fo:list-item-label>
            <fo:list-item-body start-indent="body-start()">
                <xsl:call-template name="itemizedlist" />
            </fo:list-item-body>
        </fo:list-item>
    </xsl:template>

    <xsl:template match="docbook:itemizedlist" mode="ul">
        <fo:list-item>
            <fo:list-item-label>
                <fo:block></fo:block>
            </fo:list-item-label>
            <fo:list-item-body start-indent="body-start()">
                <xsl:call-template name="itemizedlist" />
            </fo:list-item-body>
        </fo:list-item>
    </xsl:template>

    <xsl:template match="docbook:table">

    	<xsl:if test="@title">
	    	<fo:block>
	    		<xsl:call-template name="table-caption"/>
				<xsl:value-of select="@title"/>
			</fo:block>
		</xsl:if>

   		<fo:table table-layout="fixed">
            <xsl:if test="normalize-space(@width) != ''">
                <xsl:attribute name="width">
                    <xsl:value-of select="@width"/>
                </xsl:attribute>
            </xsl:if>
            
   			<xsl:call-template name="table-style">
        		<xsl:with-param name="class" select="@class"/>
        	</xsl:call-template>
        	
   			<fo:table-body>
   				<xsl:apply-templates select="docbook:tbody" />
   			</fo:table-body>
   		</fo:table>

    </xsl:template>

    <xsl:template match="docbook:tbody">
        <xsl:apply-templates select="docbook:tr" />
    </xsl:template>

    <xsl:template match="docbook:tr">
    	<xsl:variable name="style">
      		<xsl:choose>
      			<xsl:when test="position() mod 2 = 0"><xsl:text>even</xsl:text></xsl:when>
      			<xsl:otherwise><xsl:text>odd</xsl:text></xsl:otherwise>
      		</xsl:choose>
      		<xsl:if test="docbook:td and not(preceding-sibling::*[docbook:td])"><xsl:text> first</xsl:text></xsl:if>
      		<xsl:if test="position() = last()"><xsl:text> last</xsl:text></xsl:if>
      	</xsl:variable>
      	
        <fo:table-row>
            <xsl:call-template name="tr-style">
                <xsl:with-param name="class" select="$style"/>
                <xsl:with-param name="table-class" select="ancestor::docbook:table[1]/@class"/>
            </xsl:call-template>
            
            <xsl:apply-templates select="docbook:td|docbook:th">
            	 <xsl:with-param name="style" select="$style"/>
            </xsl:apply-templates>
        </fo:table-row>
    </xsl:template>

    <xsl:template match="docbook:td">
    	<xsl:param name="style"/>
    	
    	<xsl:variable name="class">
    		<xsl:value-of select="ancestor::docbook:table[1]/@class"/>
    		<xsl:if test="$style != ''"><xsl:text> </xsl:text><xsl:value-of select="$style"/></xsl:if>
    	</xsl:variable>
    	
        <fo:table-cell>
            <xsl:if test="normalize-space(@width) != ''">
                <xsl:attribute name="width">
                    <xsl:value-of select="@width"/>
                </xsl:attribute>
            </xsl:if>
            
           	<xsl:call-template name="td-style">
      			<xsl:with-param name="class" select="$class"/>
      		</xsl:call-template>
            
            <xsl:if test="@colspan">
                <xsl:attribute name="number-columns-spanned"><xsl:value-of select="@colspan" /></xsl:attribute>
            </xsl:if>
            <xsl:if test="@rowspan">
                <xsl:attribute name="number-rows-spanned"><xsl:value-of select="@rowspan" /></xsl:attribute>
            </xsl:if>
            
            <xsl:choose>
                <xsl:when test="para">
                    <xsl:apply-templates />
                </xsl:when>
                <xsl:otherwise>
                    <fo:block>
                        <xsl:apply-templates />
                    </fo:block>
                </xsl:otherwise>
            </xsl:choose>
        </fo:table-cell>
    </xsl:template>

    <xsl:template match="docbook:th">
        <fo:table-cell>
        	<xsl:call-template name="th-style">
      			<xsl:with-param name="class" select="ancestor::docbook:table[1]/@class"/>
      		</xsl:call-template>
      		
            <xsl:if test="@colspan">
                <xsl:attribute name="number-columns-spanned"><xsl:value-of select="@colspan" /></xsl:attribute>
            </xsl:if>
            <xsl:if test="@rowspan">
                <xsl:attribute name="number-rows-spanned"><xsl:value-of select="@rowspan" /></xsl:attribute>
            </xsl:if>
            
            <xsl:choose>
                <xsl:when test="para">
                    <xsl:apply-templates />
                </xsl:when>
                <xsl:otherwise>
                    <fo:block>
                        <xsl:apply-templates />
                    </fo:block>
                </xsl:otherwise>
            </xsl:choose>
        </fo:table-cell>
    </xsl:template>

	<xsl:template match="docbook:link">
		<xsl:choose>
			<!-- Image within a link => fo:block -->
			<xsl:when test="docbook:mediaobject/docbook:imageobject">
				<fo:block>
					<xsl:call-template name="link" />
				</fo:block>
			</xsl:when>
			<!-- Link with text + icon => fo:inline to handle text-align: right for instance -->
			<xsl:otherwise>
				<fo:inline>
					<xsl:call-template name="link" />
				</fo:inline>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="link">
		<xsl:call-template name="link-style">
			<xsl:with-param name="class" select="@xrefstyle" />
		</xsl:call-template>

		<xsl:variable name="href">
			<xsl:choose>
				<xsl:when test="not(@xlink:type) or @xlink:type = ''">
					<xsl:value-of select="@xlink:href" />
				</xsl:when>
				<xsl:otherwise>
					<xsl:variable name="hrefResolved"
						select="resolver:resolve(@xlink:type, @xlink:href, true(), true())" />
					<xsl:value-of select="$hrefResolved" />
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>

		<xsl:choose>
			<xsl:when test="$href != '' and not(contains($href, '#'))">
				<fo:basic-link external-destination="{$href}">
					<xsl:call-template name="link-href-style" />
					<xsl:apply-templates />
				</fo:basic-link>
			</xsl:when>
			<xsl:otherwise>
				<!-- Removing link. A better way to handle internal links might be found later... -->
				<xsl:call-template name="link-href-style" />
				<xsl:apply-templates />
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

    <xsl:template match="docbook:mediaobject">
        <xsl:apply-templates select="docbook:*" />
    </xsl:template>

    <xsl:template match="docbook:mediaobject/docbook:alt" />
    <xsl:template match="docbook:mediaobject/docbook:caption" />

    <xsl:template match="docbook:imageobject">
        <fo:block>
            <xsl:variable name="mimeType" select="resolver:getMimeType(docbook:imagedata/@type, docbook:imagedata/@fileref)"/>
            <xsl:choose>
                <xsl:when test="$mimeType = 'image/svg+xml'">
                    <xsl:apply-templates select="." mode="svg"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:apply-templates select="." mode="normal"/>
                </xsl:otherwise>
            </xsl:choose>
        </fo:block>
    </xsl:template>
    
    <xsl:template match="docbook:imageobject" mode="normal">
        <xsl:variable name="srcResolved" select="resolver:resolveImageAsBase64(docbook:imagedata/@type, docbook:imagedata/@fileref, substring-before(docbook:imagedata/@depth, 'px'), substring-before(docbook:imagedata/@width, 'px'))"/>
        <xsl:variable name="finalSrc">
            <xsl:choose>
                <xsl:when test="$srcResolved = '' or $srcResolved = docbook:imagedata/@fileref">
                    <xsl:value-of select="ametys:pluginImageBase64('core-ui', 'img/imagenotfound.png')"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="$srcResolved"/>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        
        <fo:external-graphic src="url({uri:decode($finalSrc)})"
                    content-width="scale-to-fit"
                    content-height="100%"
                    width="100%"
                    scaling="uniform">
            
            <xsl:call-template name="image-style">
                <xsl:with-param name="class" select="../@class"/>
            </xsl:call-template>
        </fo:external-graphic>
    </xsl:template>
    
    <xsl:template match="docbook:imageobject" mode="svg">
        <fo:instream-foreign-object content-width="{docbook:imagedata/@width}" content-height="{docbook:imagedata/@depth}">
            <xsl:call-template name="image-style">
                <xsl:with-param name="class" select="../@class"/>
            </xsl:call-template>
            
            <xsl:copy-of select="document(uri:decode(resolver:resolveImage(docbook:imagedata/@type, docbook:imagedata/@fileref, substring-before(docbook:imagedata/@depth, 'px'), substring-before(docbook:imagedata/@width, 'px'), false(), false(), true())))"/>
        </fo:instream-foreign-object>
    </xsl:template>
    
    <xsl:template match="html:htmlexpert">
    </xsl:template>
    
    <xsl:template match="html:toc">
    </xsl:template>
    
    <!-- Table of contents -->
    <xsl:template match="docbook:para[html:toc]">
         <xsl:if test="following-sibling::docbook:section">
             <xsl:apply-templates select="following-sibling::docbook:section" mode="toc"/>
         </xsl:if>
    </xsl:template>
    
    <!-- Section -->
    <xsl:template match="docbook:section" mode="toc">
        <fo:block margin-top="0.2cm" margin-right="1.2cm" margin-left="1.2cm" text-align='justify' text-align-last="justify" space-after="3pt">
            <xsl:call-template name="toc-section"/>
        </fo:block>

        <xsl:apply-templates select="docbook:section" mode="toc_subsection"/>
    </xsl:template>
    
    <!-- Subsection -->
    <xsl:template match="docbook:section" mode="toc_subsection">
        <fo:block margin-right="1.2cm" margin-left="2cm" text-align='justify' text-align-last="justify" space-after="3pt">
            <xsl:call-template name="toc-subsection"/>
        </fo:block>
        <xsl:apply-templates select="docbook:section" mode="toc_subsubsection"/>
    </xsl:template>
    
    <!-- Subsubsection -->
    <xsl:template match="docbook:section" mode="toc_subsubsection">
        <fo:block margin-right="1.2cm" margin-left="2.8cm" text-align='justify' text-align-last="justify" space-after="3pt">
            <xsl:call-template name="toc-subsubsection"/>
        </fo:block>
    </xsl:template>
    
    <!-- Toc section -->
    <xsl:template name="toc-section">
	    <fo:basic-link margin-top="0.7cm" font-size="14px">
		    <xsl:variable name="ref"><xsl:call-template name="section-reference"/></xsl:variable>
		    <xsl:variable name="id" select="generate-id()"/>
            
		    <xsl:attribute name='internal-destination'><xsl:value-of select="$id"/>-toc-<xsl:value-of select="$ref"/></xsl:attribute>
		    
		    <xsl:call-template name="section-number"/><xsl:value-of select="docbook:title"/>
		    &#160;<fo:leader leader-pattern='dots' rule-thickness='.2pt' leader-alignment='reference-area' font-size="10pt"/>&#160;
		    
		    <fo:page-number-citation>
		        <xsl:attribute name='ref-id'><xsl:value-of select="$id"/>-toc-<xsl:value-of select="$ref"/></xsl:attribute>
		    </fo:page-number-citation>
        </fo:basic-link>
    </xsl:template>
    
    <!-- Toc subsection -->
    <xsl:template name="toc-subsection">
        <fo:basic-link margin-top="0.7cm" font-size="14px">
            <xsl:variable name="ref"><xsl:call-template name="subsection-reference"/></xsl:variable>
            <xsl:variable name="id" select="generate-id()"/>
            
            <xsl:attribute name='internal-destination'><xsl:value-of select="$id"/>-toc-<xsl:value-of select="$ref"/></xsl:attribute>
            
            <xsl:call-template name="subsection-number"/><xsl:value-of select="docbook:title"/>
            &#160;<fo:leader leader-pattern='dots' rule-thickness='.2pt' leader-alignment='reference-area' font-size="10pt"/>&#160;
            
            <fo:page-number-citation>
                <xsl:attribute name='ref-id'><xsl:value-of select="$id"/>-toc-<xsl:value-of select="$ref"/></xsl:attribute>
            </fo:page-number-citation>
        </fo:basic-link>
    </xsl:template>
    
    <!-- Toc subsubsection -->
    <xsl:template name="toc-subsubsection">
        <fo:basic-link margin-top="0.7cm" font-size="14px">
            <xsl:variable name="ref"><xsl:call-template name="subsubsection-reference"/></xsl:variable>
            <xsl:variable name="id" select="generate-id()"/>
            
            <xsl:attribute name='internal-destination'><xsl:value-of select="$id"/>-toc-<xsl:value-of select="$ref"/></xsl:attribute>
            
            <xsl:call-template name="subsubsection-number"/><xsl:value-of select="docbook:title"/>
            &#160;<fo:leader leader-pattern='dots' rule-thickness='.2pt' leader-alignment='reference-area' font-size="10pt"/>&#160;
            
            <fo:page-number-citation>
                <xsl:attribute name='ref-id'><xsl:value-of select="$id"/>-toc-<xsl:value-of select="$ref"/></xsl:attribute>
            </fo:page-number-citation>
        </fo:basic-link>
    </xsl:template>
        
    <xsl:template name="section-number">
	   <xsl:number value="position()" format="1. "/>
    </xsl:template>
    
    <xsl:template name="section-reference">
        <xsl:number level="multiple" format="1"/>
    </xsl:template>
    
    <xsl:template name="subsection-number">
        <xsl:variable name="parent-position">
            <xsl:value-of select="count(../preceding-sibling::docbook:section) + 1"/>
        </xsl:variable>
        <xsl:value-of select="$parent-position"/>.<xsl:value-of select="position()"/><xsl:text> </xsl:text>
    </xsl:template>
    
    <xsl:template name="subsection-reference">
        <xsl:number level="multiple" format="1.1"/>
    </xsl:template>
    
    <xsl:template name="subsubsection-number">
        <xsl:variable name="parent-parent-position">
            <xsl:value-of select="count(../../preceding-sibling::docbook:section) + 1"/>
        </xsl:variable>
        <xsl:variable name="parent-position">
            <xsl:value-of select="count(../preceding-sibling::docbook:section) + 1"/>
        </xsl:variable>
        <xsl:value-of select="$parent-parent-position"/>.<xsl:value-of select="$parent-position"/>.<xsl:value-of select="position()"/><xsl:text> </xsl:text>
    </xsl:template>
    
    <xsl:template name="subsubsection-reference">
        <xsl:number level="multiple" format="1.1.1"/>
    </xsl:template>
    
    <!-- +
         | Default style
         + -->
    <xsl:template name="region-body-definition"/>
    
    <xsl:template name="region-before-definition"/>
    
    <xsl:template name="region-after-definition"/>
    
    <xsl:template name="main-body-block"/>
    
    <xsl:template name="content-body-style"/>
    
    <xsl:template name="para-style">
        <xsl:param name="class"/>
        
        <xsl:attribute name="space-before">0mm</xsl:attribute>
        <xsl:attribute name="space-after">4mm</xsl:attribute>
    </xsl:template>
    
    <xsl:template name="subscript">
        <xsl:attribute name="font-size">60%</xsl:attribute>
        <xsl:attribute name="baseline-shift">sub</xsl:attribute>
    </xsl:template>
    
    <xsl:template name="supscript">
        <xsl:attribute name="font-size">60%</xsl:attribute>
        <xsl:attribute name="baseline-shift">super</xsl:attribute>
    </xsl:template>
    
    <xsl:template name="title-style">
        <xsl:param name="level"/>
        <xsl:attribute name="font-size"><xsl:value-of select="130 - 5 * $level"/>%</xsl:attribute>
    </xsl:template>
    
    <xsl:template name="image-style">
        <xsl:param name="class"/>
    </xsl:template>
    
    <xsl:template name="image-caption">
    </xsl:template>
    
    <xsl:template name="link-style">
        <xsl:param name="class"/>
    </xsl:template>
    
    <xsl:template name="link-href-style">
    </xsl:template>
    
    <xsl:template name="table-style">
        <xsl:param name="class"/>
    </xsl:template>
    
    <xsl:template name="table-caption"/>
    
    <xsl:template name="tr-style">
        <xsl:param name="class"/>
    </xsl:template>
         
    <xsl:template name="th-style">
        <xsl:param name="class"/>
    </xsl:template>
    
    <xsl:template name="td-style">
        <xsl:param name="class"/>
    </xsl:template>
    
    <xsl:template name="ol-style">
        <xsl:param name="mark"/>
    </xsl:template>
    
    <xsl:template name="ul-style">
        <xsl:param name="mark"/>
    </xsl:template>
</xsl:stylesheet>
