<?xml version="1.0" encoding="UTF-8"?>
<!--
   Copyright 2010 Anyware Services

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
   -->
<xsl:stylesheet version="1.0" 
				xmlns:docbook="http://docbook.org/ns/docbook" 
                xmlns:html="http://www.w3.org/1999/xhtml"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:i18n="http://apache.org/cocoon/i18n/2.1"
                xmlns:xlink="http://www.w3.org/1999/xlink"
                xmlns:resolver="org.ametys.cms.transformation.xslt.ResolveURIComponent"
                xmlns:htmlexpertresolver="org.ametys.cms.transformation.xslt.HTMLExpertLinkResolver"
                exclude-result-prefixes="docbook xlink resolver html i18n htmlexpertresolver">
    
    <xsl:import href="plugin:cms://stylesheets/helper/common.xsl"/>
    
    <xsl:template match="docbook:article">
    	<xsl:param name="level" select="1"/>
    
        <xsl:apply-templates>
            <xsl:with-param name="level" select="$level"/>
            <xsl:with-param name="localLevel" select="1"/>
        </xsl:apply-templates>
    </xsl:template>
    
    <xsl:template match="docbook:section">
        <xsl:param name="level"/>
        <xsl:param name="localLevel"/>
        
        <a name="{generate-id()}"/>
        <xsl:if test="docbook:title/node()">
            <xsl:element name="h{$level}">
                <xsl:call-template name="get-title-styles">
                    <xsl:with-param name="level" select="$localLevel"/>
                </xsl:call-template>
                <xsl:apply-templates select="docbook:title/node()"/>
            </xsl:element>
        </xsl:if>
        <xsl:apply-templates select="*[namespace-uri() != 'http://docbook.org/ns/docbook' or (local-name() != 'section' and local-name() != 'title')]"/>
        <xsl:apply-templates select="docbook:section">
            <xsl:with-param name="level" select="$level+1"/>
            <xsl:with-param name="localLevel" select="$localLevel+1"/>
        </xsl:apply-templates>
    </xsl:template>
    
    <xsl:template match="docbook:para">
        <p>
            <xsl:call-template name="get-styles"/>
            <xsl:apply-templates/>
        </p>
    </xsl:template>
    
    <xsl:template match="docbook:subscript">
        <sub>
            <xsl:apply-templates/>
        </sub>
    </xsl:template>
    
    <xsl:template match="docbook:supscript">
        <sup>
            <xsl:apply-templates/>
        </sup>
    </xsl:template>
    
    <xsl:template match="docbook:para" mode="listitem">
        <xsl:call-template name="get-style"/>
        <xsl:apply-templates/>
    </xsl:template>
    
    <xsl:template match="docbook:phrase[@role='linebreak']">
        <br/>
    </xsl:template>

    <xsl:template match="docbook:emphasis">
        <xsl:choose>
            <xsl:when test="@role='strong'">
                <strong><xsl:apply-templates/></strong>
            </xsl:when>
            <xsl:otherwise>
                <em><xsl:apply-templates/></em>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    
    <xsl:template match="docbook:abbrev">
        <abbr title="{@title}"><xsl:apply-templates/></abbr>
    </xsl:template>
    
    <xsl:template match="docbook:acronym">
        <acronym title="{@title}"><xsl:apply-templates/></acronym>
    </xsl:template>
    
    <xsl:template match="docbook:quote">
        <cite><xsl:apply-templates/></cite>
    </xsl:template>
    
    <xsl:template match="docbook:foreignphrase">
        <span lang="{@xml:lang}" class="language"><xsl:apply-templates/></span>
    </xsl:template>
    
    <xsl:template match="docbook:itemizedlist">
        <ul>
            <xsl:if test="@mark">
                <xsl:attribute name="class"><xsl:value-of select="@mark"/></xsl:attribute>
            </xsl:if>
            <xsl:apply-templates select="docbook:listitem"/>
        </ul>
    </xsl:template>
    
    <xsl:template match="docbook:orderedlist">
        <ol>
            <xsl:if test="@numeration">
                <xsl:attribute name="class"><xsl:value-of select="@numeration"/></xsl:attribute>
            </xsl:if>
            <xsl:apply-templates select="docbook:listitem"/>
        </ol>
    </xsl:template>
    
    <xsl:template match="docbook:listitem">
        <li>
            <xsl:apply-templates select="docbook:para" mode="listitem"/>
        </li>
    </xsl:template>

    <xsl:template match="docbook:table">
        <table>
            <xsl:if test="@width = '100%'">
                <xsl:attribute name="style">width: 100%;</xsl:attribute>
            </xsl:if>
            
            <xsl:copy-of select="@class"/>
            <xsl:copy-of select="@summary"/>
            <xsl:copy-of select="@align"/>
            
            <xsl:if test="@title">
                <caption>
                    <xsl:if test="@titleAlign">
                        <xsl:attribute name="style">text-align: <xsl:value-of select="@titleAlign"/>;</xsl:attribute>
                    </xsl:if>
                    <xsl:value-of select="@title"/>
                </caption>
            </xsl:if>
 
            <xsl:apply-templates select="docbook:tbody"/>
        </table>
    </xsl:template>
    
    <xsl:template match="docbook:tbody">
    	<xsl:choose>
    		<xsl:when test="../@title or ../@summary or docbook:tr/docbook:th">
        		<tbody>
    	    	    <xsl:apply-templates select="docbook:tr"/>
	        	</tbody>
    		</xsl:when>
    		<xsl:otherwise>
   	    	    <xsl:apply-templates select="docbook:tr"/>
    		</xsl:otherwise>
    	</xsl:choose>
    </xsl:template>
    
    <xsl:template match="docbook:tr">
        <tr>
        	<xsl:attribute name="class">
        		<xsl:choose>
        			<xsl:when test="position() mod 2 = 0"><xsl:text>even</xsl:text></xsl:when>
        			<xsl:otherwise><xsl:text>odd</xsl:text></xsl:otherwise>
        		</xsl:choose>
        		<xsl:if test="docbook:td and not(preceding-sibling::*[docbook:td])"><xsl:text> first</xsl:text></xsl:if>
        		<xsl:if test="position() = last()"><xsl:text> last</xsl:text></xsl:if>
        	</xsl:attribute>
            <xsl:apply-templates select="docbook:td|docbook:th"/>
        </tr>
    </xsl:template>
    
    <xsl:template match="docbook:td|docbook:th">
        <xsl:element name="{local-name(.)}">
            <xsl:copy-of select="@colspan"/>
            <xsl:copy-of select="@rowspan"/>
            
            <xsl:variable name="style">
                <xsl:if test="@align">text-align: <xsl:value-of select="@align"/>;</xsl:if>
                <xsl:if test="@valign">vertical-align: <xsl:value-of select="@valign"/>;</xsl:if>
                <xsl:if test="@height">height: <xsl:value-of select="@height"/>;</xsl:if>
                <xsl:if test="@width">width: <xsl:value-of select="@width"/>;</xsl:if>
            </xsl:variable>
            
            <xsl:if test="$style != ''">
                <xsl:attribute name="style"><xsl:value-of select="$style"/></xsl:attribute>
            </xsl:if>
            
            <xsl:apply-templates/>
        </xsl:element>
    </xsl:template>
    
	<xsl:variable name="void">javascript:void(0);</xsl:variable>
    
    <xsl:template match="docbook:link">
    	
    	<xsl:variable name="href">
        	 <xsl:choose>
				<xsl:when test="not(@xlink:type) or @xlink:type = ''"><xsl:value-of select="@xlink:href"/></xsl:when>
               	<xsl:otherwise>
               		<xsl:variable name="hrefResolved" select="resolver:resolve(@xlink:type, @xlink:href, true())"/>
	               	<xsl:choose>
	               		<xsl:when test="$hrefResolved != ''"><xsl:value-of select="$hrefResolved"/></xsl:when>
	               		<xsl:otherwise><xsl:text/><xsl:value-of select="$void"/><xsl:text/></xsl:otherwise>
	               	</xsl:choose>
               </xsl:otherwise>
             </xsl:choose>
        </xsl:variable>
             
    	<xsl:choose>
    		<xsl:when test="starts-with($href,'mailto:')">
    			<xsl:call-template name="mail-antispam">
					<xsl:with-param name="mail" select="$href"></xsl:with-param>
					<xsl:with-param name="class" select="@xrefstyle"></xsl:with-param>
					<xsl:with-param name="title" select="@xlink:title"></xsl:with-param>
					<xsl:with-param name="apply-templates" select="'true'"></xsl:with-param>
				</xsl:call-template>
    		</xsl:when>
    		
    		<xsl:otherwise>
    			<a>
		           	<xsl:attribute name="href"><xsl:value-of select="$href"/></xsl:attribute>
		            
                    <xsl:call-template name="link-title-attribute">
                        <xsl:with-param name="href" select="$href"/>
                    </xsl:call-template>
                    
                    <xsl:call-template name="link-class-attribute">
                        <xsl:with-param name="href" select="$href"/>
                    </xsl:call-template>
		           	
		           	<xsl:if test="@xlink:show = 'new'">
		                <xsl:attribute name="target">_blank</xsl:attribute>
		            </xsl:if>
		           	
		            <xsl:apply-templates/>
		        </a>
    		</xsl:otherwise>
    	</xsl:choose>
        
    </xsl:template>
    
    <xsl:template name="link-title-attribute">
        <xsl:param name="href"/>
        <xsl:if test="@xlink:title">
            <xsl:attribute name="title"><xsl:value-of select="@xlink:title"/></xsl:attribute>
        </xsl:if>
    </xsl:template>
    
    <xsl:template name="link-class-attribute">
        <xsl:param name="href"/>
        <xsl:if test="@xrefstyle">
            <xsl:attribute name="class"><xsl:value-of select="@xrefstyle"/></xsl:attribute>
        </xsl:if>
    </xsl:template>
    
    <xsl:template match="docbook:mediaobject">
        <xsl:apply-templates select="docbook:*"/>
    </xsl:template>
    
    <xsl:template match="docbook:mediaobject/docbook:alt"/>
    <xsl:template match="docbook:mediaobject/docbook:caption"/>
    
    <xsl:template match="docbook:imageobject">
   		
    	<xsl:call-template name="image-render"/>
    </xsl:template>
    
    <xsl:template name="image-render">
    	<xsl:call-template name="image-wrapper"/>
    </xsl:template>
    
    <xsl:template name="image-wrapper">
	      <xsl:variable name="src-full" select="resolver:resolve(docbook:imagedata/@type, docbook:imagedata/@fileref)"/>

          <span style="display: inline-block; text-align: center" class="image-wrapper {../@class}">

				<xsl:choose>
					<xsl:when test="../@zoomable and not($src-full = '') and not(ancestor::docbook:link)">
						<a href="{$src-full}" class="pirobox" rel="single" title="{../docbook:caption}">
                            <xsl:call-template name="image-wrapper-link-attributes"/>
				    		<xsl:call-template name="image" />
				    	</a>
					</xsl:when>
					<xsl:otherwise>
				    	<xsl:call-template name="image" />
					</xsl:otherwise>
				</xsl:choose>          
				                
                <xsl:if test="../docbook:caption">
                    <br style="clear: both"/>
                
                	<span class="legend">
            			<xsl:variable name="width"><xsl:value-of select="substring-before(docbook:imagedata/@width, 'px')" /></xsl:variable>
			            <xsl:attribute name="style">display: inline-block;<xsl:if test="$width != ''"> width: <xsl:value-of select="$width"/>px;</xsl:if></xsl:attribute>
			            
                        <xsl:value-of select="../docbook:caption" />
                    </span>
                </xsl:if>
    	</span>
    </xsl:template>
    
    <xsl:template name="image-wrapper-link-attributes"/>
    
    <xsl:template name="image">
       	<xsl:variable name="srcResolved" select="resolver:resolveImage(docbook:imagedata/@type, docbook:imagedata/@fileref, substring-before(docbook:imagedata/@depth, 'px'), substring-before(docbook:imagedata/@width, 'px'))"/>
        
        <xsl:variable name="src">
            <xsl:call-template name="get-image-src">
                <xsl:with-param name="srcResolved" select="$srcResolved"/>
            </xsl:call-template>
        </xsl:variable>
        
      	<img src="{$src}">
        	<xsl:attribute name="alt"><xsl:value-of select="../docbook:alt"/></xsl:attribute>
            
            <xsl:call-template name="image-title-attribute">
                <xsl:with-param name="srcResolved" select="$srcResolved"/>
            </xsl:call-template>
            
            <xsl:variable name="width"><xsl:value-of select="substring-before(docbook:imagedata/@width, 'px')" /></xsl:variable>
            <xsl:if test="$width != ''"><xsl:attribute name="width"><xsl:value-of select="$width"/></xsl:attribute></xsl:if>

           	<xsl:variable name="height"><xsl:value-of select="substring-before(docbook:imagedata/@depth, 'px')"/></xsl:variable>
            <xsl:if test="$height != ''"><xsl:attribute name="height"><xsl:value-of select="$height"/></xsl:attribute></xsl:if>

            <xsl:call-template name="image-style-attribute">
                <xsl:with-param name="srcResolved" select="$srcResolved"/>
                <xsl:with-param name="height" select="$height"/>
                <xsl:with-param name="width" select="$width"/>
            </xsl:call-template>
            
            <xsl:if test="docbook:imagedata/@align"><xsl:attribute name="align"><xsl:value-of select="docbook:imagedata/@align"/></xsl:attribute></xsl:if>
        </img>
	</xsl:template>
    
    <xsl:template name="get-image-src">
        <xsl:param name="srcResolved"/>
        
        <xsl:value-of select="$srcResolved"/>
    </xsl:template>
    
    <xsl:template name="image-title-attribute">
    	<xsl:param name="srcResolved"/>
        <xsl:if test="../docbook:caption">
            <xsl:attribute name="title"><xsl:value-of select="../docbook:caption"/></xsl:attribute>
        </xsl:if>
    </xsl:template>

    <xsl:template name="image-style-attribute">
        <xsl:param name="srcResolved"/>
        <xsl:param name="width">128</xsl:param>
        <xsl:param name="height">128</xsl:param>
    </xsl:template>
    
    <xsl:template match="html:htmlexpert">
    	<!-- Processing instruction to not touch the HTML produced -->
    	<xsl:processing-instruction name="ametys-unmodifiable">start</xsl:processing-instruction> 
    	<xsl:value-of disable-output-escaping="yes" select="htmlexpertresolver:parseAndResolve(.)"/>
    	<xsl:processing-instruction name="ametys-unmodifiable">end</xsl:processing-instruction> 
    </xsl:template>
    
    <xsl:template match="html:toc">
    </xsl:template>
    
    <xsl:template match="docbook:para[html:toc]">
        <xsl:if test="following-sibling::docbook:section">
            <nav id="toc-{generate-id()}">
              	<ol class="toc">
                 	 <xsl:apply-templates select="following-sibling::docbook:section" mode="toc">
                      	<xsl:with-param name="level" select="'1'"/>
                  	</xsl:apply-templates>
              	</ol>
            </nav>
        </xsl:if>
    </xsl:template>
    
    <xsl:template match="docbook:section" mode="toc">
        <xsl:param name="level"/>
        <xsl:param name="style"/>
        <li>
            <a href="#{generate-id()}">
                <xsl:value-of select="docbook:title"/>
            </a>
            <xsl:if test="docbook:section">
                <ol>
                    <xsl:if test="$style != ''"><xsl:attribute name="class"><xsl:value-of select="$style"/></xsl:attribute></xsl:if>
                    <xsl:apply-templates select="docbook:section" mode="toc">
                        <xsl:with-param name="level" select="$level + 1"/>
                    </xsl:apply-templates>
                </ol>
            </xsl:if>
        </li>
    </xsl:template>
    
    <xsl:template name="get-title-styles">
        <xsl:param name="level"/>
        
        <xsl:attribute name="class">
            <xsl:text>ametys-richtext-title-</xsl:text><xsl:value-of select="$level"/>
        
            <xsl:if test="@class != ''">
                <xsl:text> </xsl:text><xsl:value-of select="@class"/>
            </xsl:if>
        </xsl:attribute>
        
        <xsl:call-template name="get-style"/>
    </xsl:template>
    
    <xsl:template name="get-styles">
        <xsl:copy-of select="@class"/>
    	<xsl:call-template name="get-style"/>
    </xsl:template>
    
    <xsl:template name="get-style">
        <xsl:variable name="style">
            <xsl:if test="@align">text-align:<xsl:value-of select="@align"/>;</xsl:if>
        </xsl:variable>
        <xsl:if test="$style != ''">
            <xsl:attribute name="style"><xsl:value-of select="$style"/></xsl:attribute>
        </xsl:if>
    </xsl:template>
</xsl:stylesheet>
