<?xml version="1.0" encoding="UTF-8"?>
<!--
   Copyright 2010 Anyware Services

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
   -->
<xsl:stylesheet version="1.0" 
                xmlns:docbook="http://docbook.org/ns/docbook" 
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:html="http://www.w3.org/1999/xhtml"
                xmlns:xlink="http://www.w3.org/1999/xlink"
                xmlns:resolver="org.ametys.cms.transformation.xslt.ResolveURIComponent"
                exclude-result-prefixes="docbook xlink resolver html">
	
	<xsl:param name="contextPath"/>
    <xsl:param name="workspaceName"/>
    <xsl:param name="workspaceURI"/>
	
	<xsl:template match="/docbook:article">
  		<xsl:apply-templates>
  			<xsl:with-param name="level" select="1"/>
		</xsl:apply-templates>
	</xsl:template>
	
	<xsl:template match="docbook:section">
		<xsl:param name="level"/>
		<xsl:if test="docbook:title/node()">
			<xsl:element name="h{$level}">
				<xsl:call-template name="get-styles"/>
				<xsl:apply-templates select="docbook:title/node()"/>
			</xsl:element>
		</xsl:if>
        <xsl:apply-templates select="*[namespace-uri() != 'http://docbook.org/ns/docbook' or (local-name() != 'section' and local-name() != 'title')]"/>
		<xsl:apply-templates select="docbook:section">
  			<xsl:with-param name="level" select="$level+1"/>
		</xsl:apply-templates>
	</xsl:template>
    
	<xsl:template match="docbook:para">
		<p>
            <xsl:copy-of select="@class"/>
            <xsl:call-template name="get-style"/>
  			<xsl:apply-templates/>
		</p>
	</xsl:template>
	
	<xsl:template match="docbook:subscript">
		<sub>
  			<xsl:apply-templates/>
		</sub>
	</xsl:template>
	
	<xsl:template match="docbook:supscript">
		<sup>
  			<xsl:apply-templates/>
		</sup>
	</xsl:template>
	
	<xsl:template match="docbook:para" mode="listitem">
        <xsl:call-template name="get-style"/>
		<xsl:apply-templates/>
	</xsl:template>
	
	<xsl:template match="docbook:phrase[@role='linebreak']">
		<br/>
	</xsl:template>
	
	<xsl:template match="docbook:phrase[@class='semantic' and @role]">
		<span class="semantic" annotation="{@role}"><xsl:apply-templates/></span>
	</xsl:template>

	<xsl:template match="docbook:emphasis">
		<xsl:choose>
			<xsl:when test="@role='strong'">
				<strong><xsl:apply-templates/></strong>
			</xsl:when>
			<xsl:otherwise>
				<em><xsl:apply-templates/></em>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
    
    <xsl:template match="docbook:abbrev">
        <abbr title="{@title}"><xsl:apply-templates/></abbr>
    </xsl:template>
    
    <xsl:template match="docbook:acronym">
        <acronym title="{@title}"><xsl:apply-templates/></acronym>
    </xsl:template>
    
    <xsl:template match="docbook:quote">
        <cite><xsl:apply-templates/></cite>
    </xsl:template>
    
    <xsl:template match="docbook:foreignphrase">
        <span lang="{@xml:lang}" class="language"><xsl:apply-templates/></span>
    </xsl:template>
    
    <xsl:template match="docbook:itemizedlist">
        <ul>
            <xsl:if test="@mark">
                <xsl:attribute name="class"><xsl:value-of select="@mark"/></xsl:attribute>
            </xsl:if>
            <xsl:apply-templates select="docbook:listitem"/>
        </ul>
    </xsl:template>
    
    <xsl:template match="docbook:orderedlist">
        <ol>
            <xsl:if test="@numeration">
                <xsl:attribute name="class"><xsl:value-of select="@numeration"/></xsl:attribute>
            </xsl:if>
            <xsl:apply-templates select="docbook:listitem"/>
        </ol>
    </xsl:template>
    
    <xsl:template match="docbook:itemizedlist|docbook:orderedlist" mode="listitem">
        <xsl:apply-templates select="."/>
    </xsl:template>
    
    <xsl:template match="docbook:listitem">
        <li>
            <xsl:apply-templates select="docbook:para" mode="listitem"/>
        </li>
    </xsl:template>

    <xsl:template match="docbook:table">
        <table>
            <xsl:if test="@width = '100%'">
                <xsl:attribute name="style">width: 100%;</xsl:attribute>
            </xsl:if>
            
            <xsl:copy-of select="@class"/>
            <xsl:copy-of select="@summary"/>
            <xsl:copy-of select="@align"/>
            <xsl:copy-of select="@marker"/>
            
            <xsl:if test="@title">
                <caption>
                    <xsl:if test="@titleAlign">
                        <xsl:attribute name="style">text-align: <xsl:value-of select="@titleAlign"/>;</xsl:attribute>
                    </xsl:if>
                    <xsl:value-of select="@title"/>
                </caption>
            </xsl:if>
 
            <xsl:apply-templates select="docbook:tbody"/>
        </table>
    </xsl:template>
    
    <xsl:template match="docbook:tbody">
        <tbody>
            <xsl:apply-templates select="docbook:tr"/>
        </tbody>
    </xsl:template>
    
    <xsl:template match="docbook:tr">
        <tr>
            <xsl:apply-templates select="docbook:td|docbook:th"/>
        </tr>
    </xsl:template>
    
    <xsl:template match="docbook:td|docbook:th">
        <xsl:element name="{local-name(.)}">
            <xsl:copy-of select="@colspan"/>
            <xsl:copy-of select="@rowspan"/>
            
            <xsl:variable name="style">
                <xsl:if test="@align">text-align: <xsl:value-of select="@align"/>;</xsl:if>
                <xsl:if test="@valign">vertical-align: <xsl:value-of select="@valign"/>;</xsl:if>
                <xsl:if test="@height">height: <xsl:value-of select="@height"/>;</xsl:if>
                <xsl:if test="@width">width: <xsl:value-of select="@width"/>;</xsl:if>
            </xsl:variable>
            
            <xsl:if test="$style != ''">
                <xsl:attribute name="style"><xsl:value-of select="$style"/></xsl:attribute>
            </xsl:if>
            
            <xsl:apply-templates/>
        </xsl:element>
    </xsl:template>
    
    <xsl:template match="docbook:link">
        <a href="{resolver:resolve(@xlink:type, @xlink:href, true())}">
            <xsl:attribute name="data-ametys-href"><xsl:value-of select="@xlink:href"/></xsl:attribute>
            
            <xsl:if test="@xlink:type">
                <xsl:attribute name="data-ametys-type"><xsl:value-of select="@xlink:type"/></xsl:attribute>
            </xsl:if>
 
            <xsl:if test="@xlink:title">
                <xsl:attribute name="title"><xsl:value-of select="@xlink:title"/></xsl:attribute>
            </xsl:if>
 
            <xsl:if test="@xrefstyle">
                <xsl:attribute name="class"><xsl:value-of select="@xrefstyle"/></xsl:attribute>
            </xsl:if>
            
            <xsl:if test="@xlink:show = 'new'">
                <xsl:attribute name="target">_blank</xsl:attribute>
            </xsl:if>
 
            <xsl:apply-templates/>
        </a>
    </xsl:template>
    
    <xsl:template match="docbook:mediaobject">
        <xsl:apply-templates select="docbook:*"/>
    </xsl:template>

    <xsl:template match="docbook:mediaobject/docbook:alt"/>
    <xsl:template match="docbook:mediaobject/docbook:caption"/>

    <xsl:template match="docbook:imageobject">
        <img data-ametys-src="{docbook:imagedata/@fileref}" data-ametys-type="{docbook:imagedata/@type}">
            <xsl:variable name="width"><xsl:value-of select="substring-before(docbook:imagedata/@width, 'px')"/></xsl:variable>
            <xsl:if test="$width != ''"><xsl:attribute name="width"><xsl:value-of select="$width"/></xsl:attribute></xsl:if>
            
            <xsl:variable name="height"><xsl:value-of select="substring-before(docbook:imagedata/@depth, 'px')"/></xsl:variable>
            <xsl:if test="$height != ''"><xsl:attribute name="height"><xsl:value-of select="$height"/></xsl:attribute></xsl:if>
            
            <xsl:variable name="srcResolved">
	            <xsl:choose>
	                <xsl:when test="docbook:imagedata/@type != 'local'">
	                    <xsl:value-of select="resolver:resolve(docbook:imagedata/@type, docbook:imagedata/@fileref)"/>
	                </xsl:when>
	                <xsl:when test="docbook:imagedata/@resourceByUUID != ''">
	                    <xsl:value-of select="docbook:imagedata/@resourceByUUID"/>
	                </xsl:when>
	                <xsl:otherwise>
	                    <xsl:value-of select="docbook:imagedata/@base64"/>
	                </xsl:otherwise>
	            </xsl:choose>
            </xsl:variable>
            
            <xsl:attribute name="src">
                    <xsl:choose>
                        <xsl:when test="$srcResolved != ''"><xsl:value-of select="$srcResolved"/></xsl:when>
                        <!-- 1 pixel transparent gif -->
                        <xsl:otherwise>data:image/gif;base64,R0lGODlhAQABAIAAAAAAAP///yH5BAEAAAAALAAAAAABAAEAAAIBRAA7</xsl:otherwise>
                    </xsl:choose>
            </xsl:attribute>
            <xsl:if test="not($srcResolved != '')">
                <xsl:attribute name="data-ametys-missing">true</xsl:attribute>
            </xsl:if>

            <xsl:copy-of select="../@class"/>
            
            <xsl:if test="../@zoomable">
            	<xsl:copy-of select="../@zoomable"/>
            </xsl:if>

            <xsl:if test="../docbook:alt">
                <xsl:attribute name="alt"><xsl:value-of select="../docbook:alt"/></xsl:attribute>
            </xsl:if>
            <xsl:if test="../docbook:caption">
                <xsl:attribute name="title"><xsl:value-of select="../docbook:caption"/></xsl:attribute>
            </xsl:if>
            
            <xsl:if test="docbook:imagedata/@align"><xsl:attribute name="align"><xsl:value-of select="docbook:imagedata/@align"/></xsl:attribute></xsl:if>
        </img>
    </xsl:template>
    
    <xsl:template match="html:htmlexpert">
    	<xsl:comment>
    		<xsl:text> htmlexpert</xsl:text>
    		<xsl:if test="@pellet">
    			<xsl:text>:</xsl:text><xsl:value-of select="@pellet"/>
    		</xsl:if>
    		<xsl:text> </xsl:text>
    		<xsl:value-of select="."/>
    		<xsl:text> </xsl:text>
    	</xsl:comment>
    </xsl:template>
    
    <xsl:template match="html:toc">
        <xsl:comment>
            <xsl:text> toc</xsl:text>
            <xsl:if test="@pellet">
                <xsl:text>:</xsl:text><xsl:value-of select="@pellet"/>
            </xsl:if>
            <xsl:text> </xsl:text>
            <xsl:value-of select="."/>
            <xsl:text> </xsl:text>
        </xsl:comment>
    </xsl:template>
    
    <xsl:template name="get-styles">
         <xsl:copy-of select="@class"/>
         <xsl:call-template name="get-style"/>
    </xsl:template>
    
    <xsl:template name="get-style">
        <xsl:variable name="style">
            <xsl:if test="@align">text-align:<xsl:value-of select="@align"/>;</xsl:if>
        </xsl:variable>
        <xsl:if test="$style != ''">
            <xsl:attribute name="style"><xsl:value-of select="$style"/></xsl:attribute>
        </xsl:if>
    </xsl:template>
</xsl:stylesheet>
