<?xml version="1.0" encoding="UTF-8"?>
<!--
   Copyright 2010 Anyware Services

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
   -->
<!--DOCTYPE xsl:stylesheet PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "xhtml1-transitional.dtd"-->
<xsl:stylesheet version="1.0" 
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:resolver="org.ametys.cms.transformation.xslt.ResolveURIComponent"
                xmlns:htmlexpertresolver="org.ametys.cms.transformation.xslt.HTMLExpertLinkResolver"
                exclude-result-prefixes="resolver htmlexpertresolver">
                
	<xsl:variable name="void">javascript:void(0);</xsl:variable>
    <xsl:variable name="notfound-image-url-prefix" select="concat($contextPath, '/plugins/core-ui/resources/img/imagenotfound')"/>
    
    <xsl:template match="a">
        <a>
           	<xsl:variable name="href">
           	 	<xsl:choose>
					<xsl:when test="not(@data-ametys-type) or @data-ametys-type = ''"><xsl:value-of select="@href"/></xsl:when>
	                 <xsl:otherwise>
	                 	<xsl:variable name="hrefResolved" select="resolver:resolve(@data-ametys-type, @href, true())"/>
	                 	<xsl:choose>
	                 		<xsl:when test="$hrefResolved != ''"><xsl:value-of select="$hrefResolved"/></xsl:when>
	                 		<xsl:otherwise><xsl:text/><xsl:value-of select="$void"/><xsl:text/></xsl:otherwise>
	                 	</xsl:choose>
	                 </xsl:otherwise>
                 </xsl:choose>
            </xsl:variable>
           	 
            <xsl:attribute name="href"><xsl:value-of select="$href"/></xsl:attribute>
            
            <xsl:call-template name="link-title-attribute">
                <xsl:with-param name="href" select="$href"/>
            </xsl:call-template>
            
            <xsl:call-template name="link-class-attribute">
                <xsl:with-param name="href" select="$href"/>
            </xsl:call-template>
            
            <xsl:if test="@class">
                <xsl:attribute name="class"><xsl:value-of select="@class"/></xsl:attribute>
            </xsl:if>
            
            <xsl:if test="@target = '_blank'">
                <xsl:attribute name="onclick">window.open(this.href); return false;</xsl:attribute>
            </xsl:if>
            
            <xsl:apply-templates/>
        </a>
    </xsl:template>
    
    <xsl:template name="link-title-attribute">
        <xsl:param name="href"/>
        <xsl:if test="$href != $void and @title">
            <xsl:attribute name="title"><xsl:value-of select="@title"/></xsl:attribute>
        </xsl:if>
    </xsl:template>
    
    <xsl:template name="link-class-attribute">
        <xsl:param name="href"/>
        <xsl:if test="@class">
            <xsl:attribute name="class"><xsl:value-of select="@class"/></xsl:attribute>
        </xsl:if>
    </xsl:template>
    
    <xsl:template match="img">
         <img>
          	<xsl:variable name="srcResolved" select="resolver:resolveImage(@data-ametys-type, @href, substring-before(@height, 'px'), substring-before(@width, 'px'))"/>
            
            <xsl:attribute name="src">
                <xsl:call-template name="get-image-src">
                    <xsl:with-param name="srcResolved" select="$srcResolved"/>
                    <xsl:with-param name="width" select="@width"/>
                    <xsl:with-param name="height" select="@height"/>
                </xsl:call-template>
            </xsl:attribute>

            <xsl:copy-of select="@class"/>
			<xsl:copy-of select="@alt"/>
            
            <xsl:call-template name="image-title-attribute">
                <xsl:with-param name="srcResolved" select="$srcResolved"/>
            </xsl:call-template>
                        
            <xsl:call-template name="image-style-attribute">
                <xsl:with-param name="srcResolved" select="$srcResolved"/>
                <xsl:with-param name="width" select="substring-before(@width, 'px')"/>
                <xsl:with-param name="height" select="substring-before(@height, 'px')"/>
            </xsl:call-template>
            
            <xsl:if test="@align">
            	 <xsl:copy-of select="@align"/>
            </xsl:if>
            
            <xsl:if test="@width">
            	 <xsl:copy-of select="@width"/>
            </xsl:if>
            
            <xsl:if test="@height">
            	 <xsl:copy-of select="@height"/>
            </xsl:if>
      	</img>
    </xsl:template>
    
    <xsl:template name="get-image-src">
        <xsl:param name="srcResolved"/>
        <xsl:param name="width"/>
        <xsl:param name="height"/>
        
        <xsl:choose>
            <xsl:when test="$srcResolved != ''"><xsl:value-of select="$srcResolved"/></xsl:when>
            <xsl:otherwise>
                 <xsl:variable name="image-not-found-end">
                    <xsl:choose>
                        <xsl:when test="$width != '' and $height != ''">_max<xsl:value-of select="$height"/>x<xsl:value-of select="$width"/>.png</xsl:when>
                        <xsl:otherwise>.png</xsl:otherwise>
                    </xsl:choose>
                </xsl:variable>
                <xsl:value-of select="$notfound-image-url-prefix"/><xsl:value-of select="$image-not-found-end"/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    
    <xsl:template name="image-title-attribute">
        <xsl:param name="srcResolved"/>
        <xsl:if test="@title">
            <xsl:copy-of select="@title"/>
        </xsl:if>
    </xsl:template>
    
    <xsl:template name="image-style-attribute">
        <xsl:param name="srcResolved"/>
        <xsl:param name="width">128</xsl:param>
        <xsl:param name="height">128</xsl:param>
    </xsl:template>    
    
    <xsl:template match="htmlexpert">
    	<xsl:value-of disable-output-escaping="yes" select="htmlexpertresolver:parseAndResolve(.)"/>
    </xsl:template>
    
    <xsl:template match="*">
    	<xsl:copy>
    		<xsl:copy-of select="@*"/>
    		<xsl:apply-templates/>
    	</xsl:copy>
    </xsl:template>
</xsl:stylesheet>
