<?xml version="1.0" encoding="UTF-8"?>
<!--
   Copyright 2010 Anyware Services

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
   -->
<!--DOCTYPE xsl:stylesheet PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "xhtml1-transitional.dtd"-->
<xsl:stylesheet version="1.0" 
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:resolver="org.ametys.cms.transformation.xslt.ResolveURIComponent"
                exclude-result-prefixes="resolver">
                
    <xsl:param name="contextPath"/>
    <xsl:param name="prefix"/>
    
    <xsl:variable name="notfound-image-url-prefix" select="concat($contextPath, '/plugins/core-ui/resources/img/imagenotfound')"/>
    
    <xsl:template match="*">
    	<xsl:copy>
    		<xsl:copy-of select="@*"/>
    		<xsl:apply-templates/>
    	</xsl:copy>
    </xsl:template>
    
    <!-- Transmit comments to avoid auto-closing tags. -->
    <xsl:template match="comment()">
        <xsl:copy-of select="."/>
    </xsl:template>
    
    <xsl:template match="a">
        <a>
            <xsl:attribute name="href">
                <xsl:choose>
                    <xsl:when test="not(@data-ametys-type) or @data-ametys-type = ''"><xsl:value-of select="@href"/></xsl:when>
                    <xsl:otherwise><xsl:value-of select="resolver:resolve(@data-ametys-type, @href, true())"/></xsl:otherwise>
                </xsl:choose>
            </xsl:attribute>
			
			<xsl:attribute name="data-ametys-href"><xsl:value-of select="@href"/></xsl:attribute>
			<xsl:if test="@data-ametys-type">
                <xsl:copy-of select="@data-ametys-type"/>
            </xsl:if>
                        
            <xsl:if test="@title">
               <xsl:copy-of select="@title"/>
            </xsl:if>
            
             <xsl:if test="@class">
               <xsl:copy-of select="@class"/>
            </xsl:if>
 
            <xsl:apply-templates/>
        </a>
    </xsl:template>
    
     <xsl:template match="img">
        <img data-ametys-src="{@href}" data-ametys-type="{@data-ametys-type}">
            <xsl:variable name="width"><xsl:value-of select="substring-before(@width, 'px')"/></xsl:variable>
            <xsl:if test="$width != ''"><xsl:attribute name="width"><xsl:value-of select="$width"/></xsl:attribute></xsl:if>
            
            <xsl:variable name="height"><xsl:value-of select="substring-before(@height, 'px')"/></xsl:variable>
            <xsl:if test="$height != ''"><xsl:attribute name="height"><xsl:value-of select="$height"/></xsl:attribute></xsl:if>
            
            <xsl:variable name="srcResolved" select="resolver:resolve(@data-ametys-type, @absolutehref)"/>
            <xsl:attribute name="src">
                    <xsl:choose>
                        <xsl:when test="$srcResolved != ''"><xsl:value-of select="$srcResolved"/></xsl:when>
                        <!-- 1 pixel transparent gif -->
                        <xsl:otherwise>data:image/gif;base64,R0lGODlhAQABAIAAAAAAAP///yH5BAEAAAAALAAAAAABAAEAAAIBRAA7</xsl:otherwise>
                    </xsl:choose>
            </xsl:attribute>
            <xsl:if test="not($srcResolved != '')">
                <xsl:variable name="image-not-found-end">
                    <xsl:choose>
                        <xsl:when test="$width != '' and $height != ''">_max<xsl:value-of select="$height"/>x<xsl:value-of select="$width"/>.png</xsl:when>
                        <xsl:otherwise>.png</xsl:otherwise>
                    </xsl:choose>
                </xsl:variable>
                <xsl:attribute name="style">background-image: url('<xsl:value-of select="$notfound-image-url-prefix"/><xsl:value-of select="$image-not-found-end"/>'); background-position: center;</xsl:attribute>
            </xsl:if>
            
           	<xsl:copy-of select="@class"/>
 			<xsl:copy-of select="@alt"/>
           	
           	<xsl:if test="@title">
                <xsl:copy-of select="@title"/>
            </xsl:if>
            
            <xsl:if test="@align">
            	 <xsl:copy-of select="@align"/>
            </xsl:if>
        </img>
    </xsl:template>
    
    <xsl:template match="htmlexpert">
    	<xsl:comment>
    		<xsl:text> htmlexpert</xsl:text>
    		<xsl:if test="@pellet">
    			<xsl:text>:</xsl:text><xsl:value-of select="@pellet"/>
    		</xsl:if>
    		<xsl:text> </xsl:text>
    		<xsl:value-of select="."/>
    		<xsl:text> </xsl:text>
    	</xsl:comment>
    </xsl:template>
    
    <xsl:template match="toc">
        <xsl:comment>
            <xsl:text> toc</xsl:text>
            <xsl:if test="@pellet">
                <xsl:text>:</xsl:text><xsl:value-of select="@pellet"/>
            </xsl:if>
            <xsl:text> </xsl:text>
            <xsl:value-of select="."/>
            <xsl:text> </xsl:text>
        </xsl:comment>
    </xsl:template>
    
</xsl:stylesheet>
