<?xml version="1.0" encoding="UTF-8"?>
<!--
   Copyright 2010 Anyware Services

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
   -->
<xsl:stylesheet version="1.0"
    xmlns="http://docbook.org/ns/docbook" 
    xmlns:html="http://www.w3.org/1999/xhtml"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:math="http://exslt.org/math"
	xmlns:dyn="http://exslt.org/dynamic"
	xmlns:xalan="http://xml.apache.org/xalan"
    xmlns:editor="org.ametys.cms.transformation.xslt.InlineEditorHelper"
    xmlns:xlink="http://www.w3.org/1999/xlink"
	exclude-result-prefixes="math dyn xalan editor">
	
	<xsl:output method="xml" indent="yes"/>
	
	<xsl:template match="/*">
		<article version="5.0">
			<xsl:apply-templates select="*"/>
		</article>
	</xsl:template>
	
	<xsl:template match="*[starts-with(name(),'h') and string-length(name())=2 and string(number(substring(name(),2,1)))!='NaN']">
		<xsl:param name="mode"/>
        <xsl:choose>
        	<!-- A <h*> is kept if it is a root element or in a <div> (which are eliminated) -->
            <xsl:when test="count(ancestor::div) + 1 = count(ancestor::*) and $mode != 'para-content'">
				<xsl:variable name="content">
					<section level="{substring(name(),2,1)}">
		            	<xsl:call-template name="get-styles"/>

						<title><xsl:apply-templates select="node()[name() != 'table']"/></title>
					</section>
				</xsl:variable>
				<xsl:choose>
					<xsl:when test="table">
						<xsl:apply-templates select="table"/>
						<xsl:if test="count(./*[local-name(.)!='table'])!=0 or string-length(.)!=0">
							<xsl:copy-of select="$content"/>
						</xsl:if>
					</xsl:when>
					<xsl:otherwise>
						<xsl:copy-of select="$content"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>			
			<!-- For <h*> not root elements (in tables, ...) -->
			<xsl:otherwise>
				<xsl:call-template name="para-content"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template match="p">
		<xsl:call-template name="para-content"/>
	</xsl:template>

	<xsl:template match="sub">
   		<subscript>
   			<xsl:apply-templates/>
      	</subscript>
	</xsl:template>

	<xsl:template match="sup">
   		<supscript>
   			<xsl:apply-templates/>
      	</supscript>
	</xsl:template>

	<xsl:template match="br">
		<phrase role="linebreak"/>
	</xsl:template>
	
	<xsl:template match="strong|b">
		<emphasis role="strong">
			<xsl:apply-templates/>
		</emphasis>
	</xsl:template>
	
	<xsl:template match="em|i">
		<emphasis>
			<xsl:apply-templates/>
		</emphasis>
	</xsl:template>
    
    <xsl:template match="abbr">
        <abbrev title="{@title}"><xsl:apply-templates/></abbrev>
    </xsl:template>
	
    <xsl:template match="acronym">
        <acronym title="{@title}"><xsl:apply-templates/></acronym>
    </xsl:template>
    
    <xsl:template match="cite">
        <quote><xsl:apply-templates/></quote>
    </xsl:template>
    
    <xsl:template match="span[@class='language' and @lang]">
        <foreignphrase xml:lang="{@lang}"><xsl:apply-templates/></foreignphrase>
    </xsl:template>
    
    <xsl:template match="span[@class='semantic' and @annotation]">
        <phrase class="semantic" role="{@annotation}"><xsl:apply-templates/></phrase>
    </xsl:template>
    
    <xsl:template match="ol">
        <orderedlist>
            <xsl:if test="@class">
                <xsl:attribute name="numeration"><xsl:value-of select="@class"/></xsl:attribute>
            </xsl:if>
            <xsl:apply-templates/>
        </orderedlist>
    </xsl:template>
    
    <xsl:template match="ul">
        <itemizedlist>
            <xsl:if test="@class">
                <xsl:attribute name="mark"><xsl:value-of select="@class"/></xsl:attribute>
            </xsl:if>
            <xsl:apply-templates/>
        </itemizedlist>
    </xsl:template>
    
    <xsl:template match="ol|ul" mode="listitem">
        <xsl:apply-templates select="." />
    </xsl:template>
    
    <xsl:template match="li">
        <listitem>
            <para>
                <xsl:variable name="align" select="editor:getStyleValue(@style, 'text-align')"/>
                <xsl:if test="$align != ''">
                    <xsl:attribute name="align"><xsl:value-of select="$align"/></xsl:attribute>
                </xsl:if>
                
                <xsl:apply-templates/>
            </para>
        </listitem>
    </xsl:template>
    
    <xsl:template match="table">
        <table>
            <xsl:variable name="width" select="editor:getStyleValue(@style, 'width')"/>
            <xsl:if test="$width = '100%'">
                <xsl:attribute name="width">100%</xsl:attribute>
            </xsl:if>
            
            <xsl:if test="caption/text()">
                <xsl:attribute name="title"><xsl:value-of select="caption/text()"/></xsl:attribute>
                
                <xsl:variable name="captionTextAlign" select="editor:getStyleValue(caption/@style, 'text-align')"/>
                <xsl:if test="$captionTextAlign != ''">
                    <xsl:attribute name="titleAlign"><xsl:value-of select="$captionTextAlign"/></xsl:attribute>
                </xsl:if>
            </xsl:if>
            
            <xsl:copy-of select="@class"/>
            <xsl:copy-of select="@summary"/>
            <xsl:copy-of select="@align"/>
            <xsl:copy-of select="@marker"/>
            
            <xsl:apply-templates select="tbody"/>
        </table>
    </xsl:template>
    
    <xsl:template match="tbody">
        <tbody>
            <xsl:apply-templates select="tr"/>
        </tbody>
    </xsl:template>
    
    <xsl:template match="tr">
        <tr>
            <xsl:apply-templates select="td|th"/>
        </tr>
    </xsl:template>
    
    <xsl:template match="td|th">
        <xsl:copy>
            <xsl:copy-of select="@colspan"/>
            <xsl:copy-of select="@rowspan"/>
            
            <xsl:variable name="valign" select="editor:getStyleValue(@style, 'vertical-align')"/>
            <xsl:if test="$valign != ''">
                <xsl:attribute name="valign"><xsl:value-of select="$valign"/></xsl:attribute>
            </xsl:if>
            
            <xsl:variable name="align" select="editor:getStyleValue(@style, 'text-align')"/>
            <xsl:if test="$align != ''">
                <xsl:attribute name="align"><xsl:value-of select="$align"/></xsl:attribute>
            </xsl:if>
            
            <xsl:variable name="height" select="editor:getStyleValue(@style, 'height')"/>
            <xsl:if test="$height != ''">
                <xsl:attribute name="height"><xsl:value-of select="$height"/></xsl:attribute>
            </xsl:if>
            
            <xsl:variable name="width" select="editor:getStyleValue(@style, 'width')"/>
            <xsl:if test="$width != ''">
                <xsl:attribute name="width"><xsl:value-of select="$width"/></xsl:attribute>
            </xsl:if>
            
            <!-- When coming from tinymce, user can create two kind of html in a table cell 
                 can be classic blocks elements (normal behavior): <td><p>test 1</p><p>test 2</p></td>
                 or can be non-blocks elements (abnormal behavior): <td>direct <strong>text</strong> <img src="..."/></td> 
                 but usually tinymce does not generate mixed block and non-blocks content 
                 
                 meanwhile when generating the normal behavior, some useless text (&#160; or \n) can stay, so we do not simply call para-content
                 because it would generate additional empty para -->
            <xsl:choose>
            	<xsl:when test="p|div|ol|ul|table|form|*[starts-with(name(),'h') and string-length(name())=2 and string(number(substring(name(),2,1)))!='NaN']">
            		<xsl:apply-templates/>
            	</xsl:when>
            	<xsl:otherwise>
		            <xsl:call-template name="para-content"/>
            	</xsl:otherwise>
            </xsl:choose>
        </xsl:copy>
    </xsl:template>
    
    <xsl:template match="a">
        <link>
            <xsl:choose>
                <xsl:when test="@data-ametys-type">
                    <xsl:attribute name="xlink:href"><xsl:value-of select="@data-ametys-href"/></xsl:attribute>
                    <xsl:attribute name="xlink:type"><xsl:value-of select="@data-ametys-type"/></xsl:attribute>                
                </xsl:when>
                <xsl:when test="@data-ametys-href">
                    <xsl:attribute name="xlink:href"><xsl:value-of select="@data-ametys-href"/></xsl:attribute>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:attribute name="xlink:href"><xsl:value-of select="@href"/></xsl:attribute>
                </xsl:otherwise>
            </xsl:choose>
            
            <xsl:if test="@title">
                <xsl:attribute name="xlink:title"><xsl:value-of select="@title"/></xsl:attribute>
            </xsl:if>
 
            <xsl:if test="@target = '_blank'">
                <xsl:attribute name="xlink:show">new</xsl:attribute>
            </xsl:if>
 
            <xsl:if test="@class">
                <xsl:attribute name="xrefstyle"><xsl:value-of select="@class"/></xsl:attribute>
            </xsl:if>
            
            <xsl:apply-templates/>
        </link>
    </xsl:template>
    
    <xsl:template match="img[not(@marker)]">
        <mediaobject>
            <xsl:copy-of select="@class"/>
            <xsl:copy-of select="@zoomable"/>
            
            <xsl:if test="@alt">
                <alt><xsl:value-of select="@alt"/></alt>
            </xsl:if>
            
            <xsl:if test="@title">
                <caption><xsl:value-of select="@title"/></caption>
            </xsl:if>
            
            <xsl:if test="@align">
                <xsl:attribute name="align"><xsl:value-of select="@align"/></xsl:attribute>
            </xsl:if>
            
            <xsl:variable name="width" select="editor:getStyleValue(@style, 'width', concat(@width, 'px'))"/>
            <xsl:variable name="height" select="editor:getStyleValue(@style, 'height', concat(@height, 'px'))"/>
            
            <imageobject>
                <imagedata fileref="{@data-ametys-src}" type="{@data-ametys-type}">
                    <xsl:if test="$width != ''"><xsl:attribute name="width"><xsl:value-of select="$width"/></xsl:attribute></xsl:if>
                    <xsl:if test="$height != ''"><xsl:attribute name="depth"><xsl:value-of select="$height"/></xsl:attribute></xsl:if>
                </imagedata>
            </imageobject>
        </mediaobject>
    </xsl:template>

    <xsl:template match="comment()[starts-with(., ' htmlexpert ') or starts-with(., ' htmlexpert:')]">
    	<html:htmlexpert>
   			<xsl:if test="starts-with(., ' htmlexpert:')">
	    		<xsl:attribute name="pellet"><xsl:value-of select="substring-before(substring-after(., ' htmlexpert:'), ' ')"/></xsl:attribute>
	    	</xsl:if>
	    	
			<xsl:value-of select="substring-before(substring-after(substring-after(., ' htmlexpert'), ' '), ' ')"/>
    	</html:htmlexpert>
	</xsl:template>

    <xsl:template match="comment()[starts-with(., ' toc ') or starts-with(., ' toc:')]">
        <html:toc>
            <xsl:if test="starts-with(., ' autooutline:')">
                <xsl:attribute name="pellet"><xsl:value-of select="substring-before(substring-after(., ' toc:'), ' ')"/></xsl:attribute>
            </xsl:if>
            
            <xsl:value-of select="substring-before(substring-after(substring-after(., ' toc'), ' '), ' ')"/>
        </html:toc>
    </xsl:template>
    
    <xsl:template match="div">
        <xsl:call-template name="para-content"/>
    </xsl:template>
    
    <xsl:template match="span">
        <xsl:apply-templates/>
    </xsl:template>
    
    <xsl:template match="*" priority="-1000">
        <!-- Ignore others unsupported tags -->
    </xsl:template>

    <xsl:template name="para-content">
        <xsl:apply-templates select="p|div|ol|ul|table|form|*[starts-with(name(),'h') and string-length(name())=2 and string(number(substring(name(),2,1)))!='NaN']" />
        <xsl:if test="node()[name()!='p' and name()!='div' and name()!='ol' and name()!='ul' and name()!='table' and name()!='form' and not(starts-with(name(),'h') and string-length(name())=2 and string(number(substring(name(),2,1)))!='NaN')]">
            <para>
            	<xsl:call-template name="get-styles"/>
                
                <xsl:apply-templates select="node()[name()!='p' and name()!='div' and name()!='ol' and name()!='ul' and name()!='table' and name()!='form' and not(starts-with(name(),'h') and string-length(name())=2)]">
                    <xsl:with-param name="mode" select="'para-content'"/>
                </xsl:apply-templates>
            </para>
        </xsl:if>
    </xsl:template>
    
    <xsl:template name="get-styles">
	    <xsl:copy-of select="@class"/>
	    
	    <xsl:variable name="align" select="editor:getStyleValue(@style, 'text-align')"/>
	    <xsl:if test="$align != ''">
	        <xsl:attribute name="align"><xsl:value-of select="$align"/></xsl:attribute>
	    </xsl:if>
    </xsl:template>
</xsl:stylesheet>
