<?xml version="1.0" encoding="UTF-8"?>
<!--
   Copyright 2010 Anyware Services

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
   -->
<xsl:stylesheet version="1.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:math="http://exslt.org/math"
	xmlns:dyn="http://exslt.org/dynamic"
	xmlns:xalan="http://xml.apache.org/xalan"
    xmlns:editor="org.ametys.cms.transformation.xslt.InlineEditorHelper"
	exclude-result-prefixes="math dyn xalan editor">
	
	<xsl:output method="xml" indent="yes"/>
	
	<xsl:template match="*">
    	<xsl:copy>
    		<xsl:copy-of select="@*"/>
    		<xsl:apply-templates/>
    	</xsl:copy>
    </xsl:template>
    
    <xsl:template match="a">
        <a>
        	<xsl:if test="@title">
        		<xsl:copy-of select="@title"/>
        	</xsl:if>
        	
        	<xsl:if test="@target = '_blank'">
        		<xsl:copy-of select="@target"/>
        	</xsl:if>
        	
        	<xsl:if test="@class">
        		<xsl:copy-of select="@class"/>
        	</xsl:if>
        	
            <xsl:choose>
                <xsl:when test="@data-ametys-type">
                   	<xsl:copy-of select="@data-ametys-type"/>
        		   	<xsl:attribute name="href"><xsl:value-of select="@data-ametys-href"/></xsl:attribute>
                </xsl:when>
                <xsl:otherwise>
                   <xsl:copy-of select="@href"/>
                </xsl:otherwise>
            </xsl:choose>
            
            <xsl:apply-templates/>
        </a>
    </xsl:template>
    
    <xsl:template match="img[not(@marker)]">
        <img>
            <xsl:copy-of select="@class"/>
            <xsl:copy-of select="@alt"/>
            
            <xsl:if test="@title">
                 <xsl:copy-of select="@title"/>
            </xsl:if>
            
            <xsl:if test="@align">
            	 <xsl:copy-of select="@align"/>
            </xsl:if>
            
            <xsl:variable name="width" select="editor:getStyleValue(@style, 'width', concat(@width, 'px'))"/>
            <xsl:variable name="height" select="editor:getStyleValue(@style, 'height', concat(@height, 'px'))"/>
            
            <xsl:if test="$width != ''"><xsl:attribute name="width"><xsl:value-of select="$width"/></xsl:attribute></xsl:if>
            <xsl:if test="$height != ''"><xsl:attribute name="height"><xsl:value-of select="$height"/></xsl:attribute></xsl:if>
            
            <xsl:attribute name="href"><xsl:value-of select="@data-ametys-src"/></xsl:attribute>
            <xsl:attribute name="data-ametys-type"><xsl:value-of select="@data-ametys-type"/></xsl:attribute>
        </img>
    </xsl:template>

    <xsl:template match="comment()[starts-with(., ' htmlexpert ') or starts-with(., ' htmlexpert:')]">
    	<htmlexpert>
   			<xsl:if test="starts-with(., ' htmlexpert:')">
	    		<xsl:attribute name="pellet"><xsl:value-of select="substring-before(substring-after(., ' htmlexpert:'), ' ')"/></xsl:attribute>
	    	</xsl:if>
	    	
			<xsl:value-of select="substring-before(substring-after(substring-after(., ' htmlexpert'), ' '), ' ')"/>
    	</htmlexpert>
	</xsl:template>
	
    <xsl:template match="comment()[starts-with(., ' toc ') or starts-with(., ' toc:')]">
        <toc>
            <xsl:if test="starts-with(., ' toc:')">
                <xsl:attribute name="pellet"><xsl:value-of select="substring-before(substring-after(., ' toc:'), ' ')"/></xsl:attribute>
            </xsl:if>
            
            <xsl:value-of select="substring-before(substring-after(substring-after(., ' toc'), ' '), ' ')"/>
        </toc>
    </xsl:template>
    
    <xsl:template match="comment()">
    	<xsl:copy-of select="."/>
    </xsl:template>
</xsl:stylesheet>