<?xml version="1.0" encoding="UTF-8"?>
<!--
   Copyright 2018 Anyware Services

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
   -->
<xsl:stylesheet version="1.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:axsl="http://www.w3.org/1999/XSL/TransformAlias"
    xmlns:i18n="http://apache.org/cocoon/i18n/2.1"
    xmlns:exslt="http://exslt.org/common"
    xmlns:math="http://exslt.org/math">
    
    <xsl:namespace-alias stylesheet-prefix="axsl" result-prefix="xsl"/>

    <xsl:variable name="uniqueId" select="substring-after(math:random(), '.')"/>
    
    <xsl:template match="/">
        <axsl:stylesheet version="1.0" xmlns:i18n="http://apache.org/cocoon/i18n/2.1"
                                       xmlns:resolver="org.ametys.cms.transformation.xslt.ResolveURIComponent"
                                       xmlns:ametys="org.ametys.cms.transformation.xslt.AmetysXSLTHelper"
                                       xmlns:docbook="http://docbook.org/ns/docbook" 
                                       xmlns:exslt="http://exslt.org/common"
                                       exclude-result-prefixes="exslt ametys resolver docbook">
            <axsl:import href="view://stylesheets/content/common.xsl"/>
            
            <!-- Variables -->
            <xsl:call-template name="variables"/>
    
            <!-- Used in common.xsl -->
            <axsl:variable name="common-content-name">default-content</axsl:variable>
            <axsl:variable name="common-content-css-class-name">default-content</axsl:variable>

            <xsl:apply-templates select="contentType"/>
            
            <xsl:call-template name="additionnal-templates"/>
        </axsl:stylesheet>
    </xsl:template>
    
    <xsl:template name="variables">
        <axsl:param name="show-missing" select="'false'"/>
        <axsl:variable name="showMissing" select="$show-missing = 'true'"/>
        
        <axsl:param name="show-technical-names" select="'false'"/>
        <axsl:variable name="showTechnicalNames" select="$show-technical-names = 'true'"/>
    </xsl:template>
    
    <xsl:template name="additionnal-templates">
        <xsl:call-template name="additionnal-templates-js"/>
        <xsl:call-template name="additionnal-templates-css"/>
        <xsl:call-template name="additionnal-templates-other"/>
    </xsl:template>
    
    <xsl:template name="additionnal-templates-js">
        <axsl:template name="common-content-head-js">
             <script>
                $j().ready(function() {
                    $j(".ametys-cms-content.default-content div[role=tabpanel]").tabs();
                });
             </script>
        </axsl:template>
    </xsl:template>
    
    <xsl:template name="additionnal-templates-css">
        <axsl:template name="common-content-head-css">
            <link rel="stylesheet" type="text/css">
                <xsl:attribute name="href">{ametys:uriPrefix()}/plugins/cms/resources/css/content/model2content.css</xsl:attribute>
            </link>
        </axsl:template>
    </xsl:template>
    
    <xsl:template name="additionnal-templates-other"/>
    
    <xsl:template name="common-content-body">
        <xsl:call-template name="common-content-body-title"/>
        <xsl:call-template name="common-content-body-content"/>
    </xsl:template>
    
    <xsl:template name="common-content-body-title">
        <axsl:template name="common-content-body-title">
            <h1 data-ametys-content-title="true"><axsl:value-of select="metadata/title"/></h1>
        </axsl:template>
    </xsl:template>
    
    <xsl:template name="common-content-body-content">
        <axsl:template name="common-content-body-content">
            <div data-ametys-content-root="true">
                <xsl:apply-templates select="metadata[@name != 'title']|fieldset[not(@role) or @role != 'tab']"/>
                
                <xsl:if test="fieldset[@role = 'tab']">
                    <xsl:variable name="conditions">
                        <xsl:apply-templates select="metadata|fieldset" mode="condition"/>
                    </xsl:variable>
                    
                    <xsl:variable name="condition">$showMissing<xsl:for-each select="exslt:node-set($conditions)/condition"> or <xsl:value-of select="."/></xsl:for-each></xsl:variable>
                    <axsl:if test="{$condition}">
                        <div role="tabpanel">
                            <ul role="tablist">
                                <xsl:apply-templates select="fieldset[@role = 'tab']" mode="list"/>
                            </ul>
                            
                            <div>
                                <xsl:apply-templates select="fieldset[@role = 'tab']" mode="tab"/>
                            </div>
                        </div>
                    </axsl:if>
                </xsl:if>
            </div>
        </axsl:template>
    </xsl:template>
            
    <xsl:template match="contentType">
        <xsl:apply-templates select=".//metadata" mode="template"/>
        
        <axsl:template name="attribute">
            <axsl:param name="name"/>
            <axsl:param name="path"/>
            <axsl:param name="type"/>
            <axsl:param name="multiple"/>
            <axsl:param name="label"/>
            <axsl:param name="description"/>
            <axsl:param name="value"/>
            
            <div data-ametys-content-attribute="true">
                <axsl:call-template name="attribute-name">
                    <axsl:with-param name="name" select="$name"/>
                    <axsl:with-param name="label" select="$label"/>
                </axsl:call-template>
                <div data-ametys-content-attribute-value="true">
                    <axsl:for-each select="$value">
                        <axsl:if test="position() != 1"><br/></axsl:if>
                        <axsl:choose>
                            <axsl:when test="$type = 'geocode'">
                                <axsl:call-template name="geocode-attribute">  
                                    <axsl:with-param name="value" select="."/>
                                </axsl:call-template>
                            </axsl:when>
                            <axsl:when test="$type = 'content'">
                                <axsl:call-template name="content-attribute">  
                                    <axsl:with-param name="value" select="."/>
                                </axsl:call-template>
                            </axsl:when>
                            <axsl:when test="$type = 'file'">
                                <axsl:call-template name="file-attribute">  
                                    <axsl:with-param name="value" select="."/>
                                </axsl:call-template>
                            </axsl:when>
                            <axsl:when test="$type = 'reference'">
                                <axsl:call-template name="reference-attribute">  
                                    <axsl:with-param name="value" select="."/>
                                </axsl:call-template>
                            </axsl:when>
                            <axsl:when test="$type = 'rich-text'">
                                <axsl:call-template name="richtext-attribute">
                                    <axsl:with-param name="value" select="."/>
                                </axsl:call-template>
                            </axsl:when>
                            <axsl:when test="$type = 'boolean'">
                                <axsl:call-template name="boolean-attribute">  
                                    <axsl:with-param name="value" select="."/>
                                </axsl:call-template>
                            </axsl:when>
                            <axsl:when test="$type = 'long'">
                                <axsl:call-template name="long-attribute">  
                                    <axsl:with-param name="value" select="."/>
                                </axsl:call-template>
                            </axsl:when>
                            <axsl:when test="$type = 'double'">
                                <axsl:call-template name="double-attribute">  
                                    <axsl:with-param name="value" select="."/>
                                </axsl:call-template>
                            </axsl:when>
                            <axsl:when test="$type = 'date'">
                                <axsl:call-template name="date-attribute">  
                                    <axsl:with-param name="value" select="."/>
                                </axsl:call-template>
                            </axsl:when>
                            <axsl:when test="$type = 'datetime'">
                                <axsl:call-template name="datetime-attribute">  
                                    <axsl:with-param name="value" select="."/>
                                </axsl:call-template>
                            </axsl:when>
                            <axsl:when test="$type = 'string'">
                                <axsl:call-template name="string-attribute">  
                                    <axsl:with-param name="value" select="."/>
                                </axsl:call-template>
                            </axsl:when>
                            <axsl:otherwise>
                                <axsl:value-of select="."/>
                            </axsl:otherwise>
                        </axsl:choose>
                    </axsl:for-each>
                </div>
            </div>
        </axsl:template>
        
        <xsl:call-template name="attribute-name"/>
        <xsl:call-template name="string-attribute"/>
        <xsl:call-template name="boolean-attribute"/>
        <xsl:call-template name="long-attribute"/>
        <xsl:call-template name="double-attribute"/>
        <xsl:call-template name="date-attribute"/>
        <xsl:call-template name="datetime-attribute"/>
        <xsl:call-template name="content-attribute"/>
        <xsl:call-template name="reference-attribute"/>
        <xsl:call-template name="file-attribute"/>
        <xsl:call-template name="geocode-attribute"/>
        <xsl:call-template name="richtext-attribute"/>
        <xsl:call-template name="container"/>
        <xsl:call-template name="entry"/>
        <xsl:call-template name="entry-label"/>
        <xsl:call-template name="repeater"/>
        <xsl:call-template name="repeater-label"/>
        
        <!-- +
             | HEAD
             + -->
        <axsl:template name="common-content-head-title">
            <axsl:call-template name="common-content-head-title-content"/>
        </axsl:template> 
        
        <axsl:template name="common-content-attribute-other"/>
        <!-- +
             | BODY
             + -->
        <xsl:call-template name="common-content-body"/>
    </xsl:template>
    
    <xsl:template name="attribute-name">
        <axsl:template name="attribute-name">
            <axsl:param name="label"/>
            <axsl:param name="name"/>
            
            <div data-ametys-content-attribute-name="true"><axsl:value-of select="$label"/>
            <axsl:if test="$showTechnicalNames"><span class="minimize"> (<axsl:value-of select="$name"/>)</span></axsl:if> </div>
        </axsl:template>
    </xsl:template>
    
    <xsl:template name="string-attribute">
        <axsl:template name="string-attribute">
            <axsl:param name="value"/>
            <axsl:call-template name="text.nl2br">  
                <axsl:with-param name="input" select="$value"/>
            </axsl:call-template>
        </axsl:template>
    </xsl:template>
        
    <xsl:template name="boolean-attribute">
        <axsl:template name="boolean-attribute">
            <axsl:param name="value"/>
            
            <axsl:value-of select="$value"/>
        </axsl:template>
    </xsl:template>
        
    <xsl:template name="long-attribute">
        <axsl:template name="long-attribute">
            <axsl:param name="value"/>
            
            <axsl:value-of select="$value"/>
        </axsl:template>
    </xsl:template>
        
    <xsl:template name="double-attribute">
        <axsl:template name="double-attribute">
            <axsl:param name="value"/>
            
            <axsl:value-of select="$value"/>
        </axsl:template>
    </xsl:template>
        
    <xsl:template name="date-attribute">
        <axsl:template name="date-attribute">
            <axsl:param name="value"/>
            
            <i18n:date pattern="medium" src-pattern="yyyy-MM-dd'T'HH:mm:ss.SSSXXX">
                <axsl:value-of select="$value"/>
            </i18n:date>
        </axsl:template>
    </xsl:template>
        
    <xsl:template name="datetime-attribute">
        <axsl:template name="datetime-attribute">
            <axsl:param name="value"/>
            
            <i18n:date-time pattern="medium" src-pattern="yyyy-MM-dd'T'HH:mm:ss.SSSXXX">
                <axsl:value-of select="$value"/>
            </i18n:date-time>
        </axsl:template>
    </xsl:template>
        
    <xsl:template name="content-attribute">
        <axsl:template name="content-attribute">
            <axsl:param name="value"/>
            <axsl:variable name="contentId" select="$value/@id" />
            <axsl:if test="$contentId != ''">
                <axsl:choose>
                    <axsl:when test="ametys:isReferenceTableContent($contentId)">
                        <axsl:value-of select="$value/@title"/>
                    </axsl:when>
                    <axsl:otherwise>
                        <a>
                            <xsl:attribute name="href">{resolver:resolve('content', $contentId)}</xsl:attribute>
                            <axsl:value-of select="$value/@title"/>
                        </a>
                    </axsl:otherwise>
                </axsl:choose>
            </axsl:if>
        </axsl:template>
    </xsl:template>
        
    <xsl:template name="reference-attribute">
        <axsl:template name="reference-attribute">
            <axsl:param name="value"/>
            <a>
                <axsl:attribute name="href"><axsl:value-of select="$value"/></axsl:attribute>
                <axsl:value-of select="$value"/>
            </a>
        </axsl:template>
    </xsl:template>
        
    <xsl:template name="file-attribute">
        <axsl:template name="file-attribute">
            <axsl:param name="value"/>
            <a>
                <xsl:attribute name="href">{resolver:resolve($value/@type, $value/@uri, 'true')}</xsl:attribute>
                <xsl:attribute name="title">{$value/@filename} ({$value/@size})</xsl:attribute>
                <axsl:value-of select="$value/@filename"/>
            </a>
        </axsl:template>
    </xsl:template>
        
    <xsl:template name="geocode-attribute">
        <axsl:template name="geocode-attribute">
            <axsl:param name="value"/>
            <axsl:value-of select="concat(substring-before($value/@latitude, '.'), '.', substring(substring-after($value/@latitude, '.'), 1, 4))"/><axsl:text>°N , </axsl:text><axsl:value-of select="concat(substring-before($value/@longitude, '.'), '.', substring(substring-after($value/@longitude, '.'), 1, 4))"/><axsl:text>°E</axsl:text>
            <br/>
            <a external="external">
                <xsl:attribute name="href">https://maps.google.com/maps?q={$value/@latitude},{$value/@longitude}&amp;z=30&amp;ll={$value/@latitude},{$value/@longitude}</xsl:attribute>
                <i18n:text i18n:key="CONTENT_VIEW_GOOGLEMAPS_LINK" i18n:catalogue="plugin.cms"/>
            </a>
        </axsl:template>
    </xsl:template>
        
    <xsl:template name="richtext-attribute">
        <axsl:template name="richtext-attribute">
            <axsl:param name="value"/>
            <axsl:apply-templates select="$value/docbook:article">
                <axsl:with-param name="level" select="2"/>
            </axsl:apply-templates>
        </axsl:template>
    </xsl:template>
        
    <xsl:template name="container">
        <axsl:template name="container">
            <axsl:param name="label"/>
            <axsl:param name="name"/>
            <axsl:param name="path"/>
            <axsl:param name="content"/>
            
            <div data-ametys-content-container="true">
                <axsl:call-template name="entry">
                    <axsl:with-param name="label" select="$label"/>
                    <axsl:with-param name="name" select="$name"/>
                    <axsl:with-param name="path" select="$path"/>
                    <axsl:with-param name="content" select="$content"/>
                </axsl:call-template>
            </div>
        </axsl:template>
    </xsl:template>
        
    <xsl:template name="entry">
        <axsl:template name="entry">
            <axsl:param name="label"/>
            <axsl:param name="name"/>
            <axsl:param name="path"/>
            <axsl:param name="content"/>
            
            <div data-ametys-content-repeater-entry="true">
                <axsl:call-template name="entry-label">
                    <axsl:with-param name="label" select="$label"/>
                    <axsl:with-param name="name" select="$name"/>
                    <axsl:with-param name="path" select="$path"/>
                </axsl:call-template>
                <div data-ametys-content-attribute-container="true">
                    <axsl:copy-of select="$content"/>
                </div>
            </div>
        </axsl:template>
    </xsl:template>
        
    <xsl:template name="repeater">
        <axsl:template name="repeater">
            <axsl:param name="label"/>
            <axsl:param name="name"/>
            <axsl:param name="path"/>
            <axsl:param name="content"/>
            
            <div data-ametys-content-repeater="true">
                <div>
                    <axsl:call-template name="repeater-label">
                        <axsl:with-param name="label" select="$label"/>
                        <axsl:with-param name="name" select="$name"/>
                        <axsl:with-param name="path" select="$path"/>
                    </axsl:call-template>
                    <div data-ametys-content-attribute-container="true">
                        <axsl:for-each select="exslt:node-set($content)/entry">
                            <axsl:call-template name="entry">
                                <axsl:with-param name="label"><axsl:value-of select="concat($label, ' ', position())"/></axsl:with-param>
                                <axsl:with-param name="content" select="node()"/>
                            </axsl:call-template>
                        </axsl:for-each>
                    </div>
                </div>
            </div>
        </axsl:template>
    </xsl:template>
    
    <xsl:template name="entry-label">
        <axsl:template name="entry-label">
            <axsl:param name="label"/>
            
            <div><h5><axsl:value-of select="$label"/></h5></div>
        </axsl:template>
    </xsl:template>
    
    <xsl:template name="repeater-label">
        <axsl:template name="repeater-label">
            <axsl:param name="label"/>
            
            <div><h4><axsl:value-of select="$label"/></h4></div>
        </axsl:template>
    </xsl:template>
    
    <xsl:template match="metadata" mode="template">
        <xsl:param name="prefix">metadata/</xsl:param>
        <xsl:choose>
            <xsl:when test="@type = 'composite'">
                <axsl:template name="attribute-{translate(@path, '/', '-')}">
                    <axsl:param name="value" select="{concat($prefix, @name)}"/>
                    
                    <xsl:variable name="conditions">
                        <xsl:apply-templates select="metadata|fieldset" mode="condition">
                            <xsl:with-param name="prefix">$value/</xsl:with-param>
                        </xsl:apply-templates>
                    </xsl:variable>
                    
                    <xsl:variable name="condition">$showMissing<xsl:for-each select="exslt:node-set($conditions)/condition"> or <xsl:value-of select="."/></xsl:for-each></xsl:variable>
                    
                    <axsl:if test="{$condition}">
                        <axsl:call-template name="container">
                            <axsl:with-param name="content">
                                <xsl:apply-templates select="metadata|fieldset">
                                    <xsl:with-param name="prefix">$value/</xsl:with-param>
                                </xsl:apply-templates>
                            </axsl:with-param>
                            <axsl:with-param name="label"><xsl:value-of select="label"/></axsl:with-param>
                            <axsl:with-param name="name"><xsl:value-of select="@name"/></axsl:with-param>
                            <axsl:with-param name="path"><xsl:value-of select="@path"/></axsl:with-param>
                        </axsl:call-template>
                    </axsl:if>
                </axsl:template>
            </xsl:when>
            <xsl:when test="@type = 'repeater'">
                <axsl:template name="attribute-{translate(@path, '/', '-')}">
                    <axsl:param name="value" select="{concat($prefix, @name)}"/>
                    
                    <xsl:variable name="conditions">
                        <xsl:apply-templates select="metadata|fieldset" mode="condition">
<!--                             <xsl:with-param name="prefix" select="concat($prefix, @name, '/entry/')"/> -->
                            <xsl:with-param name="prefix">$value/entry/</xsl:with-param>
                        </xsl:apply-templates>
                    </xsl:variable>
                    
                    <xsl:variable name="condition">$showMissing<xsl:for-each select="exslt:node-set($conditions)/condition"> or <xsl:value-of select="."/></xsl:for-each></xsl:variable>
                    
                    <axsl:if test="{$condition}">
                        <axsl:call-template name="repeater">
                            <axsl:with-param name="content">
<!--                                 <axsl:for-each select="{$prefix}{@name}/entry"> -->
                                <axsl:for-each select="$value/entry">
                                    <xsl:variable name="entryConditions">
                                        <xsl:apply-templates select="metadata|fieldset" mode="condition">
                                            <xsl:with-param name="prefix"/>
                                        </xsl:apply-templates>
                                    </xsl:variable>
                                    
                                    <xsl:variable name="entryCondition">$showMissing<xsl:for-each select="exslt:node-set($entryConditions)/condition"> or <xsl:value-of select="."/></xsl:for-each></xsl:variable>
                                    <axsl:if test="{$entryCondition}">
                                        <entry>
                                            <xsl:apply-templates select="metadata|fieldset">
                                                <xsl:with-param name="prefix"/>
                                            </xsl:apply-templates>
                                        </entry>
                                    </axsl:if>
                                </axsl:for-each>
                            </axsl:with-param>
                            <axsl:with-param name="label"><xsl:value-of select="label"/></axsl:with-param>
                            <axsl:with-param name="name"><xsl:value-of select="@name"/></axsl:with-param>
                            <axsl:with-param name="path"><xsl:value-of select="@path"/></axsl:with-param>
                        </axsl:call-template>
                    </axsl:if>
                </axsl:template>
            </xsl:when>
            <xsl:when test="@type = 'content'">
                <axsl:template name="attribute-{translate(@path, '/', '-')}">
                    <axsl:param name="value"/>
                    
                    <axsl:if test="$showMissing or $value">
                        <axsl:call-template name="attribute">
                            <axsl:with-param name="name"><xsl:value-of select="@name"/></axsl:with-param>
                            <axsl:with-param name="path"><xsl:value-of select="@path"/></axsl:with-param>
                            <axsl:with-param name="type"><xsl:value-of select="@type"/></axsl:with-param>
                            <axsl:with-param name="multiple"><xsl:value-of select="@multiple"/></axsl:with-param>
                            <axsl:with-param name="label"><xsl:value-of select="label"/></axsl:with-param>
                            <axsl:with-param name="description"><xsl:value-of select="description"/></axsl:with-param>
                            <axsl:with-param name="value" select="$value"/>
                        </axsl:call-template>
                    </axsl:if>
                    <xsl:if test="metadata|fieldset">
                        <xsl:apply-templates select="metadata|fieldset">
                            <xsl:with-param name="prefix">$value/</xsl:with-param>
                        </xsl:apply-templates>
                    </xsl:if>
                </axsl:template>
            </xsl:when>
            <xsl:otherwise>
                <axsl:template name="attribute-{translate(@path, '/', '-')}">
                    <axsl:param name="value"/>
                    
                    <axsl:if test="$showMissing or $value">
                        <axsl:call-template name="attribute">
                            <axsl:with-param name="name"><xsl:value-of select="@name"/></axsl:with-param>
                            <axsl:with-param name="path"><xsl:value-of select="@path"/></axsl:with-param>
                            <axsl:with-param name="type"><xsl:value-of select="@type"/></axsl:with-param>
                            <axsl:with-param name="multiple"><xsl:value-of select="@multiple"/></axsl:with-param>
                            <axsl:with-param name="label"><xsl:value-of select="label"/></axsl:with-param>
                            <axsl:with-param name="description"><xsl:value-of select="description"/></axsl:with-param>
                            <axsl:with-param name="value" select="$value"/>
                        </axsl:call-template>
                    </axsl:if>
                </axsl:template>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    
    <xsl:template match="metadata">
        <xsl:param name="prefix">metadata/</xsl:param>
        
        <axsl:call-template name="attribute-{translate(@path, '/', '-')}">
            <axsl:with-param name="value" select="{$prefix}{@name}"/>
            <axsl:with-param name="name"><xsl:value-of select="@name"/></axsl:with-param>
            <axsl:with-param name="path"><xsl:value-of select="@path"/></axsl:with-param>
            <axsl:with-param name="type"><xsl:value-of select="@type"/></axsl:with-param>
            <axsl:with-param name="multiple"><xsl:value-of select="@multiple"/></axsl:with-param>
            <axsl:with-param name="label"><xsl:value-of select="label"/></axsl:with-param>
            <axsl:with-param name="description"><xsl:value-of select="description"/></axsl:with-param>
        </axsl:call-template>
    </xsl:template>
    
    <xsl:template match="fieldset[@role = 'fieldset']">
        <xsl:param name="prefix">metadata/</xsl:param>
        
        <xsl:variable name="conditions">
            <xsl:apply-templates select="metadata|fieldset" mode="condition">
                <xsl:with-param name="prefix" select="$prefix"/>
            </xsl:apply-templates>
        </xsl:variable>
        
        <xsl:variable name="condition">$showMissing<xsl:for-each select="exslt:node-set($conditions)/condition"> or <xsl:value-of select="."/></xsl:for-each></xsl:variable>
        
        <axsl:if test="{$condition}">
            <axsl:call-template name="container">
                <axsl:with-param name="content">
                    <xsl:apply-templates select="metadata|fieldset">
                        <xsl:with-param name="prefix" select="$prefix"/>
                    </xsl:apply-templates>
                </axsl:with-param>
                <axsl:with-param name="label"><xsl:value-of select="label"/></axsl:with-param>
            </axsl:call-template>
        </axsl:if>
    </xsl:template>
    
    <xsl:template match="fieldset[@role = 'tab']" mode="list">
        <xsl:variable name="conditions">
            <xsl:apply-templates select="metadata|fieldset" mode="condition"/>
        </xsl:variable>
        
        <xsl:variable name="condition">$showMissing<xsl:for-each select="exslt:node-set($conditions)/condition"> or <xsl:value-of select="."/></xsl:for-each></xsl:variable>
        
        <axsl:if test="{$condition}">
            <li role="presentation">
                <a href="#tab-{$uniqueId}-{position()}" data-toggle="tab"><xsl:value-of select="label"/></a>
            </li>
        </axsl:if>
    </xsl:template>
    
    <xsl:template match="fieldset[@role = 'tab']" mode="tab">
        <xsl:variable name="conditions">
            <xsl:apply-templates select="metadata|fieldset" mode="condition"/>
        </xsl:variable>
        
        <xsl:variable name="condition">$showMissing<xsl:for-each select="exslt:node-set($conditions)/condition"> or <xsl:value-of select="."/></xsl:for-each></xsl:variable>
        
        <axsl:if test="{$condition}">
            <div role="tab" id="tab-{$uniqueId}-{position()}">
                <div data-ametys-content-tab-attribute-container="true">
                    <div data-ametys-content-fieldset-title="true"><xsl:value-of select="label"/></div>
                    <xsl:apply-templates select="metadata|fieldset"/>
                </div>
            </div>
        </axsl:if>
    </xsl:template>
    
    <xsl:template match="fieldset" mode="condition">
        <xsl:param name="prefix">metadata/</xsl:param>
        <xsl:apply-templates select="metadata|fieldset" mode="condition">
            <xsl:with-param name="prefix" select="$prefix"/>
        </xsl:apply-templates>
    </xsl:template>
    
    <xsl:template match="metadata" mode="condition">
        <xsl:param name="prefix">metadata/</xsl:param>
        <xsl:choose>
            <xsl:when test="@type = 'composite'">
                <xsl:apply-templates select="metadata|fieldset" mode="condition">
                    <xsl:with-param name="prefix" select="concat($prefix, @name, '/')"/>
                </xsl:apply-templates>
            </xsl:when>
            <xsl:when test="@type = 'repeater'">
                <xsl:apply-templates select="metadata|fieldset" mode="condition">
                    <xsl:with-param name="prefix" select="concat($prefix, @name, '/entry/')"/>
                </xsl:apply-templates>
            </xsl:when>
            <xsl:when test="@type = 'content'">
                <xsl:choose>
                    <xsl:when test="metadata|fieldset">
                        <xsl:apply-templates select="metadata|fieldset" mode="condition">
                            <xsl:with-param name="prefix" select="concat($prefix, @name, '/')"/>
                        </xsl:apply-templates>
                    </xsl:when>
                    <xsl:otherwise>
                        <condition><xsl:value-of select="concat($prefix, @name)"/></condition>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:when>
            <xsl:otherwise>
                <condition><xsl:value-of select="concat($prefix, @name)"/></condition>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>

</xsl:stylesheet>
