<?xml version="1.0" encoding="UTF-8"?>
<!--
   Copyright 2010 Anyware Services

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
   -->
<xsl:stylesheet version="1.0"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
                xmlns:i18n="http://apache.org/cocoon/i18n/2.1"
                xmlns:math="java.lang.Math" 
                xmlns:str="http://exslt.org/strings"
                exclude-result-prefixes="math str">  
    
    <xsl:import href="view://stylesheets/helper/common.xsl"/>
    <xsl:import href="plugin:core://stylesheets/helper/text.xsl"/>    
    
    <!-- +
         | UTILS
         + -->    
    
    <!-- Template used by lists to style items -->   
    <xsl:template name="common-utils-class">
        <xsl:if test="position() mod 2 = 0"><xsl:text>even </xsl:text></xsl:if>                                
        <xsl:if test="position() = 1"><xsl:text>first </xsl:text></xsl:if>
        <xsl:if test="position() = last()"><xsl:text>last</xsl:text></xsl:if>
    </xsl:template>

   <!-- Template used by submit button -->
    <xsl:template name="common-utils-input-submit">
        <xsl:param name="class-name"/>
        <xsl:param name="text"/>
        <xsl:param name="i18nkey"/>
        <xsl:param name="name"/>   
        <xsl:param name="i18ntitle"/>  
        <xsl:param name="title"/>             
        <xsl:param name="id"/>        
        <xsl:param name="onclick"/>        
        <xsl:param name="width"/>        
        <xsl:param name="type">submit</xsl:param>        
        <xsl:param name="disabled" select="false()"/>        
        
        <div class="button">
            <input type="{$type}">
                <xsl:choose>
                    <!-- i18n key -->
                    <xsl:when test="$i18nkey != ''">
                        <xsl:attribute name="value"><xsl:value-of select="$i18nkey"/></xsl:attribute>
                        <xsl:attribute name="i18n:attr">value</xsl:attribute>
                    </xsl:when>
                    <!-- text value -->
                    <xsl:otherwise><xsl:attribute name="value"><xsl:value-of select="$text"/></xsl:attribute></xsl:otherwise>                
                </xsl:choose>
                <xsl:if test="$class-name != ''">
                    <xsl:attribute name="class"><xsl:value-of select="$class-name"/></xsl:attribute>
                </xsl:if>
                <xsl:if test="$name != ''">
                    <xsl:attribute name="name"><xsl:value-of select="$name"/></xsl:attribute>
                </xsl:if>
                <xsl:if test="$id != ''">
                    <xsl:attribute name="id"><xsl:value-of select="$id"/></xsl:attribute>
                </xsl:if>
                <xsl:if test="$onclick">
                    <xsl:attribute name="onclick"><xsl:value-of select="$onclick"/></xsl:attribute>
                </xsl:if>
                <xsl:if test="$disabled">
                    <xsl:attribute name="disabled">disabled</xsl:attribute>
                </xsl:if>
                <xsl:if test="$width != ''">
                    <xsl:attribute name="style">width: <xsl:value-of select="$width"/>px;</xsl:attribute>
                </xsl:if>
                <xsl:choose>
                    <xsl:when test="$i18ntitle != ''">
                        <xsl:attribute name="title"><xsl:value-of select="$i18ntitle"/></xsl:attribute>
                        <xsl:attribute name="i18n:attr">title<xsl:if test="$i18nkey != ''"> value</xsl:if></xsl:attribute>
                    </xsl:when>
                    <xsl:otherwise><xsl:attribute name="title"><xsl:value-of select="$title"/></xsl:attribute></xsl:otherwise>                
                </xsl:choose>
            </input>
        </div>        
    </xsl:template>                     

    <xsl:template name="common-utils-jswrite-input-submit">
        <xsl:param name="class-name"/>
        <xsl:param name="text"/>
        <xsl:param name="i18nkey"/>
        <xsl:param name="name"/>        
        <xsl:param name="id"/>        
        <xsl:param name="onclick"/>        
        <xsl:param name="width"/>        
        <xsl:param name="type">submit</xsl:param>        
        <xsl:param name="disabled" select="false()"/>        
        
        <xsl:text>document.write("&lt;div class=\"button\"&gt;&lt;input type=\"</xsl:text><xsl:value-of select="$type"/><xsl:text>\" value=\"</xsl:text>
        
        <xsl:choose>
            <!-- i18n key -->
            <xsl:when test="$i18nkey != ''">
            	<xsl:choose>
            		<xsl:when test="contains($i18nkey,':')">
		            	<i18n:text i18n:catalogue="{substring-before($i18nkey,':')}" i18n:key="{substring-after($i18nkey,':')}"/>
            		</xsl:when>
            		<xsl:otherwise>
		            	<i18n:text i18n:key="{$i18nkey}"/>
            		</xsl:otherwise>
            	</xsl:choose>
            </xsl:when>
            <xsl:otherwise>
            	<xsl:value-of select="$text"/>
            </xsl:otherwise>
        </xsl:choose>
        
        <xsl:text>\"</xsl:text>
        
        <xsl:if test="$class-name != ''">
        	<xsl:text> class=\"</xsl:text><xsl:value-of select="$class-name"/><xsl:text>\"</xsl:text>
        </xsl:if>
        <xsl:if test="$name != ''">
        	<xsl:text> name=\"</xsl:text><xsl:value-of select="$name"/><xsl:text>\"</xsl:text>
        </xsl:if>
        <xsl:if test="$id != ''">
        	<xsl:text> id=\"</xsl:text><xsl:value-of select="$id"/><xsl:text>\"</xsl:text>
        </xsl:if>
        <xsl:if test="$onclick != ''">
        	<xsl:text> onclick=\"</xsl:text><xsl:value-of select="$onclick"/><xsl:text>\"</xsl:text>
        </xsl:if>
        <xsl:if test="$disabled">
        	<xsl:text> disabled=\"disabled\"</xsl:text>
        </xsl:if>
        <xsl:if test="$width != ''">
        	<xsl:text> style=\"width: </xsl:text><xsl:value-of select="$width"/><xsl:text>px\"</xsl:text>
        </xsl:if>
    	
        <xsl:text>/&gt;&lt;/div&gt;");</xsl:text>
    </xsl:template>   
    
    <!-- Template used for date format -->
    <xsl:template name="common-utils-date-pattern">
        <xsl:param name="date"/>
        
        <i18n:date src-pattern="yyyy-MM-dd'T'HH:mm:ss.SSSXXX" pattern="long"><xsl:value-of select="$date"/></i18n:date>
    </xsl:template>     
    
    <xsl:template name="common-utils-date-role-pattern">
        <xsl:param name="date"/>
        <xsl:param name="role"/>
        
        <xsl:choose>
            <xsl:when test="$role = 'dtstart' or $role = 'dtend'">
                <abbr class="{$role}">
                    <span class="value-title" title="{$date}"></span>
                    <xsl:call-template name="common-utils-date-pattern">
                        <xsl:with-param name="date" select="$date"/>
                    </xsl:call-template>
                </abbr>
            </xsl:when>
            <xsl:otherwise>
                <xsl:call-template name="common-utils-date-pattern">
                    <xsl:with-param name="date" select="$date"/>
                </xsl:call-template>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    
    <xsl:template name="common-utils-dates">
        <xsl:param name="startDate"/>
        <xsl:param name="endDate"/>
        
        <p class="content-date">
            <xsl:choose>
                <xsl:when test="$startDate and not($endDate)">
                    <i18n:text i18n:key="PLUGINS_CMS_COMMON_UTILS_DATE" i18n:catalogue="plugin.cms"/>
                    <xsl:call-template name="common-utils-date-role-pattern">
                        <xsl:with-param name="date" select="$startDate"/>
                        <xsl:with-param name="role" select="'dtstart'"/>
                    </xsl:call-template>
                </xsl:when>
                <xsl:when test="$endDate and not($startDate)">
                    <i18n:text i18n:key="PLUGINS_CMS_COMMON_UTILS_DATE" i18n:catalogue="plugin.cms"/>
                    <xsl:call-template name="common-utils-date-role-pattern">
                        <xsl:with-param name="date" select="$endDate"/>
                        <xsl:with-param name="role" select="'dtstart'"/>
                    </xsl:call-template>
                </xsl:when>
                <xsl:when test="$startDate and $endDate">
                    <i18n:text i18n:key="PLUGINS_CMS_COMMON_UTILS_DATE_FROM" i18n:catalogue="plugin.cms"/>
                    <xsl:call-template name="common-utils-date-role-pattern">
                        <xsl:with-param name="date" select="$startDate"/>
                        <xsl:with-param name="role" select="'dtstart'"/>
                    </xsl:call-template>
                    <i18n:text i18n:key="PLUGINS_CMS_COMMON_UTILS_DATE_TO" i18n:catalogue="plugin.cms"/>
                    <xsl:call-template name="common-utils-date-role-pattern">
                        <xsl:with-param name="date" select="$endDate"/>
                        <xsl:with-param name="role" select="'dtend'"/>
                    </xsl:call-template>
                </xsl:when>
            </xsl:choose>
        </p>
    </xsl:template>  
    
    <!-- Template used to truncate text -->                                  
    <xsl:template name="common-utils-simpletext">
        <xsl:param name="text"/>
        <xsl:param name="defaultText"/>
        <xsl:param name="maxDefaultTextSize">200</xsl:param>
    
            <xsl:choose>
                <xsl:when test="normalize-space($text) != ''">
                    <xsl:call-template name="text.nl2br">
                        <xsl:with-param name="input"><xsl:value-of select="$text"/></xsl:with-param>
                    </xsl:call-template>
                </xsl:when>
                <xsl:when test="normalize-space($defaultText) != ''">
                    <xsl:call-template name="truncate">
                        <xsl:with-param name="content" select="$defaultText"/>
                        <xsl:with-param name="length" select="$maxDefaultTextSize"/>
                    </xsl:call-template>
                </xsl:when>
            </xsl:choose>
    </xsl:template>    
        
</xsl:stylesheet>    
