/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.workspace;

import java.io.IOException;
import java.util.Map;

import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.cocoon.ProcessingException;
import org.apache.cocoon.generation.ServiceableGenerator;
import org.apache.cocoon.xml.AttributesImpl;
import org.apache.cocoon.xml.XMLUtils;
import org.xml.sax.SAXException;

import org.ametys.cms.languages.Language;
import org.ametys.cms.languages.LanguagesManager;
import org.ametys.runtime.i18n.I18nizableText;

/**
 * SAX events for available languages.
 *
 */
public class LanguagesGenerator extends ServiceableGenerator
{
    private LanguagesManager _languagesManager;

    @Override
    public void service(ServiceManager smanager) throws ServiceException
    {
        super.service(smanager);
        _languagesManager = (LanguagesManager) smanager.lookup(LanguagesManager.ROLE);
    }

    @Override
    public void generate() throws IOException, SAXException, ProcessingException
    {
        contentHandler.startDocument();
        XMLUtils.startElement(contentHandler, "languages");
        
        Map<String, Language> availableLanguages = _languagesManager.getAvailableLanguages();
        
        for (Language language : availableLanguages.values())
        {
            saxLanguage(language);
        }

        XMLUtils.endElement(contentHandler, "languages");
        contentHandler.endDocument();
    }
    
    /**
     * Sax the language informations
     * @param language The language to sax
     * @throws SAXException if an error occurred
     */
    protected void saxLanguage (Language language) throws SAXException
    {
        AttributesImpl attrs = new AttributesImpl();
        attrs.addAttribute("", "name", "name", "CDATA", language.getCode());
        XMLUtils.startElement(contentHandler, "language", attrs);
        
        language.getLabel().toSAX(contentHandler, "label");
        new I18nizableText(language.getSmallIcon()).toSAX(contentHandler, "small-icon");
        new I18nizableText(language.getMediumIcon()).toSAX(contentHandler, "medium-icon");
        new I18nizableText(language.getLargeIcon()).toSAX(contentHandler, "large-icon");
        
        XMLUtils.endElement(contentHandler, "language");
    }

}
