<?xml version="1.0" encoding="UTF-8"?>
<!--
   Copyright 2013 Anyware Services

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
   -->
<xsl:stylesheet version="1.0" 
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

    <xsl:import href="plugin:core-ui://stylesheets/workspace.xsl"/>

    <xsl:template name="ui-extension-after-static-load">
        <!-- Explorer specific. Loading applications and associated resources. -->
        <xsl:call-template name="kernel-load">
            <xsl:with-param name="scripts" select="/Ametys/explorer/applications/application/scripts/file" />
            <xsl:with-param name="css" select="/Ametys/explorer/applications/application/css/file" />
        </xsl:call-template>
        
        <!-- Loading languages -->
        <script type="text/javascript" src="{$contextPath}/plugins/cms/resources/js/Ametys/cms/language/Language.js"/>
        <script type="text/javascript" src="{$contextPath}/plugins/cms/resources/js/Ametys/cms/language/LanguageDAO.js"/>
        
        <script type="text/javascript">
            var langStore = Ametys.cms.language.LanguageDAO.getStore();
            
            <xsl:for-each select="/Ametys/languages/language">
                langStore.add ({
                    name: "<xsl:value-of select="@name"/>",
                    label: "<xsl:value-of select="label"/>",
                    iconSmall: "<xsl:value-of select="small-icon"/>",
                    iconMedium: "<xsl:value-of select="medium-icon"/>",
                    iconLarge: "<xsl:value-of select="large-icon"/>"
                });
            </xsl:for-each>
            
            var defaultLang,
                userLocale = Ametys.getAppParameter('user').locale;
    		
            if (langStore.find('name', userLocale) != -1)
    		{
    			defaultLang = userLocale;
    		}
    		else if (langStore.find('name', 'en') != -1)
    		{
    			defaultLang = 'en';
    		}
    		else
    		{
    			defaultLang = langStore.getAt(0).get('name');
    		}    
            
            Ametys.cms.language.LanguageDAO.setCurrentLanguage (defaultLang);
        </script>
        
        <!-- Loading ContentTypes -->
        <script type="text/javascript" src="{$contextPath}/plugins/cms/resources/js/Ametys/cms/content/ContentType.js"/>
        <script type="text/javascript" src="{$contextPath}/plugins/cms/resources/js/Ametys/cms/content/ContentTypeDAO.js"/>

        <script type="text/javascript">
            var ctypeStore = Ametys.cms.content.ContentTypeDAO.getStore();
            
            <xsl:for-each select="/Ametys/ActionResult/ContentTypes/ContentTypes">
                ctypeStore.add ({
                    "id": "<xsl:value-of select="id"/>", 
                    "label": "<xsl:value-of select="label"/>", 
                    "description": "<xsl:value-of select="description"/>", 
                    "defaultTitle": "<xsl:value-of select="defaultTitle"/>", 
                    "iconGlyph": "<xsl:value-of select="iconGlyph"/>", 
                    "iconDecorator": "<xsl:value-of select="iconDecorator"/>", 
                    "iconSmall": "<xsl:value-of select="iconSmall"/>", 
                    "iconMedium": "<xsl:value-of select="iconMedium"/>", 
                    "iconLarge": "<xsl:value-of select="iconLarge"/>", 
                    "right": "<xsl:value-of select="right"/>", 
                    "rightEvaluated": "<xsl:value-of select="rightEvaluated"/>", 
                    "isSimple": <xsl:value-of select="isSimple"/>, 
                    "isMultilingual": <xsl:value-of select="isMultilingual"/>, 
                    "isPrivate": <xsl:value-of select="isPrivate"/>, 
                    "isMixin": <xsl:value-of select="isMixin"/>, 
                    "isAbstract": <xsl:value-of select="isAbstract"/>, 
                    "isReferenceTable": <xsl:value-of select="isReferenceTable"/>,
                    "superTypes": [<xsl:for-each select="superTypes/superTypes">"<xsl:value-of select='.'/>"<xsl:if test="position()!=last()">,</xsl:if></xsl:for-each>], 
                    "tags": [<xsl:for-each select="tags/tags">"<xsl:value-of select='.'/>"<xsl:if test="position()!=last()">,</xsl:if></xsl:for-each>],
                    "parentModelItemName": "<xsl:value-of select="parentModelItemName"/>"
                });
            </xsl:for-each>
        </script>
    </xsl:template>
    
    <xsl:template name="app-contexts">["/application"]</xsl:template>
</xsl:stylesheet>
