<?xml version="1.0" encoding="UTF-8"?>
<!--
   Copyright 2023 Anyware Services

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
   -->
<xsl:stylesheet version="1.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
    xmlns:i18n="http://apache.org/cocoon/i18n/2.1"
    xmlns:ametys="org.ametys.cms.transformation.xslt.AmetysXSLTHelper"
    extension-element-prefixes="ametys">
    
    <!-- rendering helper -->
    <xsl:template name="head-js-jquery">
        <script type="text/javascript" src="{$uri-prefix}/plugins/jquery/resources/js/jquery.js"></script>
        <script type="text/javascript" src="{$uri-prefix}/plugins/jquery-ui/resources/js/jquery-ui.js"></script>
        <xsl:if test="$lang != 'en'">
            <script src="{$uri-prefix}/plugins/jquery-ui/resources/js/i18n/datepicker-{$lang}.js" type="text/javascript"></script>
        </xsl:if>
        <script type="text/javascript">
            $j = jQuery.noConflict();
        </script>
    </xsl:template>
    
    <xsl:template name="head-js-jquery-additional"/>
    
    <xsl:template name="head-css-jquery">
        <link type="text/css" href="{$uri-prefix}/plugins/jquery-ui/resources/css/ui-lightness/jquery-ui.css" rel="stylesheet" />
    </xsl:template>
    
    <xsl:template name="head-js-user">
        <script type="text/javascript">
            ametysUser = null;
            
            var _ametysUserCallbacks = [];
            var _ametysUserRunning = false;
            
            var _fillUserInputs = function(id, field, callback)
            {
                if (this[field])
                {
                    var input = document.getElementById(id);
                    if (!input.value)
                    {
                        input.value = this[field];
                        if (typeof callback == "function")
                        {
                           callback(id, input, this[field]);
                        }
                    }
                }
            }
            
            <xsl:call-template name="head-js-user-init"/>
            
            function getAmetysUser(callback)
            {
                if (ametysUser &amp;&amp; typeof(callback) == "function")
                {
                    callback(ametysUser);
                }
                else
                {
                    if (typeof(callback) == "function")
                    {
                        _ametysUserCallbacks.push(callback);
                    }
                    
                    if (!_ametysUserRunning)
                    {
                        _ametysUserRunning = true;
                        
                        $j.ajax({
                            url: "<xsl:value-of select="$cms-context"/>/_plugins/cms/current-user",
                            dataType: "json",
                            error: function(result, status, error) {
                                console.log(error);
                                ametysUser = null;
                                _ametysUserRunning = false;
                            },
                            success: function(user) {
                                ametysUser = user;
                                
                                if (ametysUser)
                                {
                                    ametysUser.fill = _fillUserInputs;
                                }
                                
                                for (var i=0; i &lt; _ametysUserCallbacks.length; i++)
                                {
                                    try 
                                    {
                                        _ametysUserCallbacks[i](ametysUser);
                                    } 
                                    catch(e) 
                                    {
                                        console.error("Failed to invoked callback function " + _ametysUserCallbacks[i].name + ":", e);
                                    }
                                }
                                
                                _ametysUserRunning = false;
                            }
                        });
                    }
                }
            }
        </script>
     </xsl:template>
     
    <xsl:template name="head-js-user-init">
        <xsl:variable name="user" select="ametys:user()/user"/>
        <xsl:if test="$user">
            ametysUser = {
                "login": "<xsl:value-of select="$user/@login" />",
                "populationId": "<xsl:value-of select="$user/@population" />",
                "firstname": "<xsl:value-of select="ametys:escapeJS($user/firstname)" />",
                "lastname": "<xsl:value-of select="ametys:escapeJS($user/lastname)" />",
                "fullname": "<xsl:value-of select="ametys:escapeJS($user/fullname)" />",
                "sortablename": "<xsl:value-of select="ametys:escapeJS($user/sortablename)" />",
                "email": "<xsl:value-of select="ametys:escapeJS($user/email)" />",
                
                fill: _fillUserInputs
            }
        </xsl:if>
    </xsl:template>
    
    <xsl:template name="head-js-front">
        <script type="text/javascript" src="{$uri-prefix}/plugins/cms/resources/js/AmetysFront.{$lang}.js"></script>
        <script type="text/javascript" src="{$uri-prefix}/plugins/cms/resources/js/AmetysFront/Event.js"></script>
        <script type="text/javascript" src="{$uri-prefix}/plugins/cms/resources/js/AmetysFront/Utils.{$lang}.js"></script>
        <script type="text/javascript" src="{$uri-prefix}/plugins/cms/resources/js/AmetysFront/ServerComm.{$lang}.js"></script>
        
        <xsl:call-template name="head-js-front-init"/>
    </xsl:template>
    
    <xsl:template name="head-js-front-init">
        <script type="text/javascript">
            AmetysFront.CONTEXT_PATH = '<xsl:value-of select="$uri-prefix"/>';
            AmetysFront.URI_PREFIX = '<xsl:value-of select="$cms-context"/>';
            AmetysFront.ABSOLUTE_URI_PREFIX = '<xsl:value-of select="$absolute-uri-prefix"/>';
            AmetysFront.MAX_UPLOAD_SIZE = <xsl:value-of select="ametys:config('runtime.upload.max-size')"/> - 1000; // 1000 for request overhead
                
            AmetysFront.setAppParameter('locale', '<xsl:value-of select="$lang" />');
        </script>
    </xsl:template>
    
</xsl:stylesheet>