/*
 *  Copyright 2018 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.test.framework;

import org.ametys.runtime.test.framework.CocoonTestCase;
import org.ametys.runtime.test.framework.CocoonTestCase.NeedFeatures;
import org.ametys.runtime.test.framework.TestConfigSet;

/**
 * Marker interface in order to {@link NeedFeatures load} features needed by a CMS application.
 */
@NeedFeatures({
    "cms/cms.init", // init for CMS
    
    "cms/content-attribute-type.dependencies", // for extensions of ContentAttributeTypeExtensionPoint (automatically initialized) (HTMLRichTextContentElementType...)
    "cms/content-type-descriptor.dependencies", // for extensions of DynamicContentTypeDescriptorExtentionPoint (automatically initialized) (DynamicContentTypeDescriptor, AbstractContentTypeDescriptor, DefaultContentType...)
    "cms/search-model.dependencies", // for extensions of SearchUIModelExtensionPoint (StaticSearchUIModel, AbstractSearchUIModel...)
})
public interface WithCmsFeaturesTestCase extends CocoonTestCase
{
    @Override
    default TestConfigSet getConfigSet()
    {
        return CocoonTestCase.super.getConfigSet()
                .withConfigFile("test/environments/config.xml")
                .withWebappPath("test/environments/webapp");
    }
}
