/*
 *  Copyright 2022 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.content;

import org.ametys.cms.model.properties.AbstractProperty;
import org.ametys.cms.model.properties.Property;
import org.ametys.cms.repository.Content;
import org.ametys.runtime.model.type.ModelItemTypeConstants;

/**
 * {@link Property} that computes the sum of long values for tests
 */
public class LongmultSumProperty extends AbstractProperty<Long, Content>
{

    public Object getValue(Content content)
    {
        Long[] longs = content.getValue("composite/longmult");
        Long sum = 0L;
        for (Long singleLong : longs)
        {
            sum += singleLong;
        }

        return sum;
    }

    @Override
    protected String _getTypeId()
    {
        return ModelItemTypeConstants.LONG_TYPE_ID;
    }
    
}
