/*
 *  Copyright 2020 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.repository.utils;

import java.util.Map;
import java.util.Set;

import org.ametys.cms.contenttype.ContentType;
import org.ametys.cms.repository.ModifiableContentDataHolderTestCase;
import org.ametys.plugins.repository.data.external.ExternalizableDataProvider;
import org.ametys.plugins.repository.data.holder.ModelAwareDataHolder;
import org.ametys.runtime.model.ModelItem;

/**
 * Externalizable data provider for {@link ModifiableContentDataHolderTestCase}
 */
public class ContentDataHolderTestExternalizableDataProvider implements ExternalizableDataProvider
{
    private static final String __SOURCE_CONTENT_TYPE_ID = "tests.invert.relations.source";
    private static final Set<String> __EXTERNALIZABLE_DATA_IN_SOURCE_CONTENT_TYPE = Set.of("externalizableSingleToSingle");
    
    private static final String __DESTINATION_CONTENT_TYPE_ID = "tests.invert.relations.destination";
    private static final Set<String> __EXTERNALIZABLE_DATA_IN_DESTINATION_CONTENT_TYPE = Set.of("externalizableSingleFromSingle");
    
    public Set<String> getExternalizableDataPaths(ModelAwareDataHolder dataHolder)
    {
        if (_isnstanceOfType(dataHolder, __SOURCE_CONTENT_TYPE_ID))
        {
            return __EXTERNALIZABLE_DATA_IN_SOURCE_CONTENT_TYPE;
        }
        else if (_isnstanceOfType(dataHolder, __DESTINATION_CONTENT_TYPE_ID))
        {
            return __EXTERNALIZABLE_DATA_IN_DESTINATION_CONTENT_TYPE;
        }
        else
        {
            return Set.of();
        }
    }

    public boolean isDataExternalizable(ModelAwareDataHolder dataHolder, ModelItem modelItem, Map<String, Object> context)
    {
        return getExternalizableDataPaths(dataHolder).contains(modelItem.getPath());
    }
    
    private boolean _isnstanceOfType(ModelAwareDataHolder dataHolder, String contentTypeId)
    {
        return dataHolder.getModel()
                .stream()
                .filter(ContentType.class::isInstance)
                .map(ContentType.class::cast)
                .map(ContentType::getId)
                .anyMatch(contentTypeId::equals);
    }
}
