/*
 *  Copyright 2016 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.cms.rights.access.controller;

import java.time.ZonedDateTime;

import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.junit.Ignore;
import org.junit.Test;

import org.ametys.cms.WithCmsTestWebappFeatures;
import org.ametys.cms.repository.Content;
import org.ametys.cms.repository.ModifiableDefaultContent;
import org.ametys.cms.rights.ContentAccessController;
import org.ametys.cms.test.framework.WithCmsFeaturesTestCase;
import org.ametys.core.user.UserIdentity;
import org.ametys.plugins.repository.AmetysObjectResolver;
import org.ametys.plugins.repository.RepositoryConstants;
import org.ametys.plugins.repository.collection.AmetysObjectCollection;
import org.ametys.plugins.repository.root.RootAmetysObject;
import org.ametys.runtime.test.framework.CocoonTestCase.NeedFeatures;
import org.ametys.runtime.test.framework.TestConfigSet;
import org.ametys.runtime.test.rights.access.controller.AbstractStringBasedAccessControllerTestCase;

/**
 * Common test class for testing the {@link ContentAccessController}
 */
@NeedFeatures({
    "repository/repository.rights.storage.assignments.impl.jcr",
    "cms/cms.rights.accesscontroller.impl.content",
    "test/content-type",
    
    "repository/resolver", 
    "cms/factories",
    "cms/workflow.content"
})
public class ContentAccessControllerTestCase extends AbstractStringBasedAccessControllerTestCase implements WithCmsFeaturesTestCase, WithCmsTestWebappFeatures
{
    /** Default content node type name. */
    public static final String NT_COLLECTION = "ametys:collection";
    
    /** Default content node type name. */
    public static final String NT_DEFAULT_CONTENT = "ametys:defaultContent";
    
    /** Ametys object resolver to subclasses. */
    protected static AmetysObjectResolver _ametysObjectResolver;
    
    private static Content _content1;
    private static Content _content2;
    
    @Override
    public TestConfigSet getConfigSet()
    {
        return WithCmsFeaturesTestCase.super.getConfigSet();
    }
    
    @Override
    public void lookupComponents(ServiceManager manager) throws ServiceException
    {
        super.lookupComponents(manager);
        _ametysObjectResolver = (AmetysObjectResolver) manager.lookup(AmetysObjectResolver.ROLE);
    }
    
    @Override
    public void prepareComponents() throws Exception
    {
        super.prepareComponents();
        if (isPluginsManagerOk())
        {
            _createContents();
        }
    }
    
    private void _createContents() throws Exception
    {
        RootAmetysObject root = _ametysObjectResolver.resolveByPath("/");
        
        AmetysObjectCollection rootContents = root.createChild(RepositoryConstants.NAMESPACE_PREFIX_INTERNAL + ":contents", NT_COLLECTION);
        
        ModifiableDefaultContent content1 = (ModifiableDefaultContent) rootContents.createChild("content1", NT_DEFAULT_CONTENT);
        content1.setTypes(new String[]{"type1"});
        content1.setLanguage("fr");
        content1.setTitle("title1");
        content1.setCreationDate(ZonedDateTime.now());
        content1.setCreator(new UserIdentity("john", "anyPopulation"));
        content1.setLastContributor(new UserIdentity("brian", "anyPopulation"));
        content1.setLastModified(ZonedDateTime.now());
        _content1 = content1;
        
        ModifiableDefaultContent content2 = (ModifiableDefaultContent) rootContents.createChild("content2", NT_DEFAULT_CONTENT);
        content2.setTypes(new String[]{"type1"});
        content2.setLanguage("fr");
        content2.setTitle("title2");
        content2.setCreationDate(ZonedDateTime.now());
        content2.setCreator(new UserIdentity("john", "anyPopulation"));
        content2.setLastContributor(new UserIdentity("brian", "anyPopulation"));
        content2.setLastModified(ZonedDateTime.now());
        _content2 = content2;
    }
    
    @Override
    protected String _getExtensionId()
    {
        return ContentAccessController.class.getName();
    }

    @Override
    protected Object _getTest1()
    {
        return _content1;
    }

    @Override
    protected Object _getTest2()
    {
        return _content2;
    }
    
    @Override
    protected Object _getTest3()
    {
        return _ametysObjectResolver.resolveByPath("/" + RepositoryConstants.NAMESPACE_PREFIX_INTERNAL + ":contents");
    }
    
    @Override
    protected Object _getTest3SubContext()
    {
        return _content1;
    }
    
    @Override
    @Test
    @Ignore
    public void testHasUserAnyPermission()
    {
        // Too complex :(
        
        // Contents should be created at the real location (not at root) 
    }
    
}
